Class: SchemaOrg::AggregateOffer
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::AggregateOffer
- Includes:
- Mixins::AggregateOffer, _AggregateOffer
- Defined in:
- lib/schema_org/types/aggregate_offer.rb,
sig/schema_org.rbs
Overview
https://schema.org/AggregateOffer
When a single product is associated with multiple offers (for example, the same pair of shoes is offered by different merchants), then AggregateOffer can be used.\n\nNote: AggregateOffers are normally expected to associate multiple offers that all share the same defined [[businessFunction]] value, or default to http://purl.org/goodrelations/v1#Sell if businessFunction is not explicitly defined.
Constant Summary collapse
- SCHEMA_NAME =
"AggregateOffer"- SCHEMA_TYPES =
[self, SchemaOrg::Offer, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ AggregateOffer
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::AggregateOffer
#high_price, #high_price=, #low_price, #low_price=, #offer_count, #offer_count=, #offers, #offers=, schema_property_definitions
Methods included from Mixins::Offer
#accepted_payment_method, #accepted_payment_method=, #add_on, #add_on=, #additional_property, #additional_property=, #advance_booking_requirement, #advance_booking_requirement=, #aggregate_rating, #aggregate_rating=, #area_served, #area_served=, #asin, #asin=, #availability, #availability=, #availability_ends, #availability_ends=, #availability_starts, #availability_starts=, #available_at_or_from, #available_at_or_from=, #available_delivery_method, #available_delivery_method=, #business_function, #business_function=, #category, #category=, #checkout_page_url_template, #checkout_page_url_template=, #delivery_lead_time, #delivery_lead_time=, #eligible_customer_type, #eligible_customer_type=, #eligible_duration, #eligible_duration=, #eligible_quantity, #eligible_quantity=, #eligible_region, #eligible_region=, #eligible_transaction_volume, #eligible_transaction_volume=, #gtin, #gtin12, #gtin12=, #gtin13, #gtin13=, #gtin14, #gtin14=, #gtin8, #gtin8=, #gtin=, #has_adult_consideration, #has_adult_consideration=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_measurement, #has_measurement=, #has_merchant_return_policy, #has_merchant_return_policy=, #includes_object, #includes_object=, #ineligible_region, #ineligible_region=, #inventory_level, #inventory_level=, #is_family_friendly, #is_family_friendly=, #item_condition, #item_condition=, #item_offered, #item_offered=, #lease_length, #lease_length=, #mobile_url, #mobile_url=, #mpn, #mpn=, #offered_by, #offered_by=, #price, #price=, #price_currency, #price_currency=, #price_specification, #price_specification=, #price_valid_until, #price_valid_until=, #review, #review=, #reviews, #reviews=, schema_property_definitions, #seller, #seller=, #serial_number, #serial_number=, #shipping_details, #shipping_details=, #sku, #sku=, #valid_for_member_tier, #valid_for_member_tier=, #valid_from, #valid_from=, #valid_through, #valid_through=, #warranty, #warranty=
Methods included from Mixins::Intangible
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _AggregateOffer
#accepted_payment_method, #accepted_payment_method=, #add_on, #add_on=, #additional_property, #additional_property=, #additional_type, #additional_type=, #advance_booking_requirement, #advance_booking_requirement=, #aggregate_rating, #aggregate_rating=, #alternate_name, #alternate_name=, #area_served, #area_served=, #asin, #asin=, #availability, #availability=, #availability_ends, #availability_ends=, #availability_starts, #availability_starts=, #available_at_or_from, #available_at_or_from=, #available_delivery_method, #available_delivery_method=, #business_function, #business_function=, #category, #category=, #checkout_page_url_template, #checkout_page_url_template=, #delivery_lead_time, #delivery_lead_time=, #description, #description=, #disambiguating_description, #disambiguating_description=, #eligible_customer_type, #eligible_customer_type=, #eligible_duration, #eligible_duration=, #eligible_quantity, #eligible_quantity=, #eligible_region, #eligible_region=, #eligible_transaction_volume, #eligible_transaction_volume=, #gtin, #gtin12, #gtin12=, #gtin13, #gtin13=, #gtin14, #gtin14=, #gtin8, #gtin8=, #gtin=, #has_adult_consideration, #has_adult_consideration=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_measurement, #has_measurement=, #has_merchant_return_policy, #has_merchant_return_policy=, #high_price, #high_price=, #identifier, #identifier=, #image, #image=, #includes_object, #includes_object=, #ineligible_region, #ineligible_region=, #inventory_level, #inventory_level=, #is_family_friendly, #is_family_friendly=, #item_condition, #item_condition=, #item_offered, #item_offered=, #lease_length, #lease_length=, #low_price, #low_price=, #main_entity_of_page, #main_entity_of_page=, #mobile_url, #mobile_url=, #mpn, #mpn=, #name, #name=, #offer_count, #offer_count=, #offered_by, #offered_by=, #offers, #offers=, #owner, #owner=, #potential_action, #potential_action=, #price, #price=, #price_currency, #price_currency=, #price_specification, #price_specification=, #price_valid_until, #price_valid_until=, #review, #review=, #reviews, #reviews=, #same_as, #same_as=, #seller, #seller=, #serial_number, #serial_number=, #shipping_details, #shipping_details=, #sku, #sku=, #subject_of, #subject_of=, #url, #url=, #valid_for_member_tier, #valid_for_member_tier=, #valid_from, #valid_from=, #valid_through, #valid_through=, #warranty, #warranty=
Class Method Details
.new(**properties) ⇒ AggregateOffer
30 31 32 |
# File 'lib/schema_org/types/aggregate_offer.rb', line 30 def new(**properties) super end |
.schema_name ⇒ String
17 18 19 |
# File 'lib/schema_org/types/aggregate_offer.rb', line 17 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
25 26 27 28 |
# File 'lib/schema_org/types/aggregate_offer.rb', line 25 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
21 22 23 |
# File 'lib/schema_org/types/aggregate_offer.rb', line 21 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
2756 |
# File 'sig/schema_org.rbs', line 2756
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
2755 |
# File 'sig/schema_org.rbs', line 2755
def schema_types: () -> ::Array[::Class]
|