Class: SchemaOrg::AlignmentObject

Inherits:
Base
  • Object
show all
Includes:
Mixins::AlignmentObject, _AlignmentObject
Defined in:
lib/schema_org/types/alignment_object.rb,
sig/schema_org.rbs

Overview

https://schema.org/AlignmentObject

An intangible item that describes an alignment between a learning resource and a node in an educational framework. Should not be used where the nature of the alignment can be described using a simple property, for example to express that a resource [[teaches]] or [[assesses]] a competency.

Constant Summary collapse

SCHEMA_NAME =
"AlignmentObject"
SCHEMA_TYPES =
[self, SchemaOrg::Intangible, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::AlignmentObject

#alignment_type, #alignment_type=, #educational_framework, #educational_framework=, schema_property_definitions, #target_description, #target_description=, #target_name, #target_name=, #target_url, #target_url=

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _AlignmentObject

#additional_type, #additional_type=, #alignment_type, #alignment_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #educational_framework, #educational_framework=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #target_description, #target_description=, #target_name, #target_name=, #target_url, #target_url=, #url, #url=

Class Method Details

.new(**properties) ⇒ AlignmentObject

Parameters:

Returns:



31
32
33
# File 'lib/schema_org/types/alignment_object.rb', line 31

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


18
19
20
# File 'lib/schema_org/types/alignment_object.rb', line 18

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



26
27
28
29
# File 'lib/schema_org/types/alignment_object.rb', line 26

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


22
23
24
# File 'lib/schema_org/types/alignment_object.rb', line 22

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



3263
# File 'sig/schema_org.rbs', line 3263

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


3262
# File 'sig/schema_org.rbs', line 3262

def schema_types: () -> ::Array[::Class]