Class: SchemaOrg::BreadcrumbList
Overview
https://schema.org/BreadcrumbList
A BreadcrumbList is an ItemList consisting of a chain of linked Web pages, typically described using at least their URL and their name, and typically ending with the current page.\n\nThe [[position]] property is used to reconstruct the order of the items in a BreadcrumbList. The convention is that a breadcrumb list has an [[itemListOrder]] of [[ItemListOrderAscending]] (lower values listed first), and that the first items in this list correspond to the "top" or beginning of the breadcrumb trail, e.g. with a site or section homepage. The specific values of 'position' are not assigned meaning for a BreadcrumbList, but they should be integers, e.g. beginning with '1' for the first item in the list.
Constant Summary
collapse
- SCHEMA_NAME =
"BreadcrumbList"
- SCHEMA_TYPES =
[self, SchemaOrg::ItemList, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
Class Method Summary
collapse
Instance Method Summary
collapse
schema_property_definitions
#aggregate_element, #aggregate_element=, #item_list_element, #item_list_element=, #item_list_order, #item_list_order=, #number_of_items, #number_of_items=, schema_property_definitions
schema_property_definitions
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
#additional_type, #additional_type=, #aggregate_element, #aggregate_element=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #item_list_element, #item_list_element=, #item_list_order, #item_list_order=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #number_of_items, #number_of_items=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
30
31
32
|
# File 'lib/schema_org/types/breadcrumb_list.rb', line 30
def new(**properties)
super
end
|
.schema_name ⇒ String
17
18
19
|
# File 'lib/schema_org/types/breadcrumb_list.rb', line 17
def schema_name
SCHEMA_NAME
end
|
.schema_type?(other_type) ⇒ Boolean
25
26
27
28
|
# File 'lib/schema_org/types/breadcrumb_list.rb', line 25
def schema_type?(other_type)
Base.schema_type_argument!(other_type)
SCHEMA_TYPES.include?(other_type)
end
|
.schema_types ⇒ ::Array[::Class]
21
22
23
|
# File 'lib/schema_org/types/breadcrumb_list.rb', line 21
def schema_types
SCHEMA_TYPES
end
|
Instance Method Details
#schema_type? ⇒ Boolean
16462
|
# File 'sig/schema_org.rbs', line 16462
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
16461
|
# File 'sig/schema_org.rbs', line 16461
def schema_types: () -> ::Array[::Class]
|