Class: SchemaOrg::CDCPMDRecord

Inherits:
Base
  • Object
show all
Includes:
Mixins::CDCPMDRecord, _CDCPMDRecord
Defined in:
lib/schema_org/types/cdcpmd_record.rb,
sig/schema_org.rbs

Overview

https://schema.org/CDCPMDRecord

A CDCPMDRecord is a data structure representing a record in a CDC tabular data format used for hospital data reporting. See documentation for details, and the linked CDC materials for authoritative definitions used as the source here.

Constant Summary collapse

SCHEMA_NAME =
"CDCPMDRecord"
SCHEMA_TYPES =
[self, SchemaOrg::StructuredValue, SchemaOrg::Intangible, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::CDCPMDRecord

#cvd_collection_date, #cvd_collection_date=, #cvd_facility_county, #cvd_facility_county=, #cvd_facility_id, #cvd_facility_id=, #cvd_num_beds, #cvd_num_beds=, #cvd_num_beds_occ, #cvd_num_beds_occ=, #cvd_num_c19_died, #cvd_num_c19_died=, #cvd_num_c19_ho_pats, #cvd_num_c19_ho_pats=, #cvd_num_c19_hosp_pats, #cvd_num_c19_hosp_pats=, #cvd_num_c19_mech_vent_pats, #cvd_num_c19_mech_vent_pats=, #cvd_num_c19_of_mech_vent_pats, #cvd_num_c19_of_mech_vent_pats=, #cvd_num_c19_overflow_pats, #cvd_num_c19_overflow_pats=, #cvd_num_icu_beds, #cvd_num_icu_beds=, #cvd_num_icu_beds_occ, #cvd_num_icu_beds_occ=, #cvd_num_tot_beds, #cvd_num_tot_beds=, #cvd_num_vent, #cvd_num_vent=, #cvd_num_vent_use, #cvd_num_vent_use=, #date_posted, #date_posted=, schema_property_definitions

Methods included from Mixins::StructuredValue

schema_property_definitions

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _CDCPMDRecord

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #cvd_collection_date, #cvd_collection_date=, #cvd_facility_county, #cvd_facility_county=, #cvd_facility_id, #cvd_facility_id=, #cvd_num_beds, #cvd_num_beds=, #cvd_num_beds_occ, #cvd_num_beds_occ=, #cvd_num_c19_died, #cvd_num_c19_died=, #cvd_num_c19_ho_pats, #cvd_num_c19_ho_pats=, #cvd_num_c19_hosp_pats, #cvd_num_c19_hosp_pats=, #cvd_num_c19_mech_vent_pats, #cvd_num_c19_mech_vent_pats=, #cvd_num_c19_of_mech_vent_pats, #cvd_num_c19_of_mech_vent_pats=, #cvd_num_c19_overflow_pats, #cvd_num_c19_overflow_pats=, #cvd_num_icu_beds, #cvd_num_icu_beds=, #cvd_num_icu_beds_occ, #cvd_num_icu_beds_occ=, #cvd_num_tot_beds, #cvd_num_tot_beds=, #cvd_num_vent, #cvd_num_vent=, #cvd_num_vent_use, #cvd_num_vent_use=, #date_posted, #date_posted=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.new(**properties) ⇒ CDCPMDRecord

Parameters:

Returns:



32
33
34
# File 'lib/schema_org/types/cdcpmd_record.rb', line 32

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


19
20
21
# File 'lib/schema_org/types/cdcpmd_record.rb', line 19

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



27
28
29
30
# File 'lib/schema_org/types/cdcpmd_record.rb', line 27

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


23
24
25
# File 'lib/schema_org/types/cdcpmd_record.rb', line 23

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



18497
# File 'sig/schema_org.rbs', line 18497

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


18496
# File 'sig/schema_org.rbs', line 18496

def schema_types: () -> ::Array[::Class]