Class: SchemaOrg::CampingPitch

Inherits:
Base
  • Object
show all
Includes:
Mixins::CampingPitch, _CampingPitch
Defined in:
lib/schema_org/types/camping_pitch.rb,
sig/schema_org.rbs

Overview

https://schema.org/CampingPitch

A [[CampingPitch]] is an individual place for overnight stay in the outdoors, typically being part of a larger camping site, or [[Campground]].\n\n In British English a campsite, or campground, is an area, usually divided into a number of pitches, where people can camp overnight using tents or camper vans or caravans; this British English use of the word is synonymous with the American English expression campground. In American English the term campsite generally means an area where an individual, family, group, or military unit can pitch a tent or park a camper; a campground may contain many campsites. (Source: Wikipedia, see https://en.wikipedia.org/wiki/Campsite.)\n\n See also the dedicated document on the use of schema.org for marking up hotels and other forms of accommodations.

Constant Summary collapse

SCHEMA_NAME =
"CampingPitch"
SCHEMA_TYPES =
[self, SchemaOrg::Accommodation, SchemaOrg::Place, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::CampingPitch

schema_property_definitions

Methods included from Mixins::Accommodation

#accommodation_category, #accommodation_category=, #accommodation_floor_plan, #accommodation_floor_plan=, #amenity_feature, #amenity_feature=, #bed, #bed=, #floor_level, #floor_level=, #floor_size, #floor_size=, #lease_length, #lease_length=, #number_of_bathrooms_total, #number_of_bathrooms_total=, #number_of_bedrooms, #number_of_bedrooms=, #number_of_full_bathrooms, #number_of_full_bathrooms=, #number_of_partial_bathrooms, #number_of_partial_bathrooms=, #number_of_rooms, #number_of_rooms=, #occupancy, #occupancy=, #permitted_usage, #permitted_usage=, #pets_allowed, #pets_allowed=, schema_property_definitions, #tour_booking_page, #tour_booking_page=, #year_built, #year_built=

Methods included from Mixins::Place

#additional_property, #additional_property=, #address, #address=, #aggregate_rating, #aggregate_rating=, #amenity_feature, #amenity_feature=, #branch_code, #branch_code=, #contained_in, #contained_in=, #contained_in_place, #contained_in_place=, #contains_place, #contains_place=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #geo, #geo=, #geo_contains, #geo_contains=, #geo_covered_by, #geo_covered_by=, #geo_covers, #geo_covers=, #geo_crosses, #geo_crosses=, #geo_disjoint, #geo_disjoint=, #geo_equals, #geo_equals=, #geo_intersects, #geo_intersects=, #geo_overlaps, #geo_overlaps=, #geo_touches, #geo_touches=, #geo_within, #geo_within=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_drive_through_service, #has_drive_through_service=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_map, #has_map=, #is_accessible_for_free, #is_accessible_for_free=, #isic_v4, #isic_v4=, #keywords, #keywords=, #latitude, #latitude=, #logo, #logo=, #longitude, #longitude=, #map, #map=, #maps, #maps=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #opening_hours_specification, #opening_hours_specification=, #photo, #photo=, #photos, #photos=, #public_access, #public_access=, #review, #review=, #reviews, #reviews=, schema_property_definitions, #slogan, #slogan=, #smoking_allowed, #smoking_allowed=, #special_opening_hours_specification, #special_opening_hours_specification=, #telephone, #telephone=, #tour_booking_page, #tour_booking_page=

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _CampingPitch

#accommodation_category, #accommodation_category=, #accommodation_floor_plan, #accommodation_floor_plan=, #additional_property, #additional_property=, #additional_type, #additional_type=, #address, #address=, #aggregate_rating, #aggregate_rating=, #alternate_name, #alternate_name=, #amenity_feature, #amenity_feature=, #bed, #bed=, #branch_code, #branch_code=, #contained_in, #contained_in=, #contained_in_place, #contained_in_place=, #contains_place, #contains_place=, #description, #description=, #disambiguating_description, #disambiguating_description=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #floor_level, #floor_level=, #floor_size, #floor_size=, #geo, #geo=, #geo_contains, #geo_contains=, #geo_covered_by, #geo_covered_by=, #geo_covers, #geo_covers=, #geo_crosses, #geo_crosses=, #geo_disjoint, #geo_disjoint=, #geo_equals, #geo_equals=, #geo_intersects, #geo_intersects=, #geo_overlaps, #geo_overlaps=, #geo_touches, #geo_touches=, #geo_within, #geo_within=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_drive_through_service, #has_drive_through_service=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_map, #has_map=, #identifier, #identifier=, #image, #image=, #is_accessible_for_free, #is_accessible_for_free=, #isic_v4, #isic_v4=, #keywords, #keywords=, #latitude, #latitude=, #lease_length, #lease_length=, #logo, #logo=, #longitude, #longitude=, #main_entity_of_page, #main_entity_of_page=, #map, #map=, #maps, #maps=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #name, #name=, #number_of_bathrooms_total, #number_of_bathrooms_total=, #number_of_bedrooms, #number_of_bedrooms=, #number_of_full_bathrooms, #number_of_full_bathrooms=, #number_of_partial_bathrooms, #number_of_partial_bathrooms=, #number_of_rooms, #number_of_rooms=, #occupancy, #occupancy=, #opening_hours_specification, #opening_hours_specification=, #owner, #owner=, #permitted_usage, #permitted_usage=, #pets_allowed, #pets_allowed=, #photo, #photo=, #photos, #photos=, #potential_action, #potential_action=, #public_access, #public_access=, #review, #review=, #reviews, #reviews=, #same_as, #same_as=, #slogan, #slogan=, #smoking_allowed, #smoking_allowed=, #special_opening_hours_specification, #special_opening_hours_specification=, #subject_of, #subject_of=, #telephone, #telephone=, #tour_booking_page, #tour_booking_page=, #url, #url=, #year_built, #year_built=

Class Method Details

.new(**properties) ⇒ CampingPitch

Parameters:

Returns:



33
34
35
# File 'lib/schema_org/types/camping_pitch.rb', line 33

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


20
21
22
# File 'lib/schema_org/types/camping_pitch.rb', line 20

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



28
29
30
31
# File 'lib/schema_org/types/camping_pitch.rb', line 28

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


24
25
26
# File 'lib/schema_org/types/camping_pitch.rb', line 24

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



19311
# File 'sig/schema_org.rbs', line 19311

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


19310
# File 'sig/schema_org.rbs', line 19310

def schema_types: () -> ::Array[::Class]