Class: SchemaOrg::ChemicalSubstance
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::ChemicalSubstance
- Includes:
- Mixins::ChemicalSubstance, _ChemicalSubstance
- Defined in:
- lib/schema_org/types/chemical_substance.rb,
sig/schema_org.rbs
Overview
https://schema.org/ChemicalSubstance
A chemical substance is 'a portion of matter of constant composition, composed of molecular entities of the same type or of different types' (source: ChEBI:59999).
Constant Summary collapse
- SCHEMA_NAME =
"ChemicalSubstance"- SCHEMA_TYPES =
[self, SchemaOrg::BioChemEntity, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ ChemicalSubstance
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::ChemicalSubstance
#chemical_composition, #chemical_composition=, #chemical_role, #chemical_role=, #potential_use, #potential_use=, schema_property_definitions
Methods included from Mixins::BioChemEntity
#associated_disease, #associated_disease=, #bio_chem_interaction, #bio_chem_interaction=, #bio_chem_similarity, #bio_chem_similarity=, #biological_role, #biological_role=, #funding, #funding=, #has_bio_chem_entity_part, #has_bio_chem_entity_part=, #has_molecular_function, #has_molecular_function=, #has_representation, #has_representation=, #is_encoded_by_bio_chem_entity, #is_encoded_by_bio_chem_entity=, #is_involved_in_biological_process, #is_involved_in_biological_process=, #is_located_in_subcellular_location, #is_located_in_subcellular_location=, #is_part_of_bio_chem_entity, #is_part_of_bio_chem_entity=, schema_property_definitions, #taxonomic_range, #taxonomic_range=
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _ChemicalSubstance
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #associated_disease, #associated_disease=, #bio_chem_interaction, #bio_chem_interaction=, #bio_chem_similarity, #bio_chem_similarity=, #biological_role, #biological_role=, #chemical_composition, #chemical_composition=, #chemical_role, #chemical_role=, #description, #description=, #disambiguating_description, #disambiguating_description=, #funding, #funding=, #has_bio_chem_entity_part, #has_bio_chem_entity_part=, #has_molecular_function, #has_molecular_function=, #has_representation, #has_representation=, #identifier, #identifier=, #image, #image=, #is_encoded_by_bio_chem_entity, #is_encoded_by_bio_chem_entity=, #is_involved_in_biological_process, #is_involved_in_biological_process=, #is_located_in_subcellular_location, #is_located_in_subcellular_location=, #is_part_of_bio_chem_entity, #is_part_of_bio_chem_entity=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #potential_use, #potential_use=, #same_as, #same_as=, #subject_of, #subject_of=, #taxonomic_range, #taxonomic_range=, #url, #url=
Class Method Details
.new(**properties) ⇒ ChemicalSubstance
30 31 32 |
# File 'lib/schema_org/types/chemical_substance.rb', line 30 def new(**properties) super end |
.schema_name ⇒ String
17 18 19 |
# File 'lib/schema_org/types/chemical_substance.rb', line 17 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
25 26 27 28 |
# File 'lib/schema_org/types/chemical_substance.rb', line 25 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
21 22 23 |
# File 'lib/schema_org/types/chemical_substance.rb', line 21 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
21841 |
# File 'sig/schema_org.rbs', line 21841
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
21840 |
# File 'sig/schema_org.rbs', line 21840
def schema_types: () -> ::Array[::Class]
|