Class: SchemaOrg::ConstraintNode

Inherits:
Base
  • Object
show all
Includes:
Mixins::ConstraintNode, _ConstraintNode
Defined in:
lib/schema_org/types/constraint_node.rb,
sig/schema_org.rbs

Overview

https://schema.org/ConstraintNode

The ConstraintNode type is provided to support usecases in which a node in a structured data graph is described with properties which appear to describe a single entity, but are being used in a situation where they serve a more abstract purpose. A [[ConstraintNode]] can be described using [[constraintProperty]] and [[numConstraints]]. These constraint properties can serve a variety of purposes, and their values may sometimes be understood to indicate sets of possible values rather than single, exact and specific values.

Constant Summary collapse

SCHEMA_NAME =
"ConstraintNode"
SCHEMA_TYPES =
[self, SchemaOrg::Intangible, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::ConstraintNode

#constraint_property, #constraint_property=, #num_constraints, #num_constraints=, schema_property_definitions

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _ConstraintNode

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #constraint_property, #constraint_property=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #num_constraints, #num_constraints=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.new(**properties) ⇒ ConstraintNode

Parameters:

Returns:



31
32
33
# File 'lib/schema_org/types/constraint_node.rb', line 31

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


18
19
20
# File 'lib/schema_org/types/constraint_node.rb', line 18

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



26
27
28
29
# File 'lib/schema_org/types/constraint_node.rb', line 26

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


22
23
24
# File 'lib/schema_org/types/constraint_node.rb', line 22

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



28176
# File 'sig/schema_org.rbs', line 28176

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


28175
# File 'sig/schema_org.rbs', line 28175

def schema_types: () -> ::Array[::Class]