Class: SchemaOrg::CourseInstance
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::CourseInstance
- Includes:
- Mixins::CourseInstance, _CourseInstance
- Defined in:
- lib/schema_org/types/course_instance.rb,
sig/schema_org.rbs
Overview
https://schema.org/CourseInstance
An instance of a [[Course]] which is distinct from other instances because it is offered at a different time or location or through different media or modes of study or to a specific section of students.
Constant Summary collapse
Class Method Summary collapse
- .new(**properties) ⇒ CourseInstance
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::CourseInstance
#course_mode, #course_mode=, #course_schedule, #course_schedule=, #course_workload, #course_workload=, #instructor, #instructor=, schema_property_definitions
Methods included from Mixins::Event
#about, #about=, #actor, #actor=, #aggregate_rating, #aggregate_rating=, #attendee, #attendee=, #attendees, #attendees=, #audience, #audience=, #composer, #composer=, #contributor, #contributor=, #director, #director=, #door_time, #door_time=, #duration, #duration=, #end_date, #end_date=, #event_attendance_mode, #event_attendance_mode=, #event_schedule, #event_schedule=, #event_status, #event_status=, #funder, #funder=, #funding, #funding=, #has_participation_offer, #has_participation_offer=, #has_sponsorship_offer, #has_sponsorship_offer=, #in_language, #in_language=, #is_accessible_for_free, #is_accessible_for_free=, #keywords, #keywords=, #location, #location=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #maximum_physical_attendee_capacity, #maximum_physical_attendee_capacity=, #maximum_virtual_attendee_capacity, #maximum_virtual_attendee_capacity=, #offers, #offers=, #organizer, #organizer=, #performer, #performer=, #performers, #performers=, #previous_start_date, #previous_start_date=, #recorded_in, #recorded_in=, #remaining_attendee_capacity, #remaining_attendee_capacity=, #review, #review=, schema_property_definitions, #sponsor, #sponsor=, #start_date, #start_date=, #sub_event, #sub_event=, #sub_events, #sub_events=, #super_event, #super_event=, #translator, #translator=, #typical_age_range, #typical_age_range=, #work_featured, #work_featured=, #work_performed, #work_performed=
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _CourseInstance
#about, #about=, #actor, #actor=, #additional_type, #additional_type=, #aggregate_rating, #aggregate_rating=, #alternate_name, #alternate_name=, #attendee, #attendee=, #attendees, #attendees=, #audience, #audience=, #composer, #composer=, #contributor, #contributor=, #course_mode, #course_mode=, #course_schedule, #course_schedule=, #course_workload, #course_workload=, #description, #description=, #director, #director=, #disambiguating_description, #disambiguating_description=, #door_time, #door_time=, #duration, #duration=, #end_date, #end_date=, #event_attendance_mode, #event_attendance_mode=, #event_schedule, #event_schedule=, #event_status, #event_status=, #funder, #funder=, #funding, #funding=, #has_participation_offer, #has_participation_offer=, #has_sponsorship_offer, #has_sponsorship_offer=, #identifier, #identifier=, #image, #image=, #in_language, #in_language=, #instructor, #instructor=, #is_accessible_for_free, #is_accessible_for_free=, #keywords, #keywords=, #location, #location=, #main_entity_of_page, #main_entity_of_page=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #maximum_physical_attendee_capacity, #maximum_physical_attendee_capacity=, #maximum_virtual_attendee_capacity, #maximum_virtual_attendee_capacity=, #name, #name=, #offers, #offers=, #organizer, #organizer=, #owner, #owner=, #performer, #performer=, #performers, #performers=, #potential_action, #potential_action=, #previous_start_date, #previous_start_date=, #recorded_in, #recorded_in=, #remaining_attendee_capacity, #remaining_attendee_capacity=, #review, #review=, #same_as, #same_as=, #sponsor, #sponsor=, #start_date, #start_date=, #sub_event, #sub_event=, #sub_events, #sub_events=, #subject_of, #subject_of=, #super_event, #super_event=, #translator, #translator=, #typical_age_range, #typical_age_range=, #url, #url=, #work_featured, #work_featured=, #work_performed, #work_performed=
Class Method Details
.new(**properties) ⇒ CourseInstance
30 31 32 |
# File 'lib/schema_org/types/course_instance.rb', line 30 def new(**properties) super end |
.schema_name ⇒ String
17 18 19 |
# File 'lib/schema_org/types/course_instance.rb', line 17 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
25 26 27 28 |
# File 'lib/schema_org/types/course_instance.rb', line 25 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
21 22 23 |
# File 'lib/schema_org/types/course_instance.rb', line 21 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
30674 |
# File 'sig/schema_org.rbs', line 30674
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
30673 |
# File 'sig/schema_org.rbs', line 30673
def schema_types: () -> ::Array[::Class]
|