Class: SchemaOrg::DefinedRegion

Inherits:
Base
  • Object
show all
Includes:
Mixins::DefinedRegion, _DefinedRegion
Defined in:
lib/schema_org/types/defined_region.rb,
sig/schema_org.rbs

Overview

https://schema.org/DefinedRegion

A DefinedRegion is a geographic area defined by potentially arbitrary (rather than political, administrative or natural geographical) criteria. Properties are provided for defining a region by reference to sets of postal codes.

Examples: a delivery destination when shopping. Region where regional pricing is configured.

Requirement 1: Country: US States: "NY", "CA"

Requirement 2: Country: US PostalCode Set: { [94000-94585], [97000, 97999], [13000, 13599]} { [12345, 12345], [78945, 78945], } Region = state, canton, prefecture, autonomous community...

Constant Summary collapse

SCHEMA_NAME =
"DefinedRegion"
SCHEMA_TYPES =
[self, SchemaOrg::Place, SchemaOrg::StructuredValue, SchemaOrg::Thing, SchemaOrg::Intangible].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::DefinedRegion

#address_country, #address_country=, #address_region, #address_region=, #postal_code, #postal_code=, #postal_code_prefix, #postal_code_prefix=, #postal_code_range, #postal_code_range=, schema_property_definitions

Methods included from Mixins::StructuredValue

schema_property_definitions

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from Mixins::Place

#additional_property, #additional_property=, #address, #address=, #aggregate_rating, #aggregate_rating=, #amenity_feature, #amenity_feature=, #branch_code, #branch_code=, #contained_in, #contained_in=, #contained_in_place, #contained_in_place=, #contains_place, #contains_place=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #geo, #geo=, #geo_contains, #geo_contains=, #geo_covered_by, #geo_covered_by=, #geo_covers, #geo_covers=, #geo_crosses, #geo_crosses=, #geo_disjoint, #geo_disjoint=, #geo_equals, #geo_equals=, #geo_intersects, #geo_intersects=, #geo_overlaps, #geo_overlaps=, #geo_touches, #geo_touches=, #geo_within, #geo_within=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_drive_through_service, #has_drive_through_service=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_map, #has_map=, #is_accessible_for_free, #is_accessible_for_free=, #isic_v4, #isic_v4=, #keywords, #keywords=, #latitude, #latitude=, #logo, #logo=, #longitude, #longitude=, #map, #map=, #maps, #maps=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #opening_hours_specification, #opening_hours_specification=, #photo, #photo=, #photos, #photos=, #public_access, #public_access=, #review, #review=, #reviews, #reviews=, schema_property_definitions, #slogan, #slogan=, #smoking_allowed, #smoking_allowed=, #special_opening_hours_specification, #special_opening_hours_specification=, #telephone, #telephone=, #tour_booking_page, #tour_booking_page=

Methods included from _DefinedRegion

#additional_property, #additional_property=, #additional_type, #additional_type=, #address, #address=, #address_country, #address_country=, #address_region, #address_region=, #aggregate_rating, #aggregate_rating=, #alternate_name, #alternate_name=, #amenity_feature, #amenity_feature=, #branch_code, #branch_code=, #contained_in, #contained_in=, #contained_in_place, #contained_in_place=, #contains_place, #contains_place=, #description, #description=, #disambiguating_description, #disambiguating_description=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #geo, #geo=, #geo_contains, #geo_contains=, #geo_covered_by, #geo_covered_by=, #geo_covers, #geo_covers=, #geo_crosses, #geo_crosses=, #geo_disjoint, #geo_disjoint=, #geo_equals, #geo_equals=, #geo_intersects, #geo_intersects=, #geo_overlaps, #geo_overlaps=, #geo_touches, #geo_touches=, #geo_within, #geo_within=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_drive_through_service, #has_drive_through_service=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_map, #has_map=, #identifier, #identifier=, #image, #image=, #is_accessible_for_free, #is_accessible_for_free=, #isic_v4, #isic_v4=, #keywords, #keywords=, #latitude, #latitude=, #logo, #logo=, #longitude, #longitude=, #main_entity_of_page, #main_entity_of_page=, #map, #map=, #maps, #maps=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #name, #name=, #opening_hours_specification, #opening_hours_specification=, #owner, #owner=, #photo, #photo=, #photos, #photos=, #postal_code, #postal_code=, #postal_code_prefix, #postal_code_prefix=, #postal_code_range, #postal_code_range=, #potential_action, #potential_action=, #public_access, #public_access=, #review, #review=, #reviews, #reviews=, #same_as, #same_as=, #slogan, #slogan=, #smoking_allowed, #smoking_allowed=, #special_opening_hours_specification, #special_opening_hours_specification=, #subject_of, #subject_of=, #telephone, #telephone=, #tour_booking_page, #tour_booking_page=, #url, #url=

Class Method Details

.new(**properties) ⇒ DefinedRegion

Parameters:

Returns:



42
43
44
# File 'lib/schema_org/types/defined_region.rb', line 42

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


29
30
31
# File 'lib/schema_org/types/defined_region.rb', line 29

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



37
38
39
40
# File 'lib/schema_org/types/defined_region.rb', line 37

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


33
34
35
# File 'lib/schema_org/types/defined_region.rb', line 33

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



35618
# File 'sig/schema_org.rbs', line 35618

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


35617
# File 'sig/schema_org.rbs', line 35617

def schema_types: () -> ::Array[::Class]