Class: SchemaOrg::DigitalPlatformEnumeration
Overview
https://schema.org/DigitalPlatformEnumeration
Enumerates some common technology platforms, for use with properties such as [[actionPlatform]]. It is not supposed to be comprehensive - when a suitable code is not enumerated here, textual or URL values can be used instead. These codes are at a fairly high level and do not deal with versioning and other nuance. Additional codes can be suggested in github.
Constant Summary
collapse
- SCHEMA_NAME =
"DigitalPlatformEnumeration"
- SCHEMA_TYPES =
[self, SchemaOrg::Enumeration, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
- ANDROID_PLATFORM =
EnumerationValue.new("AndroidPlatform", [SchemaOrg::DigitalPlatformEnumeration])
- DESKTOP_WEB_PLATFORM =
EnumerationValue.new("DesktopWebPlatform", [SchemaOrg::DigitalPlatformEnumeration])
- GENERIC_WEB_PLATFORM =
EnumerationValue.new("GenericWebPlatform", [SchemaOrg::DigitalPlatformEnumeration])
- IOS_PLATFORM =
EnumerationValue.new("IOSPlatform", [SchemaOrg::DigitalPlatformEnumeration])
- MOBILE_WEB_PLATFORM =
EnumerationValue.new("MobileWebPlatform", [SchemaOrg::DigitalPlatformEnumeration])
- VALUES =
[ANDROID_PLATFORM, DESKTOP_WEB_PLATFORM, GENERIC_WEB_PLATFORM, IOS_PLATFORM, MOBILE_WEB_PLATFORM].freeze
Class Method Summary
collapse
Instance Method Summary
collapse
schema_property_definitions
schema_property_definitions, #superseded_by, #superseded_by=
schema_property_definitions
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #superseded_by, #superseded_by=, #url, #url=
Class Method Details
30
31
32
|
# File 'lib/schema_org/types/digital_platform_enumeration.rb', line 30
def new(**properties)
super
end
|
.schema_name ⇒ String
17
18
19
|
# File 'lib/schema_org/types/digital_platform_enumeration.rb', line 17
def schema_name
SCHEMA_NAME
end
|
.schema_type?(other_type) ⇒ Boolean
25
26
27
28
|
# File 'lib/schema_org/types/digital_platform_enumeration.rb', line 25
def schema_type?(other_type)
Base.schema_type_argument!(other_type)
SCHEMA_TYPES.include?(other_type)
end
|
.schema_types ⇒ ::Array[::Class]
21
22
23
|
# File 'lib/schema_org/types/digital_platform_enumeration.rb', line 21
def schema_types
SCHEMA_TYPES
end
|
41
42
43
|
# File 'lib/schema_org/types/digital_platform_enumeration.rb', line 41
def self.values
VALUES
end
|
Instance Method Details
#schema_type? ⇒ Boolean
38278
|
# File 'sig/schema_org.rbs', line 38278
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
38277
|
# File 'sig/schema_org.rbs', line 38277
def schema_types: () -> ::Array[::Class]
|