Class: SchemaOrg::Drug

Inherits:
Base
  • Object
show all
Includes:
Mixins::Drug, _Drug
Defined in:
lib/schema_org/types/drug.rb,
sig/schema_org.rbs

Overview

https://schema.org/Drug

A chemical or biologic substance, used as a medical therapy, that has a physiological effect on an organism. Here the term drug is used interchangeably with the term medicine although clinical knowledge makes a clear difference between them.

Constant Summary collapse

SCHEMA_NAME =
"Drug"
SCHEMA_TYPES =
[self, SchemaOrg::Product, SchemaOrg::Substance, SchemaOrg::Thing, SchemaOrg::MedicalEntity].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::Drug

#active_ingredient, #active_ingredient=, #administration_route, #administration_route=, #alcohol_warning, #alcohol_warning=, #available_strength, #available_strength=, #breastfeeding_warning, #breastfeeding_warning=, #clincal_pharmacology, #clincal_pharmacology=, #clinical_pharmacology, #clinical_pharmacology=, #dosage_form, #dosage_form=, #dose_schedule, #dose_schedule=, #drug_class, #drug_class=, #drug_unit, #drug_unit=, #food_warning, #food_warning=, #included_in_health_insurance_plan, #included_in_health_insurance_plan=, #interacting_drug, #interacting_drug=, #is_available_generically, #is_available_generically=, #is_proprietary, #is_proprietary=, #label_details, #label_details=, #legal_status, #legal_status=, #maximum_intake, #maximum_intake=, #mechanism_of_action, #mechanism_of_action=, #non_proprietary_name, #non_proprietary_name=, #overdosage, #overdosage=, #pregnancy_category, #pregnancy_category=, #pregnancy_warning, #pregnancy_warning=, #prescribing_info, #prescribing_info=, #prescription_status, #prescription_status=, #proprietary_name, #proprietary_name=, #related_drug, #related_drug=, #rxcui, #rxcui=, schema_property_definitions, #warning, #warning=

Methods included from Mixins::Substance

#active_ingredient, #active_ingredient=, #maximum_intake, #maximum_intake=, schema_property_definitions

Methods included from Mixins::MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, schema_property_definitions, #study, #study=

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from Mixins::Product

#additional_property, #additional_property=, #aggregate_rating, #aggregate_rating=, #asin, #asin=, #audience, #audience=, #award, #award=, #awards, #awards=, #brand, #brand=, #category, #category=, #color, #color=, #color_swatch, #color_swatch=, #country_of_assembly, #country_of_assembly=, #country_of_last_processing, #country_of_last_processing=, #country_of_origin, #country_of_origin=, #depth, #depth=, #display_location, #display_location=, #funding, #funding=, #gtin, #gtin12, #gtin12=, #gtin13, #gtin13=, #gtin14, #gtin14=, #gtin8, #gtin8=, #gtin=, #has_adult_consideration, #has_adult_consideration=, #has_certification, #has_certification=, #has_energy_consumption_details, #has_energy_consumption_details=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_measurement, #has_measurement=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_product_return_policy, #has_product_return_policy=, #height, #height=, #in_product_group_with_id, #in_product_group_with_id=, #is_accessory_or_spare_part_for, #is_accessory_or_spare_part_for=, #is_consumable_for, #is_consumable_for=, #is_family_friendly, #is_family_friendly=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #is_variant_of, #is_variant_of=, #item_condition, #item_condition=, #keywords, #keywords=, #logo, #logo=, #manufacturer, #manufacturer=, #material, #material=, #mobile_url, #mobile_url=, #model, #model=, #mpn, #mpn=, #negative_notes, #negative_notes=, #nsn, #nsn=, #offers, #offers=, #pattern, #pattern=, #positive_notes, #positive_notes=, #product_id, #product_id=, #production_date, #production_date=, #purchase_date, #purchase_date=, #release_date, #release_date=, #review, #review=, #reviews, #reviews=, schema_property_definitions, #size, #size=, #sku, #sku=, #slogan, #slogan=, #weight, #weight=, #width, #width=

Methods included from _Drug

#active_ingredient, #active_ingredient=, #additional_property, #additional_property=, #additional_type, #additional_type=, #administration_route, #administration_route=, #aggregate_rating, #aggregate_rating=, #alcohol_warning, #alcohol_warning=, #alternate_name, #alternate_name=, #asin, #asin=, #audience, #audience=, #available_strength, #available_strength=, #award, #award=, #awards, #awards=, #brand, #brand=, #breastfeeding_warning, #breastfeeding_warning=, #category, #category=, #clincal_pharmacology, #clincal_pharmacology=, #clinical_pharmacology, #clinical_pharmacology=, #code, #code=, #color, #color=, #color_swatch, #color_swatch=, #country_of_assembly, #country_of_assembly=, #country_of_last_processing, #country_of_last_processing=, #country_of_origin, #country_of_origin=, #depth, #depth=, #description, #description=, #disambiguating_description, #disambiguating_description=, #display_location, #display_location=, #dosage_form, #dosage_form=, #dose_schedule, #dose_schedule=, #drug_class, #drug_class=, #drug_unit, #drug_unit=, #food_warning, #food_warning=, #funding, #funding=, #gtin, #gtin12, #gtin12=, #gtin13, #gtin13=, #gtin14, #gtin14=, #gtin8, #gtin8=, #gtin=, #guideline, #guideline=, #has_adult_consideration, #has_adult_consideration=, #has_certification, #has_certification=, #has_energy_consumption_details, #has_energy_consumption_details=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_measurement, #has_measurement=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_product_return_policy, #has_product_return_policy=, #height, #height=, #identifier, #identifier=, #image, #image=, #in_product_group_with_id, #in_product_group_with_id=, #included_in_health_insurance_plan, #included_in_health_insurance_plan=, #interacting_drug, #interacting_drug=, #is_accessory_or_spare_part_for, #is_accessory_or_spare_part_for=, #is_available_generically, #is_available_generically=, #is_consumable_for, #is_consumable_for=, #is_family_friendly, #is_family_friendly=, #is_proprietary, #is_proprietary=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #is_variant_of, #is_variant_of=, #item_condition, #item_condition=, #keywords, #keywords=, #label_details, #label_details=, #legal_status, #legal_status=, #logo, #logo=, #main_entity_of_page, #main_entity_of_page=, #manufacturer, #manufacturer=, #material, #material=, #maximum_intake, #maximum_intake=, #mechanism_of_action, #mechanism_of_action=, #medicine_system, #medicine_system=, #mobile_url, #mobile_url=, #model, #model=, #mpn, #mpn=, #name, #name=, #negative_notes, #negative_notes=, #non_proprietary_name, #non_proprietary_name=, #nsn, #nsn=, #offers, #offers=, #overdosage, #overdosage=, #owner, #owner=, #pattern, #pattern=, #positive_notes, #positive_notes=, #potential_action, #potential_action=, #pregnancy_category, #pregnancy_category=, #pregnancy_warning, #pregnancy_warning=, #prescribing_info, #prescribing_info=, #prescription_status, #prescription_status=, #product_id, #product_id=, #production_date, #production_date=, #proprietary_name, #proprietary_name=, #purchase_date, #purchase_date=, #recognizing_authority, #recognizing_authority=, #related_drug, #related_drug=, #release_date, #release_date=, #relevant_specialty, #relevant_specialty=, #review, #review=, #reviews, #reviews=, #rxcui, #rxcui=, #same_as, #same_as=, #size, #size=, #sku, #sku=, #slogan, #slogan=, #study, #study=, #subject_of, #subject_of=, #url, #url=, #warning, #warning=, #weight, #weight=, #width, #width=

Class Method Details

.new(**properties) ⇒ Drug

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/drug.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/drug.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/drug.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/drug.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



39965
# File 'sig/schema_org.rbs', line 39965

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


39964
# File 'sig/schema_org.rbs', line 39964

def schema_types: () -> ::Array[::Class]