Class: SchemaOrg::EnergyConsumptionDetails

Inherits:
Base
  • Object
show all
Includes:
Mixins::EnergyConsumptionDetails, _EnergyConsumptionDetails
Defined in:
lib/schema_org/types/energy_consumption_details.rb,
sig/schema_org.rbs

Overview

https://schema.org/EnergyConsumptionDetails

EnergyConsumptionDetails represents information related to the energy efficiency of a product that consumes energy. The information that can be provided is based on international regulations such as for example EU directive 2017/1369 for energy labeling and the Energy labeling rule under the Energy Policy and Conservation Act (EPCA) in the US.

Constant Summary collapse

SCHEMA_NAME =
"EnergyConsumptionDetails"
SCHEMA_TYPES =
[self, SchemaOrg::Intangible, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::EnergyConsumptionDetails

#energy_efficiency_scale_max, #energy_efficiency_scale_max=, #energy_efficiency_scale_min, #energy_efficiency_scale_min=, #has_energy_efficiency_category, #has_energy_efficiency_category=, schema_property_definitions

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _EnergyConsumptionDetails

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #energy_efficiency_scale_max, #energy_efficiency_scale_max=, #energy_efficiency_scale_min, #energy_efficiency_scale_min=, #has_energy_efficiency_category, #has_energy_efficiency_category=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.new(**properties) ⇒ EnergyConsumptionDetails

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/energy_consumption_details.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/energy_consumption_details.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/energy_consumption_details.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/energy_consumption_details.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



43888
# File 'sig/schema_org.rbs', line 43888

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


43887
# File 'sig/schema_org.rbs', line 43887

def schema_types: () -> ::Array[::Class]