Class: SchemaOrg::EventAttendanceModeEnumeration

Inherits:
Base
  • Object
show all
Includes:
Mixins::EventAttendanceModeEnumeration, _EventAttendanceModeEnumeration
Defined in:
lib/schema_org/types/event_attendance_mode_enumeration.rb,
sig/schema_org.rbs

Overview

https://schema.org/EventAttendanceModeEnumeration

An EventAttendanceModeEnumeration value is one of potentially several modes of organising an event, relating to whether it is online or offline.

Constant Summary collapse

SCHEMA_NAME =
"EventAttendanceModeEnumeration"
SCHEMA_TYPES =
[self, SchemaOrg::Enumeration, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
MIXED_EVENT_ATTENDANCE_MODE =

Returns:

EnumerationValue.new("MixedEventAttendanceMode", [SchemaOrg::EventAttendanceModeEnumeration])
OFFLINE_EVENT_ATTENDANCE_MODE =

Returns:

EnumerationValue.new("OfflineEventAttendanceMode", [SchemaOrg::EventAttendanceModeEnumeration])
ONLINE_EVENT_ATTENDANCE_MODE =

Returns:

EnumerationValue.new("OnlineEventAttendanceMode", [SchemaOrg::EventAttendanceModeEnumeration])
VALUES =
[MIXED_EVENT_ATTENDANCE_MODE, OFFLINE_EVENT_ATTENDANCE_MODE, ONLINE_EVENT_ATTENDANCE_MODE].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::EventAttendanceModeEnumeration

schema_property_definitions

Methods included from Mixins::Enumeration

schema_property_definitions, #superseded_by, #superseded_by=

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _EventAttendanceModeEnumeration

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #superseded_by, #superseded_by=, #url, #url=

Class Method Details

.new(**properties) ⇒ EventAttendanceModeEnumeration

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/event_attendance_mode_enumeration.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/event_attendance_mode_enumeration.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/event_attendance_mode_enumeration.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/event_attendance_mode_enumeration.rb', line 21

def schema_types
  SCHEMA_TYPES
end

.values::Array[SchemaOrg::EnumerationValue[SchemaOrg::_EventAttendanceModeEnumeration]]

Returns:



39
40
41
# File 'lib/schema_org/types/event_attendance_mode_enumeration.rb', line 39

def self.values
  VALUES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



44890
# File 'sig/schema_org.rbs', line 44890

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


44889
# File 'sig/schema_org.rbs', line 44889

def schema_types: () -> ::Array[::Class]