Class: SchemaOrg::EventReservation

Inherits:
Base
  • Object
show all
Includes:
Mixins::EventReservation, _EventReservation
Defined in:
lib/schema_org/types/event_reservation.rb,
sig/schema_org.rbs

Overview

https://schema.org/EventReservation

A reservation for an event like a concert, sporting event, or lecture.\n\nNote: This type is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations. For offers of tickets, use [[Offer]].

Constant Summary collapse

SCHEMA_NAME =
"EventReservation"
SCHEMA_TYPES =
[self, SchemaOrg::Reservation, SchemaOrg::Intangible, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::EventReservation

schema_property_definitions

Methods included from Mixins::Reservation

#booking_agent, #booking_agent=, #booking_time, #booking_time=, #broker, #broker=, #modified_time, #modified_time=, #price_currency, #price_currency=, #program_membership_used, #program_membership_used=, #provider, #provider=, #reservation_for, #reservation_for=, #reservation_id, #reservation_id=, #reservation_status, #reservation_status=, #reserved_ticket, #reserved_ticket=, schema_property_definitions, #total_price, #total_price=, #under_name, #under_name=

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _EventReservation

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #booking_agent, #booking_agent=, #booking_time, #booking_time=, #broker, #broker=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #modified_time, #modified_time=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #price_currency, #price_currency=, #program_membership_used, #program_membership_used=, #provider, #provider=, #reservation_for, #reservation_for=, #reservation_id, #reservation_id=, #reservation_status, #reservation_status=, #reserved_ticket, #reserved_ticket=, #same_as, #same_as=, #subject_of, #subject_of=, #total_price, #total_price=, #under_name, #under_name=, #url, #url=

Class Method Details

.new(**properties) ⇒ EventReservation

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/event_reservation.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/event_reservation.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/event_reservation.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/event_reservation.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



44959
# File 'sig/schema_org.rbs', line 44959

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


44958
# File 'sig/schema_org.rbs', line 44958

def schema_types: () -> ::Array[::Class]