Class: SchemaOrg::FloorPlan

Inherits:
Base
  • Object
show all
Includes:
Mixins::FloorPlan, _FloorPlan
Defined in:
lib/schema_org/types/floor_plan.rb,
sig/schema_org.rbs

Overview

https://schema.org/FloorPlan

A FloorPlan is an explicit representation of a collection of similar accommodations, allowing the provision of common information (room counts, sizes, layout diagrams) and offers for rental or sale. In typical use, some [[ApartmentComplex]] has an [[accommodationFloorPlan]] which is a [[FloorPlan]]. A FloorPlan is always in the context of a particular place, either a larger [[ApartmentComplex]] or a single [[Apartment]]. The visual/spatial aspects of a floor plan (i.e. room layout, see wikipedia) can be indicated using [[image]].

Constant Summary collapse

SCHEMA_NAME =
"FloorPlan"
SCHEMA_TYPES =
[self, SchemaOrg::Intangible, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::FloorPlan

#amenity_feature, #amenity_feature=, #floor_size, #floor_size=, #is_plan_for_apartment, #is_plan_for_apartment=, #layout_image, #layout_image=, #number_of_accommodation_units, #number_of_accommodation_units=, #number_of_available_accommodation_units, #number_of_available_accommodation_units=, #number_of_bathrooms_total, #number_of_bathrooms_total=, #number_of_bedrooms, #number_of_bedrooms=, #number_of_full_bathrooms, #number_of_full_bathrooms=, #number_of_partial_bathrooms, #number_of_partial_bathrooms=, #number_of_rooms, #number_of_rooms=, #pets_allowed, #pets_allowed=, schema_property_definitions

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _FloorPlan

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #amenity_feature, #amenity_feature=, #description, #description=, #disambiguating_description, #disambiguating_description=, #floor_size, #floor_size=, #identifier, #identifier=, #image, #image=, #is_plan_for_apartment, #is_plan_for_apartment=, #layout_image, #layout_image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #number_of_accommodation_units, #number_of_accommodation_units=, #number_of_available_accommodation_units, #number_of_available_accommodation_units=, #number_of_bathrooms_total, #number_of_bathrooms_total=, #number_of_bedrooms, #number_of_bedrooms=, #number_of_full_bathrooms, #number_of_full_bathrooms=, #number_of_partial_bathrooms, #number_of_partial_bathrooms=, #number_of_rooms, #number_of_rooms=, #owner, #owner=, #pets_allowed, #pets_allowed=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.new(**properties) ⇒ FloorPlan

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/floor_plan.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/floor_plan.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/floor_plan.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/floor_plan.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



47921
# File 'sig/schema_org.rbs', line 47921

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


47920
# File 'sig/schema_org.rbs', line 47920

def schema_types: () -> ::Array[::Class]