Class: SchemaOrg::GeoShape
Overview
https://schema.org/GeoShape
The geographic shape of a place. A GeoShape can be described using several properties whose values are based on latitude/longitude pairs. Either whitespace or commas can be used to separate latitude and longitude; whitespace should be used when writing a list of several such points.
Constant Summary
collapse
- SCHEMA_NAME =
"GeoShape"
- SCHEMA_TYPES =
[self, SchemaOrg::StructuredValue, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
Class Method Summary
collapse
Instance Method Summary
collapse
#address, #address=, #address_country, #address_country=, #box, #box=, #circle, #circle=, #elevation, #elevation=, #line, #line=, #polygon, #polygon=, #postal_code, #postal_code=, schema_property_definitions
schema_property_definitions
schema_property_definitions
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _GeoShape
#additional_type, #additional_type=, #address, #address=, #address_country, #address_country=, #alternate_name, #alternate_name=, #box, #box=, #circle, #circle=, #description, #description=, #disambiguating_description, #disambiguating_description=, #elevation, #elevation=, #identifier, #identifier=, #image, #image=, #line, #line=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #polygon, #polygon=, #postal_code, #postal_code=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.new(**properties) ⇒ GeoShape
30
31
32
|
# File 'lib/schema_org/types/geo_shape.rb', line 30
def new(**properties)
super
end
|
.schema_name ⇒ String
17
18
19
|
# File 'lib/schema_org/types/geo_shape.rb', line 17
def schema_name
SCHEMA_NAME
end
|
.schema_type?(other_type) ⇒ Boolean
25
26
27
28
|
# File 'lib/schema_org/types/geo_shape.rb', line 25
def schema_type?(other_type)
Base.schema_type_argument!(other_type)
SCHEMA_TYPES.include?(other_type)
end
|
.schema_types ⇒ ::Array[::Class]
21
22
23
|
# File 'lib/schema_org/types/geo_shape.rb', line 21
def schema_types
SCHEMA_TYPES
end
|
Instance Method Details
#schema_type? ⇒ Boolean
51210
|
# File 'sig/schema_org.rbs', line 51210
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
51209
|
# File 'sig/schema_org.rbs', line 51209
def schema_types: () -> ::Array[::Class]
|