Class: SchemaOrg::HowToItem

Inherits:
Base
  • Object
show all
Includes:
Mixins::HowToItem, _HowToItem
Defined in:
lib/schema_org/types/how_to_item.rb,
sig/schema_org.rbs

Overview

https://schema.org/HowToItem

An item used as either a tool or supply when performing the instructions for how to achieve a result.

Constant Summary collapse

SCHEMA_NAME =
"HowToItem"
SCHEMA_TYPES =
[self, SchemaOrg::ListItem, SchemaOrg::Intangible, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::HowToItem

#required_quantity, #required_quantity=, schema_property_definitions

Methods included from Mixins::ListItem

#item, #item=, #next_item, #next_item=, #position, #position=, #previous_item, #previous_item=, schema_property_definitions

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _HowToItem

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #item, #item=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #next_item, #next_item=, #owner, #owner=, #position, #position=, #potential_action, #potential_action=, #previous_item, #previous_item=, #required_quantity, #required_quantity=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.new(**properties) ⇒ HowToItem

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/how_to_item.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/how_to_item.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/how_to_item.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/how_to_item.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



58273
# File 'sig/schema_org.rbs', line 58273

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


58272
# File 'sig/schema_org.rbs', line 58272

def schema_types: () -> ::Array[::Class]