Class: SchemaOrg::IncentiveQualifiedExpenseType

Inherits:
Base
  • Object
show all
Includes:
Mixins::IncentiveQualifiedExpenseType, _IncentiveQualifiedExpenseType
Defined in:
lib/schema_org/types/incentive_qualified_expense_type.rb,
sig/schema_org.rbs

Overview

https://schema.org/IncentiveQualifiedExpenseType

The types of expenses that are covered by the incentive. For example some incentives are only for the goods (tangible items) but the services (labor) are excluded.

Constant Summary collapse

SCHEMA_NAME =
"IncentiveQualifiedExpenseType"
SCHEMA_TYPES =
[self, SchemaOrg::Enumeration, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
INCENTIVE_QUALIFIED_EXPENSE_TYPE_GOODS_ONLY =

Returns:

EnumerationValue.new("IncentiveQualifiedExpenseTypeGoodsOnly", [SchemaOrg::IncentiveQualifiedExpenseType])
INCENTIVE_QUALIFIED_EXPENSE_TYPE_GOODS_OR_SERVICES =

Returns:

EnumerationValue.new("IncentiveQualifiedExpenseTypeGoodsOrServices", [SchemaOrg::IncentiveQualifiedExpenseType])
INCENTIVE_QUALIFIED_EXPENSE_TYPE_SERVICES_ONLY =

Returns:

EnumerationValue.new("IncentiveQualifiedExpenseTypeServicesOnly", [SchemaOrg::IncentiveQualifiedExpenseType])
INCENTIVE_QUALIFIED_EXPENSE_TYPE_UTILITY_BILL =

Returns:

EnumerationValue.new("IncentiveQualifiedExpenseTypeUtilityBill", [SchemaOrg::IncentiveQualifiedExpenseType])
VALUES =
[INCENTIVE_QUALIFIED_EXPENSE_TYPE_GOODS_ONLY, INCENTIVE_QUALIFIED_EXPENSE_TYPE_GOODS_OR_SERVICES, INCENTIVE_QUALIFIED_EXPENSE_TYPE_SERVICES_ONLY, INCENTIVE_QUALIFIED_EXPENSE_TYPE_UTILITY_BILL].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::IncentiveQualifiedExpenseType

schema_property_definitions

Methods included from Mixins::Enumeration

schema_property_definitions, #superseded_by, #superseded_by=

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _IncentiveQualifiedExpenseType

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #superseded_by, #superseded_by=, #url, #url=

Class Method Details

.new(**properties) ⇒ IncentiveQualifiedExpenseType

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/incentive_qualified_expense_type.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/incentive_qualified_expense_type.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/incentive_qualified_expense_type.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/incentive_qualified_expense_type.rb', line 21

def schema_types
  SCHEMA_TYPES
end

.values::Array[SchemaOrg::EnumerationValue[SchemaOrg::_IncentiveQualifiedExpenseType]]

Returns:



40
41
42
# File 'lib/schema_org/types/incentive_qualified_expense_type.rb', line 40

def self.values
  VALUES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



61250
# File 'sig/schema_org.rbs', line 61250

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


61249
# File 'sig/schema_org.rbs', line 61249

def schema_types: () -> ::Array[::Class]