Class: SchemaOrg::InvestmentOrDeposit

Inherits:
Base
  • Object
show all
Includes:
Mixins::InvestmentOrDeposit, _InvestmentOrDeposit
Defined in:
lib/schema_org/types/investment_or_deposit.rb,
sig/schema_org.rbs

Overview

https://schema.org/InvestmentOrDeposit

A type of financial product that typically requires the client to transfer funds to a financial service in return for potential beneficial financial return.

Constant Summary collapse

SCHEMA_NAME =
"InvestmentOrDeposit"
SCHEMA_TYPES =
[self, SchemaOrg::FinancialProduct, SchemaOrg::Service, SchemaOrg::Intangible, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::InvestmentOrDeposit

#amount, #amount=, schema_property_definitions

Methods included from Mixins::FinancialProduct

#annual_percentage_rate, #annual_percentage_rate=, #fees_and_commissions_specification, #fees_and_commissions_specification=, #interest_rate, #interest_rate=, schema_property_definitions

Methods included from Mixins::Service

#aggregate_rating, #aggregate_rating=, #area_served, #area_served=, #audience, #audience=, #available_channel, #available_channel=, #award, #award=, #brand, #brand=, #broker, #broker=, #category, #category=, #has_certification, #has_certification=, #has_offer_catalog, #has_offer_catalog=, #hours_available, #hours_available=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #logo, #logo=, #offers, #offers=, #produces, #produces=, #provider, #provider=, #provider_mobility, #provider_mobility=, #review, #review=, schema_property_definitions, #service_area, #service_area=, #service_audience, #service_audience=, #service_output, #service_output=, #service_type, #service_type=, #slogan, #slogan=, #terms_of_service, #terms_of_service=

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _InvestmentOrDeposit

#additional_type, #additional_type=, #aggregate_rating, #aggregate_rating=, #alternate_name, #alternate_name=, #amount, #amount=, #annual_percentage_rate, #annual_percentage_rate=, #area_served, #area_served=, #audience, #audience=, #available_channel, #available_channel=, #award, #award=, #brand, #brand=, #broker, #broker=, #category, #category=, #description, #description=, #disambiguating_description, #disambiguating_description=, #fees_and_commissions_specification, #fees_and_commissions_specification=, #has_certification, #has_certification=, #has_offer_catalog, #has_offer_catalog=, #hours_available, #hours_available=, #identifier, #identifier=, #image, #image=, #interest_rate, #interest_rate=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #logo, #logo=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #offers, #offers=, #owner, #owner=, #potential_action, #potential_action=, #produces, #produces=, #provider, #provider=, #provider_mobility, #provider_mobility=, #review, #review=, #same_as, #same_as=, #service_area, #service_area=, #service_audience, #service_audience=, #service_output, #service_output=, #service_type, #service_type=, #slogan, #slogan=, #subject_of, #subject_of=, #terms_of_service, #terms_of_service=, #url, #url=

Class Method Details

.new(**properties) ⇒ InvestmentOrDeposit

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/investment_or_deposit.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/investment_or_deposit.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/investment_or_deposit.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/investment_or_deposit.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



63099
# File 'sig/schema_org.rbs', line 63099

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


63098
# File 'sig/schema_org.rbs', line 63098

def schema_types: () -> ::Array[::Class]