Class: SchemaOrg::Ligament
Overview
https://schema.org/Ligament
A short band of tough, flexible, fibrous connective tissue that functions to connect multiple bones, cartilages, and structurally support joints.
Constant Summary
collapse
- SCHEMA_NAME =
"Ligament"
- SCHEMA_TYPES =
[self, SchemaOrg::AnatomicalStructure, SchemaOrg::MedicalEntity, SchemaOrg::Thing].freeze
Class Method Summary
collapse
Instance Method Summary
collapse
schema_property_definitions
#associated_pathophysiology, #associated_pathophysiology=, #body_location, #body_location=, #connected_to, #connected_to=, #diagram, #diagram=, #part_of_system, #part_of_system=, #related_condition, #related_condition=, #related_therapy, #related_therapy=, schema_property_definitions, #sub_structure, #sub_structure=
#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, schema_property_definitions, #study, #study=
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _Ligament
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #associated_pathophysiology, #associated_pathophysiology=, #body_location, #body_location=, #code, #code=, #connected_to, #connected_to=, #description, #description=, #diagram, #diagram=, #disambiguating_description, #disambiguating_description=, #funding, #funding=, #guideline, #guideline=, #identifier, #identifier=, #image, #image=, #legal_status, #legal_status=, #main_entity_of_page, #main_entity_of_page=, #medicine_system, #medicine_system=, #name, #name=, #owner, #owner=, #part_of_system, #part_of_system=, #potential_action, #potential_action=, #recognizing_authority, #recognizing_authority=, #related_condition, #related_condition=, #related_therapy, #related_therapy=, #relevant_specialty, #relevant_specialty=, #same_as, #same_as=, #study, #study=, #sub_structure, #sub_structure=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.new(**properties) ⇒ Ligament
30
31
32
|
# File 'lib/schema_org/types/ligament.rb', line 30
def new(**properties)
super
end
|
.schema_name ⇒ String
17
18
19
|
# File 'lib/schema_org/types/ligament.rb', line 17
def schema_name
SCHEMA_NAME
end
|
.schema_type?(other_type) ⇒ Boolean
25
26
27
28
|
# File 'lib/schema_org/types/ligament.rb', line 25
def schema_type?(other_type)
Base.schema_type_argument!(other_type)
SCHEMA_TYPES.include?(other_type)
end
|
.schema_types ⇒ ::Array[::Class]
21
22
23
|
# File 'lib/schema_org/types/ligament.rb', line 21
def schema_types
SCHEMA_TYPES
end
|
Instance Method Details
#schema_type? ⇒ Boolean
66802
|
# File 'sig/schema_org.rbs', line 66802
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
66801
|
# File 'sig/schema_org.rbs', line 66801
def schema_types: () -> ::Array[::Class]
|