Class: SchemaOrg::LoanOrCredit
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::LoanOrCredit
- Includes:
- Mixins::LoanOrCredit, _LoanOrCredit
- Defined in:
- lib/schema_org/types/loan_or_credit.rb,
sig/schema_org.rbs
Overview
https://schema.org/LoanOrCredit
A financial product for the loaning of an amount of money, or line of credit, under agreed terms and charges.
Constant Summary collapse
- SCHEMA_NAME =
"LoanOrCredit"- SCHEMA_TYPES =
[self, SchemaOrg::FinancialProduct, SchemaOrg::Service, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ LoanOrCredit
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::LoanOrCredit
#amount, #amount=, #currency, #currency=, #grace_period, #grace_period=, #loan_repayment_form, #loan_repayment_form=, #loan_term, #loan_term=, #loan_type, #loan_type=, #recourse_loan, #recourse_loan=, #renegotiable_loan, #renegotiable_loan=, #required_collateral, #required_collateral=, schema_property_definitions
Methods included from Mixins::FinancialProduct
#annual_percentage_rate, #annual_percentage_rate=, #fees_and_commissions_specification, #fees_and_commissions_specification=, #interest_rate, #interest_rate=, schema_property_definitions
Methods included from Mixins::Service
#aggregate_rating, #aggregate_rating=, #area_served, #area_served=, #audience, #audience=, #available_channel, #available_channel=, #award, #award=, #brand, #brand=, #broker, #broker=, #category, #category=, #has_certification, #has_certification=, #has_offer_catalog, #has_offer_catalog=, #hours_available, #hours_available=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #logo, #logo=, #offers, #offers=, #produces, #produces=, #provider, #provider=, #provider_mobility, #provider_mobility=, #review, #review=, schema_property_definitions, #service_area, #service_area=, #service_audience, #service_audience=, #service_output, #service_output=, #service_type, #service_type=, #slogan, #slogan=, #terms_of_service, #terms_of_service=
Methods included from Mixins::Intangible
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _LoanOrCredit
#additional_type, #additional_type=, #aggregate_rating, #aggregate_rating=, #alternate_name, #alternate_name=, #amount, #amount=, #annual_percentage_rate, #annual_percentage_rate=, #area_served, #area_served=, #audience, #audience=, #available_channel, #available_channel=, #award, #award=, #brand, #brand=, #broker, #broker=, #category, #category=, #currency, #currency=, #description, #description=, #disambiguating_description, #disambiguating_description=, #fees_and_commissions_specification, #fees_and_commissions_specification=, #grace_period, #grace_period=, #has_certification, #has_certification=, #has_offer_catalog, #has_offer_catalog=, #hours_available, #hours_available=, #identifier, #identifier=, #image, #image=, #interest_rate, #interest_rate=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #loan_repayment_form, #loan_repayment_form=, #loan_term, #loan_term=, #loan_type, #loan_type=, #logo, #logo=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #offers, #offers=, #owner, #owner=, #potential_action, #potential_action=, #produces, #produces=, #provider, #provider=, #provider_mobility, #provider_mobility=, #recourse_loan, #recourse_loan=, #renegotiable_loan, #renegotiable_loan=, #required_collateral, #required_collateral=, #review, #review=, #same_as, #same_as=, #service_area, #service_area=, #service_audience, #service_audience=, #service_output, #service_output=, #service_type, #service_type=, #slogan, #slogan=, #subject_of, #subject_of=, #terms_of_service, #terms_of_service=, #url, #url=
Class Method Details
.new(**properties) ⇒ LoanOrCredit
30 31 32 |
# File 'lib/schema_org/types/loan_or_credit.rb', line 30 def new(**properties) super end |
.schema_name ⇒ String
17 18 19 |
# File 'lib/schema_org/types/loan_or_credit.rb', line 17 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
25 26 27 28 |
# File 'lib/schema_org/types/loan_or_credit.rb', line 25 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
21 22 23 |
# File 'lib/schema_org/types/loan_or_credit.rb', line 21 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
67834 |
# File 'sig/schema_org.rbs', line 67834
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
67833 |
# File 'sig/schema_org.rbs', line 67833
def schema_types: () -> ::Array[::Class]
|