Class: SchemaOrg::LocationFeatureSpecification

Inherits:
Base
  • Object
show all
Includes:
Mixins::LocationFeatureSpecification, _LocationFeatureSpecification
Defined in:
lib/schema_org/types/location_feature_specification.rb,
sig/schema_org.rbs

Overview

https://schema.org/LocationFeatureSpecification

Specifies a location feature by providing a structured value representing a feature of an accommodation as a property-value pair of varying degrees of formality.

Constant Summary collapse

SCHEMA_NAME =
"LocationFeatureSpecification"
SCHEMA_TYPES =
[self, SchemaOrg::PropertyValue, SchemaOrg::StructuredValue, SchemaOrg::Intangible, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::LocationFeatureSpecification

#hours_available, #hours_available=, schema_property_definitions, #valid_from, #valid_from=, #valid_through, #valid_through=

Methods included from Mixins::PropertyValue

#max_value, #max_value=, #measurement_method, #measurement_method=, #measurement_technique, #measurement_technique=, #min_value, #min_value=, #property_id, #property_id=, schema_property_definitions, #unit_code, #unit_code=, #unit_text, #unit_text=, #value, #value=, #value_reference, #value_reference=

Methods included from Mixins::StructuredValue

schema_property_definitions

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _LocationFeatureSpecification

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #hours_available, #hours_available=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #max_value, #max_value=, #measurement_method, #measurement_method=, #measurement_technique, #measurement_technique=, #min_value, #min_value=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #property_id, #property_id=, #same_as, #same_as=, #subject_of, #subject_of=, #unit_code, #unit_code=, #unit_text, #unit_text=, #url, #url=, #valid_from, #valid_from=, #valid_through, #valid_through=, #value, #value=, #value_reference, #value_reference=

Class Method Details

.new(**properties) ⇒ LocationFeatureSpecification

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/location_feature_specification.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/location_feature_specification.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/location_feature_specification.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/location_feature_specification.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



68166
# File 'sig/schema_org.rbs', line 68166

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


68165
# File 'sig/schema_org.rbs', line 68165

def schema_types: () -> ::Array[::Class]