Class: SchemaOrg::MediaManipulationRatingEnumeration
Overview
https://schema.org/MediaManipulationRatingEnumeration
Codes for use with the [[mediaAuthenticityCategory]] property, indicating the authenticity of a media object (in the context of how it was published or shared). In general these codes are not mutually exclusive, although some combinations (such as 'original' versus 'transformed', 'edited' and 'staged') would be contradictory if applied in the same [[MediaReview]]. Note that the application of these codes is with regard to a piece of media shared or published in a particular context.
Constant Summary
collapse
- SCHEMA_NAME =
"MediaManipulationRatingEnumeration"
- SCHEMA_TYPES =
[self, SchemaOrg::Enumeration, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
- DECONTEXTUALIZED_CONTENT =
EnumerationValue.new("DecontextualizedContent", [SchemaOrg::MediaManipulationRatingEnumeration])
- EDITED_OR_CROPPED_CONTENT =
EnumerationValue.new("EditedOrCroppedContent", [SchemaOrg::MediaManipulationRatingEnumeration])
- ORIGINAL_MEDIA_CONTENT =
EnumerationValue.new("OriginalMediaContent", [SchemaOrg::MediaManipulationRatingEnumeration])
- SATIRE_OR_PARODY_CONTENT =
EnumerationValue.new("SatireOrParodyContent", [SchemaOrg::MediaManipulationRatingEnumeration])
- STAGED_CONTENT =
EnumerationValue.new("StagedContent", [SchemaOrg::MediaManipulationRatingEnumeration])
- TRANSFORMED_CONTENT =
EnumerationValue.new("TransformedContent", [SchemaOrg::MediaManipulationRatingEnumeration])
- VALUES =
[DECONTEXTUALIZED_CONTENT, EDITED_OR_CROPPED_CONTENT, ORIGINAL_MEDIA_CONTENT, SATIRE_OR_PARODY_CONTENT, STAGED_CONTENT, TRANSFORMED_CONTENT].freeze
Class Method Summary
collapse
Instance Method Summary
collapse
schema_property_definitions
schema_property_definitions, #superseded_by, #superseded_by=
schema_property_definitions
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #superseded_by, #superseded_by=, #url, #url=
Class Method Details
30
31
32
|
# File 'lib/schema_org/types/media_manipulation_rating_enumeration.rb', line 30
def new(**properties)
super
end
|
.schema_name ⇒ String
17
18
19
|
# File 'lib/schema_org/types/media_manipulation_rating_enumeration.rb', line 17
def schema_name
SCHEMA_NAME
end
|
.schema_type?(other_type) ⇒ Boolean
25
26
27
28
|
# File 'lib/schema_org/types/media_manipulation_rating_enumeration.rb', line 25
def schema_type?(other_type)
Base.schema_type_argument!(other_type)
SCHEMA_TYPES.include?(other_type)
end
|
.schema_types ⇒ ::Array[::Class]
21
22
23
|
# File 'lib/schema_org/types/media_manipulation_rating_enumeration.rb', line 21
def schema_types
SCHEMA_TYPES
end
|
42
43
44
|
# File 'lib/schema_org/types/media_manipulation_rating_enumeration.rb', line 42
def self.values
VALUES
end
|
Instance Method Details
#schema_type? ⇒ Boolean
70465
|
# File 'sig/schema_org.rbs', line 70465
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
70464
|
# File 'sig/schema_org.rbs', line 70464
def schema_types: () -> ::Array[::Class]
|