Class: SchemaOrg::MedicalObservationalStudy

Inherits:
Base
  • Object
show all
Includes:
SchemaOrg::Mixins::MedicalObservationalStudy, _MedicalObservationalStudy
Defined in:
lib/schema_org/types/medical_observational_study.rb,
sig/schema_org.rbs

Overview

https://schema.org/MedicalObservationalStudy

An observational study is a type of medical study that attempts to infer the possible effect of a treatment through observation of a cohort of subjects over a period of time. In an observational study, the assignment of subjects into treatment groups versus control groups is outside the control of the investigator. This is in contrast with controlled studies, such as the randomized controlled trials represented by MedicalTrial, where each subject is randomly assigned to a treatment group or a control group before the start of the treatment.

Constant Summary collapse

SCHEMA_NAME =
"MedicalObservationalStudy"
SCHEMA_TYPES =
[self, SchemaOrg::MedicalStudy, SchemaOrg::MedicalEntity, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from SchemaOrg::Mixins::MedicalObservationalStudy

schema_property_definitions, #study_design, #study_design=

Methods included from SchemaOrg::Mixins::MedicalStudy

#health_condition, #health_condition=, schema_property_definitions, #sponsor, #sponsor=, #status, #status=, #study_location, #study_location=, #study_subject, #study_subject=

Methods included from SchemaOrg::Mixins::MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, schema_property_definitions, #study, #study=

Methods included from SchemaOrg::Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _MedicalObservationalStudy

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #code, #code=, #description, #description=, #disambiguating_description, #disambiguating_description=, #funding, #funding=, #guideline, #guideline=, #health_condition, #health_condition=, #identifier, #identifier=, #image, #image=, #legal_status, #legal_status=, #main_entity_of_page, #main_entity_of_page=, #medicine_system, #medicine_system=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #same_as, #same_as=, #sponsor, #sponsor=, #status, #status=, #study, #study=, #study_design, #study_design=, #study_location, #study_location=, #study_subject, #study_subject=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.new(**properties) ⇒ MedicalObservationalStudy

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/medical_observational_study.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/medical_observational_study.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/medical_observational_study.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/medical_observational_study.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



73036
# File 'sig/schema_org.rbs', line 73036

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


73035
# File 'sig/schema_org.rbs', line 73035

def schema_types: () -> ::Array[::Class]