Class: SchemaOrg::MedicalRiskFactor
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::MedicalRiskFactor
- Defined in:
- lib/schema_org/types/medical_risk_factor.rb,
sig/schema_org.rbs
Overview
https://schema.org/MedicalRiskFactor
A risk factor is anything that increases a person's likelihood of developing or contracting a disease, medical condition, or complication.
Constant Summary collapse
- SCHEMA_NAME =
"MedicalRiskFactor"- SCHEMA_TYPES =
[self, SchemaOrg::MedicalEntity, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ MedicalRiskFactor
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from SchemaOrg::Mixins::MedicalRiskFactor
#increases_risk_of, #increases_risk_of=, schema_property_definitions
Methods included from SchemaOrg::Mixins::MedicalEntity
#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, schema_property_definitions, #study, #study=
Methods included from SchemaOrg::Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _MedicalRiskFactor
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #code, #code=, #description, #description=, #disambiguating_description, #disambiguating_description=, #funding, #funding=, #guideline, #guideline=, #identifier, #identifier=, #image, #image=, #increases_risk_of, #increases_risk_of=, #legal_status, #legal_status=, #main_entity_of_page, #main_entity_of_page=, #medicine_system, #medicine_system=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #same_as, #same_as=, #study, #study=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.new(**properties) ⇒ MedicalRiskFactor
30 31 32 |
# File 'lib/schema_org/types/medical_risk_factor.rb', line 30 def new(**properties) super end |
.schema_name ⇒ String
17 18 19 |
# File 'lib/schema_org/types/medical_risk_factor.rb', line 17 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
25 26 27 28 |
# File 'lib/schema_org/types/medical_risk_factor.rb', line 25 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
21 22 23 |
# File 'lib/schema_org/types/medical_risk_factor.rb', line 21 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
73569 |
# File 'sig/schema_org.rbs', line 73569
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
73568 |
# File 'sig/schema_org.rbs', line 73568
def schema_types: () -> ::Array[::Class]
|