Class: SchemaOrg::MedicalSignOrSymptom

Inherits:
Base
  • Object
show all
Includes:
SchemaOrg::Mixins::MedicalSignOrSymptom, _MedicalSignOrSymptom
Defined in:
lib/schema_org/types/medical_sign_or_symptom.rb,
sig/schema_org.rbs

Overview

https://schema.org/MedicalSignOrSymptom

Any feature associated or not with a medical condition. In medicine a symptom is generally subjective while a sign is objective.

Constant Summary collapse

SCHEMA_NAME =
"MedicalSignOrSymptom"
SCHEMA_TYPES =
[self, SchemaOrg::MedicalCondition, SchemaOrg::MedicalEntity, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from SchemaOrg::Mixins::MedicalSignOrSymptom

#possible_treatment, #possible_treatment=, schema_property_definitions

Methods included from SchemaOrg::Mixins::MedicalCondition

#associated_anatomy, #associated_anatomy=, #cause, #cause=, #differential_diagnosis, #differential_diagnosis=, #drug, #drug=, #epidemiology, #epidemiology=, #expected_prognosis, #expected_prognosis=, #natural_progression, #natural_progression=, #pathophysiology, #pathophysiology=, #possible_complication, #possible_complication=, #possible_treatment, #possible_treatment=, #primary_prevention, #primary_prevention=, #risk_factor, #risk_factor=, schema_property_definitions, #secondary_prevention, #secondary_prevention=, #sign_or_symptom, #sign_or_symptom=, #stage, #stage=, #status, #status=, #typical_test, #typical_test=

Methods included from SchemaOrg::Mixins::MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, schema_property_definitions, #study, #study=

Methods included from SchemaOrg::Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _MedicalSignOrSymptom

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #associated_anatomy, #associated_anatomy=, #cause, #cause=, #code, #code=, #description, #description=, #differential_diagnosis, #differential_diagnosis=, #disambiguating_description, #disambiguating_description=, #drug, #drug=, #epidemiology, #epidemiology=, #expected_prognosis, #expected_prognosis=, #funding, #funding=, #guideline, #guideline=, #identifier, #identifier=, #image, #image=, #legal_status, #legal_status=, #main_entity_of_page, #main_entity_of_page=, #medicine_system, #medicine_system=, #name, #name=, #natural_progression, #natural_progression=, #owner, #owner=, #pathophysiology, #pathophysiology=, #possible_complication, #possible_complication=, #possible_treatment, #possible_treatment=, #potential_action, #potential_action=, #primary_prevention, #primary_prevention=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #risk_factor, #risk_factor=, #same_as, #same_as=, #secondary_prevention, #secondary_prevention=, #sign_or_symptom, #sign_or_symptom=, #stage, #stage=, #status, #status=, #study, #study=, #subject_of, #subject_of=, #typical_test, #typical_test=, #url, #url=

Class Method Details

.new(**properties) ⇒ MedicalSignOrSymptom

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/medical_sign_or_symptom.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/medical_sign_or_symptom.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/medical_sign_or_symptom.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/medical_sign_or_symptom.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



74099
# File 'sig/schema_org.rbs', line 74099

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


74098
# File 'sig/schema_org.rbs', line 74098

def schema_types: () -> ::Array[::Class]