Class: SchemaOrg::MedicalSpecialty

Inherits:
Base
  • Object
show all
Includes:
SchemaOrg::Mixins::MedicalSpecialty, _MedicalSpecialty
Defined in:
lib/schema_org/types/medical_specialty.rb,
sig/schema_org.rbs

Overview

https://schema.org/MedicalSpecialty

Any specific branch of medical science or practice. Medical specialities include clinical specialties that pertain to particular organ systems and their respective disease states, as well as allied health specialties. Enumerated type.

Constant Summary collapse

SCHEMA_NAME =
"MedicalSpecialty"
SCHEMA_TYPES =
[self, SchemaOrg::MedicalEnumeration, SchemaOrg::Specialty, SchemaOrg::Enumeration, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
ANESTHESIA =

Returns:

EnumerationValue.new("Anesthesia", [SchemaOrg::MedicalSpecialty])
CARDIOVASCULAR =

Returns:

EnumerationValue.new("Cardiovascular", [SchemaOrg::MedicalSpecialty])
COMMUNITY_HEALTH =

Returns:

EnumerationValue.new("CommunityHealth", [SchemaOrg::MedicalSpecialty])
DENTISTRY =

Returns:

EnumerationValue.new("Dentistry", [SchemaOrg::MedicalSpecialty])
DERMATOLOGIC =

Returns:

EnumerationValue.new("Dermatologic", [SchemaOrg::MedicalSpecialty])
DERMATOLOGY =

Returns:

EnumerationValue.new("Dermatology", [SchemaOrg::MedicalSpecialty])
DIET_NUTRITION =

Returns:

EnumerationValue.new("DietNutrition", [SchemaOrg::MedicalSpecialty])
EMERGENCY =

Returns:

EnumerationValue.new("Emergency", [SchemaOrg::MedicalSpecialty])
ENDOCRINE =

Returns:

EnumerationValue.new("Endocrine", [SchemaOrg::MedicalSpecialty])
GASTROENTEROLOGIC =

Returns:

EnumerationValue.new("Gastroenterologic", [SchemaOrg::MedicalSpecialty])
GENETIC =

Returns:

EnumerationValue.new("Genetic", [SchemaOrg::MedicalSpecialty])
GERIATRIC =

Returns:

EnumerationValue.new("Geriatric", [SchemaOrg::MedicalSpecialty])
GYNECOLOGIC =

Returns:

EnumerationValue.new("Gynecologic", [SchemaOrg::MedicalSpecialty])
HEMATOLOGIC =

Returns:

EnumerationValue.new("Hematologic", [SchemaOrg::MedicalSpecialty])
INFECTIOUS =

Returns:

EnumerationValue.new("Infectious", [SchemaOrg::MedicalSpecialty])
LABORATORY_SCIENCE =

Returns:

EnumerationValue.new("LaboratoryScience", [SchemaOrg::MedicalSpecialty])
MIDWIFERY =

Returns:

EnumerationValue.new("Midwifery", [SchemaOrg::MedicalSpecialty])
MUSCULOSKELETAL =

Returns:

EnumerationValue.new("Musculoskeletal", [SchemaOrg::MedicalSpecialty])
NEUROLOGIC =

Returns:

EnumerationValue.new("Neurologic", [SchemaOrg::MedicalSpecialty])
NURSING =

Returns:

EnumerationValue.new("Nursing", [SchemaOrg::MedicalSpecialty])
OBSTETRIC =

Returns:

EnumerationValue.new("Obstetric", [SchemaOrg::MedicalSpecialty])
ONCOLOGIC =

Returns:

EnumerationValue.new("Oncologic", [SchemaOrg::MedicalSpecialty])
OPTOMETRIC =

Returns:

EnumerationValue.new("Optometric", [SchemaOrg::MedicalSpecialty])
OTOLARYNGOLOGIC =

Returns:

EnumerationValue.new("Otolaryngologic", [SchemaOrg::MedicalSpecialty])
PATHOLOGY =

Returns:

EnumerationValue.new("Pathology", [SchemaOrg::MedicalSpecialty])
PEDIATRIC =

Returns:

EnumerationValue.new("Pediatric", [SchemaOrg::MedicalSpecialty])
PHARMACY_SPECIALTY =

Returns:

EnumerationValue.new("PharmacySpecialty", [SchemaOrg::MedicalSpecialty])
PHYSIOTHERAPY =

Returns:

EnumerationValue.new("Physiotherapy", [SchemaOrg::MedicalSpecialty])
PLASTIC_SURGERY =

Returns:

EnumerationValue.new("PlasticSurgery", [SchemaOrg::MedicalSpecialty])
PODIATRIC =

Returns:

EnumerationValue.new("Podiatric", [SchemaOrg::MedicalSpecialty])
PRIMARY_CARE =

Returns:

EnumerationValue.new("PrimaryCare", [SchemaOrg::MedicalSpecialty])
PSYCHIATRIC =

Returns:

EnumerationValue.new("Psychiatric", [SchemaOrg::MedicalSpecialty])
PUBLIC_HEALTH =

Returns:

EnumerationValue.new("PublicHealth", [SchemaOrg::MedicalSpecialty])
PULMONARY =

Returns:

EnumerationValue.new("Pulmonary", [SchemaOrg::MedicalSpecialty])
RADIOGRAPHY =

Returns:

EnumerationValue.new("Radiography", [SchemaOrg::MedicalImagingTechnique, SchemaOrg::MedicalSpecialty])
RENAL =

Returns:

EnumerationValue.new("Renal", [SchemaOrg::MedicalSpecialty])
RESPIRATORY_THERAPY =

Returns:

EnumerationValue.new("RespiratoryTherapy", [SchemaOrg::MedicalSpecialty])
RHEUMATOLOGIC =

Returns:

EnumerationValue.new("Rheumatologic", [SchemaOrg::MedicalSpecialty])
SPEECH_PATHOLOGY =

Returns:

EnumerationValue.new("SpeechPathology", [SchemaOrg::MedicalSpecialty])
SURGICAL =

Returns:

EnumerationValue.new("Surgical", [SchemaOrg::MedicalSpecialty])
TOXICOLOGIC =

Returns:

EnumerationValue.new("Toxicologic", [SchemaOrg::MedicalSpecialty])
UROLOGIC =

Returns:

EnumerationValue.new("Urologic", [SchemaOrg::MedicalSpecialty])
VALUES =
[ANESTHESIA, CARDIOVASCULAR, COMMUNITY_HEALTH, DENTISTRY, DERMATOLOGIC, DERMATOLOGY, DIET_NUTRITION, EMERGENCY, ENDOCRINE, GASTROENTEROLOGIC, GENETIC, GERIATRIC, GYNECOLOGIC, HEMATOLOGIC, INFECTIOUS, LABORATORY_SCIENCE, MIDWIFERY, MUSCULOSKELETAL, NEUROLOGIC, NURSING, OBSTETRIC, ONCOLOGIC, OPTOMETRIC, OTOLARYNGOLOGIC, PATHOLOGY, PEDIATRIC, PHARMACY_SPECIALTY, PHYSIOTHERAPY, PLASTIC_SURGERY, PODIATRIC, PRIMARY_CARE, PSYCHIATRIC, PUBLIC_HEALTH, PULMONARY, RADIOGRAPHY, RENAL, RESPIRATORY_THERAPY, RHEUMATOLOGIC, SPEECH_PATHOLOGY, SURGICAL, TOXICOLOGIC, UROLOGIC].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from SchemaOrg::Mixins::MedicalSpecialty

schema_property_definitions

Methods included from SchemaOrg::Mixins::Specialty

schema_property_definitions

Methods included from SchemaOrg::Mixins::Enumeration

schema_property_definitions, #superseded_by, #superseded_by=

Methods included from SchemaOrg::Mixins::Intangible

schema_property_definitions

Methods included from SchemaOrg::Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from SchemaOrg::Mixins::MedicalEnumeration

schema_property_definitions

Methods included from _MedicalSpecialty

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #superseded_by, #superseded_by=, #url, #url=

Class Method Details

.new(**properties) ⇒ MedicalSpecialty

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/medical_specialty.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/medical_specialty.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/medical_specialty.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/medical_specialty.rb', line 21

def schema_types
  SCHEMA_TYPES
end

.values::Array[SchemaOrg::EnumerationValue[SchemaOrg::_MedicalSpecialty] | SchemaOrg::EnumerationValue[SchemaOrg::_MedicalImagingTechnique & SchemaOrg::_MedicalSpecialty]]

Returns:



78
79
80
# File 'lib/schema_org/types/medical_specialty.rb', line 78

def self.values
  VALUES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



74140
# File 'sig/schema_org.rbs', line 74140

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


74139
# File 'sig/schema_org.rbs', line 74139

def schema_types: () -> ::Array[::Class]