Module: SchemaOrg::Mixins::Accommodation

Includes:
Place
Included in:
Accommodation, Apartment, CampingPitch, House, Room, Suite
Defined in:
lib/schema_org/mixins/accommodation.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Place

#additional_property, #additional_property=, #address, #address=, #aggregate_rating, #aggregate_rating=, #branch_code, #branch_code=, #contained_in, #contained_in=, #contained_in_place, #contained_in_place=, #contains_place, #contains_place=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #geo, #geo=, #geo_contains, #geo_contains=, #geo_covered_by, #geo_covered_by=, #geo_covers, #geo_covers=, #geo_crosses, #geo_crosses=, #geo_disjoint, #geo_disjoint=, #geo_equals, #geo_equals=, #geo_intersects, #geo_intersects=, #geo_overlaps, #geo_overlaps=, #geo_touches, #geo_touches=, #geo_within, #geo_within=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_drive_through_service, #has_drive_through_service=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_map, #has_map=, #is_accessible_for_free, #is_accessible_for_free=, #isic_v4, #isic_v4=, #keywords, #keywords=, #latitude, #latitude=, #logo, #logo=, #longitude, #longitude=, #map, #map=, #maps, #maps=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #opening_hours_specification, #opening_hours_specification=, #photo, #photo=, #photos, #photos=, #public_access, #public_access=, #review, #review=, #reviews, #reviews=, #slogan, #slogan=, #smoking_allowed, #smoking_allowed=, #special_opening_hours_specification, #special_opening_hours_specification=, #telephone, #telephone=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/schema_org/mixins/accommodation.rb', line 11

def self.schema_property_definitions
  {
    accommodation_category: {
      schema_name: "accommodationCategory",
      schema_url: "https://schema.org/accommodationCategory",
      comment_lines: ["Category of an [[Accommodation]], following real estate conventions, e.g. RESO (see [PropertySubType](https://ddwiki.reso.org/display/DDW17/PropertySubType+Field), and [PropertyType](https://ddwiki.reso.org/display/DDW17/PropertyType+Field) fields  for suggested values)."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    accommodation_floor_plan: {
      schema_name: "accommodationFloorPlan",
      schema_url: "https://schema.org/accommodationFloorPlan",
      comment_lines: ["A floorplan of some [[Accommodation]]."].freeze,
      ranges: ["FloorPlan"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    amenity_feature: {
      schema_name: "amenityFeature",
      schema_url: "https://schema.org/amenityFeature",
      comment_lines: ["An amenity feature (e.g. a characteristic or service) of the Accommodation. This generic property does not make a statement about whether the feature is included in an offer for the main accommodation or available at extra costs."].freeze,
      ranges: ["LocationFeatureSpecification"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    bed: {
      schema_name: "bed",
      schema_url: "https://schema.org/bed",
      comment_lines: ["The type of bed or beds included in the accommodation. For the single case of just one bed of a certain type, you use bed directly with a text.", "      If you want to indicate the quantity of a certain kind of bed, use an instance of BedDetails. For more detailed information, use the amenityFeature property."].freeze,
      ranges: ["BedDetails", "BedType", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    floor_level: {
      schema_name: "floorLevel",
      schema_url: "https://schema.org/floorLevel",
      comment_lines: ["The floor level for an [[Accommodation]] in a multi-storey building. Since counting", "  systems [vary internationally](https://en.wikipedia.org/wiki/Storey#Consecutive_number_floor_designations), the local system should be used where possible."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    floor_size: {
      schema_name: "floorSize",
      schema_url: "https://schema.org/floorSize",
      comment_lines: ["The size of the accommodation, e.g. in square meter or squarefoot.", "Typical unit code(s): MTK for square meter, FTK for square foot, or YDK for square yard."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    lease_length: {
      schema_name: "leaseLength",
      schema_url: "https://schema.org/leaseLength",
      comment_lines: ["Length of the lease for some [[Accommodation]], either particular to some [[Offer]] or in some cases intrinsic to the property."].freeze,
      ranges: ["Duration", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    number_of_bathrooms_total: {
      schema_name: "numberOfBathroomsTotal",
      schema_url: "https://schema.org/numberOfBathroomsTotal",
      comment_lines: ["The total integer number of bathrooms in some [[Accommodation]], following real estate conventions as [documented in RESO](https://ddwiki.reso.org/display/DDW17/BathroomsTotalInteger+Field): \"The simple sum of the number of bathrooms. For example for a property with two Full Bathrooms and one Half Bathroom, the Bathrooms Total Integer will be 3.\". See also [[numberOfRooms]]."].freeze,
      ranges: ["Integer"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    number_of_bedrooms: {
      schema_name: "numberOfBedrooms",
      schema_url: "https://schema.org/numberOfBedrooms",
      comment_lines: ["The total integer number of bedrooms in a some [[Accommodation]], [[ApartmentComplex]] or [[FloorPlan]]."].freeze,
      ranges: ["Number", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    number_of_full_bathrooms: {
      schema_name: "numberOfFullBathrooms",
      schema_url: "https://schema.org/numberOfFullBathrooms",
      comment_lines: ["Number of full bathrooms - The total number of full and ¾ bathrooms in an [[Accommodation]]. This corresponds to the [BathroomsFull field in RESO](https://ddwiki.reso.org/display/DDW17/BathroomsFull+Field)."].freeze,
      ranges: ["Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    number_of_partial_bathrooms: {
      schema_name: "numberOfPartialBathrooms",
      schema_url: "https://schema.org/numberOfPartialBathrooms",
      comment_lines: ["Number of partial bathrooms - The total number of half and ¼ bathrooms in an [[Accommodation]]. This corresponds to the [BathroomsPartial field in RESO](https://ddwiki.reso.org/display/DDW17/BathroomsPartial+Field)."].freeze,
      ranges: ["Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    number_of_rooms: {
      schema_name: "numberOfRooms",
      schema_url: "https://schema.org/numberOfRooms",
      comment_lines: ["The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business.", "Typical unit code(s): ROM for room or C62 for no unit. The type of room can be put in the unitText property of the QuantitativeValue."].freeze,
      ranges: ["Number", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    occupancy: {
      schema_name: "occupancy",
      schema_url: "https://schema.org/occupancy",
      comment_lines: ["The allowed total occupancy for the accommodation in persons (including infants etc). For individual accommodations, this is not necessarily the legal maximum but defines the permitted usage as per the contractual agreement (e.g. a double room used by a single person).", "Typical unit code(s): C62 for person."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    permitted_usage: {
      schema_name: "permittedUsage",
      schema_url: "https://schema.org/permittedUsage",
      comment_lines: ["Indications regarding the permitted usage of the accommodation."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    pets_allowed: {
      schema_name: "petsAllowed",
      schema_url: "https://schema.org/petsAllowed",
      comment_lines: ["Indicates whether pets are allowed to enter the accommodation or lodging business. More detailed information can be put in a text value."].freeze,
      ranges: ["Boolean", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    tour_booking_page: {
      schema_name: "tourBookingPage",
      schema_url: "https://schema.org/tourBookingPage",
      comment_lines: ["A page providing information on how to book a tour of some [[Place]], such as an [[Accommodation]] or [[ApartmentComplex]] in a real estate setting, as well as other kinds of tours as appropriate."].freeze,
      ranges: ["URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    year_built: {
      schema_name: "yearBuilt",
      schema_url: "https://schema.org/yearBuilt",
      comment_lines: ["The year an [[Accommodation]] was constructed. This corresponds to the [YearBuilt field in RESO](https://ddwiki.reso.org/display/DDW17/YearBuilt+Field)."].freeze,
      ranges: ["Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#accommodation_categoryObject

Category of an [[Accommodation]], following real estate conventions, e.g. RESO (see PropertySubType, and PropertyType fields for suggested values).



187
188
189
# File 'lib/schema_org/mixins/accommodation.rb', line 187

def accommodation_category
  read_property(:accommodation_category)
end

#accommodation_category=(value) ⇒ Object

Category of an [[Accommodation]], following real estate conventions, e.g. RESO (see PropertySubType, and PropertyType fields for suggested values).



192
193
194
# File 'lib/schema_org/mixins/accommodation.rb', line 192

def accommodation_category=(value)
  write_property(:accommodation_category, value)
end

#accommodation_floor_planObject

A floorplan of some [[Accommodation]].



197
198
199
# File 'lib/schema_org/mixins/accommodation.rb', line 197

def accommodation_floor_plan
  read_property(:accommodation_floor_plan)
end

#accommodation_floor_plan=(value) ⇒ Object

A floorplan of some [[Accommodation]].



202
203
204
# File 'lib/schema_org/mixins/accommodation.rb', line 202

def accommodation_floor_plan=(value)
  write_property(:accommodation_floor_plan, value)
end

#amenity_featureObject

An amenity feature (e.g. a characteristic or service) of the Accommodation. This generic property does not make a statement about whether the feature is included in an offer for the main accommodation or available at extra costs.



207
208
209
# File 'lib/schema_org/mixins/accommodation.rb', line 207

def amenity_feature
  read_property(:amenity_feature)
end

#amenity_feature=(value) ⇒ Object

An amenity feature (e.g. a characteristic or service) of the Accommodation. This generic property does not make a statement about whether the feature is included in an offer for the main accommodation or available at extra costs.



212
213
214
# File 'lib/schema_org/mixins/accommodation.rb', line 212

def amenity_feature=(value)
  write_property(:amenity_feature, value)
end

#bedObject

The type of bed or beds included in the accommodation. For the single case of just one bed of a certain type, you use bed directly with a text. If you want to indicate the quantity of a certain kind of bed, use an instance of BedDetails. For more detailed information, use the amenityFeature property.



218
219
220
# File 'lib/schema_org/mixins/accommodation.rb', line 218

def bed
  read_property(:bed)
end

#bed=(value) ⇒ Object

The type of bed or beds included in the accommodation. For the single case of just one bed of a certain type, you use bed directly with a text. If you want to indicate the quantity of a certain kind of bed, use an instance of BedDetails. For more detailed information, use the amenityFeature property.



224
225
226
# File 'lib/schema_org/mixins/accommodation.rb', line 224

def bed=(value)
  write_property(:bed, value)
end

#floor_levelObject

The floor level for an [[Accommodation]] in a multi-storey building. Since counting systems vary internationally, the local system should be used where possible.



230
231
232
# File 'lib/schema_org/mixins/accommodation.rb', line 230

def floor_level
  read_property(:floor_level)
end

#floor_level=(value) ⇒ Object

The floor level for an [[Accommodation]] in a multi-storey building. Since counting systems vary internationally, the local system should be used where possible.



236
237
238
# File 'lib/schema_org/mixins/accommodation.rb', line 236

def floor_level=(value)
  write_property(:floor_level, value)
end

#floor_sizeObject

The size of the accommodation, e.g. in square meter or squarefoot. Typical unit code(s): MTK for square meter, FTK for square foot, or YDK for square yard.



242
243
244
# File 'lib/schema_org/mixins/accommodation.rb', line 242

def floor_size
  read_property(:floor_size)
end

#floor_size=(value) ⇒ Object

The size of the accommodation, e.g. in square meter or squarefoot. Typical unit code(s): MTK for square meter, FTK for square foot, or YDK for square yard.



248
249
250
# File 'lib/schema_org/mixins/accommodation.rb', line 248

def floor_size=(value)
  write_property(:floor_size, value)
end

#lease_lengthObject

Length of the lease for some [[Accommodation]], either particular to some [[Offer]] or in some cases intrinsic to the property.



253
254
255
# File 'lib/schema_org/mixins/accommodation.rb', line 253

def lease_length
  read_property(:lease_length)
end

#lease_length=(value) ⇒ Object

Length of the lease for some [[Accommodation]], either particular to some [[Offer]] or in some cases intrinsic to the property.



258
259
260
# File 'lib/schema_org/mixins/accommodation.rb', line 258

def lease_length=(value)
  write_property(:lease_length, value)
end

#number_of_bathrooms_totalObject

The total integer number of bathrooms in some [[Accommodation]], following real estate conventions as documented in RESO: "The simple sum of the number of bathrooms. For example for a property with two Full Bathrooms and one Half Bathroom, the Bathrooms Total Integer will be 3.". See also [[numberOfRooms]].



263
264
265
# File 'lib/schema_org/mixins/accommodation.rb', line 263

def number_of_bathrooms_total
  read_property(:number_of_bathrooms_total)
end

#number_of_bathrooms_total=(value) ⇒ Object

The total integer number of bathrooms in some [[Accommodation]], following real estate conventions as documented in RESO: "The simple sum of the number of bathrooms. For example for a property with two Full Bathrooms and one Half Bathroom, the Bathrooms Total Integer will be 3.". See also [[numberOfRooms]].



268
269
270
# File 'lib/schema_org/mixins/accommodation.rb', line 268

def number_of_bathrooms_total=(value)
  write_property(:number_of_bathrooms_total, value)
end

#number_of_bedroomsObject

The total integer number of bedrooms in a some [[Accommodation]], [[ApartmentComplex]] or [[FloorPlan]].



273
274
275
# File 'lib/schema_org/mixins/accommodation.rb', line 273

def number_of_bedrooms
  read_property(:number_of_bedrooms)
end

#number_of_bedrooms=(value) ⇒ Object

The total integer number of bedrooms in a some [[Accommodation]], [[ApartmentComplex]] or [[FloorPlan]].



278
279
280
# File 'lib/schema_org/mixins/accommodation.rb', line 278

def number_of_bedrooms=(value)
  write_property(:number_of_bedrooms, value)
end

#number_of_full_bathroomsObject

Number of full bathrooms - The total number of full and ¾ bathrooms in an [[Accommodation]]. This corresponds to the BathroomsFull field in RESO.



283
284
285
# File 'lib/schema_org/mixins/accommodation.rb', line 283

def number_of_full_bathrooms
  read_property(:number_of_full_bathrooms)
end

#number_of_full_bathrooms=(value) ⇒ Object

Number of full bathrooms - The total number of full and ¾ bathrooms in an [[Accommodation]]. This corresponds to the BathroomsFull field in RESO.



288
289
290
# File 'lib/schema_org/mixins/accommodation.rb', line 288

def number_of_full_bathrooms=(value)
  write_property(:number_of_full_bathrooms, value)
end

#number_of_partial_bathroomsObject

Number of partial bathrooms - The total number of half and ¼ bathrooms in an [[Accommodation]]. This corresponds to the BathroomsPartial field in RESO.



293
294
295
# File 'lib/schema_org/mixins/accommodation.rb', line 293

def number_of_partial_bathrooms
  read_property(:number_of_partial_bathrooms)
end

#number_of_partial_bathrooms=(value) ⇒ Object

Number of partial bathrooms - The total number of half and ¼ bathrooms in an [[Accommodation]]. This corresponds to the BathroomsPartial field in RESO.



298
299
300
# File 'lib/schema_org/mixins/accommodation.rb', line 298

def number_of_partial_bathrooms=(value)
  write_property(:number_of_partial_bathrooms, value)
end

#number_of_roomsObject

The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business. Typical unit code(s): ROM for room or C62 for no unit. The type of room can be put in the unitText property of the QuantitativeValue.



304
305
306
# File 'lib/schema_org/mixins/accommodation.rb', line 304

def number_of_rooms
  read_property(:number_of_rooms)
end

#number_of_rooms=(value) ⇒ Object

The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business. Typical unit code(s): ROM for room or C62 for no unit. The type of room can be put in the unitText property of the QuantitativeValue.



310
311
312
# File 'lib/schema_org/mixins/accommodation.rb', line 310

def number_of_rooms=(value)
  write_property(:number_of_rooms, value)
end

#occupancyObject

The allowed total occupancy for the accommodation in persons (including infants etc). For individual accommodations, this is not necessarily the legal maximum but defines the permitted usage as per the contractual agreement (e.g. a double room used by a single person). Typical unit code(s): C62 for person.



316
317
318
# File 'lib/schema_org/mixins/accommodation.rb', line 316

def occupancy
  read_property(:occupancy)
end

#occupancy=(value) ⇒ Object

The allowed total occupancy for the accommodation in persons (including infants etc). For individual accommodations, this is not necessarily the legal maximum but defines the permitted usage as per the contractual agreement (e.g. a double room used by a single person). Typical unit code(s): C62 for person.



322
323
324
# File 'lib/schema_org/mixins/accommodation.rb', line 322

def occupancy=(value)
  write_property(:occupancy, value)
end

#permitted_usageObject

Indications regarding the permitted usage of the accommodation.



327
328
329
# File 'lib/schema_org/mixins/accommodation.rb', line 327

def permitted_usage
  read_property(:permitted_usage)
end

#permitted_usage=(value) ⇒ Object

Indications regarding the permitted usage of the accommodation.



332
333
334
# File 'lib/schema_org/mixins/accommodation.rb', line 332

def permitted_usage=(value)
  write_property(:permitted_usage, value)
end

#pets_allowedObject

Indicates whether pets are allowed to enter the accommodation or lodging business. More detailed information can be put in a text value.



337
338
339
# File 'lib/schema_org/mixins/accommodation.rb', line 337

def pets_allowed
  read_property(:pets_allowed)
end

#pets_allowed=(value) ⇒ Object

Indicates whether pets are allowed to enter the accommodation or lodging business. More detailed information can be put in a text value.



342
343
344
# File 'lib/schema_org/mixins/accommodation.rb', line 342

def pets_allowed=(value)
  write_property(:pets_allowed, value)
end

#tour_booking_pageObject

A page providing information on how to book a tour of some [[Place]], such as an [[Accommodation]] or [[ApartmentComplex]] in a real estate setting, as well as other kinds of tours as appropriate.



347
348
349
# File 'lib/schema_org/mixins/accommodation.rb', line 347

def tour_booking_page
  read_property(:tour_booking_page)
end

#tour_booking_page=(value) ⇒ Object

A page providing information on how to book a tour of some [[Place]], such as an [[Accommodation]] or [[ApartmentComplex]] in a real estate setting, as well as other kinds of tours as appropriate.



352
353
354
# File 'lib/schema_org/mixins/accommodation.rb', line 352

def tour_booking_page=(value)
  write_property(:tour_booking_page, value)
end

#year_builtObject

The year an [[Accommodation]] was constructed. This corresponds to the YearBuilt field in RESO.



357
358
359
# File 'lib/schema_org/mixins/accommodation.rb', line 357

def year_built
  read_property(:year_built)
end

#year_built=(value) ⇒ Object

The year an [[Accommodation]] was constructed. This corresponds to the YearBuilt field in RESO.



362
363
364
# File 'lib/schema_org/mixins/accommodation.rb', line 362

def year_built=(value)
  write_property(:year_built, value)
end