Module: SchemaOrg::Mixins::AnatomicalSystem

Includes:
MedicalEntity
Included in:
AnatomicalSystem
Defined in:
lib/schema_org/mixins/anatomical_system.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/schema_org/mixins/anatomical_system.rb', line 11

def self.schema_property_definitions
  {
    associated_pathophysiology: {
      schema_name: "associatedPathophysiology",
      schema_url: "https://schema.org/associatedPathophysiology",
      comment_lines: ["If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    comprised_of: {
      schema_name: "comprisedOf",
      schema_url: "https://schema.org/comprisedOf",
      comment_lines: ["Specifying something physically contained by something else. Typically used here for the underlying anatomical structures, such as organs, that comprise the anatomical system."].freeze,
      ranges: ["AnatomicalStructure", "AnatomicalSystem"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    related_condition: {
      schema_name: "relatedCondition",
      schema_url: "https://schema.org/relatedCondition",
      comment_lines: ["A medical condition associated with this anatomy."].freeze,
      ranges: ["MedicalCondition"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    related_structure: {
      schema_name: "relatedStructure",
      schema_url: "https://schema.org/relatedStructure",
      comment_lines: ["Related anatomical structure(s) that are not part of the system but relate or connect to it, such as vascular bundles associated with an organ system."].freeze,
      ranges: ["AnatomicalStructure"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    related_therapy: {
      schema_name: "relatedTherapy",
      schema_url: "https://schema.org/relatedTherapy",
      comment_lines: ["A medical therapy related to this anatomy."].freeze,
      ranges: ["MedicalTherapy"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#associated_pathophysiologyObject

If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system.



67
68
69
# File 'lib/schema_org/mixins/anatomical_system.rb', line 67

def associated_pathophysiology
  read_property(:associated_pathophysiology)
end

#associated_pathophysiology=(value) ⇒ Object

If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system.



72
73
74
# File 'lib/schema_org/mixins/anatomical_system.rb', line 72

def associated_pathophysiology=(value)
  write_property(:associated_pathophysiology, value)
end

#comprised_ofObject

Specifying something physically contained by something else. Typically used here for the underlying anatomical structures, such as organs, that comprise the anatomical system.



77
78
79
# File 'lib/schema_org/mixins/anatomical_system.rb', line 77

def comprised_of
  read_property(:comprised_of)
end

#comprised_of=(value) ⇒ Object

Specifying something physically contained by something else. Typically used here for the underlying anatomical structures, such as organs, that comprise the anatomical system.



82
83
84
# File 'lib/schema_org/mixins/anatomical_system.rb', line 82

def comprised_of=(value)
  write_property(:comprised_of, value)
end

A medical condition associated with this anatomy.



87
88
89
# File 'lib/schema_org/mixins/anatomical_system.rb', line 87

def related_condition
  read_property(:related_condition)
end

A medical condition associated with this anatomy.



92
93
94
# File 'lib/schema_org/mixins/anatomical_system.rb', line 92

def related_condition=(value)
  write_property(:related_condition, value)
end

Related anatomical structure(s) that are not part of the system but relate or connect to it, such as vascular bundles associated with an organ system.



97
98
99
# File 'lib/schema_org/mixins/anatomical_system.rb', line 97

def related_structure
  read_property(:related_structure)
end

Related anatomical structure(s) that are not part of the system but relate or connect to it, such as vascular bundles associated with an organ system.



102
103
104
# File 'lib/schema_org/mixins/anatomical_system.rb', line 102

def related_structure=(value)
  write_property(:related_structure, value)
end

A medical therapy related to this anatomy.



107
108
109
# File 'lib/schema_org/mixins/anatomical_system.rb', line 107

def related_therapy
  read_property(:related_therapy)
end

A medical therapy related to this anatomy.



112
113
114
# File 'lib/schema_org/mixins/anatomical_system.rb', line 112

def related_therapy=(value)
  write_property(:related_therapy, value)
end