Module: SchemaOrg::Mixins::Audience

Includes:
Intangible
Included in:
Audience, BusinessAudience, EducationalAudience, MedicalAudience, PeopleAudience, Researcher
Defined in:
lib/schema_org/mixins/audience.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/schema_org/mixins/audience.rb', line 11

def self.schema_property_definitions
  {
    audience_type: {
      schema_name: "audienceType",
      schema_url: "https://schema.org/audienceType",
      comment_lines: ["The target group associated with a given audience (e.g. veterans, car owners, musicians, etc.)."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    geographic_area: {
      schema_name: "geographicArea",
      schema_url: "https://schema.org/geographicArea",
      comment_lines: ["The geographic area associated with the audience."].freeze,
      ranges: ["AdministrativeArea"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#audience_typeObject

The target group associated with a given audience (e.g. veterans, car owners, musicians, etc.).



37
38
39
# File 'lib/schema_org/mixins/audience.rb', line 37

def audience_type
  read_property(:audience_type)
end

#audience_type=(value) ⇒ Object

The target group associated with a given audience (e.g. veterans, car owners, musicians, etc.).



42
43
44
# File 'lib/schema_org/mixins/audience.rb', line 42

def audience_type=(value)
  write_property(:audience_type, value)
end

#geographic_areaObject

The geographic area associated with the audience.



47
48
49
# File 'lib/schema_org/mixins/audience.rb', line 47

def geographic_area
  read_property(:geographic_area)
end

#geographic_area=(value) ⇒ Object

The geographic area associated with the audience.



52
53
54
# File 'lib/schema_org/mixins/audience.rb', line 52

def geographic_area=(value)
  write_property(:geographic_area, value)
end