Module: SchemaOrg::Mixins::BedDetails

Includes:
Intangible
Included in:
BedDetails
Defined in:
lib/schema_org/mixins/bed_details.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/schema_org/mixins/bed_details.rb', line 11

def self.schema_property_definitions
  {
    number_of_beds: {
      schema_name: "numberOfBeds",
      schema_url: "https://schema.org/numberOfBeds",
      comment_lines: ["The quantity of the given bed type available in the HotelRoom, Suite, House, or Apartment."].freeze,
      ranges: ["Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    type_of_bed: {
      schema_name: "typeOfBed",
      schema_url: "https://schema.org/typeOfBed",
      comment_lines: ["The type of bed to which the BedDetail refers, i.e. the type of bed available in the quantity indicated by quantity."].freeze,
      ranges: ["BedType", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#number_of_bedsObject

The quantity of the given bed type available in the HotelRoom, Suite, House, or Apartment.



37
38
39
# File 'lib/schema_org/mixins/bed_details.rb', line 37

def number_of_beds
  read_property(:number_of_beds)
end

#number_of_beds=(value) ⇒ Object

The quantity of the given bed type available in the HotelRoom, Suite, House, or Apartment.



42
43
44
# File 'lib/schema_org/mixins/bed_details.rb', line 42

def number_of_beds=(value)
  write_property(:number_of_beds, value)
end

#type_of_bedObject

The type of bed to which the BedDetail refers, i.e. the type of bed available in the quantity indicated by quantity.



47
48
49
# File 'lib/schema_org/mixins/bed_details.rb', line 47

def type_of_bed
  read_property(:type_of_bed)
end

#type_of_bed=(value) ⇒ Object

The type of bed to which the BedDetail refers, i.e. the type of bed available in the quantity indicated by quantity.



52
53
54
# File 'lib/schema_org/mixins/bed_details.rb', line 52

def type_of_bed=(value)
  write_property(:type_of_bed, value)
end