Module: SchemaOrg::Mixins::BoatTrip

Includes:
Trip
Included in:
BoatTrip
Defined in:
lib/schema_org/mixins/boat_trip.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Trip

#arrival_time, #arrival_time=, #departure_time, #departure_time=, #itinerary, #itinerary=, #offers, #offers=, #part_of_trip, #part_of_trip=, #provider, #provider=, #sub_trip, #sub_trip=, #trip_origin, #trip_origin=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/schema_org/mixins/boat_trip.rb', line 11

def self.schema_property_definitions
  {
    arrival_boat_terminal: {
      schema_name: "arrivalBoatTerminal",
      schema_url: "https://schema.org/arrivalBoatTerminal",
      comment_lines: ["The terminal or port from which the boat arrives."].freeze,
      ranges: ["BoatTerminal"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    departure_boat_terminal: {
      schema_name: "departureBoatTerminal",
      schema_url: "https://schema.org/departureBoatTerminal",
      comment_lines: ["The terminal or port from which the boat departs."].freeze,
      ranges: ["BoatTerminal"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#arrival_boat_terminalObject

The terminal or port from which the boat arrives.



37
38
39
# File 'lib/schema_org/mixins/boat_trip.rb', line 37

def arrival_boat_terminal
  read_property(:arrival_boat_terminal)
end

#arrival_boat_terminal=(value) ⇒ Object

The terminal or port from which the boat arrives.



42
43
44
# File 'lib/schema_org/mixins/boat_trip.rb', line 42

def arrival_boat_terminal=(value)
  write_property(:arrival_boat_terminal, value)
end

#departure_boat_terminalObject

The terminal or port from which the boat departs.



47
48
49
# File 'lib/schema_org/mixins/boat_trip.rb', line 47

def departure_boat_terminal
  read_property(:departure_boat_terminal)
end

#departure_boat_terminal=(value) ⇒ Object

The terminal or port from which the boat departs.



52
53
54
# File 'lib/schema_org/mixins/boat_trip.rb', line 52

def departure_boat_terminal=(value)
  write_property(:departure_boat_terminal, value)
end