Module: SchemaOrg::Mixins::Brand

Includes:
Intangible
Included in:
Brand
Defined in:
lib/schema_org/mixins/brand.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/schema_org/mixins/brand.rb', line 11

def self.schema_property_definitions
  {
    aggregate_rating: {
      schema_name: "aggregateRating",
      schema_url: "https://schema.org/aggregateRating",
      comment_lines: ["The overall rating, based on a collection of reviews or ratings, of the item."].freeze,
      ranges: ["AggregateRating"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    logo: {
      schema_name: "logo",
      schema_url: "https://schema.org/logo",
      comment_lines: ["An associated logo."].freeze,
      ranges: ["ImageObject", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    review: {
      schema_name: "review",
      schema_url: "https://schema.org/review",
      comment_lines: ["A review of the item."].freeze,
      ranges: ["Review"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["reviews"].freeze
    }.freeze,
    slogan: {
      schema_name: "slogan",
      schema_url: "https://schema.org/slogan",
      comment_lines: ["A slogan or motto associated with the item."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#aggregate_ratingObject

The overall rating, based on a collection of reviews or ratings, of the item.



57
58
59
# File 'lib/schema_org/mixins/brand.rb', line 57

def aggregate_rating
  read_property(:aggregate_rating)
end

#aggregate_rating=(value) ⇒ Object

The overall rating, based on a collection of reviews or ratings, of the item.



62
63
64
# File 'lib/schema_org/mixins/brand.rb', line 62

def aggregate_rating=(value)
  write_property(:aggregate_rating, value)
end

#logoObject

An associated logo.



67
68
69
# File 'lib/schema_org/mixins/brand.rb', line 67

def 
  read_property(:logo)
end

#logo=(value) ⇒ Object

An associated logo.



72
73
74
# File 'lib/schema_org/mixins/brand.rb', line 72

def logo=(value)
  write_property(:logo, value)
end

#reviewObject

A review of the item. Supersedes reviews.



78
79
80
# File 'lib/schema_org/mixins/brand.rb', line 78

def review
  read_property(:review)
end

#review=(value) ⇒ Object

A review of the item. Supersedes reviews.



84
85
86
# File 'lib/schema_org/mixins/brand.rb', line 84

def review=(value)
  write_property(:review, value)
end

#sloganObject

A slogan or motto associated with the item.



89
90
91
# File 'lib/schema_org/mixins/brand.rb', line 89

def slogan
  read_property(:slogan)
end

#slogan=(value) ⇒ Object

A slogan or motto associated with the item.



94
95
96
# File 'lib/schema_org/mixins/brand.rb', line 94

def slogan=(value)
  write_property(:slogan, value)
end