Module: SchemaOrg::Mixins::BroadcastChannel

Includes:
Intangible
Included in:
BroadcastChannel, RadioChannel, TelevisionChannel
Defined in:
lib/schema_org/mixins/broadcast_channel.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/schema_org/mixins/broadcast_channel.rb', line 11

def self.schema_property_definitions
  {
    broadcast_channel_id: {
      schema_name: "broadcastChannelId",
      schema_url: "https://schema.org/broadcastChannelId",
      comment_lines: ["The unique address by which the BroadcastService can be identified in a provider lineup. In US, this is typically a number."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    broadcast_frequency: {
      schema_name: "broadcastFrequency",
      schema_url: "https://schema.org/broadcastFrequency",
      comment_lines: ["The frequency used for over-the-air broadcasts. Numeric values or simple ranges, e.g. 87-99. In addition a shortcut idiom is supported for frequencies of AM and FM radio channels, e.g. \"87 FM\"."].freeze,
      ranges: ["BroadcastFrequencySpecification", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    broadcast_service_tier: {
      schema_name: "broadcastServiceTier",
      schema_url: "https://schema.org/broadcastServiceTier",
      comment_lines: ["The type of service required to have access to the channel (e.g. Standard or Premium)."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    genre: {
      schema_name: "genre",
      schema_url: "https://schema.org/genre",
      comment_lines: ["Genre of the creative work, broadcast channel or group."].freeze,
      ranges: ["DefinedTerm", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    in_broadcast_lineup: {
      schema_name: "inBroadcastLineup",
      schema_url: "https://schema.org/inBroadcastLineup",
      comment_lines: ["The CableOrSatelliteService offering the channel."].freeze,
      ranges: ["CableOrSatelliteService"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    provides_broadcast_service: {
      schema_name: "providesBroadcastService",
      schema_url: "https://schema.org/providesBroadcastService",
      comment_lines: ["The BroadcastService offered on this channel."].freeze,
      ranges: ["BroadcastService"].freeze,
      external_ranges: [].freeze,
      inverse_of: "hasBroadcastChannel",
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#broadcast_channel_idObject

The unique address by which the BroadcastService can be identified in a provider lineup. In US, this is typically a number.



77
78
79
# File 'lib/schema_org/mixins/broadcast_channel.rb', line 77

def broadcast_channel_id
  read_property(:broadcast_channel_id)
end

#broadcast_channel_id=(value) ⇒ Object

The unique address by which the BroadcastService can be identified in a provider lineup. In US, this is typically a number.



82
83
84
# File 'lib/schema_org/mixins/broadcast_channel.rb', line 82

def broadcast_channel_id=(value)
  write_property(:broadcast_channel_id, value)
end

#broadcast_frequencyObject

The frequency used for over-the-air broadcasts. Numeric values or simple ranges, e.g. 87-99. In addition a shortcut idiom is supported for frequencies of AM and FM radio channels, e.g. "87 FM".



87
88
89
# File 'lib/schema_org/mixins/broadcast_channel.rb', line 87

def broadcast_frequency
  read_property(:broadcast_frequency)
end

#broadcast_frequency=(value) ⇒ Object

The frequency used for over-the-air broadcasts. Numeric values or simple ranges, e.g. 87-99. In addition a shortcut idiom is supported for frequencies of AM and FM radio channels, e.g. "87 FM".



92
93
94
# File 'lib/schema_org/mixins/broadcast_channel.rb', line 92

def broadcast_frequency=(value)
  write_property(:broadcast_frequency, value)
end

#broadcast_service_tierObject

The type of service required to have access to the channel (e.g. Standard or Premium).



97
98
99
# File 'lib/schema_org/mixins/broadcast_channel.rb', line 97

def broadcast_service_tier
  read_property(:broadcast_service_tier)
end

#broadcast_service_tier=(value) ⇒ Object

The type of service required to have access to the channel (e.g. Standard or Premium).



102
103
104
# File 'lib/schema_org/mixins/broadcast_channel.rb', line 102

def broadcast_service_tier=(value)
  write_property(:broadcast_service_tier, value)
end

#genreObject

Genre of the creative work, broadcast channel or group.



107
108
109
# File 'lib/schema_org/mixins/broadcast_channel.rb', line 107

def genre
  read_property(:genre)
end

#genre=(value) ⇒ Object

Genre of the creative work, broadcast channel or group.



112
113
114
# File 'lib/schema_org/mixins/broadcast_channel.rb', line 112

def genre=(value)
  write_property(:genre, value)
end

#in_broadcast_lineupObject

The CableOrSatelliteService offering the channel.



117
118
119
# File 'lib/schema_org/mixins/broadcast_channel.rb', line 117

def in_broadcast_lineup
  read_property(:in_broadcast_lineup)
end

#in_broadcast_lineup=(value) ⇒ Object

The CableOrSatelliteService offering the channel.



122
123
124
# File 'lib/schema_org/mixins/broadcast_channel.rb', line 122

def in_broadcast_lineup=(value)
  write_property(:in_broadcast_lineup, value)
end

#provides_broadcast_serviceObject

The BroadcastService offered on this channel. Inverse-property: hasBroadcastChannel.



128
129
130
# File 'lib/schema_org/mixins/broadcast_channel.rb', line 128

def provides_broadcast_service
  read_property(:provides_broadcast_service)
end

#provides_broadcast_service=(value) ⇒ Object

The BroadcastService offered on this channel. Inverse-property: hasBroadcastChannel.



134
135
136
# File 'lib/schema_org/mixins/broadcast_channel.rb', line 134

def provides_broadcast_service=(value)
  write_property(:provides_broadcast_service, value)
end