Module: SchemaOrg::Mixins::Car
Class Method Summary collapse
Instance Method Summary collapse
-
#acriss_code ⇒ Object
The ACRISS Car Classification Code is a code used by many car rental companies, for classifying vehicles.
-
#acriss_code=(value) ⇒ Object
The ACRISS Car Classification Code is a code used by many car rental companies, for classifying vehicles.
-
#roof_load ⇒ Object
The permitted total weight of cargo and installations (e.g. a roof rack) on top of the vehicle.\n\nTypical unit code(s): KGM for kilogram, LBR for pound\n\n* Note 1: You can indicate additional information in the [[name]] of the [[QuantitativeValue]] node.\n* Note 2: You may also link to a [[QualitativeValue]] node that provides additional information using [[valueReference]]\n* Note 3: Note that you can use [[minValue]] and [[maxValue]] to indicate ranges.
-
#roof_load=(value) ⇒ Object
The permitted total weight of cargo and installations (e.g. a roof rack) on top of the vehicle.\n\nTypical unit code(s): KGM for kilogram, LBR for pound\n\n* Note 1: You can indicate additional information in the [[name]] of the [[QuantitativeValue]] node.\n* Note 2: You may also link to a [[QualitativeValue]] node that provides additional information using [[valueReference]]\n* Note 3: Note that you can use [[minValue]] and [[maxValue]] to indicate ranges.
Methods included from Vehicle
#acceleration_time, #acceleration_time=, #body_type, #body_type=, #call_sign, #call_sign=, #cargo_volume, #cargo_volume=, #date_vehicle_first_registered, #date_vehicle_first_registered=, #drive_wheel_configuration, #drive_wheel_configuration=, #emissions_co2, #emissions_co2=, #fuel_capacity, #fuel_capacity=, #fuel_consumption, #fuel_consumption=, #fuel_efficiency, #fuel_efficiency=, #fuel_type, #fuel_type=, #known_vehicle_damages, #known_vehicle_damages=, #meets_emission_standard, #meets_emission_standard=, #mileage_from_odometer, #mileage_from_odometer=, #model_date, #model_date=, #number_of_airbags, #number_of_airbags=, #number_of_axles, #number_of_axles=, #number_of_doors, #number_of_doors=, #number_of_forward_gears, #number_of_forward_gears=, #number_of_previous_owners, #number_of_previous_owners=, #payload, #payload=, #production_date, #production_date=, #purchase_date, #purchase_date=, #seating_capacity, #seating_capacity=, #speed, #speed=, #steering_position, #steering_position=, #stupid_property, #stupid_property=, #tongue_weight, #tongue_weight=, #trailer_weight, #trailer_weight=, #vehicle_configuration, #vehicle_configuration=, #vehicle_engine, #vehicle_engine=, #vehicle_identification_number, #vehicle_identification_number=, #vehicle_interior_color, #vehicle_interior_color=, #vehicle_interior_type, #vehicle_interior_type=, #vehicle_model_date, #vehicle_model_date=, #vehicle_seating_capacity, #vehicle_seating_capacity=, #vehicle_special_usage, #vehicle_special_usage=, #vehicle_transmission, #vehicle_transmission=, #weight_total, #weight_total=, #wheelbase, #wheelbase=
Methods included from Product
#additional_property, #additional_property=, #aggregate_rating, #aggregate_rating=, #asin, #asin=, #audience, #audience=, #award, #award=, #awards, #awards=, #brand, #brand=, #category, #category=, #color, #color=, #color_swatch, #color_swatch=, #country_of_assembly, #country_of_assembly=, #country_of_last_processing, #country_of_last_processing=, #country_of_origin, #country_of_origin=, #depth, #depth=, #display_location, #display_location=, #funding, #funding=, #gtin, #gtin12, #gtin12=, #gtin13, #gtin13=, #gtin14, #gtin14=, #gtin8, #gtin8=, #gtin=, #has_adult_consideration, #has_adult_consideration=, #has_certification, #has_certification=, #has_energy_consumption_details, #has_energy_consumption_details=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_measurement, #has_measurement=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_product_return_policy, #has_product_return_policy=, #height, #height=, #in_product_group_with_id, #in_product_group_with_id=, #is_accessory_or_spare_part_for, #is_accessory_or_spare_part_for=, #is_consumable_for, #is_consumable_for=, #is_family_friendly, #is_family_friendly=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #is_variant_of, #is_variant_of=, #item_condition, #item_condition=, #keywords, #keywords=, #logo, #logo=, #manufacturer, #manufacturer=, #material, #material=, #mobile_url, #mobile_url=, #model, #model=, #mpn, #mpn=, #negative_notes, #negative_notes=, #nsn, #nsn=, #offers, #offers=, #pattern, #pattern=, #positive_notes, #positive_notes=, #product_id, #product_id=, #production_date, #production_date=, #purchase_date, #purchase_date=, #release_date, #release_date=, #review, #review=, #reviews, #reviews=, #size, #size=, #sku, #sku=, #slogan, #slogan=, #weight, #weight=, #width, #width=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/schema_org/mixins/car.rb', line 11 def self.schema_property_definitions { acriss_code: { schema_name: "acrissCode", schema_url: "https://schema.org/acrissCode", comment_lines: ["The ACRISS Car Classification Code is a code used by many car rental companies, for classifying vehicles. ACRISS stands for Association of Car Rental Industry Systems and Standards."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, roof_load: { schema_name: "roofLoad", schema_url: "https://schema.org/roofLoad", comment_lines: ["The permitted total weight of cargo and installations (e.g. a roof rack) on top of the vehicle.\\n\\nTypical unit code(s): KGM for kilogram, LBR for pound\\n\\n* Note 1: You can indicate additional information in the [[name]] of the [[QuantitativeValue]] node.\\n* Note 2: You may also link to a [[QualitativeValue]] node that provides additional information using [[valueReference]]\\n* Note 3: Note that you can use [[minValue]] and [[maxValue]] to indicate ranges."].freeze, ranges: ["QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#acriss_code ⇒ Object
The ACRISS Car Classification Code is a code used by many car rental companies, for classifying vehicles. ACRISS stands for Association of Car Rental Industry Systems and Standards.
37 38 39 |
# File 'lib/schema_org/mixins/car.rb', line 37 def acriss_code read_property(:acriss_code) end |
#acriss_code=(value) ⇒ Object
The ACRISS Car Classification Code is a code used by many car rental companies, for classifying vehicles. ACRISS stands for Association of Car Rental Industry Systems and Standards.
42 43 44 |
# File 'lib/schema_org/mixins/car.rb', line 42 def acriss_code=(value) write_property(:acriss_code, value) end |
#roof_load ⇒ Object
The permitted total weight of cargo and installations (e.g. a roof rack) on top of the vehicle.\n\nTypical unit code(s): KGM for kilogram, LBR for pound\n\n* Note 1: You can indicate additional information in the [[name]] of the [[QuantitativeValue]] node.\n* Note 2: You may also link to a [[QualitativeValue]] node that provides additional information using [[valueReference]]\n* Note 3: Note that you can use [[minValue]] and [[maxValue]] to indicate ranges.
47 48 49 |
# File 'lib/schema_org/mixins/car.rb', line 47 def roof_load read_property(:roof_load) end |
#roof_load=(value) ⇒ Object
The permitted total weight of cargo and installations (e.g. a roof rack) on top of the vehicle.\n\nTypical unit code(s): KGM for kilogram, LBR for pound\n\n* Note 1: You can indicate additional information in the [[name]] of the [[QuantitativeValue]] node.\n* Note 2: You may also link to a [[QualitativeValue]] node that provides additional information using [[valueReference]]\n* Note 3: Note that you can use [[minValue]] and [[maxValue]] to indicate ranges.
52 53 54 |
# File 'lib/schema_org/mixins/car.rb', line 52 def roof_load=(value) write_property(:roof_load, value) end |