Module: SchemaOrg::Mixins::Certification

Includes:
CreativeWork
Included in:
Certification
Defined in:
lib/schema_org/mixins/certification.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from CreativeWork

#abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/schema_org/mixins/certification.rb', line 11

def self.schema_property_definitions
  {
    about: {
      schema_name: "about",
      schema_url: "https://schema.org/about",
      comment_lines: ["The subject matter of an object."].freeze,
      ranges: ["Thing"].freeze,
      external_ranges: [].freeze,
      inverse_of: "subjectOf",
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    audit_date: {
      schema_name: "auditDate",
      schema_url: "https://schema.org/auditDate",
      comment_lines: ["Date when a certification was last audited. See also  [gs1:certificationAuditDate](https://www.gs1.org/voc/certificationAuditDate)."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    certification_identification: {
      schema_name: "certificationIdentification",
      schema_url: "https://schema.org/certificationIdentification",
      comment_lines: ["Identifier of a certification instance (as registered with an independent certification body). Typically this identifier can be used to consult and verify the certification instance. See also [gs1:certificationIdentification](https://www.gs1.org/voc/certificationIdentification)."].freeze,
      ranges: ["DefinedTerm", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    certification_rating: {
      schema_name: "certificationRating",
      schema_url: "https://schema.org/certificationRating",
      comment_lines: ["Rating of a certification instance (as defined by an independent certification body). Typically this rating can be used to rate the level to which the requirements of the certification instance are fulfilled. See also [gs1:certificationValue](https://www.gs1.org/voc/certificationValue)."].freeze,
      ranges: ["Rating"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    certification_status: {
      schema_name: "certificationStatus",
      schema_url: "https://schema.org/certificationStatus",
      comment_lines: ["Indicates the current status of a certification: active or inactive. See also  [gs1:certificationStatus](https://www.gs1.org/voc/certificationStatus)."].freeze,
      ranges: ["CertificationStatusEnumeration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    date_published: {
      schema_name: "datePublished",
      schema_url: "https://schema.org/datePublished",
      comment_lines: ["Date of first publication or broadcast. For example the date a [[CreativeWork]] was broadcast or a [[Certification]] was issued."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    expires: {
      schema_name: "expires",
      schema_url: "https://schema.org/expires",
      comment_lines: ["Date the content expires and is no longer useful or available. For example a [[VideoObject]] or [[NewsArticle]] whose availability or relevance is time-limited, a [[ClaimReview]] fact check whose publisher wants to indicate that it may no longer be relevant (or helpful to highlight) after some date, or a [[Certification]] the validity has expired."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    has_measurement: {
      schema_name: "hasMeasurement",
      schema_url: "https://schema.org/hasMeasurement",
      comment_lines: ["A measurement of an item, For example, the inseam of pants, the wheel size of a bicycle, the gauge of a screw, or the carbon footprint measured for certification by an authority. Usually an exact measurement, but can also be a range of measurements for adjustable products, for example belts and ski bindings."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    issued_by: {
      schema_name: "issuedBy",
      schema_url: "https://schema.org/issuedBy",
      comment_lines: ["The organization issuing the item, for example a [[Permit]], [[Ticket]], or [[Certification]]."].freeze,
      ranges: ["Organization"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    logo: {
      schema_name: "logo",
      schema_url: "https://schema.org/logo",
      comment_lines: ["An associated logo."].freeze,
      ranges: ["ImageObject", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    valid_from: {
      schema_name: "validFrom",
      schema_url: "https://schema.org/validFrom",
      comment_lines: ["The date when the item becomes valid."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    valid_in: {
      schema_name: "validIn",
      schema_url: "https://schema.org/validIn",
      comment_lines: ["The geographic area where the item is valid. Applies for example to a [[Permit]], a [[Certification]], or an [[EducationalOccupationalCredential]]."].freeze,
      ranges: ["AdministrativeArea"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#aboutObject

The subject matter of an object. Inverse-property: subjectOf.



138
139
140
# File 'lib/schema_org/mixins/certification.rb', line 138

def about
  read_property(:about)
end

#about=(value) ⇒ Object

The subject matter of an object. Inverse-property: subjectOf.



144
145
146
# File 'lib/schema_org/mixins/certification.rb', line 144

def about=(value)
  write_property(:about, value)
end

#audit_dateObject

Date when a certification was last audited. See also gs1:certificationAuditDate.



149
150
151
# File 'lib/schema_org/mixins/certification.rb', line 149

def audit_date
  read_property(:audit_date)
end

#audit_date=(value) ⇒ Object

Date when a certification was last audited. See also gs1:certificationAuditDate.



154
155
156
# File 'lib/schema_org/mixins/certification.rb', line 154

def audit_date=(value)
  write_property(:audit_date, value)
end

#certification_identificationObject

Identifier of a certification instance (as registered with an independent certification body). Typically this identifier can be used to consult and verify the certification instance. See also gs1:certificationIdentification.



159
160
161
# File 'lib/schema_org/mixins/certification.rb', line 159

def certification_identification
  read_property(:certification_identification)
end

#certification_identification=(value) ⇒ Object

Identifier of a certification instance (as registered with an independent certification body). Typically this identifier can be used to consult and verify the certification instance. See also gs1:certificationIdentification.



164
165
166
# File 'lib/schema_org/mixins/certification.rb', line 164

def certification_identification=(value)
  write_property(:certification_identification, value)
end

#certification_ratingObject

Rating of a certification instance (as defined by an independent certification body). Typically this rating can be used to rate the level to which the requirements of the certification instance are fulfilled. See also gs1:certificationValue.



169
170
171
# File 'lib/schema_org/mixins/certification.rb', line 169

def certification_rating
  read_property(:certification_rating)
end

#certification_rating=(value) ⇒ Object

Rating of a certification instance (as defined by an independent certification body). Typically this rating can be used to rate the level to which the requirements of the certification instance are fulfilled. See also gs1:certificationValue.



174
175
176
# File 'lib/schema_org/mixins/certification.rb', line 174

def certification_rating=(value)
  write_property(:certification_rating, value)
end

#certification_statusObject

Indicates the current status of a certification: active or inactive. See also gs1:certificationStatus.



179
180
181
# File 'lib/schema_org/mixins/certification.rb', line 179

def certification_status
  read_property(:certification_status)
end

#certification_status=(value) ⇒ Object

Indicates the current status of a certification: active or inactive. See also gs1:certificationStatus.



184
185
186
# File 'lib/schema_org/mixins/certification.rb', line 184

def certification_status=(value)
  write_property(:certification_status, value)
end

#date_publishedObject

Date of first publication or broadcast. For example the date a [[CreativeWork]] was broadcast or a [[Certification]] was issued.



189
190
191
# File 'lib/schema_org/mixins/certification.rb', line 189

def date_published
  read_property(:date_published)
end

#date_published=(value) ⇒ Object

Date of first publication or broadcast. For example the date a [[CreativeWork]] was broadcast or a [[Certification]] was issued.



194
195
196
# File 'lib/schema_org/mixins/certification.rb', line 194

def date_published=(value)
  write_property(:date_published, value)
end

#expiresObject

Date the content expires and is no longer useful or available. For example a [[VideoObject]] or [[NewsArticle]] whose availability or relevance is time-limited, a [[ClaimReview]] fact check whose publisher wants to indicate that it may no longer be relevant (or helpful to highlight) after some date, or a [[Certification]] the validity has expired.



199
200
201
# File 'lib/schema_org/mixins/certification.rb', line 199

def expires
  read_property(:expires)
end

#expires=(value) ⇒ Object

Date the content expires and is no longer useful or available. For example a [[VideoObject]] or [[NewsArticle]] whose availability or relevance is time-limited, a [[ClaimReview]] fact check whose publisher wants to indicate that it may no longer be relevant (or helpful to highlight) after some date, or a [[Certification]] the validity has expired.



204
205
206
# File 'lib/schema_org/mixins/certification.rb', line 204

def expires=(value)
  write_property(:expires, value)
end

#has_measurementObject

A measurement of an item, For example, the inseam of pants, the wheel size of a bicycle, the gauge of a screw, or the carbon footprint measured for certification by an authority. Usually an exact measurement, but can also be a range of measurements for adjustable products, for example belts and ski bindings.



209
210
211
# File 'lib/schema_org/mixins/certification.rb', line 209

def has_measurement
  read_property(:has_measurement)
end

#has_measurement=(value) ⇒ Object

A measurement of an item, For example, the inseam of pants, the wheel size of a bicycle, the gauge of a screw, or the carbon footprint measured for certification by an authority. Usually an exact measurement, but can also be a range of measurements for adjustable products, for example belts and ski bindings.



214
215
216
# File 'lib/schema_org/mixins/certification.rb', line 214

def has_measurement=(value)
  write_property(:has_measurement, value)
end

#issued_byObject

The organization issuing the item, for example a [[Permit]], [[Ticket]], or [[Certification]].



219
220
221
# File 'lib/schema_org/mixins/certification.rb', line 219

def issued_by
  read_property(:issued_by)
end

#issued_by=(value) ⇒ Object

The organization issuing the item, for example a [[Permit]], [[Ticket]], or [[Certification]].



224
225
226
# File 'lib/schema_org/mixins/certification.rb', line 224

def issued_by=(value)
  write_property(:issued_by, value)
end

#logoObject

An associated logo.



229
230
231
# File 'lib/schema_org/mixins/certification.rb', line 229

def 
  read_property(:logo)
end

#logo=(value) ⇒ Object

An associated logo.



234
235
236
# File 'lib/schema_org/mixins/certification.rb', line 234

def logo=(value)
  write_property(:logo, value)
end

#valid_fromObject

The date when the item becomes valid.



239
240
241
# File 'lib/schema_org/mixins/certification.rb', line 239

def valid_from
  read_property(:valid_from)
end

#valid_from=(value) ⇒ Object

The date when the item becomes valid.



244
245
246
# File 'lib/schema_org/mixins/certification.rb', line 244

def valid_from=(value)
  write_property(:valid_from, value)
end

#valid_inObject

The geographic area where the item is valid. Applies for example to a [[Permit]], a [[Certification]], or an [[EducationalOccupationalCredential]].



249
250
251
# File 'lib/schema_org/mixins/certification.rb', line 249

def valid_in
  read_property(:valid_in)
end

#valid_in=(value) ⇒ Object

The geographic area where the item is valid. Applies for example to a [[Permit]], a [[Certification]], or an [[EducationalOccupationalCredential]].



254
255
256
# File 'lib/schema_org/mixins/certification.rb', line 254

def valid_in=(value)
  write_property(:valid_in, value)
end