Module: SchemaOrg::Mixins::Clip

Includes:
CreativeWork
Included in:
Clip, MovieClip, RadioClip, TVClip, VideoGameClip
Defined in:
lib/schema_org/mixins/clip.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from CreativeWork

#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/schema_org/mixins/clip.rb', line 11

def self.schema_property_definitions
  {
    actor: {
      schema_name: "actor",
      schema_url: "https://schema.org/actor",
      comment_lines: ["An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip."].freeze,
      ranges: ["PerformingGroup", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["actors"].freeze
    }.freeze,
    actors: {
      schema_name: "actors",
      schema_url: "https://schema.org/actors",
      comment_lines: ["An actor, e.g. in TV, radio, movie, video games etc. Actors can be associated with individual items or with a series, episode, clip."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "actor",
      supersedes: nil
    }.freeze,
    clip_number: {
      schema_name: "clipNumber",
      schema_url: "https://schema.org/clipNumber",
      comment_lines: ["Position of the clip within an ordered group of clips."].freeze,
      ranges: ["Integer", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    director: {
      schema_name: "director",
      schema_url: "https://schema.org/director",
      comment_lines: ["A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["directors"].freeze
    }.freeze,
    directors: {
      schema_name: "directors",
      schema_url: "https://schema.org/directors",
      comment_lines: ["A director of e.g. TV, radio, movie, video games etc. content. Directors can be associated with individual items or with a series, episode, clip."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "director",
      supersedes: nil
    }.freeze,
    end_offset: {
      schema_name: "endOffset",
      schema_url: "https://schema.org/endOffset",
      comment_lines: ["The end time of the clip expressed as the number of seconds from the beginning of the work."].freeze,
      ranges: ["HyperTocEntry", "Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    music_by: {
      schema_name: "musicBy",
      schema_url: "https://schema.org/musicBy",
      comment_lines: ["The composer of the soundtrack."].freeze,
      ranges: ["MusicGroup", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    part_of_episode: {
      schema_name: "partOfEpisode",
      schema_url: "https://schema.org/partOfEpisode",
      comment_lines: ["The episode to which this clip belongs."].freeze,
      ranges: ["Episode"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    part_of_season: {
      schema_name: "partOfSeason",
      schema_url: "https://schema.org/partOfSeason",
      comment_lines: ["The season to which this episode belongs."].freeze,
      ranges: ["CreativeWorkSeason"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    part_of_series: {
      schema_name: "partOfSeries",
      schema_url: "https://schema.org/partOfSeries",
      comment_lines: ["The series to which this episode or season belongs."].freeze,
      ranges: ["CreativeWorkSeries"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["partOfTVSeries"].freeze
    }.freeze,
    start_offset: {
      schema_name: "startOffset",
      schema_url: "https://schema.org/startOffset",
      comment_lines: ["The start time of the clip expressed as the number of seconds from the beginning of the work."].freeze,
      ranges: ["HyperTocEntry", "Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#actorObject

An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip. Supersedes actors.



128
129
130
# File 'lib/schema_org/mixins/clip.rb', line 128

def actor
  read_property(:actor)
end

#actor=(value) ⇒ Object

An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip. Supersedes actors.



134
135
136
# File 'lib/schema_org/mixins/clip.rb', line 134

def actor=(value)
  write_property(:actor, value)
end

#actorsObject

An actor, e.g. in TV, radio, movie, video games etc. Actors can be associated with individual items or with a series, episode, clip. Superseded by actor.



140
141
142
# File 'lib/schema_org/mixins/clip.rb', line 140

def actors
  read_property(:actors)
end

#actors=(value) ⇒ Object

An actor, e.g. in TV, radio, movie, video games etc. Actors can be associated with individual items or with a series, episode, clip. Superseded by actor.



146
147
148
# File 'lib/schema_org/mixins/clip.rb', line 146

def actors=(value)
  write_property(:actors, value)
end

#clip_numberObject

Position of the clip within an ordered group of clips.



151
152
153
# File 'lib/schema_org/mixins/clip.rb', line 151

def clip_number
  read_property(:clip_number)
end

#clip_number=(value) ⇒ Object

Position of the clip within an ordered group of clips.



156
157
158
# File 'lib/schema_org/mixins/clip.rb', line 156

def clip_number=(value)
  write_property(:clip_number, value)
end

#directorObject

A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip. Supersedes directors.



162
163
164
# File 'lib/schema_org/mixins/clip.rb', line 162

def director
  read_property(:director)
end

#director=(value) ⇒ Object

A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip. Supersedes directors.



168
169
170
# File 'lib/schema_org/mixins/clip.rb', line 168

def director=(value)
  write_property(:director, value)
end

#directorsObject

A director of e.g. TV, radio, movie, video games etc. content. Directors can be associated with individual items or with a series, episode, clip. Superseded by director.



174
175
176
# File 'lib/schema_org/mixins/clip.rb', line 174

def directors
  read_property(:directors)
end

#directors=(value) ⇒ Object

A director of e.g. TV, radio, movie, video games etc. content. Directors can be associated with individual items or with a series, episode, clip. Superseded by director.



180
181
182
# File 'lib/schema_org/mixins/clip.rb', line 180

def directors=(value)
  write_property(:directors, value)
end

#end_offsetObject

The end time of the clip expressed as the number of seconds from the beginning of the work.



185
186
187
# File 'lib/schema_org/mixins/clip.rb', line 185

def end_offset
  read_property(:end_offset)
end

#end_offset=(value) ⇒ Object

The end time of the clip expressed as the number of seconds from the beginning of the work.



190
191
192
# File 'lib/schema_org/mixins/clip.rb', line 190

def end_offset=(value)
  write_property(:end_offset, value)
end

#music_byObject

The composer of the soundtrack.



195
196
197
# File 'lib/schema_org/mixins/clip.rb', line 195

def music_by
  read_property(:music_by)
end

#music_by=(value) ⇒ Object

The composer of the soundtrack.



200
201
202
# File 'lib/schema_org/mixins/clip.rb', line 200

def music_by=(value)
  write_property(:music_by, value)
end

#part_of_episodeObject

The episode to which this clip belongs.



205
206
207
# File 'lib/schema_org/mixins/clip.rb', line 205

def part_of_episode
  read_property(:part_of_episode)
end

#part_of_episode=(value) ⇒ Object

The episode to which this clip belongs.



210
211
212
# File 'lib/schema_org/mixins/clip.rb', line 210

def part_of_episode=(value)
  write_property(:part_of_episode, value)
end

#part_of_seasonObject

The season to which this episode belongs.



215
216
217
# File 'lib/schema_org/mixins/clip.rb', line 215

def part_of_season
  read_property(:part_of_season)
end

#part_of_season=(value) ⇒ Object

The season to which this episode belongs.



220
221
222
# File 'lib/schema_org/mixins/clip.rb', line 220

def part_of_season=(value)
  write_property(:part_of_season, value)
end

#part_of_seriesObject

The series to which this episode or season belongs. Supersedes partOfTVSeries.



226
227
228
# File 'lib/schema_org/mixins/clip.rb', line 226

def part_of_series
  read_property(:part_of_series)
end

#part_of_series=(value) ⇒ Object

The series to which this episode or season belongs. Supersedes partOfTVSeries.



232
233
234
# File 'lib/schema_org/mixins/clip.rb', line 232

def part_of_series=(value)
  write_property(:part_of_series, value)
end

#start_offsetObject

The start time of the clip expressed as the number of seconds from the beginning of the work.



237
238
239
# File 'lib/schema_org/mixins/clip.rb', line 237

def start_offset
  read_property(:start_offset)
end

#start_offset=(value) ⇒ Object

The start time of the clip expressed as the number of seconds from the beginning of the work.



242
243
244
# File 'lib/schema_org/mixins/clip.rb', line 242

def start_offset=(value)
  write_property(:start_offset, value)
end