Module: SchemaOrg::Mixins::CommunicateAction

Includes:
InteractAction
Included in:
CommunicateAction, AskAction, CheckInAction, CheckOutAction, CommentAction, InformAction, InviteAction, ReplyAction, ShareAction
Defined in:
lib/schema_org/mixins/communicate_action.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Action

#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, #start_time, #start_time=, #target, #target=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/schema_org/mixins/communicate_action.rb', line 11

def self.schema_property_definitions
  {
    about: {
      schema_name: "about",
      schema_url: "https://schema.org/about",
      comment_lines: ["The subject matter of an object."].freeze,
      ranges: ["Thing"].freeze,
      external_ranges: [].freeze,
      inverse_of: "subjectOf",
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    in_language: {
      schema_name: "inLanguage",
      schema_url: "https://schema.org/inLanguage",
      comment_lines: ["The language of the content or performance or used in an action. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[availableLanguage]]."].freeze,
      ranges: ["Language", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["language"].freeze
    }.freeze,
    language: {
      schema_name: "language",
      schema_url: "https://schema.org/language",
      comment_lines: ["A sub property of instrument. The language used on this action."].freeze,
      ranges: ["Language"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "inLanguage",
      supersedes: nil
    }.freeze,
    recipient: {
      schema_name: "recipient",
      schema_url: "https://schema.org/recipient",
      comment_lines: ["A sub property of participant. The participant who is at the receiving end of the action."].freeze,
      ranges: ["Audience", "ContactPoint", "Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#aboutObject

The subject matter of an object. Inverse-property: subjectOf.



58
59
60
# File 'lib/schema_org/mixins/communicate_action.rb', line 58

def about
  read_property(:about)
end

#about=(value) ⇒ Object

The subject matter of an object. Inverse-property: subjectOf.



64
65
66
# File 'lib/schema_org/mixins/communicate_action.rb', line 64

def about=(value)
  write_property(:about, value)
end

#in_languageObject

The language of the content or performance or used in an action. Please use one of the language codes from the IETF BCP 47 standard. See also [[availableLanguage]]. Supersedes language.



70
71
72
# File 'lib/schema_org/mixins/communicate_action.rb', line 70

def in_language
  read_property(:in_language)
end

#in_language=(value) ⇒ Object

The language of the content or performance or used in an action. Please use one of the language codes from the IETF BCP 47 standard. See also [[availableLanguage]]. Supersedes language.



76
77
78
# File 'lib/schema_org/mixins/communicate_action.rb', line 76

def in_language=(value)
  write_property(:in_language, value)
end

#languageObject

A sub property of instrument. The language used on this action. Superseded by inLanguage.



82
83
84
# File 'lib/schema_org/mixins/communicate_action.rb', line 82

def language
  read_property(:language)
end

#language=(value) ⇒ Object

A sub property of instrument. The language used on this action. Superseded by inLanguage.



88
89
90
# File 'lib/schema_org/mixins/communicate_action.rb', line 88

def language=(value)
  write_property(:language, value)
end

#recipientObject

A sub property of participant. The participant who is at the receiving end of the action.



93
94
95
# File 'lib/schema_org/mixins/communicate_action.rb', line 93

def recipient
  read_property(:recipient)
end

#recipient=(value) ⇒ Object

A sub property of participant. The participant who is at the receiving end of the action.



98
99
100
# File 'lib/schema_org/mixins/communicate_action.rb', line 98

def recipient=(value)
  write_property(:recipient, value)
end