Module: SchemaOrg::Mixins::CompoundPriceSpecification

Includes:
PriceSpecification
Included in:
CompoundPriceSpecification
Defined in:
lib/schema_org/mixins/compound_price_specification.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from PriceSpecification

#eligible_quantity, #eligible_quantity=, #eligible_transaction_volume, #eligible_transaction_volume=, #max_price, #max_price=, #membership_points_earned, #membership_points_earned=, #min_price, #min_price=, #price, #price=, #price_currency, #price_currency=, #valid_for_member_tier, #valid_for_member_tier=, #valid_from, #valid_from=, #valid_through, #valid_through=, #value_added_tax_included, #value_added_tax_included=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/schema_org/mixins/compound_price_specification.rb', line 11

def self.schema_property_definitions
  {
    price_component: {
      schema_name: "priceComponent",
      schema_url: "https://schema.org/priceComponent",
      comment_lines: ["This property links to all [[UnitPriceSpecification]] nodes that apply in parallel for the [[CompoundPriceSpecification]] node."].freeze,
      ranges: ["PriceSpecification"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    price_type: {
      schema_name: "priceType",
      schema_url: "https://schema.org/priceType",
      comment_lines: ["Defines the type of a price specified for an offered product, for example a list price, a (temporary) sale price or a manufacturer suggested retail price. If multiple prices are specified for an offer the [[priceType]] property can be used to identify the type of each such specified price. The value of priceType can be specified as a value from enumeration PriceTypeEnumeration or, a UN/EDIFACT 5387 code, or as a free form text string for price types that are not already predefined in PriceTypeEnumeration."].freeze,
      ranges: ["PriceTypeEnumeration", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#price_componentObject

This property links to all [[UnitPriceSpecification]] nodes that apply in parallel for the [[CompoundPriceSpecification]] node.



37
38
39
# File 'lib/schema_org/mixins/compound_price_specification.rb', line 37

def price_component
  read_property(:price_component)
end

#price_component=(value) ⇒ Object

This property links to all [[UnitPriceSpecification]] nodes that apply in parallel for the [[CompoundPriceSpecification]] node.



42
43
44
# File 'lib/schema_org/mixins/compound_price_specification.rb', line 42

def price_component=(value)
  write_property(:price_component, value)
end

#price_typeObject

Defines the type of a price specified for an offered product, for example a list price, a (temporary) sale price or a manufacturer suggested retail price. If multiple prices are specified for an offer the [[priceType]] property can be used to identify the type of each such specified price. The value of priceType can be specified as a value from enumeration PriceTypeEnumeration or, a UN/EDIFACT 5387 code, or as a free form text string for price types that are not already predefined in PriceTypeEnumeration.



47
48
49
# File 'lib/schema_org/mixins/compound_price_specification.rb', line 47

def price_type
  read_property(:price_type)
end

#price_type=(value) ⇒ Object

Defines the type of a price specified for an offered product, for example a list price, a (temporary) sale price or a manufacturer suggested retail price. If multiple prices are specified for an offer the [[priceType]] property can be used to identify the type of each such specified price. The value of priceType can be specified as a value from enumeration PriceTypeEnumeration or, a UN/EDIFACT 5387 code, or as a free form text string for price types that are not already predefined in PriceTypeEnumeration.



52
53
54
# File 'lib/schema_org/mixins/compound_price_specification.rb', line 52

def price_type=(value)
  write_property(:price_type, value)
end