Module: SchemaOrg::Mixins::ContactPoint

Includes:
StructuredValue
Included in:
ContactPoint, PostalAddress
Defined in:
lib/schema_org/mixins/contact_point.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/schema_org/mixins/contact_point.rb', line 11

def self.schema_property_definitions
  {
    area_served: {
      schema_name: "areaServed",
      schema_url: "https://schema.org/areaServed",
      comment_lines: ["The geographic area where a service or offered item is provided."].freeze,
      ranges: ["AdministrativeArea", "GeoShape", "Place", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["serviceArea"].freeze
    }.freeze,
    available_language: {
      schema_name: "availableLanguage",
      schema_url: "https://schema.org/availableLanguage",
      comment_lines: ["A language someone may use with or at the item, service or place. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[inLanguage]]."].freeze,
      ranges: ["Language", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    contact_option: {
      schema_name: "contactOption",
      schema_url: "https://schema.org/contactOption",
      comment_lines: ["An option available on this contact point (e.g. a toll-free number or support for hearing-impaired callers)."].freeze,
      ranges: ["ContactPointOption"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    contact_type: {
      schema_name: "contactType",
      schema_url: "https://schema.org/contactType",
      comment_lines: ["A person or organization can have different contact points, for different purposes. For example, a sales contact point, a PR contact point and so on. This property is used to specify the kind of contact point."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    email: {
      schema_name: "email",
      schema_url: "https://schema.org/email",
      comment_lines: ["Email address."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    fax_number: {
      schema_name: "faxNumber",
      schema_url: "https://schema.org/faxNumber",
      comment_lines: ["The fax number."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    hours_available: {
      schema_name: "hoursAvailable",
      schema_url: "https://schema.org/hoursAvailable",
      comment_lines: ["The hours during which this service or contact is available."].freeze,
      ranges: ["OpeningHoursSpecification"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    product_supported: {
      schema_name: "productSupported",
      schema_url: "https://schema.org/productSupported",
      comment_lines: ["The product or service this support contact point is related to (such as product support for a particular product line). This can be a specific product or product line (e.g. \"iPhone\") or a general category of products or services (e.g. \"smartphones\")."].freeze,
      ranges: ["Product", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    service_area: {
      schema_name: "serviceArea",
      schema_url: "https://schema.org/serviceArea",
      comment_lines: ["The geographic area where the service is provided."].freeze,
      ranges: ["AdministrativeArea", "GeoShape", "Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "areaServed",
      supersedes: ["area"].freeze
    }.freeze,
    telephone: {
      schema_name: "telephone",
      schema_url: "https://schema.org/telephone",
      comment_lines: ["The telephone number."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#area_servedObject

The geographic area where a service or offered item is provided. Supersedes serviceArea.



118
119
120
# File 'lib/schema_org/mixins/contact_point.rb', line 118

def area_served
  read_property(:area_served)
end

#area_served=(value) ⇒ Object

The geographic area where a service or offered item is provided. Supersedes serviceArea.



124
125
126
# File 'lib/schema_org/mixins/contact_point.rb', line 124

def area_served=(value)
  write_property(:area_served, value)
end

#available_languageObject

A language someone may use with or at the item, service or place. Please use one of the language codes from the IETF BCP 47 standard. See also [[inLanguage]].



129
130
131
# File 'lib/schema_org/mixins/contact_point.rb', line 129

def available_language
  read_property(:available_language)
end

#available_language=(value) ⇒ Object

A language someone may use with or at the item, service or place. Please use one of the language codes from the IETF BCP 47 standard. See also [[inLanguage]].



134
135
136
# File 'lib/schema_org/mixins/contact_point.rb', line 134

def available_language=(value)
  write_property(:available_language, value)
end

#contact_optionObject

An option available on this contact point (e.g. a toll-free number or support for hearing-impaired callers).



139
140
141
# File 'lib/schema_org/mixins/contact_point.rb', line 139

def contact_option
  read_property(:contact_option)
end

#contact_option=(value) ⇒ Object

An option available on this contact point (e.g. a toll-free number or support for hearing-impaired callers).



144
145
146
# File 'lib/schema_org/mixins/contact_point.rb', line 144

def contact_option=(value)
  write_property(:contact_option, value)
end

#contact_typeObject

A person or organization can have different contact points, for different purposes. For example, a sales contact point, a PR contact point and so on. This property is used to specify the kind of contact point.



149
150
151
# File 'lib/schema_org/mixins/contact_point.rb', line 149

def contact_type
  read_property(:contact_type)
end

#contact_type=(value) ⇒ Object

A person or organization can have different contact points, for different purposes. For example, a sales contact point, a PR contact point and so on. This property is used to specify the kind of contact point.



154
155
156
# File 'lib/schema_org/mixins/contact_point.rb', line 154

def contact_type=(value)
  write_property(:contact_type, value)
end

#emailObject

Email address.



159
160
161
# File 'lib/schema_org/mixins/contact_point.rb', line 159

def email
  read_property(:email)
end

#email=(value) ⇒ Object

Email address.



164
165
166
# File 'lib/schema_org/mixins/contact_point.rb', line 164

def email=(value)
  write_property(:email, value)
end

#fax_numberObject

The fax number.



169
170
171
# File 'lib/schema_org/mixins/contact_point.rb', line 169

def fax_number
  read_property(:fax_number)
end

#fax_number=(value) ⇒ Object

The fax number.



174
175
176
# File 'lib/schema_org/mixins/contact_point.rb', line 174

def fax_number=(value)
  write_property(:fax_number, value)
end

#hours_availableObject

The hours during which this service or contact is available.



179
180
181
# File 'lib/schema_org/mixins/contact_point.rb', line 179

def hours_available
  read_property(:hours_available)
end

#hours_available=(value) ⇒ Object

The hours during which this service or contact is available.



184
185
186
# File 'lib/schema_org/mixins/contact_point.rb', line 184

def hours_available=(value)
  write_property(:hours_available, value)
end

#product_supportedObject

The product or service this support contact point is related to (such as product support for a particular product line). This can be a specific product or product line (e.g. "iPhone") or a general category of products or services (e.g. "smartphones").



189
190
191
# File 'lib/schema_org/mixins/contact_point.rb', line 189

def product_supported
  read_property(:product_supported)
end

#product_supported=(value) ⇒ Object

The product or service this support contact point is related to (such as product support for a particular product line). This can be a specific product or product line (e.g. "iPhone") or a general category of products or services (e.g. "smartphones").



194
195
196
# File 'lib/schema_org/mixins/contact_point.rb', line 194

def product_supported=(value)
  write_property(:product_supported, value)
end

#service_areaObject

The geographic area where the service is provided. Supersedes area. Superseded by areaServed.



201
202
203
# File 'lib/schema_org/mixins/contact_point.rb', line 201

def service_area
  read_property(:service_area)
end

#service_area=(value) ⇒ Object

The geographic area where the service is provided. Supersedes area. Superseded by areaServed.



208
209
210
# File 'lib/schema_org/mixins/contact_point.rb', line 208

def service_area=(value)
  write_property(:service_area, value)
end

#telephoneObject

The telephone number.



213
214
215
# File 'lib/schema_org/mixins/contact_point.rb', line 213

def telephone
  read_property(:telephone)
end

#telephone=(value) ⇒ Object

The telephone number.



218
219
220
# File 'lib/schema_org/mixins/contact_point.rb', line 218

def telephone=(value)
  write_property(:telephone, value)
end