Module: SchemaOrg::Mixins::Course

Includes:
CreativeWork, LearningResource
Included in:
Course
Defined in:
lib/schema_org/mixins/course.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from LearningResource

#assesses, #assesses=, #competency_required, #competency_required=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #learning_resource_type, #learning_resource_type=, #teaches, #teaches=

Methods included from CreativeWork

#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/schema_org/mixins/course.rb', line 12

def self.schema_property_definitions
  {
    available_language: {
      schema_name: "availableLanguage",
      schema_url: "https://schema.org/availableLanguage",
      comment_lines: ["A language someone may use with or at the item, service or place. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[inLanguage]]."].freeze,
      ranges: ["Language", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    course_code: {
      schema_name: "courseCode",
      schema_url: "https://schema.org/courseCode",
      comment_lines: ["The identifier for the [[Course]] used by the course [[provider]] (e.g. CS101 or 6.001)."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    course_prerequisites: {
      schema_name: "coursePrerequisites",
      schema_url: "https://schema.org/coursePrerequisites",
      comment_lines: ["Requirements for taking the Course. May be completion of another [[Course]] or a textual description like \"permission of instructor\". Requirements may be a pre-requisite competency, referenced using [[AlignmentObject]]."].freeze,
      ranges: ["AlignmentObject", "Course", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    educational_credential_awarded: {
      schema_name: "educationalCredentialAwarded",
      schema_url: "https://schema.org/educationalCredentialAwarded",
      comment_lines: ["A description of the qualification, award, certificate, diploma or other educational credential awarded as a consequence of successful completion of this course or program."].freeze,
      ranges: ["EducationalOccupationalCredential", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    financial_aid_eligible: {
      schema_name: "financialAidEligible",
      schema_url: "https://schema.org/financialAidEligible",
      comment_lines: ["A financial aid type or program which students may use to pay for tuition or fees associated with the program."].freeze,
      ranges: ["DefinedTerm", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    has_course_instance: {
      schema_name: "hasCourseInstance",
      schema_url: "https://schema.org/hasCourseInstance",
      comment_lines: ["An offering of the course at a specific time and place or through specific media or mode of study or to a specific section of students."].freeze,
      ranges: ["CourseInstance"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    number_of_credits: {
      schema_name: "numberOfCredits",
      schema_url: "https://schema.org/numberOfCredits",
      comment_lines: ["The number of credits or units awarded by a Course or required to complete an EducationalOccupationalProgram."].freeze,
      ranges: ["Integer", "StructuredValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    occupational_credential_awarded: {
      schema_name: "occupationalCredentialAwarded",
      schema_url: "https://schema.org/occupationalCredentialAwarded",
      comment_lines: ["A description of the qualification, award, certificate, diploma or other occupational credential awarded as a consequence of successful completion of this course or program."].freeze,
      ranges: ["EducationalOccupationalCredential", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    syllabus_sections: {
      schema_name: "syllabusSections",
      schema_url: "https://schema.org/syllabusSections",
      comment_lines: ["Indicates (typically several) Syllabus entities that lay out what each section of the overall course will cover."].freeze,
      ranges: ["Syllabus"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    total_historical_enrollment: {
      schema_name: "totalHistoricalEnrollment",
      schema_url: "https://schema.org/totalHistoricalEnrollment",
      comment_lines: ["The total number of students that have enrolled in the history of the course."].freeze,
      ranges: ["Integer"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#available_languageObject

A language someone may use with or at the item, service or place. Please use one of the language codes from the IETF BCP 47 standard. See also [[inLanguage]].



118
119
120
# File 'lib/schema_org/mixins/course.rb', line 118

def available_language
  read_property(:available_language)
end

#available_language=(value) ⇒ Object

A language someone may use with or at the item, service or place. Please use one of the language codes from the IETF BCP 47 standard. See also [[inLanguage]].



123
124
125
# File 'lib/schema_org/mixins/course.rb', line 123

def available_language=(value)
  write_property(:available_language, value)
end

#course_codeObject

The identifier for the [[Course]] used by the course [[provider]] (e.g. CS101 or 6.001).



128
129
130
# File 'lib/schema_org/mixins/course.rb', line 128

def course_code
  read_property(:course_code)
end

#course_code=(value) ⇒ Object

The identifier for the [[Course]] used by the course [[provider]] (e.g. CS101 or 6.001).



133
134
135
# File 'lib/schema_org/mixins/course.rb', line 133

def course_code=(value)
  write_property(:course_code, value)
end

#course_prerequisitesObject

Requirements for taking the Course. May be completion of another [[Course]] or a textual description like "permission of instructor". Requirements may be a pre-requisite competency, referenced using [[AlignmentObject]].



138
139
140
# File 'lib/schema_org/mixins/course.rb', line 138

def course_prerequisites
  read_property(:course_prerequisites)
end

#course_prerequisites=(value) ⇒ Object

Requirements for taking the Course. May be completion of another [[Course]] or a textual description like "permission of instructor". Requirements may be a pre-requisite competency, referenced using [[AlignmentObject]].



143
144
145
# File 'lib/schema_org/mixins/course.rb', line 143

def course_prerequisites=(value)
  write_property(:course_prerequisites, value)
end

#educational_credential_awardedObject

A description of the qualification, award, certificate, diploma or other educational credential awarded as a consequence of successful completion of this course or program.



148
149
150
# File 'lib/schema_org/mixins/course.rb', line 148

def educational_credential_awarded
  read_property(:educational_credential_awarded)
end

#educational_credential_awarded=(value) ⇒ Object

A description of the qualification, award, certificate, diploma or other educational credential awarded as a consequence of successful completion of this course or program.



153
154
155
# File 'lib/schema_org/mixins/course.rb', line 153

def educational_credential_awarded=(value)
  write_property(:educational_credential_awarded, value)
end

#financial_aid_eligibleObject

A financial aid type or program which students may use to pay for tuition or fees associated with the program.



158
159
160
# File 'lib/schema_org/mixins/course.rb', line 158

def financial_aid_eligible
  read_property(:financial_aid_eligible)
end

#financial_aid_eligible=(value) ⇒ Object

A financial aid type or program which students may use to pay for tuition or fees associated with the program.



163
164
165
# File 'lib/schema_org/mixins/course.rb', line 163

def financial_aid_eligible=(value)
  write_property(:financial_aid_eligible, value)
end

#has_course_instanceObject

An offering of the course at a specific time and place or through specific media or mode of study or to a specific section of students.



168
169
170
# File 'lib/schema_org/mixins/course.rb', line 168

def has_course_instance
  read_property(:has_course_instance)
end

#has_course_instance=(value) ⇒ Object

An offering of the course at a specific time and place or through specific media or mode of study or to a specific section of students.



173
174
175
# File 'lib/schema_org/mixins/course.rb', line 173

def has_course_instance=(value)
  write_property(:has_course_instance, value)
end

#number_of_creditsObject

The number of credits or units awarded by a Course or required to complete an EducationalOccupationalProgram.



178
179
180
# File 'lib/schema_org/mixins/course.rb', line 178

def number_of_credits
  read_property(:number_of_credits)
end

#number_of_credits=(value) ⇒ Object

The number of credits or units awarded by a Course or required to complete an EducationalOccupationalProgram.



183
184
185
# File 'lib/schema_org/mixins/course.rb', line 183

def number_of_credits=(value)
  write_property(:number_of_credits, value)
end

#occupational_credential_awardedObject

A description of the qualification, award, certificate, diploma or other occupational credential awarded as a consequence of successful completion of this course or program.



188
189
190
# File 'lib/schema_org/mixins/course.rb', line 188

def occupational_credential_awarded
  read_property(:occupational_credential_awarded)
end

#occupational_credential_awarded=(value) ⇒ Object

A description of the qualification, award, certificate, diploma or other occupational credential awarded as a consequence of successful completion of this course or program.



193
194
195
# File 'lib/schema_org/mixins/course.rb', line 193

def occupational_credential_awarded=(value)
  write_property(:occupational_credential_awarded, value)
end

#syllabus_sectionsObject

Indicates (typically several) Syllabus entities that lay out what each section of the overall course will cover.



198
199
200
# File 'lib/schema_org/mixins/course.rb', line 198

def syllabus_sections
  read_property(:syllabus_sections)
end

#syllabus_sections=(value) ⇒ Object

Indicates (typically several) Syllabus entities that lay out what each section of the overall course will cover.



203
204
205
# File 'lib/schema_org/mixins/course.rb', line 203

def syllabus_sections=(value)
  write_property(:syllabus_sections, value)
end

#total_historical_enrollmentObject

The total number of students that have enrolled in the history of the course.



208
209
210
# File 'lib/schema_org/mixins/course.rb', line 208

def total_historical_enrollment
  read_property(:total_historical_enrollment)
end

#total_historical_enrollment=(value) ⇒ Object

The total number of students that have enrolled in the history of the course.



213
214
215
# File 'lib/schema_org/mixins/course.rb', line 213

def total_historical_enrollment=(value)
  write_property(:total_historical_enrollment, value)
end