Module: SchemaOrg::Mixins::CreativeWorkSeason

Includes:
CreativeWork
Included in:
CreativeWorkSeason, PodcastSeason, RadioSeason, TVSeason
Defined in:
lib/schema_org/mixins/creative_work_season.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from CreativeWork

#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/schema_org/mixins/creative_work_season.rb', line 11

def self.schema_property_definitions
  {
    actor: {
      schema_name: "actor",
      schema_url: "https://schema.org/actor",
      comment_lines: ["An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip."].freeze,
      ranges: ["PerformingGroup", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["actors"].freeze
    }.freeze,
    director: {
      schema_name: "director",
      schema_url: "https://schema.org/director",
      comment_lines: ["A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["directors"].freeze
    }.freeze,
    end_date: {
      schema_name: "endDate",
      schema_url: "https://schema.org/endDate",
      comment_lines: ["The end date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601))."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    episode: {
      schema_name: "episode",
      schema_url: "https://schema.org/episode",
      comment_lines: ["An episode of a TV, radio or game media within a series or season."].freeze,
      ranges: ["Episode"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["episodes"].freeze
    }.freeze,
    episodes: {
      schema_name: "episodes",
      schema_url: "https://schema.org/episodes",
      comment_lines: ["An episode of a TV/radio series or season."].freeze,
      ranges: ["Episode"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "episode",
      supersedes: nil
    }.freeze,
    number_of_episodes: {
      schema_name: "numberOfEpisodes",
      schema_url: "https://schema.org/numberOfEpisodes",
      comment_lines: ["The number of episodes in this season or series."].freeze,
      ranges: ["Integer"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    part_of_series: {
      schema_name: "partOfSeries",
      schema_url: "https://schema.org/partOfSeries",
      comment_lines: ["The series to which this episode or season belongs."].freeze,
      ranges: ["CreativeWorkSeries"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["partOfTVSeries"].freeze
    }.freeze,
    production_company: {
      schema_name: "productionCompany",
      schema_url: "https://schema.org/productionCompany",
      comment_lines: ["The production company or studio responsible for the item, e.g. series, video game, episode etc."].freeze,
      ranges: ["Organization"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    season_number: {
      schema_name: "seasonNumber",
      schema_url: "https://schema.org/seasonNumber",
      comment_lines: ["Position of the season within an ordered group of seasons."].freeze,
      ranges: ["Integer", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    start_date: {
      schema_name: "startDate",
      schema_url: "https://schema.org/startDate",
      comment_lines: ["The start date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601))."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    trailer: {
      schema_name: "trailer",
      schema_url: "https://schema.org/trailer",
      comment_lines: ["The trailer of a movie or TV/radio series, season, episode, etc."].freeze,
      ranges: ["VideoObject"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#actorObject

An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip. Supersedes actors.



128
129
130
# File 'lib/schema_org/mixins/creative_work_season.rb', line 128

def actor
  read_property(:actor)
end

#actor=(value) ⇒ Object

An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip. Supersedes actors.



134
135
136
# File 'lib/schema_org/mixins/creative_work_season.rb', line 134

def actor=(value)
  write_property(:actor, value)
end

#directorObject

A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip. Supersedes directors.



140
141
142
# File 'lib/schema_org/mixins/creative_work_season.rb', line 140

def director
  read_property(:director)
end

#director=(value) ⇒ Object

A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip. Supersedes directors.



146
147
148
# File 'lib/schema_org/mixins/creative_work_season.rb', line 146

def director=(value)
  write_property(:director, value)
end

#end_dateObject

The end date and time of the item (in ISO 8601 date format).



151
152
153
# File 'lib/schema_org/mixins/creative_work_season.rb', line 151

def end_date
  read_property(:end_date)
end

#end_date=(value) ⇒ Object

The end date and time of the item (in ISO 8601 date format).



156
157
158
# File 'lib/schema_org/mixins/creative_work_season.rb', line 156

def end_date=(value)
  write_property(:end_date, value)
end

#episodeObject

An episode of a TV, radio or game media within a series or season. Supersedes episodes.



162
163
164
# File 'lib/schema_org/mixins/creative_work_season.rb', line 162

def episode
  read_property(:episode)
end

#episode=(value) ⇒ Object

An episode of a TV, radio or game media within a series or season. Supersedes episodes.



168
169
170
# File 'lib/schema_org/mixins/creative_work_season.rb', line 168

def episode=(value)
  write_property(:episode, value)
end

#episodesObject

An episode of a TV/radio series or season. Superseded by episode.



174
175
176
# File 'lib/schema_org/mixins/creative_work_season.rb', line 174

def episodes
  read_property(:episodes)
end

#episodes=(value) ⇒ Object

An episode of a TV/radio series or season. Superseded by episode.



180
181
182
# File 'lib/schema_org/mixins/creative_work_season.rb', line 180

def episodes=(value)
  write_property(:episodes, value)
end

#number_of_episodesObject

The number of episodes in this season or series.



185
186
187
# File 'lib/schema_org/mixins/creative_work_season.rb', line 185

def number_of_episodes
  read_property(:number_of_episodes)
end

#number_of_episodes=(value) ⇒ Object

The number of episodes in this season or series.



190
191
192
# File 'lib/schema_org/mixins/creative_work_season.rb', line 190

def number_of_episodes=(value)
  write_property(:number_of_episodes, value)
end

#part_of_seriesObject

The series to which this episode or season belongs. Supersedes partOfTVSeries.



196
197
198
# File 'lib/schema_org/mixins/creative_work_season.rb', line 196

def part_of_series
  read_property(:part_of_series)
end

#part_of_series=(value) ⇒ Object

The series to which this episode or season belongs. Supersedes partOfTVSeries.



202
203
204
# File 'lib/schema_org/mixins/creative_work_season.rb', line 202

def part_of_series=(value)
  write_property(:part_of_series, value)
end

#production_companyObject

The production company or studio responsible for the item, e.g. series, video game, episode etc.



207
208
209
# File 'lib/schema_org/mixins/creative_work_season.rb', line 207

def production_company
  read_property(:production_company)
end

#production_company=(value) ⇒ Object

The production company or studio responsible for the item, e.g. series, video game, episode etc.



212
213
214
# File 'lib/schema_org/mixins/creative_work_season.rb', line 212

def production_company=(value)
  write_property(:production_company, value)
end

#season_numberObject

Position of the season within an ordered group of seasons.



217
218
219
# File 'lib/schema_org/mixins/creative_work_season.rb', line 217

def season_number
  read_property(:season_number)
end

#season_number=(value) ⇒ Object

Position of the season within an ordered group of seasons.



222
223
224
# File 'lib/schema_org/mixins/creative_work_season.rb', line 222

def season_number=(value)
  write_property(:season_number, value)
end

#start_dateObject

The start date and time of the item (in ISO 8601 date format).



227
228
229
# File 'lib/schema_org/mixins/creative_work_season.rb', line 227

def start_date
  read_property(:start_date)
end

#start_date=(value) ⇒ Object

The start date and time of the item (in ISO 8601 date format).



232
233
234
# File 'lib/schema_org/mixins/creative_work_season.rb', line 232

def start_date=(value)
  write_property(:start_date, value)
end

#trailerObject

The trailer of a movie or TV/radio series, season, episode, etc.



237
238
239
# File 'lib/schema_org/mixins/creative_work_season.rb', line 237

def trailer
  read_property(:trailer)
end

#trailer=(value) ⇒ Object

The trailer of a movie or TV/radio series, season, episode, etc.



242
243
244
# File 'lib/schema_org/mixins/creative_work_season.rb', line 242

def trailer=(value)
  write_property(:trailer, value)
end