Module: SchemaOrg::Mixins::Credential

Includes:
CreativeWork
Included in:
Credential, EducationalOccupationalCredential
Defined in:
lib/schema_org/mixins/credential.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from CreativeWork

#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/schema_org/mixins/credential.rb', line 11

def self.schema_property_definitions
  {
    credential_category: {
      schema_name: "credentialCategory",
      schema_url: "https://schema.org/credentialCategory",
      comment_lines: ["The category or type of credential being described, for example \"degree”, “certificate”, “badge”, or more specific term."].freeze,
      ranges: ["DefinedTerm", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    recognized_by: {
      schema_name: "recognizedBy",
      schema_url: "https://schema.org/recognizedBy",
      comment_lines: ["An organization that acknowledges the validity, value or utility of a credential. Note: recognition may include a process of quality assurance or accreditation."].freeze,
      ranges: ["Organization"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    valid_for: {
      schema_name: "validFor",
      schema_url: "https://schema.org/validFor",
      comment_lines: ["The duration of validity of a permit or similar thing."].freeze,
      ranges: ["Duration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    valid_in: {
      schema_name: "validIn",
      schema_url: "https://schema.org/validIn",
      comment_lines: ["The geographic area where the item is valid. Applies for example to a [[Permit]], a [[Certification]], or an [[EducationalOccupationalCredential]]."].freeze,
      ranges: ["AdministrativeArea"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#credential_categoryObject

The category or type of credential being described, for example "degree”, “certificate”, “badge”, or more specific term.



57
58
59
# File 'lib/schema_org/mixins/credential.rb', line 57

def credential_category
  read_property(:credential_category)
end

#credential_category=(value) ⇒ Object

The category or type of credential being described, for example "degree”, “certificate”, “badge”, or more specific term.



62
63
64
# File 'lib/schema_org/mixins/credential.rb', line 62

def credential_category=(value)
  write_property(:credential_category, value)
end

#recognized_byObject

An organization that acknowledges the validity, value or utility of a credential. Note: recognition may include a process of quality assurance or accreditation.



67
68
69
# File 'lib/schema_org/mixins/credential.rb', line 67

def recognized_by
  read_property(:recognized_by)
end

#recognized_by=(value) ⇒ Object

An organization that acknowledges the validity, value or utility of a credential. Note: recognition may include a process of quality assurance or accreditation.



72
73
74
# File 'lib/schema_org/mixins/credential.rb', line 72

def recognized_by=(value)
  write_property(:recognized_by, value)
end

#valid_forObject

The duration of validity of a permit or similar thing.



77
78
79
# File 'lib/schema_org/mixins/credential.rb', line 77

def valid_for
  read_property(:valid_for)
end

#valid_for=(value) ⇒ Object

The duration of validity of a permit or similar thing.



82
83
84
# File 'lib/schema_org/mixins/credential.rb', line 82

def valid_for=(value)
  write_property(:valid_for, value)
end

#valid_inObject

The geographic area where the item is valid. Applies for example to a [[Permit]], a [[Certification]], or an [[EducationalOccupationalCredential]].



87
88
89
# File 'lib/schema_org/mixins/credential.rb', line 87

def valid_in
  read_property(:valid_in)
end

#valid_in=(value) ⇒ Object

The geographic area where the item is valid. Applies for example to a [[Permit]], a [[Certification]], or an [[EducationalOccupationalCredential]].



92
93
94
# File 'lib/schema_org/mixins/credential.rb', line 92

def valid_in=(value)
  write_property(:valid_in, value)
end