Module: SchemaOrg::Mixins::DefinedRegion

Includes:
Place, StructuredValue
Included in:
DefinedRegion
Defined in:
lib/schema_org/mixins/defined_region.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Methods included from Place

#additional_property, #additional_property=, #address, #address=, #aggregate_rating, #aggregate_rating=, #amenity_feature, #amenity_feature=, #branch_code, #branch_code=, #contained_in, #contained_in=, #contained_in_place, #contained_in_place=, #contains_place, #contains_place=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #geo, #geo=, #geo_contains, #geo_contains=, #geo_covered_by, #geo_covered_by=, #geo_covers, #geo_covers=, #geo_crosses, #geo_crosses=, #geo_disjoint, #geo_disjoint=, #geo_equals, #geo_equals=, #geo_intersects, #geo_intersects=, #geo_overlaps, #geo_overlaps=, #geo_touches, #geo_touches=, #geo_within, #geo_within=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_drive_through_service, #has_drive_through_service=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_map, #has_map=, #is_accessible_for_free, #is_accessible_for_free=, #isic_v4, #isic_v4=, #keywords, #keywords=, #latitude, #latitude=, #logo, #logo=, #longitude, #longitude=, #map, #map=, #maps, #maps=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #opening_hours_specification, #opening_hours_specification=, #photo, #photo=, #photos, #photos=, #public_access, #public_access=, #review, #review=, #reviews, #reviews=, #slogan, #slogan=, #smoking_allowed, #smoking_allowed=, #special_opening_hours_specification, #special_opening_hours_specification=, #telephone, #telephone=, #tour_booking_page, #tour_booking_page=

Class Method Details

.schema_property_definitionsObject



12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/schema_org/mixins/defined_region.rb', line 12

def self.schema_property_definitions
  {
    address_country: {
      schema_name: "addressCountry",
      schema_url: "https://schema.org/addressCountry",
      comment_lines: ["The country. Recommended to be in 2-letter [ISO 3166-1 alpha-2](http://en.wikipedia.org/wiki/ISO_3166-1) format, for example \"US\". For backward compatibility, a 3-letter [ISO 3166-1 alpha-3](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-3) country code such as \"SGP\" or a full country name such as \"Singapore\" can also be used."].freeze,
      ranges: ["Country", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    address_region: {
      schema_name: "addressRegion",
      schema_url: "https://schema.org/addressRegion",
      comment_lines: ["The region in which the locality is, and which is in the country. For example, California or another appropriate first-level [Administrative division](https://en.wikipedia.org/wiki/List_of_administrative_divisions_by_country) such as the Province in Italy or Region in Germany."].freeze,
      ranges: ["AdministrativeArea", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    postal_code: {
      schema_name: "postalCode",
      schema_url: "https://schema.org/postalCode",
      comment_lines: ["The postal code. For example, 94043."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    postal_code_prefix: {
      schema_name: "postalCodePrefix",
      schema_url: "https://schema.org/postalCodePrefix",
      comment_lines: ["A defined range of postal codes indicated by a common textual prefix. Used for non-numeric systems such as UK."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    postal_code_range: {
      schema_name: "postalCodeRange",
      schema_url: "https://schema.org/postalCodeRange",
      comment_lines: ["A defined range of postal codes."].freeze,
      ranges: ["PostalCodeRangeSpecification"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#address_countryObject

The country. Recommended to be in 2-letter ISO 3166-1 alpha-2 format, for example "US". For backward compatibility, a 3-letter ISO 3166-1 alpha-3 country code such as "SGP" or a full country name such as "Singapore" can also be used.



68
69
70
# File 'lib/schema_org/mixins/defined_region.rb', line 68

def address_country
  read_property(:address_country)
end

#address_country=(value) ⇒ Object

The country. Recommended to be in 2-letter ISO 3166-1 alpha-2 format, for example "US". For backward compatibility, a 3-letter ISO 3166-1 alpha-3 country code such as "SGP" or a full country name such as "Singapore" can also be used.



73
74
75
# File 'lib/schema_org/mixins/defined_region.rb', line 73

def address_country=(value)
  write_property(:address_country, value)
end

#address_regionObject

The region in which the locality is, and which is in the country. For example, California or another appropriate first-level Administrative division such as the Province in Italy or Region in Germany.



78
79
80
# File 'lib/schema_org/mixins/defined_region.rb', line 78

def address_region
  read_property(:address_region)
end

#address_region=(value) ⇒ Object

The region in which the locality is, and which is in the country. For example, California or another appropriate first-level Administrative division such as the Province in Italy or Region in Germany.



83
84
85
# File 'lib/schema_org/mixins/defined_region.rb', line 83

def address_region=(value)
  write_property(:address_region, value)
end

#postal_codeObject

The postal code. For example, 94043.



88
89
90
# File 'lib/schema_org/mixins/defined_region.rb', line 88

def postal_code
  read_property(:postal_code)
end

#postal_code=(value) ⇒ Object

The postal code. For example, 94043.



93
94
95
# File 'lib/schema_org/mixins/defined_region.rb', line 93

def postal_code=(value)
  write_property(:postal_code, value)
end

#postal_code_prefixObject

A defined range of postal codes indicated by a common textual prefix. Used for non-numeric systems such as UK.



98
99
100
# File 'lib/schema_org/mixins/defined_region.rb', line 98

def postal_code_prefix
  read_property(:postal_code_prefix)
end

#postal_code_prefix=(value) ⇒ Object

A defined range of postal codes indicated by a common textual prefix. Used for non-numeric systems such as UK.



103
104
105
# File 'lib/schema_org/mixins/defined_region.rb', line 103

def postal_code_prefix=(value)
  write_property(:postal_code_prefix, value)
end

#postal_code_rangeObject

A defined range of postal codes.



108
109
110
# File 'lib/schema_org/mixins/defined_region.rb', line 108

def postal_code_range
  read_property(:postal_code_range)
end

#postal_code_range=(value) ⇒ Object

A defined range of postal codes.



113
114
115
# File 'lib/schema_org/mixins/defined_region.rb', line 113

def postal_code_range=(value)
  write_property(:postal_code_range, value)
end