Module: SchemaOrg::Mixins::DeliveryTimeSettings

Includes:
StructuredValue
Included in:
DeliveryTimeSettings
Defined in:
lib/schema_org/mixins/delivery_time_settings.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/schema_org/mixins/delivery_time_settings.rb', line 11

def self.schema_property_definitions
  {
    delivery_time: {
      schema_name: "deliveryTime",
      schema_url: "https://schema.org/deliveryTime",
      comment_lines: ["The total delay between the receipt of the order and the goods reaching the final customer."].freeze,
      ranges: ["ShippingDeliveryTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    is_unlabelled_fallback: {
      schema_name: "isUnlabelledFallback",
      schema_url: "https://schema.org/isUnlabelledFallback",
      comment_lines: ["This can be marked 'true' to indicate that some published [[DeliveryTimeSettings]] or [[ShippingRateSettings]] are intended to apply to all [[OfferShippingDetails]] published by the same merchant, when referenced by a [[shippingSettingsLink]] in those settings. It is not meaningful to use a 'true' value for this property alongside a transitTimeLabel (for [[DeliveryTimeSettings]]) or shippingLabel (for [[ShippingRateSettings]]), since this property is for use with unlabelled settings."].freeze,
      ranges: ["Boolean"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    shipping_destination: {
      schema_name: "shippingDestination",
      schema_url: "https://schema.org/shippingDestination",
      comment_lines: ["indicates (possibly multiple) shipping destinations. These can be defined in several ways, e.g. postalCode ranges."].freeze,
      ranges: ["DefinedRegion"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    transit_time_label: {
      schema_name: "transitTimeLabel",
      schema_url: "https://schema.org/transitTimeLabel",
      comment_lines: ["Label to match an [[OfferShippingDetails]] with a [[DeliveryTimeSettings]] (within the context of a [[shippingSettingsLink]] cross-reference)."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#delivery_timeObject

The total delay between the receipt of the order and the goods reaching the final customer.



57
58
59
# File 'lib/schema_org/mixins/delivery_time_settings.rb', line 57

def delivery_time
  read_property(:delivery_time)
end

#delivery_time=(value) ⇒ Object

The total delay between the receipt of the order and the goods reaching the final customer.



62
63
64
# File 'lib/schema_org/mixins/delivery_time_settings.rb', line 62

def delivery_time=(value)
  write_property(:delivery_time, value)
end

#is_unlabelled_fallbackObject

This can be marked 'true' to indicate that some published [[DeliveryTimeSettings]] or [[ShippingRateSettings]] are intended to apply to all [[OfferShippingDetails]] published by the same merchant, when referenced by a [[shippingSettingsLink]] in those settings. It is not meaningful to use a 'true' value for this property alongside a transitTimeLabel (for [[DeliveryTimeSettings]]) or shippingLabel (for [[ShippingRateSettings]]), since this property is for use with unlabelled settings.



67
68
69
# File 'lib/schema_org/mixins/delivery_time_settings.rb', line 67

def is_unlabelled_fallback
  read_property(:is_unlabelled_fallback)
end

#is_unlabelled_fallback=(value) ⇒ Object

This can be marked 'true' to indicate that some published [[DeliveryTimeSettings]] or [[ShippingRateSettings]] are intended to apply to all [[OfferShippingDetails]] published by the same merchant, when referenced by a [[shippingSettingsLink]] in those settings. It is not meaningful to use a 'true' value for this property alongside a transitTimeLabel (for [[DeliveryTimeSettings]]) or shippingLabel (for [[ShippingRateSettings]]), since this property is for use with unlabelled settings.



72
73
74
# File 'lib/schema_org/mixins/delivery_time_settings.rb', line 72

def is_unlabelled_fallback=(value)
  write_property(:is_unlabelled_fallback, value)
end

#shipping_destinationObject

indicates (possibly multiple) shipping destinations. These can be defined in several ways, e.g. postalCode ranges.



77
78
79
# File 'lib/schema_org/mixins/delivery_time_settings.rb', line 77

def shipping_destination
  read_property(:shipping_destination)
end

#shipping_destination=(value) ⇒ Object

indicates (possibly multiple) shipping destinations. These can be defined in several ways, e.g. postalCode ranges.



82
83
84
# File 'lib/schema_org/mixins/delivery_time_settings.rb', line 82

def shipping_destination=(value)
  write_property(:shipping_destination, value)
end

#transit_time_labelObject

Label to match an [[OfferShippingDetails]] with a [[DeliveryTimeSettings]] (within the context of a [[shippingSettingsLink]] cross-reference).



87
88
89
# File 'lib/schema_org/mixins/delivery_time_settings.rb', line 87

def transit_time_label
  read_property(:transit_time_label)
end

#transit_time_label=(value) ⇒ Object

Label to match an [[OfferShippingDetails]] with a [[DeliveryTimeSettings]] (within the context of a [[shippingSettingsLink]] cross-reference).



92
93
94
# File 'lib/schema_org/mixins/delivery_time_settings.rb', line 92

def transit_time_label=(value)
  write_property(:transit_time_label, value)
end