Module: SchemaOrg::Mixins::DrugStrength

Includes:
MedicalIntangible
Included in:
DrugStrength
Defined in:
lib/schema_org/mixins/drug_strength.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/schema_org/mixins/drug_strength.rb', line 11

def self.schema_property_definitions
  {
    active_ingredient: {
      schema_name: "activeIngredient",
      schema_url: "https://schema.org/activeIngredient",
      comment_lines: ["An active ingredient, typically chemical compounds and/or biologic substances."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    available_in: {
      schema_name: "availableIn",
      schema_url: "https://schema.org/availableIn",
      comment_lines: ["The location in which the strength is available."].freeze,
      ranges: ["AdministrativeArea"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    maximum_intake: {
      schema_name: "maximumIntake",
      schema_url: "https://schema.org/maximumIntake",
      comment_lines: ["Recommended intake of this supplement for a given population as defined by a specific recommending authority."].freeze,
      ranges: ["MaximumDoseSchedule"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    strength_unit: {
      schema_name: "strengthUnit",
      schema_url: "https://schema.org/strengthUnit",
      comment_lines: ["The units of an active ingredient's strength, e.g. mg."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    strength_value: {
      schema_name: "strengthValue",
      schema_url: "https://schema.org/strengthValue",
      comment_lines: ["The value of an active ingredient's strength, e.g. 325."].freeze,
      ranges: ["Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#active_ingredientObject

An active ingredient, typically chemical compounds and/or biologic substances.



67
68
69
# File 'lib/schema_org/mixins/drug_strength.rb', line 67

def active_ingredient
  read_property(:active_ingredient)
end

#active_ingredient=(value) ⇒ Object

An active ingredient, typically chemical compounds and/or biologic substances.



72
73
74
# File 'lib/schema_org/mixins/drug_strength.rb', line 72

def active_ingredient=(value)
  write_property(:active_ingredient, value)
end

#available_inObject

The location in which the strength is available.



77
78
79
# File 'lib/schema_org/mixins/drug_strength.rb', line 77

def available_in
  read_property(:available_in)
end

#available_in=(value) ⇒ Object

The location in which the strength is available.



82
83
84
# File 'lib/schema_org/mixins/drug_strength.rb', line 82

def available_in=(value)
  write_property(:available_in, value)
end

#maximum_intakeObject

Recommended intake of this supplement for a given population as defined by a specific recommending authority.



87
88
89
# File 'lib/schema_org/mixins/drug_strength.rb', line 87

def maximum_intake
  read_property(:maximum_intake)
end

#maximum_intake=(value) ⇒ Object

Recommended intake of this supplement for a given population as defined by a specific recommending authority.



92
93
94
# File 'lib/schema_org/mixins/drug_strength.rb', line 92

def maximum_intake=(value)
  write_property(:maximum_intake, value)
end

#strength_unitObject

The units of an active ingredient's strength, e.g. mg.



97
98
99
# File 'lib/schema_org/mixins/drug_strength.rb', line 97

def strength_unit
  read_property(:strength_unit)
end

#strength_unit=(value) ⇒ Object

The units of an active ingredient's strength, e.g. mg.



102
103
104
# File 'lib/schema_org/mixins/drug_strength.rb', line 102

def strength_unit=(value)
  write_property(:strength_unit, value)
end

#strength_valueObject

The value of an active ingredient's strength, e.g. 325.



107
108
109
# File 'lib/schema_org/mixins/drug_strength.rb', line 107

def strength_value
  read_property(:strength_value)
end

#strength_value=(value) ⇒ Object

The value of an active ingredient's strength, e.g. 325.



112
113
114
# File 'lib/schema_org/mixins/drug_strength.rb', line 112

def strength_value=(value)
  write_property(:strength_value, value)
end