Module: SchemaOrg::Mixins::EducationEvent

Includes:
Event
Included in:
EducationEvent
Defined in:
lib/schema_org/mixins/education_event.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Event

#about, #about=, #actor, #actor=, #aggregate_rating, #aggregate_rating=, #attendee, #attendee=, #attendees, #attendees=, #audience, #audience=, #composer, #composer=, #contributor, #contributor=, #director, #director=, #door_time, #door_time=, #duration, #duration=, #end_date, #end_date=, #event_attendance_mode, #event_attendance_mode=, #event_schedule, #event_schedule=, #event_status, #event_status=, #funder, #funder=, #funding, #funding=, #has_participation_offer, #has_participation_offer=, #has_sponsorship_offer, #has_sponsorship_offer=, #in_language, #in_language=, #is_accessible_for_free, #is_accessible_for_free=, #keywords, #keywords=, #location, #location=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #maximum_physical_attendee_capacity, #maximum_physical_attendee_capacity=, #maximum_virtual_attendee_capacity, #maximum_virtual_attendee_capacity=, #offers, #offers=, #organizer, #organizer=, #performer, #performer=, #performers, #performers=, #previous_start_date, #previous_start_date=, #recorded_in, #recorded_in=, #remaining_attendee_capacity, #remaining_attendee_capacity=, #review, #review=, #sponsor, #sponsor=, #start_date, #start_date=, #sub_event, #sub_event=, #sub_events, #sub_events=, #super_event, #super_event=, #translator, #translator=, #typical_age_range, #typical_age_range=, #work_featured, #work_featured=, #work_performed, #work_performed=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/schema_org/mixins/education_event.rb', line 11

def self.schema_property_definitions
  {
    assesses: {
      schema_name: "assesses",
      schema_url: "https://schema.org/assesses",
      comment_lines: ["The item being described is intended to assess the competency or learning outcome defined by the referenced term."].freeze,
      ranges: ["DefinedTerm", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    educational_level: {
      schema_name: "educationalLevel",
      schema_url: "https://schema.org/educationalLevel",
      comment_lines: ["The level in terms of progression through an educational or training context. Examples of educational levels include 'beginner', 'intermediate' or 'advanced', and formal sets of level indicators."].freeze,
      ranges: ["DefinedTerm", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    teaches: {
      schema_name: "teaches",
      schema_url: "https://schema.org/teaches",
      comment_lines: ["The item being described is intended to help a person learn the competency or learning outcome defined by the referenced term."].freeze,
      ranges: ["DefinedTerm", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#assessesObject

The item being described is intended to assess the competency or learning outcome defined by the referenced term.



47
48
49
# File 'lib/schema_org/mixins/education_event.rb', line 47

def assesses
  read_property(:assesses)
end

#assesses=(value) ⇒ Object

The item being described is intended to assess the competency or learning outcome defined by the referenced term.



52
53
54
# File 'lib/schema_org/mixins/education_event.rb', line 52

def assesses=(value)
  write_property(:assesses, value)
end

#educational_levelObject

The level in terms of progression through an educational or training context. Examples of educational levels include 'beginner', 'intermediate' or 'advanced', and formal sets of level indicators.



57
58
59
# File 'lib/schema_org/mixins/education_event.rb', line 57

def educational_level
  read_property(:educational_level)
end

#educational_level=(value) ⇒ Object

The level in terms of progression through an educational or training context. Examples of educational levels include 'beginner', 'intermediate' or 'advanced', and formal sets of level indicators.



62
63
64
# File 'lib/schema_org/mixins/education_event.rb', line 62

def educational_level=(value)
  write_property(:educational_level, value)
end

#teachesObject

The item being described is intended to help a person learn the competency or learning outcome defined by the referenced term.



67
68
69
# File 'lib/schema_org/mixins/education_event.rb', line 67

def teaches
  read_property(:teaches)
end

#teaches=(value) ⇒ Object

The item being described is intended to help a person learn the competency or learning outcome defined by the referenced term.



72
73
74
# File 'lib/schema_org/mixins/education_event.rb', line 72

def teaches=(value)
  write_property(:teaches, value)
end