Module: SchemaOrg::Mixins::EmployeeRole

Includes:
OrganizationRole
Included in:
EmployeeRole
Defined in:
lib/schema_org/mixins/employee_role.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from OrganizationRole

#numbered_position, #numbered_position=

Methods included from Role

#end_date, #end_date=, #named_position, #named_position=, #role_name, #role_name=, #start_date, #start_date=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/schema_org/mixins/employee_role.rb', line 11

def self.schema_property_definitions
  {
    base_salary: {
      schema_name: "baseSalary",
      schema_url: "https://schema.org/baseSalary",
      comment_lines: ["The base salary of the job or of an employee in an EmployeeRole."].freeze,
      ranges: ["MonetaryAmount", "Number", "PriceSpecification"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    salary_currency: {
      schema_name: "salaryCurrency",
      schema_url: "https://schema.org/salaryCurrency",
      comment_lines: ["The currency (coded using [ISO 4217](http://en.wikipedia.org/wiki/ISO_4217)) used for the main salary information in this job posting or for this employee."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#base_salaryObject

The base salary of the job or of an employee in an EmployeeRole.



37
38
39
# File 'lib/schema_org/mixins/employee_role.rb', line 37

def base_salary
  read_property(:base_salary)
end

#base_salary=(value) ⇒ Object

The base salary of the job or of an employee in an EmployeeRole.



42
43
44
# File 'lib/schema_org/mixins/employee_role.rb', line 42

def base_salary=(value)
  write_property(:base_salary, value)
end

#salary_currencyObject

The currency (coded using ISO 4217) used for the main salary information in this job posting or for this employee.



47
48
49
# File 'lib/schema_org/mixins/employee_role.rb', line 47

def salary_currency
  read_property(:salary_currency)
end

#salary_currency=(value) ⇒ Object

The currency (coded using ISO 4217) used for the main salary information in this job posting or for this employee.



52
53
54
# File 'lib/schema_org/mixins/employee_role.rb', line 52

def salary_currency=(value)
  write_property(:salary_currency, value)
end