Module: SchemaOrg::Mixins::EngineSpecification

Includes:
StructuredValue
Included in:
EngineSpecification
Defined in:
lib/schema_org/mixins/engine_specification.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/schema_org/mixins/engine_specification.rb', line 11

def self.schema_property_definitions
  {
    engine_displacement: {
      schema_name: "engineDisplacement",
      schema_url: "https://schema.org/engineDisplacement",
      comment_lines: ["The volume swept by all of the pistons inside the cylinders of an internal combustion engine in a single movement. \\n\\nTypical unit code(s): CMQ for cubic centimeter, LTR for liters, INQ for cubic inches\\n* Note 1: You can link to information about how the given value has been determined using the [[valueReference]] property.\\n* Note 2: You can use [[minValue]] and [[maxValue]] to indicate ranges."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    engine_power: {
      schema_name: "enginePower",
      schema_url: "https://schema.org/enginePower",
      comment_lines: ["The power of the vehicle's engine.", "    Typical unit code(s): KWT for kilowatt, BHP for brake horsepower, N12 for metric horsepower (PS, with 1 PS = 735,49875 W)\\n\\n* Note 1: There are many different ways of measuring an engine's power. For an overview, see  [http://en.wikipedia.org/wiki/Horsepower#Engine\\_power\\_test\\_codes](http://en.wikipedia.org/wiki/Horsepower#Engine_power_test_codes).\\n* Note 2: You can link to information about how the given value has been determined using the [[valueReference]] property.\\n* Note 3: You can use [[minValue]] and [[maxValue]] to indicate ranges."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    engine_type: {
      schema_name: "engineType",
      schema_url: "https://schema.org/engineType",
      comment_lines: ["The type of engine or engines powering the vehicle."].freeze,
      ranges: ["QualitativeValue", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    fuel_type: {
      schema_name: "fuelType",
      schema_url: "https://schema.org/fuelType",
      comment_lines: ["The type of fuel suitable for the engine or engines of the vehicle. If the vehicle has only one engine, this property can be attached directly to the vehicle."].freeze,
      ranges: ["QualitativeValue", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    torque: {
      schema_name: "torque",
      schema_url: "https://schema.org/torque",
      comment_lines: ["The torque (turning force) of the vehicle's engine.\\n\\nTypical unit code(s): NU for newton metre (N m), F17 for pound-force per foot, or F48 for pound-force per inch\\n\\n* Note 1: You can link to information about how the given value has been determined (e.g. reference RPM) using the [[valueReference]] property.\\n* Note 2: You can use [[minValue]] and [[maxValue]] to indicate ranges."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#engine_displacementObject

The volume swept by all of the pistons inside the cylinders of an internal combustion engine in a single movement. \n\nTypical unit code(s): CMQ for cubic centimeter, LTR for liters, INQ for cubic inches\n* Note 1: You can link to information about how the given value has been determined using the [[valueReference]] property.\n* Note 2: You can use [[minValue]] and [[maxValue]] to indicate ranges.



67
68
69
# File 'lib/schema_org/mixins/engine_specification.rb', line 67

def engine_displacement
  read_property(:engine_displacement)
end

#engine_displacement=(value) ⇒ Object

The volume swept by all of the pistons inside the cylinders of an internal combustion engine in a single movement. \n\nTypical unit code(s): CMQ for cubic centimeter, LTR for liters, INQ for cubic inches\n* Note 1: You can link to information about how the given value has been determined using the [[valueReference]] property.\n* Note 2: You can use [[minValue]] and [[maxValue]] to indicate ranges.



72
73
74
# File 'lib/schema_org/mixins/engine_specification.rb', line 72

def engine_displacement=(value)
  write_property(:engine_displacement, value)
end

#engine_powerObject

The power of the vehicle's engine. Typical unit code(s): KWT for kilowatt, BHP for brake horsepower, N12 for metric horsepower (PS, with 1 PS = 735,49875 W)\n\n* Note 1: There are many different ways of measuring an engine's power. For an overview, see http://en.wikipedia.org/wiki/Horsepower#Engine_power_test_codes.\n* Note 2: You can link to information about how the given value has been determined using the [[valueReference]] property.\n* Note 3: You can use [[minValue]] and [[maxValue]] to indicate ranges.



78
79
80
# File 'lib/schema_org/mixins/engine_specification.rb', line 78

def engine_power
  read_property(:engine_power)
end

#engine_power=(value) ⇒ Object

The power of the vehicle's engine. Typical unit code(s): KWT for kilowatt, BHP for brake horsepower, N12 for metric horsepower (PS, with 1 PS = 735,49875 W)\n\n* Note 1: There are many different ways of measuring an engine's power. For an overview, see http://en.wikipedia.org/wiki/Horsepower#Engine_power_test_codes.\n* Note 2: You can link to information about how the given value has been determined using the [[valueReference]] property.\n* Note 3: You can use [[minValue]] and [[maxValue]] to indicate ranges.



84
85
86
# File 'lib/schema_org/mixins/engine_specification.rb', line 84

def engine_power=(value)
  write_property(:engine_power, value)
end

#engine_typeObject

The type of engine or engines powering the vehicle.



89
90
91
# File 'lib/schema_org/mixins/engine_specification.rb', line 89

def engine_type
  read_property(:engine_type)
end

#engine_type=(value) ⇒ Object

The type of engine or engines powering the vehicle.



94
95
96
# File 'lib/schema_org/mixins/engine_specification.rb', line 94

def engine_type=(value)
  write_property(:engine_type, value)
end

#fuel_typeObject

The type of fuel suitable for the engine or engines of the vehicle. If the vehicle has only one engine, this property can be attached directly to the vehicle.



99
100
101
# File 'lib/schema_org/mixins/engine_specification.rb', line 99

def fuel_type
  read_property(:fuel_type)
end

#fuel_type=(value) ⇒ Object

The type of fuel suitable for the engine or engines of the vehicle. If the vehicle has only one engine, this property can be attached directly to the vehicle.



104
105
106
# File 'lib/schema_org/mixins/engine_specification.rb', line 104

def fuel_type=(value)
  write_property(:fuel_type, value)
end

#torqueObject

The torque (turning force) of the vehicle's engine.\n\nTypical unit code(s): NU for newton metre (N m), F17 for pound-force per foot, or F48 for pound-force per inch\n\n* Note 1: You can link to information about how the given value has been determined (e.g. reference RPM) using the [[valueReference]] property.\n* Note 2: You can use [[minValue]] and [[maxValue]] to indicate ranges.



109
110
111
# File 'lib/schema_org/mixins/engine_specification.rb', line 109

def torque
  read_property(:torque)
end

#torque=(value) ⇒ Object

The torque (turning force) of the vehicle's engine.\n\nTypical unit code(s): NU for newton metre (N m), F17 for pound-force per foot, or F48 for pound-force per inch\n\n* Note 1: You can link to information about how the given value has been determined (e.g. reference RPM) using the [[valueReference]] property.\n* Note 2: You can use [[minValue]] and [[maxValue]] to indicate ranges.



114
115
116
# File 'lib/schema_org/mixins/engine_specification.rb', line 114

def torque=(value)
  write_property(:torque, value)
end