Module: SchemaOrg::Mixins::Event

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'lib/schema_org/mixins/event.rb', line 11

def self.schema_property_definitions
  {
    about: {
      schema_name: "about",
      schema_url: "https://schema.org/about",
      comment_lines: ["The subject matter of an object."].freeze,
      ranges: ["Thing"].freeze,
      external_ranges: [].freeze,
      inverse_of: "subjectOf",
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    actor: {
      schema_name: "actor",
      schema_url: "https://schema.org/actor",
      comment_lines: ["An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip."].freeze,
      ranges: ["PerformingGroup", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["actors"].freeze
    }.freeze,
    aggregate_rating: {
      schema_name: "aggregateRating",
      schema_url: "https://schema.org/aggregateRating",
      comment_lines: ["The overall rating, based on a collection of reviews or ratings, of the item."].freeze,
      ranges: ["AggregateRating"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    attendee: {
      schema_name: "attendee",
      schema_url: "https://schema.org/attendee",
      comment_lines: ["A person or organization attending the event."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["attendees"].freeze
    }.freeze,
    attendees: {
      schema_name: "attendees",
      schema_url: "https://schema.org/attendees",
      comment_lines: ["A person attending the event."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "attendee",
      supersedes: nil
    }.freeze,
    audience: {
      schema_name: "audience",
      schema_url: "https://schema.org/audience",
      comment_lines: ["An intended audience, i.e. a group for whom something was created."].freeze,
      ranges: ["Audience"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["serviceAudience"].freeze
    }.freeze,
    composer: {
      schema_name: "composer",
      schema_url: "https://schema.org/composer",
      comment_lines: ["The person or organization who wrote a composition, or who is the composer of a work performed at some event."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    contributor: {
      schema_name: "contributor",
      schema_url: "https://schema.org/contributor",
      comment_lines: ["A secondary contributor to the CreativeWork or Event."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    director: {
      schema_name: "director",
      schema_url: "https://schema.org/director",
      comment_lines: ["A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["directors"].freeze
    }.freeze,
    door_time: {
      schema_name: "doorTime",
      schema_url: "https://schema.org/doorTime",
      comment_lines: ["The time admission will commence."].freeze,
      ranges: ["DateTime", "Time"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    duration: {
      schema_name: "duration",
      schema_url: "https://schema.org/duration",
      comment_lines: ["The duration of the item (movie, audio recording, event, etc.) in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601)."].freeze,
      ranges: ["Duration", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    end_date: {
      schema_name: "endDate",
      schema_url: "https://schema.org/endDate",
      comment_lines: ["The end date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601))."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    event_attendance_mode: {
      schema_name: "eventAttendanceMode",
      schema_url: "https://schema.org/eventAttendanceMode",
      comment_lines: ["The eventAttendanceMode of an event indicates whether it occurs online, offline, or a mix."].freeze,
      ranges: ["EventAttendanceModeEnumeration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    event_schedule: {
      schema_name: "eventSchedule",
      schema_url: "https://schema.org/eventSchedule",
      comment_lines: ["Associates an [[Event]] with a [[Schedule]]. There are circumstances where it is preferable to share a schedule for a series of", "      repeating events rather than data on the individual events themselves. For example, a website or application might prefer to publish a schedule for a weekly", "      gym class rather than provide data on every event. A schedule could be processed by applications to add forthcoming events to a calendar. An [[Event]] that", "      is associated with a [[Schedule]] using this property should not have [[startDate]] or [[endDate]] properties. These are instead defined within the associated", "      [[Schedule]], this avoids any ambiguity for clients using the data. The property might have repeated values to specify different schedules, e.g. for different months", "      or seasons."].freeze,
      ranges: ["Schedule"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    event_status: {
      schema_name: "eventStatus",
      schema_url: "https://schema.org/eventStatus",
      comment_lines: ["An eventStatus of an event represents its status; particularly useful when an event is cancelled or rescheduled."].freeze,
      ranges: ["EventStatusType"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    funder: {
      schema_name: "funder",
      schema_url: "https://schema.org/funder",
      comment_lines: ["A person or organization that supports (sponsors) something through some kind of financial contribution."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    funding: {
      schema_name: "funding",
      schema_url: "https://schema.org/funding",
      comment_lines: ["A [[Grant]] that directly or indirectly provide funding or sponsorship for this item. See also [[ownershipFundingInfo]]."].freeze,
      ranges: ["Grant"].freeze,
      external_ranges: [].freeze,
      inverse_of: "fundedItem",
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    has_participation_offer: {
      schema_name: "hasParticipationOffer",
      schema_url: "https://schema.org/hasParticipationOffer",
      comment_lines: ["An offer to participate in the event, for example, Call for Proposals, Call for Speakers, or Call for Performers."].freeze,
      ranges: ["Offer"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    has_sponsorship_offer: {
      schema_name: "hasSponsorshipOffer",
      schema_url: "https://schema.org/hasSponsorshipOffer",
      comment_lines: ["An offer to sponsor the event, for example, Sponsorship Prospectus, Sponsorship Opportunities, or Sponsor Packages."].freeze,
      ranges: ["Offer"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    in_language: {
      schema_name: "inLanguage",
      schema_url: "https://schema.org/inLanguage",
      comment_lines: ["The language of the content or performance or used in an action. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[availableLanguage]]."].freeze,
      ranges: ["Language", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["language"].freeze
    }.freeze,
    is_accessible_for_free: {
      schema_name: "isAccessibleForFree",
      schema_url: "https://schema.org/isAccessibleForFree",
      comment_lines: ["A flag to signal that the item, event, or place is accessible for free."].freeze,
      ranges: ["Boolean"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["free"].freeze
    }.freeze,
    keywords: {
      schema_name: "keywords",
      schema_url: "https://schema.org/keywords",
      comment_lines: ["Keywords or tags used to describe some item. Multiple textual entries in a keywords list are typically delimited by commas, or by repeating the property."].freeze,
      ranges: ["DefinedTerm", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    location: {
      schema_name: "location",
      schema_url: "https://schema.org/location",
      comment_lines: ["The location of, for example, where an event is happening, where an organization is located, or where an action takes place."].freeze,
      ranges: ["Place", "PostalAddress", "Text", "VirtualLocation"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    maximum_attendee_capacity: {
      schema_name: "maximumAttendeeCapacity",
      schema_url: "https://schema.org/maximumAttendeeCapacity",
      comment_lines: ["The total number of individuals that may attend an event or venue."].freeze,
      ranges: ["Integer"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    maximum_physical_attendee_capacity: {
      schema_name: "maximumPhysicalAttendeeCapacity",
      schema_url: "https://schema.org/maximumPhysicalAttendeeCapacity",
      comment_lines: ["The maximum physical attendee capacity of an [[Event]] whose [[eventAttendanceMode]] is [[OfflineEventAttendanceMode]] (or the offline aspects, in the case of a [[MixedEventAttendanceMode]])."].freeze,
      ranges: ["Integer"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    maximum_virtual_attendee_capacity: {
      schema_name: "maximumVirtualAttendeeCapacity",
      schema_url: "https://schema.org/maximumVirtualAttendeeCapacity",
      comment_lines: ["The maximum virtual attendee capacity of an [[Event]] whose [[eventAttendanceMode]] is [[OnlineEventAttendanceMode]] (or the online aspects, in the case of a [[MixedEventAttendanceMode]])."].freeze,
      ranges: ["Integer"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    offers: {
      schema_name: "offers",
      schema_url: "https://schema.org/offers",
      comment_lines: ["An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer."].freeze,
      ranges: ["Demand", "Offer"].freeze,
      external_ranges: [].freeze,
      inverse_of: "itemOffered",
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    organizer: {
      schema_name: "organizer",
      schema_url: "https://schema.org/organizer",
      comment_lines: ["An organizer of an Event."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    performer: {
      schema_name: "performer",
      schema_url: "https://schema.org/performer",
      comment_lines: ["A performer at the event—for example, a presenter, musician, musical group or actor."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["performers"].freeze
    }.freeze,
    performers: {
      schema_name: "performers",
      schema_url: "https://schema.org/performers",
      comment_lines: ["The main performer or performers of the event—for example, a presenter, musician, or actor."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "performer",
      supersedes: nil
    }.freeze,
    previous_start_date: {
      schema_name: "previousStartDate",
      schema_url: "https://schema.org/previousStartDate",
      comment_lines: ["Used in conjunction with eventStatus for rescheduled or cancelled events. This property contains the previously scheduled start date. For rescheduled events, the startDate property should be used for the newly scheduled start date. In the (rare) case of an event that has been postponed and rescheduled multiple times, this field may be repeated."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    recorded_in: {
      schema_name: "recordedIn",
      schema_url: "https://schema.org/recordedIn",
      comment_lines: ["The CreativeWork that captured all or part of this Event."].freeze,
      ranges: ["CreativeWork"].freeze,
      external_ranges: [].freeze,
      inverse_of: "recordedAt",
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    remaining_attendee_capacity: {
      schema_name: "remainingAttendeeCapacity",
      schema_url: "https://schema.org/remainingAttendeeCapacity",
      comment_lines: ["The number of attendee places for an event that remain unallocated."].freeze,
      ranges: ["Integer"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    review: {
      schema_name: "review",
      schema_url: "https://schema.org/review",
      comment_lines: ["A review of the item."].freeze,
      ranges: ["Review"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["reviews"].freeze
    }.freeze,
    sponsor: {
      schema_name: "sponsor",
      schema_url: "https://schema.org/sponsor",
      comment_lines: ["A person or organization that supports a thing through a pledge, promise, or financial contribution. E.g. a sponsor of a Medical Study or a corporate sponsor of an event."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    start_date: {
      schema_name: "startDate",
      schema_url: "https://schema.org/startDate",
      comment_lines: ["The start date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601))."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    sub_event: {
      schema_name: "subEvent",
      schema_url: "https://schema.org/subEvent",
      comment_lines: ["An Event that is part of this event. For example, a conference event includes many presentations, each of which is a subEvent of the conference."].freeze,
      ranges: ["Event"].freeze,
      external_ranges: [].freeze,
      inverse_of: "superEvent",
      superseded_by: nil,
      supersedes: ["subEvents"].freeze
    }.freeze,
    sub_events: {
      schema_name: "subEvents",
      schema_url: "https://schema.org/subEvents",
      comment_lines: ["Events that are a part of this event. For example, a conference event includes many presentations, each subEvents of the conference."].freeze,
      ranges: ["Event"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "subEvent",
      supersedes: nil
    }.freeze,
    super_event: {
      schema_name: "superEvent",
      schema_url: "https://schema.org/superEvent",
      comment_lines: ["An event that this event is a part of. For example, a collection of individual music performances might each have a music festival as their superEvent."].freeze,
      ranges: ["Event"].freeze,
      external_ranges: [].freeze,
      inverse_of: "subEvent",
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    translator: {
      schema_name: "translator",
      schema_url: "https://schema.org/translator",
      comment_lines: ["Organization or person who adapts a creative work to different languages, regional differences and technical requirements of a target market, or that translates during some event."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    typical_age_range: {
      schema_name: "typicalAgeRange",
      schema_url: "https://schema.org/typicalAgeRange",
      comment_lines: ["The typical expected age range, e.g. '7-9', '11-'."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    work_featured: {
      schema_name: "workFeatured",
      schema_url: "https://schema.org/workFeatured",
      comment_lines: ["A work featured in some event, e.g. exhibited in an ExhibitionEvent.", "       Specific subproperties are available for workPerformed (e.g. a play), or a workPresented (a Movie at a ScreeningEvent)."].freeze,
      ranges: ["CreativeWork"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    work_performed: {
      schema_name: "workPerformed",
      schema_url: "https://schema.org/workPerformed",
      comment_lines: ["A work performed in some event, for example a play performed in a TheaterEvent."].freeze,
      ranges: ["CreativeWork"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#aboutObject

The subject matter of an object. Inverse-property: subjectOf.



448
449
450
# File 'lib/schema_org/mixins/event.rb', line 448

def about
  read_property(:about)
end

#about=(value) ⇒ Object

The subject matter of an object. Inverse-property: subjectOf.



454
455
456
# File 'lib/schema_org/mixins/event.rb', line 454

def about=(value)
  write_property(:about, value)
end

#actorObject

An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip. Supersedes actors.



460
461
462
# File 'lib/schema_org/mixins/event.rb', line 460

def actor
  read_property(:actor)
end

#actor=(value) ⇒ Object

An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip. Supersedes actors.



466
467
468
# File 'lib/schema_org/mixins/event.rb', line 466

def actor=(value)
  write_property(:actor, value)
end

#aggregate_ratingObject

The overall rating, based on a collection of reviews or ratings, of the item.



471
472
473
# File 'lib/schema_org/mixins/event.rb', line 471

def aggregate_rating
  read_property(:aggregate_rating)
end

#aggregate_rating=(value) ⇒ Object

The overall rating, based on a collection of reviews or ratings, of the item.



476
477
478
# File 'lib/schema_org/mixins/event.rb', line 476

def aggregate_rating=(value)
  write_property(:aggregate_rating, value)
end

#attendeeObject

A person or organization attending the event. Supersedes attendees.



482
483
484
# File 'lib/schema_org/mixins/event.rb', line 482

def attendee
  read_property(:attendee)
end

#attendee=(value) ⇒ Object

A person or organization attending the event. Supersedes attendees.



488
489
490
# File 'lib/schema_org/mixins/event.rb', line 488

def attendee=(value)
  write_property(:attendee, value)
end

#attendeesObject

A person attending the event. Superseded by attendee.



494
495
496
# File 'lib/schema_org/mixins/event.rb', line 494

def attendees
  read_property(:attendees)
end

#attendees=(value) ⇒ Object

A person attending the event. Superseded by attendee.



500
501
502
# File 'lib/schema_org/mixins/event.rb', line 500

def attendees=(value)
  write_property(:attendees, value)
end

#audienceObject

An intended audience, i.e. a group for whom something was created. Supersedes serviceAudience.



506
507
508
# File 'lib/schema_org/mixins/event.rb', line 506

def audience
  read_property(:audience)
end

#audience=(value) ⇒ Object

An intended audience, i.e. a group for whom something was created. Supersedes serviceAudience.



512
513
514
# File 'lib/schema_org/mixins/event.rb', line 512

def audience=(value)
  write_property(:audience, value)
end

#composerObject

The person or organization who wrote a composition, or who is the composer of a work performed at some event.



517
518
519
# File 'lib/schema_org/mixins/event.rb', line 517

def composer
  read_property(:composer)
end

#composer=(value) ⇒ Object

The person or organization who wrote a composition, or who is the composer of a work performed at some event.



522
523
524
# File 'lib/schema_org/mixins/event.rb', line 522

def composer=(value)
  write_property(:composer, value)
end

#contributorObject

A secondary contributor to the CreativeWork or Event.



527
528
529
# File 'lib/schema_org/mixins/event.rb', line 527

def contributor
  read_property(:contributor)
end

#contributor=(value) ⇒ Object

A secondary contributor to the CreativeWork or Event.



532
533
534
# File 'lib/schema_org/mixins/event.rb', line 532

def contributor=(value)
  write_property(:contributor, value)
end

#directorObject

A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip. Supersedes directors.



538
539
540
# File 'lib/schema_org/mixins/event.rb', line 538

def director
  read_property(:director)
end

#director=(value) ⇒ Object

A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip. Supersedes directors.



544
545
546
# File 'lib/schema_org/mixins/event.rb', line 544

def director=(value)
  write_property(:director, value)
end

#door_timeObject

The time admission will commence.



549
550
551
# File 'lib/schema_org/mixins/event.rb', line 549

def door_time
  read_property(:door_time)
end

#door_time=(value) ⇒ Object

The time admission will commence.



554
555
556
# File 'lib/schema_org/mixins/event.rb', line 554

def door_time=(value)
  write_property(:door_time, value)
end

#durationObject

The duration of the item (movie, audio recording, event, etc.) in ISO 8601 duration format.



559
560
561
# File 'lib/schema_org/mixins/event.rb', line 559

def duration
  read_property(:duration)
end

#duration=(value) ⇒ Object

The duration of the item (movie, audio recording, event, etc.) in ISO 8601 duration format.



564
565
566
# File 'lib/schema_org/mixins/event.rb', line 564

def duration=(value)
  write_property(:duration, value)
end

#end_dateObject

The end date and time of the item (in ISO 8601 date format).



569
570
571
# File 'lib/schema_org/mixins/event.rb', line 569

def end_date
  read_property(:end_date)
end

#end_date=(value) ⇒ Object

The end date and time of the item (in ISO 8601 date format).



574
575
576
# File 'lib/schema_org/mixins/event.rb', line 574

def end_date=(value)
  write_property(:end_date, value)
end

#event_attendance_modeObject

The eventAttendanceMode of an event indicates whether it occurs online, offline, or a mix.



579
580
581
# File 'lib/schema_org/mixins/event.rb', line 579

def event_attendance_mode
  read_property(:event_attendance_mode)
end

#event_attendance_mode=(value) ⇒ Object

The eventAttendanceMode of an event indicates whether it occurs online, offline, or a mix.



584
585
586
# File 'lib/schema_org/mixins/event.rb', line 584

def event_attendance_mode=(value)
  write_property(:event_attendance_mode, value)
end

#event_scheduleObject

Associates an [[Event]] with a [[Schedule]]. There are circumstances where it is preferable to share a schedule for a series of repeating events rather than data on the individual events themselves. For example, a website or application might prefer to publish a schedule for a weekly gym class rather than provide data on every event. A schedule could be processed by applications to add forthcoming events to a calendar. An [[Event]] that is associated with a [[Schedule]] using this property should not have [[startDate]] or [[endDate]] properties. These are instead defined within the associated [[Schedule]], this avoids any ambiguity for clients using the data. The property might have repeated values to specify different schedules, e.g. for different months or seasons.



594
595
596
# File 'lib/schema_org/mixins/event.rb', line 594

def event_schedule
  read_property(:event_schedule)
end

#event_schedule=(value) ⇒ Object

Associates an [[Event]] with a [[Schedule]]. There are circumstances where it is preferable to share a schedule for a series of repeating events rather than data on the individual events themselves. For example, a website or application might prefer to publish a schedule for a weekly gym class rather than provide data on every event. A schedule could be processed by applications to add forthcoming events to a calendar. An [[Event]] that is associated with a [[Schedule]] using this property should not have [[startDate]] or [[endDate]] properties. These are instead defined within the associated [[Schedule]], this avoids any ambiguity for clients using the data. The property might have repeated values to specify different schedules, e.g. for different months or seasons.



604
605
606
# File 'lib/schema_org/mixins/event.rb', line 604

def event_schedule=(value)
  write_property(:event_schedule, value)
end

#event_statusObject

An eventStatus of an event represents its status; particularly useful when an event is cancelled or rescheduled.



609
610
611
# File 'lib/schema_org/mixins/event.rb', line 609

def event_status
  read_property(:event_status)
end

#event_status=(value) ⇒ Object

An eventStatus of an event represents its status; particularly useful when an event is cancelled or rescheduled.



614
615
616
# File 'lib/schema_org/mixins/event.rb', line 614

def event_status=(value)
  write_property(:event_status, value)
end

#funderObject

A person or organization that supports (sponsors) something through some kind of financial contribution.



619
620
621
# File 'lib/schema_org/mixins/event.rb', line 619

def funder
  read_property(:funder)
end

#funder=(value) ⇒ Object

A person or organization that supports (sponsors) something through some kind of financial contribution.



624
625
626
# File 'lib/schema_org/mixins/event.rb', line 624

def funder=(value)
  write_property(:funder, value)
end

#fundingObject

A [[Grant]] that directly or indirectly provide funding or sponsorship for this item. See also [[ownershipFundingInfo]]. Inverse-property: fundedItem.



630
631
632
# File 'lib/schema_org/mixins/event.rb', line 630

def funding
  read_property(:funding)
end

#funding=(value) ⇒ Object

A [[Grant]] that directly or indirectly provide funding or sponsorship for this item. See also [[ownershipFundingInfo]]. Inverse-property: fundedItem.



636
637
638
# File 'lib/schema_org/mixins/event.rb', line 636

def funding=(value)
  write_property(:funding, value)
end

#has_participation_offerObject

An offer to participate in the event, for example, Call for Proposals, Call for Speakers, or Call for Performers.



641
642
643
# File 'lib/schema_org/mixins/event.rb', line 641

def has_participation_offer
  read_property(:has_participation_offer)
end

#has_participation_offer=(value) ⇒ Object

An offer to participate in the event, for example, Call for Proposals, Call for Speakers, or Call for Performers.



646
647
648
# File 'lib/schema_org/mixins/event.rb', line 646

def has_participation_offer=(value)
  write_property(:has_participation_offer, value)
end

#has_sponsorship_offerObject

An offer to sponsor the event, for example, Sponsorship Prospectus, Sponsorship Opportunities, or Sponsor Packages.



651
652
653
# File 'lib/schema_org/mixins/event.rb', line 651

def has_sponsorship_offer
  read_property(:has_sponsorship_offer)
end

#has_sponsorship_offer=(value) ⇒ Object

An offer to sponsor the event, for example, Sponsorship Prospectus, Sponsorship Opportunities, or Sponsor Packages.



656
657
658
# File 'lib/schema_org/mixins/event.rb', line 656

def has_sponsorship_offer=(value)
  write_property(:has_sponsorship_offer, value)
end

#in_languageObject

The language of the content or performance or used in an action. Please use one of the language codes from the IETF BCP 47 standard. See also [[availableLanguage]]. Supersedes language.



662
663
664
# File 'lib/schema_org/mixins/event.rb', line 662

def in_language
  read_property(:in_language)
end

#in_language=(value) ⇒ Object

The language of the content or performance or used in an action. Please use one of the language codes from the IETF BCP 47 standard. See also [[availableLanguage]]. Supersedes language.



668
669
670
# File 'lib/schema_org/mixins/event.rb', line 668

def in_language=(value)
  write_property(:in_language, value)
end

#is_accessible_for_freeObject

A flag to signal that the item, event, or place is accessible for free. Supersedes free.



674
675
676
# File 'lib/schema_org/mixins/event.rb', line 674

def is_accessible_for_free
  read_property(:is_accessible_for_free)
end

#is_accessible_for_free=(value) ⇒ Object

A flag to signal that the item, event, or place is accessible for free. Supersedes free.



680
681
682
# File 'lib/schema_org/mixins/event.rb', line 680

def is_accessible_for_free=(value)
  write_property(:is_accessible_for_free, value)
end

#keywordsObject

Keywords or tags used to describe some item. Multiple textual entries in a keywords list are typically delimited by commas, or by repeating the property.



685
686
687
# File 'lib/schema_org/mixins/event.rb', line 685

def keywords
  read_property(:keywords)
end

#keywords=(value) ⇒ Object

Keywords or tags used to describe some item. Multiple textual entries in a keywords list are typically delimited by commas, or by repeating the property.



690
691
692
# File 'lib/schema_org/mixins/event.rb', line 690

def keywords=(value)
  write_property(:keywords, value)
end

#locationObject

The location of, for example, where an event is happening, where an organization is located, or where an action takes place.



695
696
697
# File 'lib/schema_org/mixins/event.rb', line 695

def location
  read_property(:location)
end

#location=(value) ⇒ Object

The location of, for example, where an event is happening, where an organization is located, or where an action takes place.



700
701
702
# File 'lib/schema_org/mixins/event.rb', line 700

def location=(value)
  write_property(:location, value)
end

#maximum_attendee_capacityObject

The total number of individuals that may attend an event or venue.



705
706
707
# File 'lib/schema_org/mixins/event.rb', line 705

def maximum_attendee_capacity
  read_property(:maximum_attendee_capacity)
end

#maximum_attendee_capacity=(value) ⇒ Object

The total number of individuals that may attend an event or venue.



710
711
712
# File 'lib/schema_org/mixins/event.rb', line 710

def maximum_attendee_capacity=(value)
  write_property(:maximum_attendee_capacity, value)
end

#maximum_physical_attendee_capacityObject

The maximum physical attendee capacity of an [[Event]] whose [[eventAttendanceMode]] is [[OfflineEventAttendanceMode]] (or the offline aspects, in the case of a [[MixedEventAttendanceMode]]).



715
716
717
# File 'lib/schema_org/mixins/event.rb', line 715

def maximum_physical_attendee_capacity
  read_property(:maximum_physical_attendee_capacity)
end

#maximum_physical_attendee_capacity=(value) ⇒ Object

The maximum physical attendee capacity of an [[Event]] whose [[eventAttendanceMode]] is [[OfflineEventAttendanceMode]] (or the offline aspects, in the case of a [[MixedEventAttendanceMode]]).



720
721
722
# File 'lib/schema_org/mixins/event.rb', line 720

def maximum_physical_attendee_capacity=(value)
  write_property(:maximum_physical_attendee_capacity, value)
end

#maximum_virtual_attendee_capacityObject

The maximum virtual attendee capacity of an [[Event]] whose [[eventAttendanceMode]] is [[OnlineEventAttendanceMode]] (or the online aspects, in the case of a [[MixedEventAttendanceMode]]).



725
726
727
# File 'lib/schema_org/mixins/event.rb', line 725

def maximum_virtual_attendee_capacity
  read_property(:maximum_virtual_attendee_capacity)
end

#maximum_virtual_attendee_capacity=(value) ⇒ Object

The maximum virtual attendee capacity of an [[Event]] whose [[eventAttendanceMode]] is [[OnlineEventAttendanceMode]] (or the online aspects, in the case of a [[MixedEventAttendanceMode]]).



730
731
732
# File 'lib/schema_org/mixins/event.rb', line 730

def maximum_virtual_attendee_capacity=(value)
  write_property(:maximum_virtual_attendee_capacity, value)
end

#offersObject

An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer. Inverse-property: itemOffered.



736
737
738
# File 'lib/schema_org/mixins/event.rb', line 736

def offers
  read_property(:offers)
end

#offers=(value) ⇒ Object

An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer. Inverse-property: itemOffered.



742
743
744
# File 'lib/schema_org/mixins/event.rb', line 742

def offers=(value)
  write_property(:offers, value)
end

#organizerObject

An organizer of an Event.



747
748
749
# File 'lib/schema_org/mixins/event.rb', line 747

def organizer
  read_property(:organizer)
end

#organizer=(value) ⇒ Object

An organizer of an Event.



752
753
754
# File 'lib/schema_org/mixins/event.rb', line 752

def organizer=(value)
  write_property(:organizer, value)
end

#performerObject

A performer at the event—for example, a presenter, musician, musical group or actor. Supersedes performers.



758
759
760
# File 'lib/schema_org/mixins/event.rb', line 758

def performer
  read_property(:performer)
end

#performer=(value) ⇒ Object

A performer at the event—for example, a presenter, musician, musical group or actor. Supersedes performers.



764
765
766
# File 'lib/schema_org/mixins/event.rb', line 764

def performer=(value)
  write_property(:performer, value)
end

#performersObject

The main performer or performers of the event—for example, a presenter, musician, or actor. Superseded by performer.



770
771
772
# File 'lib/schema_org/mixins/event.rb', line 770

def performers
  read_property(:performers)
end

#performers=(value) ⇒ Object

The main performer or performers of the event—for example, a presenter, musician, or actor. Superseded by performer.



776
777
778
# File 'lib/schema_org/mixins/event.rb', line 776

def performers=(value)
  write_property(:performers, value)
end

#previous_start_dateObject

Used in conjunction with eventStatus for rescheduled or cancelled events. This property contains the previously scheduled start date. For rescheduled events, the startDate property should be used for the newly scheduled start date. In the (rare) case of an event that has been postponed and rescheduled multiple times, this field may be repeated.



781
782
783
# File 'lib/schema_org/mixins/event.rb', line 781

def previous_start_date
  read_property(:previous_start_date)
end

#previous_start_date=(value) ⇒ Object

Used in conjunction with eventStatus for rescheduled or cancelled events. This property contains the previously scheduled start date. For rescheduled events, the startDate property should be used for the newly scheduled start date. In the (rare) case of an event that has been postponed and rescheduled multiple times, this field may be repeated.



786
787
788
# File 'lib/schema_org/mixins/event.rb', line 786

def previous_start_date=(value)
  write_property(:previous_start_date, value)
end

#recorded_inObject

The CreativeWork that captured all or part of this Event. Inverse-property: recordedAt.



792
793
794
# File 'lib/schema_org/mixins/event.rb', line 792

def recorded_in
  read_property(:recorded_in)
end

#recorded_in=(value) ⇒ Object

The CreativeWork that captured all or part of this Event. Inverse-property: recordedAt.



798
799
800
# File 'lib/schema_org/mixins/event.rb', line 798

def recorded_in=(value)
  write_property(:recorded_in, value)
end

#remaining_attendee_capacityObject

The number of attendee places for an event that remain unallocated.



803
804
805
# File 'lib/schema_org/mixins/event.rb', line 803

def remaining_attendee_capacity
  read_property(:remaining_attendee_capacity)
end

#remaining_attendee_capacity=(value) ⇒ Object

The number of attendee places for an event that remain unallocated.



808
809
810
# File 'lib/schema_org/mixins/event.rb', line 808

def remaining_attendee_capacity=(value)
  write_property(:remaining_attendee_capacity, value)
end

#reviewObject

A review of the item. Supersedes reviews.



814
815
816
# File 'lib/schema_org/mixins/event.rb', line 814

def review
  read_property(:review)
end

#review=(value) ⇒ Object

A review of the item. Supersedes reviews.



820
821
822
# File 'lib/schema_org/mixins/event.rb', line 820

def review=(value)
  write_property(:review, value)
end

A person or organization that supports a thing through a pledge, promise, or financial contribution. E.g. a sponsor of a Medical Study or a corporate sponsor of an event.



825
826
827
# File 'lib/schema_org/mixins/event.rb', line 825

def sponsor
  read_property(:sponsor)
end

#sponsor=(value) ⇒ Object

A person or organization that supports a thing through a pledge, promise, or financial contribution. E.g. a sponsor of a Medical Study or a corporate sponsor of an event.



830
831
832
# File 'lib/schema_org/mixins/event.rb', line 830

def sponsor=(value)
  write_property(:sponsor, value)
end

#start_dateObject

The start date and time of the item (in ISO 8601 date format).



835
836
837
# File 'lib/schema_org/mixins/event.rb', line 835

def start_date
  read_property(:start_date)
end

#start_date=(value) ⇒ Object

The start date and time of the item (in ISO 8601 date format).



840
841
842
# File 'lib/schema_org/mixins/event.rb', line 840

def start_date=(value)
  write_property(:start_date, value)
end

#sub_eventObject

An Event that is part of this event. For example, a conference event includes many presentations, each of which is a subEvent of the conference. Supersedes subEvents. Inverse-property: superEvent.



847
848
849
# File 'lib/schema_org/mixins/event.rb', line 847

def sub_event
  read_property(:sub_event)
end

#sub_event=(value) ⇒ Object

An Event that is part of this event. For example, a conference event includes many presentations, each of which is a subEvent of the conference. Supersedes subEvents. Inverse-property: superEvent.



854
855
856
# File 'lib/schema_org/mixins/event.rb', line 854

def sub_event=(value)
  write_property(:sub_event, value)
end

#sub_eventsObject

Events that are a part of this event. For example, a conference event includes many presentations, each subEvents of the conference. Superseded by subEvent.



860
861
862
# File 'lib/schema_org/mixins/event.rb', line 860

def sub_events
  read_property(:sub_events)
end

#sub_events=(value) ⇒ Object

Events that are a part of this event. For example, a conference event includes many presentations, each subEvents of the conference. Superseded by subEvent.



866
867
868
# File 'lib/schema_org/mixins/event.rb', line 866

def sub_events=(value)
  write_property(:sub_events, value)
end

#super_eventObject

An event that this event is a part of. For example, a collection of individual music performances might each have a music festival as their superEvent. Inverse-property: subEvent.



872
873
874
# File 'lib/schema_org/mixins/event.rb', line 872

def super_event
  read_property(:super_event)
end

#super_event=(value) ⇒ Object

An event that this event is a part of. For example, a collection of individual music performances might each have a music festival as their superEvent. Inverse-property: subEvent.



878
879
880
# File 'lib/schema_org/mixins/event.rb', line 878

def super_event=(value)
  write_property(:super_event, value)
end

#translatorObject

Organization or person who adapts a creative work to different languages, regional differences and technical requirements of a target market, or that translates during some event.



883
884
885
# File 'lib/schema_org/mixins/event.rb', line 883

def translator
  read_property(:translator)
end

#translator=(value) ⇒ Object

Organization or person who adapts a creative work to different languages, regional differences and technical requirements of a target market, or that translates during some event.



888
889
890
# File 'lib/schema_org/mixins/event.rb', line 888

def translator=(value)
  write_property(:translator, value)
end

#typical_age_rangeObject

The typical expected age range, e.g. '7-9', '11-'.



893
894
895
# File 'lib/schema_org/mixins/event.rb', line 893

def typical_age_range
  read_property(:typical_age_range)
end

#typical_age_range=(value) ⇒ Object

The typical expected age range, e.g. '7-9', '11-'.



898
899
900
# File 'lib/schema_org/mixins/event.rb', line 898

def typical_age_range=(value)
  write_property(:typical_age_range, value)
end

A work featured in some event, e.g. exhibited in an ExhibitionEvent. Specific subproperties are available for workPerformed (e.g. a play), or a workPresented (a Movie at a ScreeningEvent).



904
905
906
# File 'lib/schema_org/mixins/event.rb', line 904

def work_featured
  read_property(:work_featured)
end

#work_featured=(value) ⇒ Object

A work featured in some event, e.g. exhibited in an ExhibitionEvent. Specific subproperties are available for workPerformed (e.g. a play), or a workPresented (a Movie at a ScreeningEvent).



910
911
912
# File 'lib/schema_org/mixins/event.rb', line 910

def work_featured=(value)
  write_property(:work_featured, value)
end

#work_performedObject

A work performed in some event, for example a play performed in a TheaterEvent.



915
916
917
# File 'lib/schema_org/mixins/event.rb', line 915

def work_performed
  read_property(:work_performed)
end

#work_performed=(value) ⇒ Object

A work performed in some event, for example a play performed in a TheaterEvent.



920
921
922
# File 'lib/schema_org/mixins/event.rb', line 920

def work_performed=(value)
  write_property(:work_performed, value)
end