Module: SchemaOrg::Mixins::ExerciseAction

Includes:
PlayAction
Included in:
ExerciseAction
Defined in:
lib/schema_org/mixins/exercise_action.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from PlayAction

#audience, #audience=, #event, #event=

Methods included from Action

#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, #start_time, #start_time=, #target, #target=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/schema_org/mixins/exercise_action.rb', line 11

def self.schema_property_definitions
  {
    course: {
      schema_name: "course",
      schema_url: "https://schema.org/course",
      comment_lines: ["A sub property of location. The course where this action was taken."].freeze,
      ranges: ["Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "exerciseCourse",
      supersedes: nil
    }.freeze,
    diet: {
      schema_name: "diet",
      schema_url: "https://schema.org/diet",
      comment_lines: ["A sub property of instrument. The diet used in this action."].freeze,
      ranges: ["Diet"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    distance: {
      schema_name: "distance",
      schema_url: "https://schema.org/distance",
      comment_lines: ["The distance travelled, e.g. exercising or travelling."].freeze,
      ranges: ["Distance"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    exercise_course: {
      schema_name: "exerciseCourse",
      schema_url: "https://schema.org/exerciseCourse",
      comment_lines: ["A sub property of location. The course where this action was taken."].freeze,
      ranges: ["Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["course"].freeze
    }.freeze,
    exercise_plan: {
      schema_name: "exercisePlan",
      schema_url: "https://schema.org/exercisePlan",
      comment_lines: ["A sub property of instrument. The exercise plan used on this action."].freeze,
      ranges: ["ExercisePlan"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    exercise_related_diet: {
      schema_name: "exerciseRelatedDiet",
      schema_url: "https://schema.org/exerciseRelatedDiet",
      comment_lines: ["A sub property of instrument. The diet used in this action."].freeze,
      ranges: ["Diet"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    exercise_type: {
      schema_name: "exerciseType",
      schema_url: "https://schema.org/exerciseType",
      comment_lines: ["Type(s) of exercise or activity, such as strength training, flexibility training, aerobics, cardiac rehabilitation, etc."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    from_location: {
      schema_name: "fromLocation",
      schema_url: "https://schema.org/fromLocation",
      comment_lines: ["A sub property of location. The original location of the object or the agent before the action."].freeze,
      ranges: ["Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    opponent: {
      schema_name: "opponent",
      schema_url: "https://schema.org/opponent",
      comment_lines: ["A sub property of participant. The opponent on this action."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    sports_activity_location: {
      schema_name: "sportsActivityLocation",
      schema_url: "https://schema.org/sportsActivityLocation",
      comment_lines: ["A sub property of location. The sports activity location where this action occurred."].freeze,
      ranges: ["SportsActivityLocation"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    sports_event: {
      schema_name: "sportsEvent",
      schema_url: "https://schema.org/sportsEvent",
      comment_lines: ["A sub property of location. The sports event where this action occurred."].freeze,
      ranges: ["SportsEvent"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    sports_team: {
      schema_name: "sportsTeam",
      schema_url: "https://schema.org/sportsTeam",
      comment_lines: ["A sub property of participant. The sports team that participated on this action."].freeze,
      ranges: ["SportsTeam"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    to_location: {
      schema_name: "toLocation",
      schema_url: "https://schema.org/toLocation",
      comment_lines: ["A sub property of location. The final location of the object or the agent after the action."].freeze,
      ranges: ["Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#courseObject

A sub property of location. The course where this action was taken. Superseded by exerciseCourse.



148
149
150
# File 'lib/schema_org/mixins/exercise_action.rb', line 148

def course
  read_property(:course)
end

#course=(value) ⇒ Object

A sub property of location. The course where this action was taken. Superseded by exerciseCourse.



154
155
156
# File 'lib/schema_org/mixins/exercise_action.rb', line 154

def course=(value)
  write_property(:course, value)
end

#dietObject

A sub property of instrument. The diet used in this action.



159
160
161
# File 'lib/schema_org/mixins/exercise_action.rb', line 159

def diet
  read_property(:diet)
end

#diet=(value) ⇒ Object

A sub property of instrument. The diet used in this action.



164
165
166
# File 'lib/schema_org/mixins/exercise_action.rb', line 164

def diet=(value)
  write_property(:diet, value)
end

#distanceObject

The distance travelled, e.g. exercising or travelling.



169
170
171
# File 'lib/schema_org/mixins/exercise_action.rb', line 169

def distance
  read_property(:distance)
end

#distance=(value) ⇒ Object

The distance travelled, e.g. exercising or travelling.



174
175
176
# File 'lib/schema_org/mixins/exercise_action.rb', line 174

def distance=(value)
  write_property(:distance, value)
end

#exercise_courseObject

A sub property of location. The course where this action was taken. Supersedes course.



180
181
182
# File 'lib/schema_org/mixins/exercise_action.rb', line 180

def exercise_course
  read_property(:exercise_course)
end

#exercise_course=(value) ⇒ Object

A sub property of location. The course where this action was taken. Supersedes course.



186
187
188
# File 'lib/schema_org/mixins/exercise_action.rb', line 186

def exercise_course=(value)
  write_property(:exercise_course, value)
end

#exercise_planObject

A sub property of instrument. The exercise plan used on this action.



191
192
193
# File 'lib/schema_org/mixins/exercise_action.rb', line 191

def exercise_plan
  read_property(:exercise_plan)
end

#exercise_plan=(value) ⇒ Object

A sub property of instrument. The exercise plan used on this action.



196
197
198
# File 'lib/schema_org/mixins/exercise_action.rb', line 196

def exercise_plan=(value)
  write_property(:exercise_plan, value)
end

A sub property of instrument. The diet used in this action.



201
202
203
# File 'lib/schema_org/mixins/exercise_action.rb', line 201

def exercise_related_diet
  read_property(:exercise_related_diet)
end

A sub property of instrument. The diet used in this action.



206
207
208
# File 'lib/schema_org/mixins/exercise_action.rb', line 206

def exercise_related_diet=(value)
  write_property(:exercise_related_diet, value)
end

#exercise_typeObject

Type(s) of exercise or activity, such as strength training, flexibility training, aerobics, cardiac rehabilitation, etc.



211
212
213
# File 'lib/schema_org/mixins/exercise_action.rb', line 211

def exercise_type
  read_property(:exercise_type)
end

#exercise_type=(value) ⇒ Object

Type(s) of exercise or activity, such as strength training, flexibility training, aerobics, cardiac rehabilitation, etc.



216
217
218
# File 'lib/schema_org/mixins/exercise_action.rb', line 216

def exercise_type=(value)
  write_property(:exercise_type, value)
end

#from_locationObject

A sub property of location. The original location of the object or the agent before the action.



221
222
223
# File 'lib/schema_org/mixins/exercise_action.rb', line 221

def from_location
  read_property(:from_location)
end

#from_location=(value) ⇒ Object

A sub property of location. The original location of the object or the agent before the action.



226
227
228
# File 'lib/schema_org/mixins/exercise_action.rb', line 226

def from_location=(value)
  write_property(:from_location, value)
end

#opponentObject

A sub property of participant. The opponent on this action.



231
232
233
# File 'lib/schema_org/mixins/exercise_action.rb', line 231

def opponent
  read_property(:opponent)
end

#opponent=(value) ⇒ Object

A sub property of participant. The opponent on this action.



236
237
238
# File 'lib/schema_org/mixins/exercise_action.rb', line 236

def opponent=(value)
  write_property(:opponent, value)
end

#sports_activity_locationObject

A sub property of location. The sports activity location where this action occurred.



241
242
243
# File 'lib/schema_org/mixins/exercise_action.rb', line 241

def sports_activity_location
  read_property(:sports_activity_location)
end

#sports_activity_location=(value) ⇒ Object

A sub property of location. The sports activity location where this action occurred.



246
247
248
# File 'lib/schema_org/mixins/exercise_action.rb', line 246

def sports_activity_location=(value)
  write_property(:sports_activity_location, value)
end

#sports_eventObject

A sub property of location. The sports event where this action occurred.



251
252
253
# File 'lib/schema_org/mixins/exercise_action.rb', line 251

def sports_event
  read_property(:sports_event)
end

#sports_event=(value) ⇒ Object

A sub property of location. The sports event where this action occurred.



256
257
258
# File 'lib/schema_org/mixins/exercise_action.rb', line 256

def sports_event=(value)
  write_property(:sports_event, value)
end

#sports_teamObject

A sub property of participant. The sports team that participated on this action.



261
262
263
# File 'lib/schema_org/mixins/exercise_action.rb', line 261

def sports_team
  read_property(:sports_team)
end

#sports_team=(value) ⇒ Object

A sub property of participant. The sports team that participated on this action.



266
267
268
# File 'lib/schema_org/mixins/exercise_action.rb', line 266

def sports_team=(value)
  write_property(:sports_team, value)
end

#to_locationObject

A sub property of location. The final location of the object or the agent after the action.



271
272
273
# File 'lib/schema_org/mixins/exercise_action.rb', line 271

def to_location
  read_property(:to_location)
end

#to_location=(value) ⇒ Object

A sub property of location. The final location of the object or the agent after the action.



276
277
278
# File 'lib/schema_org/mixins/exercise_action.rb', line 276

def to_location=(value)
  write_property(:to_location, value)
end