Module: SchemaOrg::Mixins::ExercisePlan

Includes:
CreativeWork, PhysicalActivity
Included in:
ExercisePlan
Defined in:
lib/schema_org/mixins/exercise_plan.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from PhysicalActivity

#associated_anatomy, #associated_anatomy=, #category, #category=, #epidemiology, #epidemiology=, #pathophysiology, #pathophysiology=

Methods included from MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Methods included from CreativeWork

#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=

Class Method Details

.schema_property_definitionsObject



12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/schema_org/mixins/exercise_plan.rb', line 12

def self.schema_property_definitions
  {
    activity_duration: {
      schema_name: "activityDuration",
      schema_url: "https://schema.org/activityDuration",
      comment_lines: ["Length of time to engage in the activity."].freeze,
      ranges: ["Duration", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    activity_frequency: {
      schema_name: "activityFrequency",
      schema_url: "https://schema.org/activityFrequency",
      comment_lines: ["How often one should engage in the activity."].freeze,
      ranges: ["QuantitativeValue", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    additional_variable: {
      schema_name: "additionalVariable",
      schema_url: "https://schema.org/additionalVariable",
      comment_lines: ["Any additional component of the exercise prescription that may need to be articulated to the patient. This may include the order of exercises, the number of repetitions of movement, quantitative distance, progressions over time, etc."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    exercise_type: {
      schema_name: "exerciseType",
      schema_url: "https://schema.org/exerciseType",
      comment_lines: ["Type(s) of exercise or activity, such as strength training, flexibility training, aerobics, cardiac rehabilitation, etc."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    intensity: {
      schema_name: "intensity",
      schema_url: "https://schema.org/intensity",
      comment_lines: ["Quantitative measure gauging the degree of force involved in the exercise, for example, heartbeats per minute. May include the velocity of the movement."].freeze,
      ranges: ["QuantitativeValue", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    repetitions: {
      schema_name: "repetitions",
      schema_url: "https://schema.org/repetitions",
      comment_lines: ["Number of times one should repeat the activity."].freeze,
      ranges: ["Number", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    rest_periods: {
      schema_name: "restPeriods",
      schema_url: "https://schema.org/restPeriods",
      comment_lines: ["How often one should break from the activity."].freeze,
      ranges: ["QuantitativeValue", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    workload: {
      schema_name: "workload",
      schema_url: "https://schema.org/workload",
      comment_lines: ["Quantitative measure of the physiologic output of the exercise; also referred to as energy expenditure."].freeze,
      ranges: ["Energy", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#activity_durationObject

Length of time to engage in the activity.



98
99
100
# File 'lib/schema_org/mixins/exercise_plan.rb', line 98

def activity_duration
  read_property(:activity_duration)
end

#activity_duration=(value) ⇒ Object

Length of time to engage in the activity.



103
104
105
# File 'lib/schema_org/mixins/exercise_plan.rb', line 103

def activity_duration=(value)
  write_property(:activity_duration, value)
end

#activity_frequencyObject

How often one should engage in the activity.



108
109
110
# File 'lib/schema_org/mixins/exercise_plan.rb', line 108

def activity_frequency
  read_property(:activity_frequency)
end

#activity_frequency=(value) ⇒ Object

How often one should engage in the activity.



113
114
115
# File 'lib/schema_org/mixins/exercise_plan.rb', line 113

def activity_frequency=(value)
  write_property(:activity_frequency, value)
end

#additional_variableObject

Any additional component of the exercise prescription that may need to be articulated to the patient. This may include the order of exercises, the number of repetitions of movement, quantitative distance, progressions over time, etc.



118
119
120
# File 'lib/schema_org/mixins/exercise_plan.rb', line 118

def additional_variable
  read_property(:additional_variable)
end

#additional_variable=(value) ⇒ Object

Any additional component of the exercise prescription that may need to be articulated to the patient. This may include the order of exercises, the number of repetitions of movement, quantitative distance, progressions over time, etc.



123
124
125
# File 'lib/schema_org/mixins/exercise_plan.rb', line 123

def additional_variable=(value)
  write_property(:additional_variable, value)
end

#exercise_typeObject

Type(s) of exercise or activity, such as strength training, flexibility training, aerobics, cardiac rehabilitation, etc.



128
129
130
# File 'lib/schema_org/mixins/exercise_plan.rb', line 128

def exercise_type
  read_property(:exercise_type)
end

#exercise_type=(value) ⇒ Object

Type(s) of exercise or activity, such as strength training, flexibility training, aerobics, cardiac rehabilitation, etc.



133
134
135
# File 'lib/schema_org/mixins/exercise_plan.rb', line 133

def exercise_type=(value)
  write_property(:exercise_type, value)
end

#intensityObject

Quantitative measure gauging the degree of force involved in the exercise, for example, heartbeats per minute. May include the velocity of the movement.



138
139
140
# File 'lib/schema_org/mixins/exercise_plan.rb', line 138

def intensity
  read_property(:intensity)
end

#intensity=(value) ⇒ Object

Quantitative measure gauging the degree of force involved in the exercise, for example, heartbeats per minute. May include the velocity of the movement.



143
144
145
# File 'lib/schema_org/mixins/exercise_plan.rb', line 143

def intensity=(value)
  write_property(:intensity, value)
end

#repetitionsObject

Number of times one should repeat the activity.



148
149
150
# File 'lib/schema_org/mixins/exercise_plan.rb', line 148

def repetitions
  read_property(:repetitions)
end

#repetitions=(value) ⇒ Object

Number of times one should repeat the activity.



153
154
155
# File 'lib/schema_org/mixins/exercise_plan.rb', line 153

def repetitions=(value)
  write_property(:repetitions, value)
end

#rest_periodsObject

How often one should break from the activity.



158
159
160
# File 'lib/schema_org/mixins/exercise_plan.rb', line 158

def rest_periods
  read_property(:rest_periods)
end

#rest_periods=(value) ⇒ Object

How often one should break from the activity.



163
164
165
# File 'lib/schema_org/mixins/exercise_plan.rb', line 163

def rest_periods=(value)
  write_property(:rest_periods, value)
end

#workloadObject

Quantitative measure of the physiologic output of the exercise; also referred to as energy expenditure.



168
169
170
# File 'lib/schema_org/mixins/exercise_plan.rb', line 168

def workload
  read_property(:workload)
end

#workload=(value) ⇒ Object

Quantitative measure of the physiologic output of the exercise; also referred to as energy expenditure.



173
174
175
# File 'lib/schema_org/mixins/exercise_plan.rb', line 173

def workload=(value)
  write_property(:workload, value)
end