Module: SchemaOrg::Mixins::HealthInsurancePlan

Includes:
Intangible
Included in:
HealthInsurancePlan
Defined in:
lib/schema_org/mixins/health_insurance_plan.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 11

def self.schema_property_definitions
  {
    benefits_summary_url: {
      schema_name: "benefitsSummaryUrl",
      schema_url: "https://schema.org/benefitsSummaryUrl",
      comment_lines: ["The URL that goes directly to the summary of benefits and coverage for the specific standard plan or plan variation."].freeze,
      ranges: ["URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    contact_point: {
      schema_name: "contactPoint",
      schema_url: "https://schema.org/contactPoint",
      comment_lines: ["A contact point for a person or organization."].freeze,
      ranges: ["ContactPoint"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["contactPoints"].freeze
    }.freeze,
    health_plan_drug_option: {
      schema_name: "healthPlanDrugOption",
      schema_url: "https://schema.org/healthPlanDrugOption",
      comment_lines: ["TODO."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    health_plan_drug_tier: {
      schema_name: "healthPlanDrugTier",
      schema_url: "https://schema.org/healthPlanDrugTier",
      comment_lines: ["The tier(s) of drugs offered by this formulary or insurance plan."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    health_plan_id: {
      schema_name: "healthPlanId",
      schema_url: "https://schema.org/healthPlanId",
      comment_lines: ["The 14-character, HIOS-generated Plan ID number. (Plan IDs must be unique, even across different markets.)"].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    health_plan_marketing_url: {
      schema_name: "healthPlanMarketingUrl",
      schema_url: "https://schema.org/healthPlanMarketingUrl",
      comment_lines: ["The URL that goes directly to the plan brochure for the specific standard plan or plan variation."].freeze,
      ranges: ["URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    includes_health_plan_formulary: {
      schema_name: "includesHealthPlanFormulary",
      schema_url: "https://schema.org/includesHealthPlanFormulary",
      comment_lines: ["Formularies covered by this plan."].freeze,
      ranges: ["HealthPlanFormulary"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    includes_health_plan_network: {
      schema_name: "includesHealthPlanNetwork",
      schema_url: "https://schema.org/includesHealthPlanNetwork",
      comment_lines: ["Networks covered by this plan."].freeze,
      ranges: ["HealthPlanNetwork"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    uses_health_plan_id_standard: {
      schema_name: "usesHealthPlanIdStandard",
      schema_url: "https://schema.org/usesHealthPlanIdStandard",
      comment_lines: ["The standard for interpreting the Plan ID. The preferred is \"HIOS\". See the Centers for Medicare & Medicaid Services for more details."].freeze,
      ranges: ["Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#benefits_summary_urlObject

The URL that goes directly to the summary of benefits and coverage for the specific standard plan or plan variation.



107
108
109
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 107

def benefits_summary_url
  read_property(:benefits_summary_url)
end

#benefits_summary_url=(value) ⇒ Object

The URL that goes directly to the summary of benefits and coverage for the specific standard plan or plan variation.



112
113
114
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 112

def benefits_summary_url=(value)
  write_property(:benefits_summary_url, value)
end

#contact_pointObject

A contact point for a person or organization. Supersedes contactPoints.



118
119
120
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 118

def contact_point
  read_property(:contact_point)
end

#contact_point=(value) ⇒ Object

A contact point for a person or organization. Supersedes contactPoints.



124
125
126
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 124

def contact_point=(value)
  write_property(:contact_point, value)
end

#health_plan_drug_optionObject

TODO.



129
130
131
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 129

def health_plan_drug_option
  read_property(:health_plan_drug_option)
end

#health_plan_drug_option=(value) ⇒ Object

TODO.



134
135
136
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 134

def health_plan_drug_option=(value)
  write_property(:health_plan_drug_option, value)
end

#health_plan_drug_tierObject

The tier(s) of drugs offered by this formulary or insurance plan.



139
140
141
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 139

def health_plan_drug_tier
  read_property(:health_plan_drug_tier)
end

#health_plan_drug_tier=(value) ⇒ Object

The tier(s) of drugs offered by this formulary or insurance plan.



144
145
146
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 144

def health_plan_drug_tier=(value)
  write_property(:health_plan_drug_tier, value)
end

#health_plan_idObject

The 14-character, HIOS-generated Plan ID number. (Plan IDs must be unique, even across different markets.)



149
150
151
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 149

def health_plan_id
  read_property(:health_plan_id)
end

#health_plan_id=(value) ⇒ Object

The 14-character, HIOS-generated Plan ID number. (Plan IDs must be unique, even across different markets.)



154
155
156
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 154

def health_plan_id=(value)
  write_property(:health_plan_id, value)
end

#health_plan_marketing_urlObject

The URL that goes directly to the plan brochure for the specific standard plan or plan variation.



159
160
161
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 159

def health_plan_marketing_url
  read_property(:health_plan_marketing_url)
end

#health_plan_marketing_url=(value) ⇒ Object

The URL that goes directly to the plan brochure for the specific standard plan or plan variation.



164
165
166
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 164

def health_plan_marketing_url=(value)
  write_property(:health_plan_marketing_url, value)
end

#includes_health_plan_formularyObject

Formularies covered by this plan.



169
170
171
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 169

def includes_health_plan_formulary
  read_property(:includes_health_plan_formulary)
end

#includes_health_plan_formulary=(value) ⇒ Object

Formularies covered by this plan.



174
175
176
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 174

def includes_health_plan_formulary=(value)
  write_property(:includes_health_plan_formulary, value)
end

#includes_health_plan_networkObject

Networks covered by this plan.



179
180
181
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 179

def includes_health_plan_network
  read_property(:includes_health_plan_network)
end

#includes_health_plan_network=(value) ⇒ Object

Networks covered by this plan.



184
185
186
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 184

def includes_health_plan_network=(value)
  write_property(:includes_health_plan_network, value)
end

#uses_health_plan_id_standardObject

The standard for interpreting the Plan ID. The preferred is "HIOS". See the Centers for Medicare & Medicaid Services for more details.



189
190
191
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 189

def uses_health_plan_id_standard
  read_property(:uses_health_plan_id_standard)
end

#uses_health_plan_id_standard=(value) ⇒ Object

The standard for interpreting the Plan ID. The preferred is "HIOS". See the Centers for Medicare & Medicaid Services for more details.



194
195
196
# File 'lib/schema_org/mixins/health_insurance_plan.rb', line 194

def uses_health_plan_id_standard=(value)
  write_property(:uses_health_plan_id_standard, value)
end