Module: SchemaOrg::Mixins::HealthPlanCostSharingSpecification

Includes:
Intangible
Included in:
HealthPlanCostSharingSpecification
Defined in:
lib/schema_org/mixins/health_plan_cost_sharing_specification.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/schema_org/mixins/health_plan_cost_sharing_specification.rb', line 11

def self.schema_property_definitions
  {
    health_plan_coinsurance_option: {
      schema_name: "healthPlanCoinsuranceOption",
      schema_url: "https://schema.org/healthPlanCoinsuranceOption",
      comment_lines: ["Whether the coinsurance applies before or after deductible, etc. TODO: Is this a closed set?"].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    health_plan_coinsurance_rate: {
      schema_name: "healthPlanCoinsuranceRate",
      schema_url: "https://schema.org/healthPlanCoinsuranceRate",
      comment_lines: ["The rate of coinsurance expressed as a number between 0.0 and 1.0."].freeze,
      ranges: ["Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    health_plan_copay: {
      schema_name: "healthPlanCopay",
      schema_url: "https://schema.org/healthPlanCopay",
      comment_lines: ["The copay amount."].freeze,
      ranges: ["PriceSpecification"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    health_plan_copay_option: {
      schema_name: "healthPlanCopayOption",
      schema_url: "https://schema.org/healthPlanCopayOption",
      comment_lines: ["Whether the copay is before or after deductible, etc. TODO: Is this a closed set?"].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    health_plan_pharmacy_category: {
      schema_name: "healthPlanPharmacyCategory",
      schema_url: "https://schema.org/healthPlanPharmacyCategory",
      comment_lines: ["The category or type of pharmacy associated with this cost sharing."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#health_plan_coinsurance_optionObject

Whether the coinsurance applies before or after deductible, etc. TODO: Is this a closed set?



67
68
69
# File 'lib/schema_org/mixins/health_plan_cost_sharing_specification.rb', line 67

def health_plan_coinsurance_option
  read_property(:health_plan_coinsurance_option)
end

#health_plan_coinsurance_option=(value) ⇒ Object

Whether the coinsurance applies before or after deductible, etc. TODO: Is this a closed set?



72
73
74
# File 'lib/schema_org/mixins/health_plan_cost_sharing_specification.rb', line 72

def health_plan_coinsurance_option=(value)
  write_property(:health_plan_coinsurance_option, value)
end

#health_plan_coinsurance_rateObject

The rate of coinsurance expressed as a number between 0.0 and 1.0.



77
78
79
# File 'lib/schema_org/mixins/health_plan_cost_sharing_specification.rb', line 77

def health_plan_coinsurance_rate
  read_property(:health_plan_coinsurance_rate)
end

#health_plan_coinsurance_rate=(value) ⇒ Object

The rate of coinsurance expressed as a number between 0.0 and 1.0.



82
83
84
# File 'lib/schema_org/mixins/health_plan_cost_sharing_specification.rb', line 82

def health_plan_coinsurance_rate=(value)
  write_property(:health_plan_coinsurance_rate, value)
end

#health_plan_copayObject

The copay amount.



87
88
89
# File 'lib/schema_org/mixins/health_plan_cost_sharing_specification.rb', line 87

def health_plan_copay
  read_property(:health_plan_copay)
end

#health_plan_copay=(value) ⇒ Object

The copay amount.



92
93
94
# File 'lib/schema_org/mixins/health_plan_cost_sharing_specification.rb', line 92

def health_plan_copay=(value)
  write_property(:health_plan_copay, value)
end

#health_plan_copay_optionObject

Whether the copay is before or after deductible, etc. TODO: Is this a closed set?



97
98
99
# File 'lib/schema_org/mixins/health_plan_cost_sharing_specification.rb', line 97

def health_plan_copay_option
  read_property(:health_plan_copay_option)
end

#health_plan_copay_option=(value) ⇒ Object

Whether the copay is before or after deductible, etc. TODO: Is this a closed set?



102
103
104
# File 'lib/schema_org/mixins/health_plan_cost_sharing_specification.rb', line 102

def health_plan_copay_option=(value)
  write_property(:health_plan_copay_option, value)
end

#health_plan_pharmacy_categoryObject

The category or type of pharmacy associated with this cost sharing.



107
108
109
# File 'lib/schema_org/mixins/health_plan_cost_sharing_specification.rb', line 107

def health_plan_pharmacy_category
  read_property(:health_plan_pharmacy_category)
end

#health_plan_pharmacy_category=(value) ⇒ Object

The category or type of pharmacy associated with this cost sharing.



112
113
114
# File 'lib/schema_org/mixins/health_plan_cost_sharing_specification.rb', line 112

def health_plan_pharmacy_category=(value)
  write_property(:health_plan_pharmacy_category, value)
end