Module: SchemaOrg::Mixins::HealthPlanFormulary

Includes:
Intangible
Included in:
HealthPlanFormulary
Defined in:
lib/schema_org/mixins/health_plan_formulary.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/schema_org/mixins/health_plan_formulary.rb', line 11

def self.schema_property_definitions
  {
    health_plan_cost_sharing: {
      schema_name: "healthPlanCostSharing",
      schema_url: "https://schema.org/healthPlanCostSharing",
      comment_lines: ["The costs to the patient for services under this network or formulary."].freeze,
      ranges: ["Boolean", "HealthPlanCostSharingSpecification"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    health_plan_drug_tier: {
      schema_name: "healthPlanDrugTier",
      schema_url: "https://schema.org/healthPlanDrugTier",
      comment_lines: ["The tier(s) of drugs offered by this formulary or insurance plan."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    offers_prescription_by_mail: {
      schema_name: "offersPrescriptionByMail",
      schema_url: "https://schema.org/offersPrescriptionByMail",
      comment_lines: ["Whether prescriptions can be delivered by mail."].freeze,
      ranges: ["Boolean"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#health_plan_cost_sharingObject

The costs to the patient for services under this network or formulary.



47
48
49
# File 'lib/schema_org/mixins/health_plan_formulary.rb', line 47

def health_plan_cost_sharing
  read_property(:health_plan_cost_sharing)
end

#health_plan_cost_sharing=(value) ⇒ Object

The costs to the patient for services under this network or formulary.



52
53
54
# File 'lib/schema_org/mixins/health_plan_formulary.rb', line 52

def health_plan_cost_sharing=(value)
  write_property(:health_plan_cost_sharing, value)
end

#health_plan_drug_tierObject

The tier(s) of drugs offered by this formulary or insurance plan.



57
58
59
# File 'lib/schema_org/mixins/health_plan_formulary.rb', line 57

def health_plan_drug_tier
  read_property(:health_plan_drug_tier)
end

#health_plan_drug_tier=(value) ⇒ Object

The tier(s) of drugs offered by this formulary or insurance plan.



62
63
64
# File 'lib/schema_org/mixins/health_plan_formulary.rb', line 62

def health_plan_drug_tier=(value)
  write_property(:health_plan_drug_tier, value)
end

#offers_prescription_by_mailObject

Whether prescriptions can be delivered by mail.



67
68
69
# File 'lib/schema_org/mixins/health_plan_formulary.rb', line 67

def offers_prescription_by_mail
  read_property(:offers_prescription_by_mail)
end

#offers_prescription_by_mail=(value) ⇒ Object

Whether prescriptions can be delivered by mail.



72
73
74
# File 'lib/schema_org/mixins/health_plan_formulary.rb', line 72

def offers_prescription_by_mail=(value)
  write_property(:offers_prescription_by_mail, value)
end