Module: SchemaOrg::Mixins::House

Includes:
Accommodation
Included in:
House, SingleFamilyResidence
Defined in:
lib/schema_org/mixins/house.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Accommodation

#accommodation_category, #accommodation_category=, #accommodation_floor_plan, #accommodation_floor_plan=, #amenity_feature, #amenity_feature=, #bed, #bed=, #floor_level, #floor_level=, #floor_size, #floor_size=, #lease_length, #lease_length=, #number_of_bathrooms_total, #number_of_bathrooms_total=, #number_of_bedrooms, #number_of_bedrooms=, #number_of_full_bathrooms, #number_of_full_bathrooms=, #number_of_partial_bathrooms, #number_of_partial_bathrooms=, #occupancy, #occupancy=, #permitted_usage, #permitted_usage=, #pets_allowed, #pets_allowed=, #tour_booking_page, #tour_booking_page=, #year_built, #year_built=

Methods included from Place

#additional_property, #additional_property=, #address, #address=, #aggregate_rating, #aggregate_rating=, #amenity_feature, #amenity_feature=, #branch_code, #branch_code=, #contained_in, #contained_in=, #contained_in_place, #contained_in_place=, #contains_place, #contains_place=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #geo, #geo=, #geo_contains, #geo_contains=, #geo_covered_by, #geo_covered_by=, #geo_covers, #geo_covers=, #geo_crosses, #geo_crosses=, #geo_disjoint, #geo_disjoint=, #geo_equals, #geo_equals=, #geo_intersects, #geo_intersects=, #geo_overlaps, #geo_overlaps=, #geo_touches, #geo_touches=, #geo_within, #geo_within=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_drive_through_service, #has_drive_through_service=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_map, #has_map=, #is_accessible_for_free, #is_accessible_for_free=, #isic_v4, #isic_v4=, #keywords, #keywords=, #latitude, #latitude=, #logo, #logo=, #longitude, #longitude=, #map, #map=, #maps, #maps=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #opening_hours_specification, #opening_hours_specification=, #photo, #photo=, #photos, #photos=, #public_access, #public_access=, #review, #review=, #reviews, #reviews=, #slogan, #slogan=, #smoking_allowed, #smoking_allowed=, #special_opening_hours_specification, #special_opening_hours_specification=, #telephone, #telephone=, #tour_booking_page, #tour_booking_page=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
# File 'lib/schema_org/mixins/house.rb', line 11

def self.schema_property_definitions
  {
    number_of_rooms: {
      schema_name: "numberOfRooms",
      schema_url: "https://schema.org/numberOfRooms",
      comment_lines: ["The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business.", "Typical unit code(s): ROM for room or C62 for no unit. The type of room can be put in the unitText property of the QuantitativeValue."].freeze,
      ranges: ["Number", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#number_of_roomsObject

The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business. Typical unit code(s): ROM for room or C62 for no unit. The type of room can be put in the unitText property of the QuantitativeValue.



28
29
30
# File 'lib/schema_org/mixins/house.rb', line 28

def number_of_rooms
  read_property(:number_of_rooms)
end

#number_of_rooms=(value) ⇒ Object

The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business. Typical unit code(s): ROM for room or C62 for no unit. The type of room can be put in the unitText property of the QuantitativeValue.



34
35
36
# File 'lib/schema_org/mixins/house.rb', line 34

def number_of_rooms=(value)
  write_property(:number_of_rooms, value)
end