Module: SchemaOrg::Mixins::HowTo

Includes:
CreativeWork
Included in:
HowTo, Recipe
Defined in:
lib/schema_org/mixins/how_to.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from CreativeWork

#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/schema_org/mixins/how_to.rb', line 11

def self.schema_property_definitions
  {
    estimated_cost: {
      schema_name: "estimatedCost",
      schema_url: "https://schema.org/estimatedCost",
      comment_lines: ["The estimated cost of the supply or supplies consumed when performing instructions."].freeze,
      ranges: ["MonetaryAmount", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    perform_time: {
      schema_name: "performTime",
      schema_url: "https://schema.org/performTime",
      comment_lines: ["The length of time it takes to perform instructions or a direction (not including time to prepare the supplies), in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601)."].freeze,
      ranges: ["Duration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    prep_time: {
      schema_name: "prepTime",
      schema_url: "https://schema.org/prepTime",
      comment_lines: ["The length of time it takes to prepare the items to be used in instructions or a direction, in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601)."].freeze,
      ranges: ["Duration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    step: {
      schema_name: "step",
      schema_url: "https://schema.org/step",
      comment_lines: ["A single step item (as HowToStep, text, document, video, etc.) or a HowToSection."].freeze,
      ranges: ["CreativeWork", "HowToSection", "HowToStep", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["steps"].freeze
    }.freeze,
    steps: {
      schema_name: "steps",
      schema_url: "https://schema.org/steps",
      comment_lines: ["A single step item (as HowToStep, text, document, video, etc.) or a HowToSection (originally misnamed 'steps'; 'step' is preferred)."].freeze,
      ranges: ["CreativeWork", "ItemList", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "step",
      supersedes: nil
    }.freeze,
    supply: {
      schema_name: "supply",
      schema_url: "https://schema.org/supply",
      comment_lines: ["A sub-property of instrument. A supply consumed when performing instructions or a direction."].freeze,
      ranges: ["HowToSupply", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    tool: {
      schema_name: "tool",
      schema_url: "https://schema.org/tool",
      comment_lines: ["A sub property of instrument. An object used (but not consumed) when performing instructions or a direction."].freeze,
      ranges: ["HowToTool", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    total_time: {
      schema_name: "totalTime",
      schema_url: "https://schema.org/totalTime",
      comment_lines: ["The total time required to perform instructions or a direction (including time to prepare the supplies), in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601)."].freeze,
      ranges: ["Duration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    yield: {
      schema_name: "yield",
      schema_url: "https://schema.org/yield",
      comment_lines: ["The quantity that results by performing instructions. For example, a paper airplane, 10 personalized candles."].freeze,
      ranges: ["QuantitativeValue", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#estimated_costObject

The estimated cost of the supply or supplies consumed when performing instructions.



107
108
109
# File 'lib/schema_org/mixins/how_to.rb', line 107

def estimated_cost
  read_property(:estimated_cost)
end

#estimated_cost=(value) ⇒ Object

The estimated cost of the supply or supplies consumed when performing instructions.



112
113
114
# File 'lib/schema_org/mixins/how_to.rb', line 112

def estimated_cost=(value)
  write_property(:estimated_cost, value)
end

#perform_timeObject

The length of time it takes to perform instructions or a direction (not including time to prepare the supplies), in ISO 8601 duration format.



117
118
119
# File 'lib/schema_org/mixins/how_to.rb', line 117

def perform_time
  read_property(:perform_time)
end

#perform_time=(value) ⇒ Object

The length of time it takes to perform instructions or a direction (not including time to prepare the supplies), in ISO 8601 duration format.



122
123
124
# File 'lib/schema_org/mixins/how_to.rb', line 122

def perform_time=(value)
  write_property(:perform_time, value)
end

#prep_timeObject

The length of time it takes to prepare the items to be used in instructions or a direction, in ISO 8601 duration format.



127
128
129
# File 'lib/schema_org/mixins/how_to.rb', line 127

def prep_time
  read_property(:prep_time)
end

#prep_time=(value) ⇒ Object

The length of time it takes to prepare the items to be used in instructions or a direction, in ISO 8601 duration format.



132
133
134
# File 'lib/schema_org/mixins/how_to.rb', line 132

def prep_time=(value)
  write_property(:prep_time, value)
end

#stepObject

A single step item (as HowToStep, text, document, video, etc.) or a HowToSection. Supersedes steps.



138
139
140
# File 'lib/schema_org/mixins/how_to.rb', line 138

def step
  read_property(:step)
end

#step=(value) ⇒ Object

A single step item (as HowToStep, text, document, video, etc.) or a HowToSection. Supersedes steps.



144
145
146
# File 'lib/schema_org/mixins/how_to.rb', line 144

def step=(value)
  write_property(:step, value)
end

#stepsObject

A single step item (as HowToStep, text, document, video, etc.) or a HowToSection (originally misnamed 'steps'; 'step' is preferred). Superseded by step.



150
151
152
# File 'lib/schema_org/mixins/how_to.rb', line 150

def steps
  read_property(:steps)
end

#steps=(value) ⇒ Object

A single step item (as HowToStep, text, document, video, etc.) or a HowToSection (originally misnamed 'steps'; 'step' is preferred). Superseded by step.



156
157
158
# File 'lib/schema_org/mixins/how_to.rb', line 156

def steps=(value)
  write_property(:steps, value)
end

#supplyObject

A sub-property of instrument. A supply consumed when performing instructions or a direction.



161
162
163
# File 'lib/schema_org/mixins/how_to.rb', line 161

def supply
  read_property(:supply)
end

#supply=(value) ⇒ Object

A sub-property of instrument. A supply consumed when performing instructions or a direction.



166
167
168
# File 'lib/schema_org/mixins/how_to.rb', line 166

def supply=(value)
  write_property(:supply, value)
end

#toolObject

A sub property of instrument. An object used (but not consumed) when performing instructions or a direction.



171
172
173
# File 'lib/schema_org/mixins/how_to.rb', line 171

def tool
  read_property(:tool)
end

#tool=(value) ⇒ Object

A sub property of instrument. An object used (but not consumed) when performing instructions or a direction.



176
177
178
# File 'lib/schema_org/mixins/how_to.rb', line 176

def tool=(value)
  write_property(:tool, value)
end

#total_timeObject

The total time required to perform instructions or a direction (including time to prepare the supplies), in ISO 8601 duration format.



181
182
183
# File 'lib/schema_org/mixins/how_to.rb', line 181

def total_time
  read_property(:total_time)
end

#total_time=(value) ⇒ Object

The total time required to perform instructions or a direction (including time to prepare the supplies), in ISO 8601 duration format.



186
187
188
# File 'lib/schema_org/mixins/how_to.rb', line 186

def total_time=(value)
  write_property(:total_time, value)
end

#yieldObject

The quantity that results by performing instructions. For example, a paper airplane, 10 personalized candles.



191
192
193
# File 'lib/schema_org/mixins/how_to.rb', line 191

def yield
  read_property(:yield)
end

#yield=(value) ⇒ Object

The quantity that results by performing instructions. For example, a paper airplane, 10 personalized candles.



196
197
198
# File 'lib/schema_org/mixins/how_to.rb', line 196

def yield=(value)
  write_property(:yield, value)
end