Module: SchemaOrg::Mixins::HowToDirection

Includes:
CreativeWork, ListItem
Included in:
HowToDirection
Defined in:
lib/schema_org/mixins/how_to_direction.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from ListItem

#item, #item=, #next_item, #next_item=, #position, #position=, #previous_item, #previous_item=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Methods included from CreativeWork

#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=

Class Method Details

.schema_property_definitionsObject



12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/schema_org/mixins/how_to_direction.rb', line 12

def self.schema_property_definitions
  {
    after_media: {
      schema_name: "afterMedia",
      schema_url: "https://schema.org/afterMedia",
      comment_lines: ["A media object representing the circumstances after performing this direction."].freeze,
      ranges: ["MediaObject", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    before_media: {
      schema_name: "beforeMedia",
      schema_url: "https://schema.org/beforeMedia",
      comment_lines: ["A media object representing the circumstances before performing this direction."].freeze,
      ranges: ["MediaObject", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    during_media: {
      schema_name: "duringMedia",
      schema_url: "https://schema.org/duringMedia",
      comment_lines: ["A media object representing the circumstances while performing this direction."].freeze,
      ranges: ["MediaObject", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    perform_time: {
      schema_name: "performTime",
      schema_url: "https://schema.org/performTime",
      comment_lines: ["The length of time it takes to perform instructions or a direction (not including time to prepare the supplies), in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601)."].freeze,
      ranges: ["Duration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    prep_time: {
      schema_name: "prepTime",
      schema_url: "https://schema.org/prepTime",
      comment_lines: ["The length of time it takes to prepare the items to be used in instructions or a direction, in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601)."].freeze,
      ranges: ["Duration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    supply: {
      schema_name: "supply",
      schema_url: "https://schema.org/supply",
      comment_lines: ["A sub-property of instrument. A supply consumed when performing instructions or a direction."].freeze,
      ranges: ["HowToSupply", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    tool: {
      schema_name: "tool",
      schema_url: "https://schema.org/tool",
      comment_lines: ["A sub property of instrument. An object used (but not consumed) when performing instructions or a direction."].freeze,
      ranges: ["HowToTool", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    total_time: {
      schema_name: "totalTime",
      schema_url: "https://schema.org/totalTime",
      comment_lines: ["The total time required to perform instructions or a direction (including time to prepare the supplies), in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601)."].freeze,
      ranges: ["Duration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#after_mediaObject

A media object representing the circumstances after performing this direction.



98
99
100
# File 'lib/schema_org/mixins/how_to_direction.rb', line 98

def after_media
  read_property(:after_media)
end

#after_media=(value) ⇒ Object

A media object representing the circumstances after performing this direction.



103
104
105
# File 'lib/schema_org/mixins/how_to_direction.rb', line 103

def after_media=(value)
  write_property(:after_media, value)
end

#before_mediaObject

A media object representing the circumstances before performing this direction.



108
109
110
# File 'lib/schema_org/mixins/how_to_direction.rb', line 108

def before_media
  read_property(:before_media)
end

#before_media=(value) ⇒ Object

A media object representing the circumstances before performing this direction.



113
114
115
# File 'lib/schema_org/mixins/how_to_direction.rb', line 113

def before_media=(value)
  write_property(:before_media, value)
end

#during_mediaObject

A media object representing the circumstances while performing this direction.



118
119
120
# File 'lib/schema_org/mixins/how_to_direction.rb', line 118

def during_media
  read_property(:during_media)
end

#during_media=(value) ⇒ Object

A media object representing the circumstances while performing this direction.



123
124
125
# File 'lib/schema_org/mixins/how_to_direction.rb', line 123

def during_media=(value)
  write_property(:during_media, value)
end

#perform_timeObject

The length of time it takes to perform instructions or a direction (not including time to prepare the supplies), in ISO 8601 duration format.



128
129
130
# File 'lib/schema_org/mixins/how_to_direction.rb', line 128

def perform_time
  read_property(:perform_time)
end

#perform_time=(value) ⇒ Object

The length of time it takes to perform instructions or a direction (not including time to prepare the supplies), in ISO 8601 duration format.



133
134
135
# File 'lib/schema_org/mixins/how_to_direction.rb', line 133

def perform_time=(value)
  write_property(:perform_time, value)
end

#prep_timeObject

The length of time it takes to prepare the items to be used in instructions or a direction, in ISO 8601 duration format.



138
139
140
# File 'lib/schema_org/mixins/how_to_direction.rb', line 138

def prep_time
  read_property(:prep_time)
end

#prep_time=(value) ⇒ Object

The length of time it takes to prepare the items to be used in instructions or a direction, in ISO 8601 duration format.



143
144
145
# File 'lib/schema_org/mixins/how_to_direction.rb', line 143

def prep_time=(value)
  write_property(:prep_time, value)
end

#supplyObject

A sub-property of instrument. A supply consumed when performing instructions or a direction.



148
149
150
# File 'lib/schema_org/mixins/how_to_direction.rb', line 148

def supply
  read_property(:supply)
end

#supply=(value) ⇒ Object

A sub-property of instrument. A supply consumed when performing instructions or a direction.



153
154
155
# File 'lib/schema_org/mixins/how_to_direction.rb', line 153

def supply=(value)
  write_property(:supply, value)
end

#toolObject

A sub property of instrument. An object used (but not consumed) when performing instructions or a direction.



158
159
160
# File 'lib/schema_org/mixins/how_to_direction.rb', line 158

def tool
  read_property(:tool)
end

#tool=(value) ⇒ Object

A sub property of instrument. An object used (but not consumed) when performing instructions or a direction.



163
164
165
# File 'lib/schema_org/mixins/how_to_direction.rb', line 163

def tool=(value)
  write_property(:tool, value)
end

#total_timeObject

The total time required to perform instructions or a direction (including time to prepare the supplies), in ISO 8601 duration format.



168
169
170
# File 'lib/schema_org/mixins/how_to_direction.rb', line 168

def total_time
  read_property(:total_time)
end

#total_time=(value) ⇒ Object

The total time required to perform instructions or a direction (including time to prepare the supplies), in ISO 8601 duration format.



173
174
175
# File 'lib/schema_org/mixins/how_to_direction.rb', line 173

def total_time=(value)
  write_property(:total_time, value)
end