Module: SchemaOrg::Mixins::InformAction

Includes:
CommunicateAction
Included in:
InformAction, ConfirmAction, RsvpAction
Defined in:
lib/schema_org/mixins/inform_action.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from CommunicateAction

#about, #about=, #in_language, #in_language=, #language, #language=, #recipient, #recipient=

Methods included from Action

#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, #start_time, #start_time=, #target, #target=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
# File 'lib/schema_org/mixins/inform_action.rb', line 11

def self.schema_property_definitions
  {
    event: {
      schema_name: "event",
      schema_url: "https://schema.org/event",
      comment_lines: ["Upcoming or past event associated with this place, organization, or action."].freeze,
      ranges: ["Event"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["events"].freeze
    }.freeze
  }.freeze
end

Instance Method Details

#eventObject

Upcoming or past event associated with this place, organization, or action. Supersedes events.



28
29
30
# File 'lib/schema_org/mixins/inform_action.rb', line 28

def event
  read_property(:event)
end

#event=(value) ⇒ Object

Upcoming or past event associated with this place, organization, or action. Supersedes events.



34
35
36
# File 'lib/schema_org/mixins/inform_action.rb', line 34

def event=(value)
  write_property(:event, value)
end