Module: SchemaOrg::Mixins::InsertAction
- Includes:
- AddAction
- Included in:
- InsertAction, AppendAction, PrependAction
- Defined in:
- lib/schema_org/mixins/insert_action.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#to_location ⇒ Object
A sub property of location.
-
#to_location=(value) ⇒ Object
A sub property of location.
Methods included from UpdateAction
#collection, #collection=, #target_collection, #target_collection=
Methods included from Action
#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, #start_time, #start_time=, #target, #target=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 |
# File 'lib/schema_org/mixins/insert_action.rb', line 11 def self.schema_property_definitions { to_location: { schema_name: "toLocation", schema_url: "https://schema.org/toLocation", comment_lines: ["A sub property of location. The final location of the object or the agent after the action."].freeze, ranges: ["Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#to_location ⇒ Object
A sub property of location. The final location of the object or the agent after the action.
27 28 29 |
# File 'lib/schema_org/mixins/insert_action.rb', line 27 def to_location read_property(:to_location) end |
#to_location=(value) ⇒ Object
A sub property of location. The final location of the object or the agent after the action.
32 33 34 |
# File 'lib/schema_org/mixins/insert_action.rb', line 32 def to_location=(value) write_property(:to_location, value) end |