Module: SchemaOrg::Mixins::InteractionCounter

Includes:
StructuredValue
Included in:
InteractionCounter
Defined in:
lib/schema_org/mixins/interaction_counter.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/schema_org/mixins/interaction_counter.rb', line 11

def self.schema_property_definitions
  {
    end_time: {
      schema_name: "endTime",
      schema_url: "https://schema.org/endTime",
      comment_lines: ["The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to *December*. For media, including audio and video, it's the time offset of the end of a clip within a larger file.\\n\\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions."].freeze,
      ranges: ["DateTime", "Time"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    interaction_service: {
      schema_name: "interactionService",
      schema_url: "https://schema.org/interactionService",
      comment_lines: ["The WebSite or SoftwareApplication where the interactions took place."].freeze,
      ranges: ["SoftwareApplication", "WebSite"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    interaction_type: {
      schema_name: "interactionType",
      schema_url: "https://schema.org/interactionType",
      comment_lines: ["The Action representing the type of interaction. For up votes, +1s, etc. use [[LikeAction]]. For down votes use [[DislikeAction]]. Otherwise, use the most specific Action."].freeze,
      ranges: ["Action"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    location: {
      schema_name: "location",
      schema_url: "https://schema.org/location",
      comment_lines: ["The location of, for example, where an event is happening, where an organization is located, or where an action takes place."].freeze,
      ranges: ["Place", "PostalAddress", "Text", "VirtualLocation"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    start_time: {
      schema_name: "startTime",
      schema_url: "https://schema.org/startTime",
      comment_lines: ["The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from *January* to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file.\\n\\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions."].freeze,
      ranges: ["DateTime", "Time"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    user_interaction_count: {
      schema_name: "userInteractionCount",
      schema_url: "https://schema.org/userInteractionCount",
      comment_lines: ["The number of interactions for the CreativeWork using the WebSite or SoftwareApplication."].freeze,
      ranges: ["Integer"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#end_timeObject

The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the end of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.



77
78
79
# File 'lib/schema_org/mixins/interaction_counter.rb', line 77

def end_time
  read_property(:end_time)
end

#end_time=(value) ⇒ Object

The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the end of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.



82
83
84
# File 'lib/schema_org/mixins/interaction_counter.rb', line 82

def end_time=(value)
  write_property(:end_time, value)
end

#interaction_serviceObject

The WebSite or SoftwareApplication where the interactions took place.



87
88
89
# File 'lib/schema_org/mixins/interaction_counter.rb', line 87

def interaction_service
  read_property(:interaction_service)
end

#interaction_service=(value) ⇒ Object

The WebSite or SoftwareApplication where the interactions took place.



92
93
94
# File 'lib/schema_org/mixins/interaction_counter.rb', line 92

def interaction_service=(value)
  write_property(:interaction_service, value)
end

#interaction_typeObject

The Action representing the type of interaction. For up votes, +1s, etc. use [[LikeAction]]. For down votes use [[DislikeAction]]. Otherwise, use the most specific Action.



97
98
99
# File 'lib/schema_org/mixins/interaction_counter.rb', line 97

def interaction_type
  read_property(:interaction_type)
end

#interaction_type=(value) ⇒ Object

The Action representing the type of interaction. For up votes, +1s, etc. use [[LikeAction]]. For down votes use [[DislikeAction]]. Otherwise, use the most specific Action.



102
103
104
# File 'lib/schema_org/mixins/interaction_counter.rb', line 102

def interaction_type=(value)
  write_property(:interaction_type, value)
end

#locationObject

The location of, for example, where an event is happening, where an organization is located, or where an action takes place.



107
108
109
# File 'lib/schema_org/mixins/interaction_counter.rb', line 107

def location
  read_property(:location)
end

#location=(value) ⇒ Object

The location of, for example, where an event is happening, where an organization is located, or where an action takes place.



112
113
114
# File 'lib/schema_org/mixins/interaction_counter.rb', line 112

def location=(value)
  write_property(:location, value)
end

#start_timeObject

The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.



117
118
119
# File 'lib/schema_org/mixins/interaction_counter.rb', line 117

def start_time
  read_property(:start_time)
end

#start_time=(value) ⇒ Object

The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.



122
123
124
# File 'lib/schema_org/mixins/interaction_counter.rb', line 122

def start_time=(value)
  write_property(:start_time, value)
end

#user_interaction_countObject

The number of interactions for the CreativeWork using the WebSite or SoftwareApplication.



127
128
129
# File 'lib/schema_org/mixins/interaction_counter.rb', line 127

def user_interaction_count
  read_property(:user_interaction_count)
end

#user_interaction_count=(value) ⇒ Object

The number of interactions for the CreativeWork using the WebSite or SoftwareApplication.



132
133
134
# File 'lib/schema_org/mixins/interaction_counter.rb', line 132

def user_interaction_count=(value)
  write_property(:user_interaction_count, value)
end