Module: SchemaOrg::Mixins::JobPosting

Includes:
Intangible
Included in:
JobPosting
Defined in:
lib/schema_org/mixins/job_posting.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/schema_org/mixins/job_posting.rb', line 11

def self.schema_property_definitions
  {
    applicant_location_requirements: {
      schema_name: "applicantLocationRequirements",
      schema_url: "https://schema.org/applicantLocationRequirements",
      comment_lines: ["The location(s) applicants can apply from. This is usually used for telecommuting jobs where the applicant does not need to be in a physical office. Note: This should not be used for citizenship or work visa requirements."].freeze,
      ranges: ["AdministrativeArea"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    application_contact: {
      schema_name: "applicationContact",
      schema_url: "https://schema.org/applicationContact",
      comment_lines: ["Contact details for further information relevant to this job posting."].freeze,
      ranges: ["ContactPoint"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    base_salary: {
      schema_name: "baseSalary",
      schema_url: "https://schema.org/baseSalary",
      comment_lines: ["The base salary of the job or of an employee in an EmployeeRole."].freeze,
      ranges: ["MonetaryAmount", "Number", "PriceSpecification"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    benefits: {
      schema_name: "benefits",
      schema_url: "https://schema.org/benefits",
      comment_lines: ["Description of benefits associated with the job."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "jobBenefits",
      supersedes: nil
    }.freeze,
    date_posted: {
      schema_name: "datePosted",
      schema_url: "https://schema.org/datePosted",
      comment_lines: ["Publication date of an online listing."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    direct_apply: {
      schema_name: "directApply",
      schema_url: "https://schema.org/directApply",
      comment_lines: ["Indicates whether an [[url]] that is associated with a [[JobPosting]] enables direct application for the job, via the posting website. A job posting is considered to have directApply of [[True]] if an application process for the specified job can be directly initiated via the url(s) given (noting that e.g. multiple internet domains might nevertheless be involved at an implementation level). A value of [[False]] is appropriate if there is no clear path to applying directly online for the specified job, navigating directly from the JobPosting url(s) supplied."].freeze,
      ranges: ["Boolean"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    education_requirements: {
      schema_name: "educationRequirements",
      schema_url: "https://schema.org/educationRequirements",
      comment_lines: ["Educational background needed for the position or Occupation."].freeze,
      ranges: ["EducationalOccupationalCredential", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    eligibility_to_work_requirement: {
      schema_name: "eligibilityToWorkRequirement",
      schema_url: "https://schema.org/eligibilityToWorkRequirement",
      comment_lines: ["The legal requirements such as citizenship, visa and other documentation required for an applicant to this job."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    employer_overview: {
      schema_name: "employerOverview",
      schema_url: "https://schema.org/employerOverview",
      comment_lines: ["A description of the employer, career opportunities and work environment for this position."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    employment_type: {
      schema_name: "employmentType",
      schema_url: "https://schema.org/employmentType",
      comment_lines: ["Type of employment (e.g. full-time, part-time, contract, temporary, seasonal, internship)."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    employment_unit: {
      schema_name: "employmentUnit",
      schema_url: "https://schema.org/employmentUnit",
      comment_lines: ["Indicates the department, unit and/or facility where the employee reports and/or in which the job is to be performed."].freeze,
      ranges: ["Organization"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    estimated_salary: {
      schema_name: "estimatedSalary",
      schema_url: "https://schema.org/estimatedSalary",
      comment_lines: ["An estimated salary for a job posting or occupation, based on a variety of variables including, but not limited to industry, job title, and location. Estimated salaries  are often computed by outside organizations rather than the hiring organization, who may not have committed to the estimated value."].freeze,
      ranges: ["MonetaryAmount", "MonetaryAmountDistribution", "Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    experience_in_place_of_education: {
      schema_name: "experienceInPlaceOfEducation",
      schema_url: "https://schema.org/experienceInPlaceOfEducation",
      comment_lines: ["Indicates whether a [[JobPosting]] will accept experience (as indicated by [[OccupationalExperienceRequirements]]) in place of its formal educational qualifications (as indicated by [[educationRequirements]]). If true, indicates that satisfying one of these requirements is sufficient."].freeze,
      ranges: ["Boolean"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    experience_requirements: {
      schema_name: "experienceRequirements",
      schema_url: "https://schema.org/experienceRequirements",
      comment_lines: ["Description of skills and experience needed for the position or Occupation."].freeze,
      ranges: ["OccupationalExperienceRequirements", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    hiring_organization: {
      schema_name: "hiringOrganization",
      schema_url: "https://schema.org/hiringOrganization",
      comment_lines: ["Organization or Person offering the job position."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    incentive_compensation: {
      schema_name: "incentiveCompensation",
      schema_url: "https://schema.org/incentiveCompensation",
      comment_lines: ["Description of bonus and commission compensation aspects of the job."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["incentives"].freeze
    }.freeze,
    incentives: {
      schema_name: "incentives",
      schema_url: "https://schema.org/incentives",
      comment_lines: ["Description of bonus and commission compensation aspects of the job."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "incentiveCompensation",
      supersedes: nil
    }.freeze,
    industry: {
      schema_name: "industry",
      schema_url: "https://schema.org/industry",
      comment_lines: ["The industry associated with the job position."].freeze,
      ranges: ["DefinedTerm", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    job_benefits: {
      schema_name: "jobBenefits",
      schema_url: "https://schema.org/jobBenefits",
      comment_lines: ["Description of benefits associated with the job."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["benefits"].freeze
    }.freeze,
    job_duration: {
      schema_name: "jobDuration",
      schema_url: "https://schema.org/jobDuration",
      comment_lines: ["The expected duration of an employment offer as advertised by the employer. Relevant for job postings that have a clearly defined period in mind such as seasonal work, substitutes for maternal leave or any other temporary employment."].freeze,
      ranges: ["Duration", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    job_immediate_start: {
      schema_name: "jobImmediateStart",
      schema_url: "https://schema.org/jobImmediateStart",
      comment_lines: ["An indicator as to whether a position is available for an immediate start."].freeze,
      ranges: ["Boolean"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    job_location: {
      schema_name: "jobLocation",
      schema_url: "https://schema.org/jobLocation",
      comment_lines: ["A (typically single) geographic location associated with the job position."].freeze,
      ranges: ["Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    job_location_type: {
      schema_name: "jobLocationType",
      schema_url: "https://schema.org/jobLocationType",
      comment_lines: ["A description of the job location (e.g. TELECOMMUTE for telecommute jobs)."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    job_start_date: {
      schema_name: "jobStartDate",
      schema_url: "https://schema.org/jobStartDate",
      comment_lines: ["The date on which a successful applicant for this job would be expected to start work. Choose a specific date in the future or use the jobImmediateStart property to indicate the position is to be filled as soon as possible."].freeze,
      ranges: ["Date", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    occupational_category: {
      schema_name: "occupationalCategory",
      schema_url: "https://schema.org/occupationalCategory",
      comment_lines: ["A category describing the job, preferably using a term from a taxonomy such as [BLS O*NET-SOC](http://www.onetcenter.org/taxonomy.html), [ISCO-08](https://www.ilo.org/public/english/bureau/stat/isco/isco08/) or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided.\\n", "Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC."].freeze,
      ranges: ["CategoryCode", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    physical_requirement: {
      schema_name: "physicalRequirement",
      schema_url: "https://schema.org/physicalRequirement",
      comment_lines: ["A description of the types of physical activity associated with the job. Defined terms such as those in O*net may be used, but note that there is no way to specify the level of ability as well as its nature when using a defined term."].freeze,
      ranges: ["DefinedTerm", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    qualifications: {
      schema_name: "qualifications",
      schema_url: "https://schema.org/qualifications",
      comment_lines: ["Specific qualifications required for this role or Occupation."].freeze,
      ranges: ["Credential", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    relevant_occupation: {
      schema_name: "relevantOccupation",
      schema_url: "https://schema.org/relevantOccupation",
      comment_lines: ["The Occupation for the JobPosting."].freeze,
      ranges: ["Occupation"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    responsibilities: {
      schema_name: "responsibilities",
      schema_url: "https://schema.org/responsibilities",
      comment_lines: ["Responsibilities associated with this role or Occupation."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    salary_currency: {
      schema_name: "salaryCurrency",
      schema_url: "https://schema.org/salaryCurrency",
      comment_lines: ["The currency (coded using [ISO 4217](http://en.wikipedia.org/wiki/ISO_4217)) used for the main salary information in this job posting or for this employee."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    security_clearance_requirement: {
      schema_name: "securityClearanceRequirement",
      schema_url: "https://schema.org/securityClearanceRequirement",
      comment_lines: ["A description of any security clearance requirements of the job."].freeze,
      ranges: ["Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    sensory_requirement: {
      schema_name: "sensoryRequirement",
      schema_url: "https://schema.org/sensoryRequirement",
      comment_lines: ["A description of any sensory requirements and levels necessary to function on the job, including hearing and vision. Defined terms such as those in O*net may be used, but note that there is no way to specify the level of ability as well as its nature when using a defined term."].freeze,
      ranges: ["DefinedTerm", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    skills: {
      schema_name: "skills",
      schema_url: "https://schema.org/skills",
      comment_lines: ["A statement of knowledge, skill, ability, task or any other assertion expressing a competency that is either claimed by a person, an organization or desired or required to fulfill a role or to work in an occupation."].freeze,
      ranges: ["DefinedTerm", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    special_commitments: {
      schema_name: "specialCommitments",
      schema_url: "https://schema.org/specialCommitments",
      comment_lines: ["Any special commitments associated with this job posting. Valid entries include VeteranCommit, MilitarySpouseCommit, etc."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    title: {
      schema_name: "title",
      schema_url: "https://schema.org/title",
      comment_lines: ["The title of the job."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    total_job_openings: {
      schema_name: "totalJobOpenings",
      schema_url: "https://schema.org/totalJobOpenings",
      comment_lines: ["The number of positions open for this job posting. Use a positive integer. Do not use if the number of positions is unclear or not known."].freeze,
      ranges: ["Integer"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    valid_through: {
      schema_name: "validThrough",
      schema_url: "https://schema.org/validThrough",
      comment_lines: ["The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    work_hours: {
      schema_name: "workHours",
      schema_url: "https://schema.org/workHours",
      comment_lines: ["The typical working hours for this job (e.g. 1st shift, night shift, 8am-5pm)."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#applicant_location_requirementsObject

The location(s) applicants can apply from. This is usually used for telecommuting jobs where the applicant does not need to be in a physical office. Note: This should not be used for citizenship or work visa requirements.



397
398
399
# File 'lib/schema_org/mixins/job_posting.rb', line 397

def applicant_location_requirements
  read_property(:applicant_location_requirements)
end

#applicant_location_requirements=(value) ⇒ Object

The location(s) applicants can apply from. This is usually used for telecommuting jobs where the applicant does not need to be in a physical office. Note: This should not be used for citizenship or work visa requirements.



402
403
404
# File 'lib/schema_org/mixins/job_posting.rb', line 402

def applicant_location_requirements=(value)
  write_property(:applicant_location_requirements, value)
end

#application_contactObject

Contact details for further information relevant to this job posting.



407
408
409
# File 'lib/schema_org/mixins/job_posting.rb', line 407

def application_contact
  read_property(:application_contact)
end

#application_contact=(value) ⇒ Object

Contact details for further information relevant to this job posting.



412
413
414
# File 'lib/schema_org/mixins/job_posting.rb', line 412

def application_contact=(value)
  write_property(:application_contact, value)
end

#base_salaryObject

The base salary of the job or of an employee in an EmployeeRole.



417
418
419
# File 'lib/schema_org/mixins/job_posting.rb', line 417

def base_salary
  read_property(:base_salary)
end

#base_salary=(value) ⇒ Object

The base salary of the job or of an employee in an EmployeeRole.



422
423
424
# File 'lib/schema_org/mixins/job_posting.rb', line 422

def base_salary=(value)
  write_property(:base_salary, value)
end

#benefitsObject

Description of benefits associated with the job. Superseded by jobBenefits.



428
429
430
# File 'lib/schema_org/mixins/job_posting.rb', line 428

def benefits
  read_property(:benefits)
end

#benefits=(value) ⇒ Object

Description of benefits associated with the job. Superseded by jobBenefits.



434
435
436
# File 'lib/schema_org/mixins/job_posting.rb', line 434

def benefits=(value)
  write_property(:benefits, value)
end

#date_postedObject

Publication date of an online listing.



439
440
441
# File 'lib/schema_org/mixins/job_posting.rb', line 439

def date_posted
  read_property(:date_posted)
end

#date_posted=(value) ⇒ Object

Publication date of an online listing.



444
445
446
# File 'lib/schema_org/mixins/job_posting.rb', line 444

def date_posted=(value)
  write_property(:date_posted, value)
end

#direct_applyObject

Indicates whether an [[url]] that is associated with a [[JobPosting]] enables direct application for the job, via the posting website. A job posting is considered to have directApply of [[True]] if an application process for the specified job can be directly initiated via the url(s) given (noting that e.g. multiple internet domains might nevertheless be involved at an implementation level). A value of [[False]] is appropriate if there is no clear path to applying directly online for the specified job, navigating directly from the JobPosting url(s) supplied.



449
450
451
# File 'lib/schema_org/mixins/job_posting.rb', line 449

def direct_apply
  read_property(:direct_apply)
end

#direct_apply=(value) ⇒ Object

Indicates whether an [[url]] that is associated with a [[JobPosting]] enables direct application for the job, via the posting website. A job posting is considered to have directApply of [[True]] if an application process for the specified job can be directly initiated via the url(s) given (noting that e.g. multiple internet domains might nevertheless be involved at an implementation level). A value of [[False]] is appropriate if there is no clear path to applying directly online for the specified job, navigating directly from the JobPosting url(s) supplied.



454
455
456
# File 'lib/schema_org/mixins/job_posting.rb', line 454

def direct_apply=(value)
  write_property(:direct_apply, value)
end

#education_requirementsObject

Educational background needed for the position or Occupation.



459
460
461
# File 'lib/schema_org/mixins/job_posting.rb', line 459

def education_requirements
  read_property(:education_requirements)
end

#education_requirements=(value) ⇒ Object

Educational background needed for the position or Occupation.



464
465
466
# File 'lib/schema_org/mixins/job_posting.rb', line 464

def education_requirements=(value)
  write_property(:education_requirements, value)
end

#eligibility_to_work_requirementObject

The legal requirements such as citizenship, visa and other documentation required for an applicant to this job.



469
470
471
# File 'lib/schema_org/mixins/job_posting.rb', line 469

def eligibility_to_work_requirement
  read_property(:eligibility_to_work_requirement)
end

#eligibility_to_work_requirement=(value) ⇒ Object

The legal requirements such as citizenship, visa and other documentation required for an applicant to this job.



474
475
476
# File 'lib/schema_org/mixins/job_posting.rb', line 474

def eligibility_to_work_requirement=(value)
  write_property(:eligibility_to_work_requirement, value)
end

#employer_overviewObject

A description of the employer, career opportunities and work environment for this position.



479
480
481
# File 'lib/schema_org/mixins/job_posting.rb', line 479

def employer_overview
  read_property(:employer_overview)
end

#employer_overview=(value) ⇒ Object

A description of the employer, career opportunities and work environment for this position.



484
485
486
# File 'lib/schema_org/mixins/job_posting.rb', line 484

def employer_overview=(value)
  write_property(:employer_overview, value)
end

#employment_typeObject

Type of employment (e.g. full-time, part-time, contract, temporary, seasonal, internship).



489
490
491
# File 'lib/schema_org/mixins/job_posting.rb', line 489

def employment_type
  read_property(:employment_type)
end

#employment_type=(value) ⇒ Object

Type of employment (e.g. full-time, part-time, contract, temporary, seasonal, internship).



494
495
496
# File 'lib/schema_org/mixins/job_posting.rb', line 494

def employment_type=(value)
  write_property(:employment_type, value)
end

#employment_unitObject

Indicates the department, unit and/or facility where the employee reports and/or in which the job is to be performed.



499
500
501
# File 'lib/schema_org/mixins/job_posting.rb', line 499

def employment_unit
  read_property(:employment_unit)
end

#employment_unit=(value) ⇒ Object

Indicates the department, unit and/or facility where the employee reports and/or in which the job is to be performed.



504
505
506
# File 'lib/schema_org/mixins/job_posting.rb', line 504

def employment_unit=(value)
  write_property(:employment_unit, value)
end

#estimated_salaryObject

An estimated salary for a job posting or occupation, based on a variety of variables including, but not limited to industry, job title, and location. Estimated salaries are often computed by outside organizations rather than the hiring organization, who may not have committed to the estimated value.



509
510
511
# File 'lib/schema_org/mixins/job_posting.rb', line 509

def estimated_salary
  read_property(:estimated_salary)
end

#estimated_salary=(value) ⇒ Object

An estimated salary for a job posting or occupation, based on a variety of variables including, but not limited to industry, job title, and location. Estimated salaries are often computed by outside organizations rather than the hiring organization, who may not have committed to the estimated value.



514
515
516
# File 'lib/schema_org/mixins/job_posting.rb', line 514

def estimated_salary=(value)
  write_property(:estimated_salary, value)
end

#experience_in_place_of_educationObject

Indicates whether a [[JobPosting]] will accept experience (as indicated by [[OccupationalExperienceRequirements]]) in place of its formal educational qualifications (as indicated by [[educationRequirements]]). If true, indicates that satisfying one of these requirements is sufficient.



519
520
521
# File 'lib/schema_org/mixins/job_posting.rb', line 519

def experience_in_place_of_education
  read_property(:experience_in_place_of_education)
end

#experience_in_place_of_education=(value) ⇒ Object

Indicates whether a [[JobPosting]] will accept experience (as indicated by [[OccupationalExperienceRequirements]]) in place of its formal educational qualifications (as indicated by [[educationRequirements]]). If true, indicates that satisfying one of these requirements is sufficient.



524
525
526
# File 'lib/schema_org/mixins/job_posting.rb', line 524

def experience_in_place_of_education=(value)
  write_property(:experience_in_place_of_education, value)
end

#experience_requirementsObject

Description of skills and experience needed for the position or Occupation.



529
530
531
# File 'lib/schema_org/mixins/job_posting.rb', line 529

def experience_requirements
  read_property(:experience_requirements)
end

#experience_requirements=(value) ⇒ Object

Description of skills and experience needed for the position or Occupation.



534
535
536
# File 'lib/schema_org/mixins/job_posting.rb', line 534

def experience_requirements=(value)
  write_property(:experience_requirements, value)
end

#hiring_organizationObject

Organization or Person offering the job position.



539
540
541
# File 'lib/schema_org/mixins/job_posting.rb', line 539

def hiring_organization
  read_property(:hiring_organization)
end

#hiring_organization=(value) ⇒ Object

Organization or Person offering the job position.



544
545
546
# File 'lib/schema_org/mixins/job_posting.rb', line 544

def hiring_organization=(value)
  write_property(:hiring_organization, value)
end

#incentive_compensationObject

Description of bonus and commission compensation aspects of the job. Supersedes incentives.



550
551
552
# File 'lib/schema_org/mixins/job_posting.rb', line 550

def incentive_compensation
  read_property(:incentive_compensation)
end

#incentive_compensation=(value) ⇒ Object

Description of bonus and commission compensation aspects of the job. Supersedes incentives.



556
557
558
# File 'lib/schema_org/mixins/job_posting.rb', line 556

def incentive_compensation=(value)
  write_property(:incentive_compensation, value)
end

#incentivesObject

Description of bonus and commission compensation aspects of the job. Superseded by incentiveCompensation.



562
563
564
# File 'lib/schema_org/mixins/job_posting.rb', line 562

def incentives
  read_property(:incentives)
end

#incentives=(value) ⇒ Object

Description of bonus and commission compensation aspects of the job. Superseded by incentiveCompensation.



568
569
570
# File 'lib/schema_org/mixins/job_posting.rb', line 568

def incentives=(value)
  write_property(:incentives, value)
end

#industryObject

The industry associated with the job position.



573
574
575
# File 'lib/schema_org/mixins/job_posting.rb', line 573

def industry
  read_property(:industry)
end

#industry=(value) ⇒ Object

The industry associated with the job position.



578
579
580
# File 'lib/schema_org/mixins/job_posting.rb', line 578

def industry=(value)
  write_property(:industry, value)
end

#job_benefitsObject

Description of benefits associated with the job. Supersedes benefits.



584
585
586
# File 'lib/schema_org/mixins/job_posting.rb', line 584

def job_benefits
  read_property(:job_benefits)
end

#job_benefits=(value) ⇒ Object

Description of benefits associated with the job. Supersedes benefits.



590
591
592
# File 'lib/schema_org/mixins/job_posting.rb', line 590

def job_benefits=(value)
  write_property(:job_benefits, value)
end

#job_durationObject

The expected duration of an employment offer as advertised by the employer. Relevant for job postings that have a clearly defined period in mind such as seasonal work, substitutes for maternal leave or any other temporary employment.



595
596
597
# File 'lib/schema_org/mixins/job_posting.rb', line 595

def job_duration
  read_property(:job_duration)
end

#job_duration=(value) ⇒ Object

The expected duration of an employment offer as advertised by the employer. Relevant for job postings that have a clearly defined period in mind such as seasonal work, substitutes for maternal leave or any other temporary employment.



600
601
602
# File 'lib/schema_org/mixins/job_posting.rb', line 600

def job_duration=(value)
  write_property(:job_duration, value)
end

#job_immediate_startObject

An indicator as to whether a position is available for an immediate start.



605
606
607
# File 'lib/schema_org/mixins/job_posting.rb', line 605

def job_immediate_start
  read_property(:job_immediate_start)
end

#job_immediate_start=(value) ⇒ Object

An indicator as to whether a position is available for an immediate start.



610
611
612
# File 'lib/schema_org/mixins/job_posting.rb', line 610

def job_immediate_start=(value)
  write_property(:job_immediate_start, value)
end

#job_locationObject

A (typically single) geographic location associated with the job position.



615
616
617
# File 'lib/schema_org/mixins/job_posting.rb', line 615

def job_location
  read_property(:job_location)
end

#job_location=(value) ⇒ Object

A (typically single) geographic location associated with the job position.



620
621
622
# File 'lib/schema_org/mixins/job_posting.rb', line 620

def job_location=(value)
  write_property(:job_location, value)
end

#job_location_typeObject

A description of the job location (e.g. TELECOMMUTE for telecommute jobs).



625
626
627
# File 'lib/schema_org/mixins/job_posting.rb', line 625

def job_location_type
  read_property(:job_location_type)
end

#job_location_type=(value) ⇒ Object

A description of the job location (e.g. TELECOMMUTE for telecommute jobs).



630
631
632
# File 'lib/schema_org/mixins/job_posting.rb', line 630

def job_location_type=(value)
  write_property(:job_location_type, value)
end

#job_start_dateObject

The date on which a successful applicant for this job would be expected to start work. Choose a specific date in the future or use the jobImmediateStart property to indicate the position is to be filled as soon as possible.



635
636
637
# File 'lib/schema_org/mixins/job_posting.rb', line 635

def job_start_date
  read_property(:job_start_date)
end

#job_start_date=(value) ⇒ Object

The date on which a successful applicant for this job would be expected to start work. Choose a specific date in the future or use the jobImmediateStart property to indicate the position is to be filled as soon as possible.



640
641
642
# File 'lib/schema_org/mixins/job_posting.rb', line 640

def job_start_date=(value)
  write_property(:job_start_date, value)
end

#occupational_categoryObject

A category describing the job, preferably using a term from a taxonomy such as BLS O*NET-SOC, ISCO-08 or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided.\n Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC.



646
647
648
# File 'lib/schema_org/mixins/job_posting.rb', line 646

def occupational_category
  read_property(:occupational_category)
end

#occupational_category=(value) ⇒ Object

A category describing the job, preferably using a term from a taxonomy such as BLS O*NET-SOC, ISCO-08 or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided.\n Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC.



652
653
654
# File 'lib/schema_org/mixins/job_posting.rb', line 652

def occupational_category=(value)
  write_property(:occupational_category, value)
end

#physical_requirementObject

A description of the types of physical activity associated with the job. Defined terms such as those in O*net may be used, but note that there is no way to specify the level of ability as well as its nature when using a defined term.



657
658
659
# File 'lib/schema_org/mixins/job_posting.rb', line 657

def physical_requirement
  read_property(:physical_requirement)
end

#physical_requirement=(value) ⇒ Object

A description of the types of physical activity associated with the job. Defined terms such as those in O*net may be used, but note that there is no way to specify the level of ability as well as its nature when using a defined term.



662
663
664
# File 'lib/schema_org/mixins/job_posting.rb', line 662

def physical_requirement=(value)
  write_property(:physical_requirement, value)
end

#qualificationsObject

Specific qualifications required for this role or Occupation.



667
668
669
# File 'lib/schema_org/mixins/job_posting.rb', line 667

def qualifications
  read_property(:qualifications)
end

#qualifications=(value) ⇒ Object

Specific qualifications required for this role or Occupation.



672
673
674
# File 'lib/schema_org/mixins/job_posting.rb', line 672

def qualifications=(value)
  write_property(:qualifications, value)
end

#relevant_occupationObject

The Occupation for the JobPosting.



677
678
679
# File 'lib/schema_org/mixins/job_posting.rb', line 677

def relevant_occupation
  read_property(:relevant_occupation)
end

#relevant_occupation=(value) ⇒ Object

The Occupation for the JobPosting.



682
683
684
# File 'lib/schema_org/mixins/job_posting.rb', line 682

def relevant_occupation=(value)
  write_property(:relevant_occupation, value)
end

#responsibilitiesObject

Responsibilities associated with this role or Occupation.



687
688
689
# File 'lib/schema_org/mixins/job_posting.rb', line 687

def responsibilities
  read_property(:responsibilities)
end

#responsibilities=(value) ⇒ Object

Responsibilities associated with this role or Occupation.



692
693
694
# File 'lib/schema_org/mixins/job_posting.rb', line 692

def responsibilities=(value)
  write_property(:responsibilities, value)
end

#salary_currencyObject

The currency (coded using ISO 4217) used for the main salary information in this job posting or for this employee.



697
698
699
# File 'lib/schema_org/mixins/job_posting.rb', line 697

def salary_currency
  read_property(:salary_currency)
end

#salary_currency=(value) ⇒ Object

The currency (coded using ISO 4217) used for the main salary information in this job posting or for this employee.



702
703
704
# File 'lib/schema_org/mixins/job_posting.rb', line 702

def salary_currency=(value)
  write_property(:salary_currency, value)
end

#security_clearance_requirementObject

A description of any security clearance requirements of the job.



707
708
709
# File 'lib/schema_org/mixins/job_posting.rb', line 707

def security_clearance_requirement
  read_property(:security_clearance_requirement)
end

#security_clearance_requirement=(value) ⇒ Object

A description of any security clearance requirements of the job.



712
713
714
# File 'lib/schema_org/mixins/job_posting.rb', line 712

def security_clearance_requirement=(value)
  write_property(:security_clearance_requirement, value)
end

#sensory_requirementObject

A description of any sensory requirements and levels necessary to function on the job, including hearing and vision. Defined terms such as those in O*net may be used, but note that there is no way to specify the level of ability as well as its nature when using a defined term.



717
718
719
# File 'lib/schema_org/mixins/job_posting.rb', line 717

def sensory_requirement
  read_property(:sensory_requirement)
end

#sensory_requirement=(value) ⇒ Object

A description of any sensory requirements and levels necessary to function on the job, including hearing and vision. Defined terms such as those in O*net may be used, but note that there is no way to specify the level of ability as well as its nature when using a defined term.



722
723
724
# File 'lib/schema_org/mixins/job_posting.rb', line 722

def sensory_requirement=(value)
  write_property(:sensory_requirement, value)
end

#skillsObject

A statement of knowledge, skill, ability, task or any other assertion expressing a competency that is either claimed by a person, an organization or desired or required to fulfill a role or to work in an occupation.



727
728
729
# File 'lib/schema_org/mixins/job_posting.rb', line 727

def skills
  read_property(:skills)
end

#skills=(value) ⇒ Object

A statement of knowledge, skill, ability, task or any other assertion expressing a competency that is either claimed by a person, an organization or desired or required to fulfill a role or to work in an occupation.



732
733
734
# File 'lib/schema_org/mixins/job_posting.rb', line 732

def skills=(value)
  write_property(:skills, value)
end

#special_commitmentsObject

Any special commitments associated with this job posting. Valid entries include VeteranCommit, MilitarySpouseCommit, etc.



737
738
739
# File 'lib/schema_org/mixins/job_posting.rb', line 737

def special_commitments
  read_property(:special_commitments)
end

#special_commitments=(value) ⇒ Object

Any special commitments associated with this job posting. Valid entries include VeteranCommit, MilitarySpouseCommit, etc.



742
743
744
# File 'lib/schema_org/mixins/job_posting.rb', line 742

def special_commitments=(value)
  write_property(:special_commitments, value)
end

#titleObject

The title of the job.



747
748
749
# File 'lib/schema_org/mixins/job_posting.rb', line 747

def title
  read_property(:title)
end

#title=(value) ⇒ Object

The title of the job.



752
753
754
# File 'lib/schema_org/mixins/job_posting.rb', line 752

def title=(value)
  write_property(:title, value)
end

#total_job_openingsObject

The number of positions open for this job posting. Use a positive integer. Do not use if the number of positions is unclear or not known.



757
758
759
# File 'lib/schema_org/mixins/job_posting.rb', line 757

def total_job_openings
  read_property(:total_job_openings)
end

#total_job_openings=(value) ⇒ Object

The number of positions open for this job posting. Use a positive integer. Do not use if the number of positions is unclear or not known.



762
763
764
# File 'lib/schema_org/mixins/job_posting.rb', line 762

def total_job_openings=(value)
  write_property(:total_job_openings, value)
end

#valid_throughObject

The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.



767
768
769
# File 'lib/schema_org/mixins/job_posting.rb', line 767

def valid_through
  read_property(:valid_through)
end

#valid_through=(value) ⇒ Object

The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.



772
773
774
# File 'lib/schema_org/mixins/job_posting.rb', line 772

def valid_through=(value)
  write_property(:valid_through, value)
end

#work_hoursObject

The typical working hours for this job (e.g. 1st shift, night shift, 8am-5pm).



777
778
779
# File 'lib/schema_org/mixins/job_posting.rb', line 777

def work_hours
  read_property(:work_hours)
end

#work_hours=(value) ⇒ Object

The typical working hours for this job (e.g. 1st shift, night shift, 8am-5pm).



782
783
784
# File 'lib/schema_org/mixins/job_posting.rb', line 782

def work_hours=(value)
  write_property(:work_hours, value)
end