Module: SchemaOrg::Mixins::LearningResource

Includes:
CreativeWork
Included in:
LearningResource, Course, Quiz, Syllabus
Defined in:
lib/schema_org/mixins/learning_resource.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from CreativeWork

#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/schema_org/mixins/learning_resource.rb', line 11

def self.schema_property_definitions
  {
    assesses: {
      schema_name: "assesses",
      schema_url: "https://schema.org/assesses",
      comment_lines: ["The item being described is intended to assess the competency or learning outcome defined by the referenced term."].freeze,
      ranges: ["DefinedTerm", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    competency_required: {
      schema_name: "competencyRequired",
      schema_url: "https://schema.org/competencyRequired",
      comment_lines: ["Knowledge, skill, ability or personal attribute that must be demonstrated by a person or other entity in order to do something such as earn an Educational Occupational Credential or understand a LearningResource."].freeze,
      ranges: ["DefinedTerm", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    educational_alignment: {
      schema_name: "educationalAlignment",
      schema_url: "https://schema.org/educationalAlignment",
      comment_lines: ["An alignment to an established educational framework.", "", "This property should not be used where the nature of the alignment can be described using a simple property, for example to express that a resource [[teaches]] or [[assesses]] a competency."].freeze,
      ranges: ["AlignmentObject"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    educational_level: {
      schema_name: "educationalLevel",
      schema_url: "https://schema.org/educationalLevel",
      comment_lines: ["The level in terms of progression through an educational or training context. Examples of educational levels include 'beginner', 'intermediate' or 'advanced', and formal sets of level indicators."].freeze,
      ranges: ["DefinedTerm", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    educational_use: {
      schema_name: "educationalUse",
      schema_url: "https://schema.org/educationalUse",
      comment_lines: ["The purpose of a work in the context of education; for example, 'assignment', 'group work'."].freeze,
      ranges: ["DefinedTerm", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    learning_resource_type: {
      schema_name: "learningResourceType",
      schema_url: "https://schema.org/learningResourceType",
      comment_lines: ["The predominant type or kind characterizing the learning resource. For example, 'presentation', 'handout'."].freeze,
      ranges: ["DefinedTerm", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    teaches: {
      schema_name: "teaches",
      schema_url: "https://schema.org/teaches",
      comment_lines: ["The item being described is intended to help a person learn the competency or learning outcome defined by the referenced term."].freeze,
      ranges: ["DefinedTerm", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#assessesObject

The item being described is intended to assess the competency or learning outcome defined by the referenced term.



87
88
89
# File 'lib/schema_org/mixins/learning_resource.rb', line 87

def assesses
  read_property(:assesses)
end

#assesses=(value) ⇒ Object

The item being described is intended to assess the competency or learning outcome defined by the referenced term.



92
93
94
# File 'lib/schema_org/mixins/learning_resource.rb', line 92

def assesses=(value)
  write_property(:assesses, value)
end

#competency_requiredObject

Knowledge, skill, ability or personal attribute that must be demonstrated by a person or other entity in order to do something such as earn an Educational Occupational Credential or understand a LearningResource.



97
98
99
# File 'lib/schema_org/mixins/learning_resource.rb', line 97

def competency_required
  read_property(:competency_required)
end

#competency_required=(value) ⇒ Object

Knowledge, skill, ability or personal attribute that must be demonstrated by a person or other entity in order to do something such as earn an Educational Occupational Credential or understand a LearningResource.



102
103
104
# File 'lib/schema_org/mixins/learning_resource.rb', line 102

def competency_required=(value)
  write_property(:competency_required, value)
end

#educational_alignmentObject

An alignment to an established educational framework.

This property should not be used where the nature of the alignment can be described using a simple property, for example to express that a resource [[teaches]] or [[assesses]] a competency.



109
110
111
# File 'lib/schema_org/mixins/learning_resource.rb', line 109

def educational_alignment
  read_property(:educational_alignment)
end

#educational_alignment=(value) ⇒ Object

An alignment to an established educational framework.

This property should not be used where the nature of the alignment can be described using a simple property, for example to express that a resource [[teaches]] or [[assesses]] a competency.



116
117
118
# File 'lib/schema_org/mixins/learning_resource.rb', line 116

def educational_alignment=(value)
  write_property(:educational_alignment, value)
end

#educational_levelObject

The level in terms of progression through an educational or training context. Examples of educational levels include 'beginner', 'intermediate' or 'advanced', and formal sets of level indicators.



121
122
123
# File 'lib/schema_org/mixins/learning_resource.rb', line 121

def educational_level
  read_property(:educational_level)
end

#educational_level=(value) ⇒ Object

The level in terms of progression through an educational or training context. Examples of educational levels include 'beginner', 'intermediate' or 'advanced', and formal sets of level indicators.



126
127
128
# File 'lib/schema_org/mixins/learning_resource.rb', line 126

def educational_level=(value)
  write_property(:educational_level, value)
end

#educational_useObject

The purpose of a work in the context of education; for example, 'assignment', 'group work'.



131
132
133
# File 'lib/schema_org/mixins/learning_resource.rb', line 131

def educational_use
  read_property(:educational_use)
end

#educational_use=(value) ⇒ Object

The purpose of a work in the context of education; for example, 'assignment', 'group work'.



136
137
138
# File 'lib/schema_org/mixins/learning_resource.rb', line 136

def educational_use=(value)
  write_property(:educational_use, value)
end

#learning_resource_typeObject

The predominant type or kind characterizing the learning resource. For example, 'presentation', 'handout'.



141
142
143
# File 'lib/schema_org/mixins/learning_resource.rb', line 141

def learning_resource_type
  read_property(:learning_resource_type)
end

#learning_resource_type=(value) ⇒ Object

The predominant type or kind characterizing the learning resource. For example, 'presentation', 'handout'.



146
147
148
# File 'lib/schema_org/mixins/learning_resource.rb', line 146

def learning_resource_type=(value)
  write_property(:learning_resource_type, value)
end

#teachesObject

The item being described is intended to help a person learn the competency or learning outcome defined by the referenced term.



151
152
153
# File 'lib/schema_org/mixins/learning_resource.rb', line 151

def teaches
  read_property(:teaches)
end

#teaches=(value) ⇒ Object

The item being described is intended to help a person learn the competency or learning outcome defined by the referenced term.



156
157
158
# File 'lib/schema_org/mixins/learning_resource.rb', line 156

def teaches=(value)
  write_property(:teaches, value)
end