Module: SchemaOrg::Mixins::LodgingBusiness

Includes:
LocalBusiness
Included in:
LodgingBusiness, BedAndBreakfast, Campground, Hostel, Hotel, Motel, Resort, VacationRental
Defined in:
lib/schema_org/mixins/lodging_business.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from LocalBusiness

#branch_of, #branch_of=, #currencies_accepted, #currencies_accepted=, #floor_level, #floor_level=, #opening_hours, #opening_hours=, #payment_accepted, #payment_accepted=, #price_range, #price_range=

Methods included from Place

#additional_property, #additional_property=, #address, #address=, #aggregate_rating, #aggregate_rating=, #branch_code, #branch_code=, #contained_in, #contained_in=, #contained_in_place, #contained_in_place=, #contains_place, #contains_place=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #geo, #geo=, #geo_contains, #geo_contains=, #geo_covered_by, #geo_covered_by=, #geo_covers, #geo_covers=, #geo_crosses, #geo_crosses=, #geo_disjoint, #geo_disjoint=, #geo_equals, #geo_equals=, #geo_intersects, #geo_intersects=, #geo_overlaps, #geo_overlaps=, #geo_touches, #geo_touches=, #geo_within, #geo_within=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_drive_through_service, #has_drive_through_service=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_map, #has_map=, #is_accessible_for_free, #is_accessible_for_free=, #isic_v4, #isic_v4=, #keywords, #keywords=, #latitude, #latitude=, #logo, #logo=, #longitude, #longitude=, #map, #map=, #maps, #maps=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #opening_hours_specification, #opening_hours_specification=, #photo, #photo=, #photos, #photos=, #public_access, #public_access=, #review, #review=, #reviews, #reviews=, #slogan, #slogan=, #smoking_allowed, #smoking_allowed=, #special_opening_hours_specification, #special_opening_hours_specification=, #telephone, #telephone=, #tour_booking_page, #tour_booking_page=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Methods included from Organization

#accepted_payment_method, #accepted_payment_method=, #actionable_feedback_policy, #actionable_feedback_policy=, #address, #address=, #agent_interaction_statistic, #agent_interaction_statistic=, #aggregate_rating, #aggregate_rating=, #alumni, #alumni=, #area_served, #area_served=, #award, #award=, #awards, #awards=, #brand, #brand=, #company_registration, #company_registration=, #contact_point, #contact_point=, #contact_points, #contact_points=, #corrections_policy, #corrections_policy=, #department, #department=, #dissolution_date, #dissolution_date=, #diversity_policy, #diversity_policy=, #diversity_staffing_report, #diversity_staffing_report=, #duns, #duns=, #email, #email=, #employee, #employee=, #employees, #employees=, #ethics_policy, #ethics_policy=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #founder, #founder=, #founders, #founders=, #founding_date, #founding_date=, #founding_location, #founding_location=, #funder, #funder=, #funding, #funding=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_credential, #has_credential=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_member_program, #has_member_program=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_offer_catalog, #has_offer_catalog=, #has_pos, #has_pos=, #has_product_return_policy, #has_product_return_policy=, #has_shipping_service, #has_shipping_service=, #interaction_statistic, #interaction_statistic=, #isic_v4, #isic_v4=, #iso6523_code, #iso6523_code=, #keywords, #keywords=, #knows_about, #knows_about=, #knows_language, #knows_language=, #legal_address, #legal_address=, #legal_name, #legal_name=, #legal_representative, #legal_representative=, #lei_code, #lei_code=, #location, #location=, #logo, #logo=, #makes_offer, #makes_offer=, #member, #member=, #member_of, #member_of=, #members, #members=, #naics, #naics=, #nonprofit_status, #nonprofit_status=, #number_of_employees, #number_of_employees=, #ownership_funding_info, #ownership_funding_info=, #owns, #owns=, #parent_organization, #parent_organization=, #publishing_principles, #publishing_principles=, #review, #review=, #reviews, #reviews=, #seeks, #seeks=, #service_area, #service_area=, #skills, #skills=, #slogan, #slogan=, #sponsor, #sponsor=, #sub_organization, #sub_organization=, #tax_id, #tax_id=, #telephone, #telephone=, #unnamed_sources_policy, #unnamed_sources_policy=, #vat_id, #vat_id=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/schema_org/mixins/lodging_business.rb', line 11

def self.schema_property_definitions
  {
    amenity_feature: {
      schema_name: "amenityFeature",
      schema_url: "https://schema.org/amenityFeature",
      comment_lines: ["An amenity feature (e.g. a characteristic or service) of the Accommodation. This generic property does not make a statement about whether the feature is included in an offer for the main accommodation or available at extra costs."].freeze,
      ranges: ["LocationFeatureSpecification"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    audience: {
      schema_name: "audience",
      schema_url: "https://schema.org/audience",
      comment_lines: ["An intended audience, i.e. a group for whom something was created."].freeze,
      ranges: ["Audience"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["serviceAudience"].freeze
    }.freeze,
    available_language: {
      schema_name: "availableLanguage",
      schema_url: "https://schema.org/availableLanguage",
      comment_lines: ["A language someone may use with or at the item, service or place. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[inLanguage]]."].freeze,
      ranges: ["Language", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    checkin_time: {
      schema_name: "checkinTime",
      schema_url: "https://schema.org/checkinTime",
      comment_lines: ["The earliest someone may check into a lodging establishment."].freeze,
      ranges: ["DateTime", "Time"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    checkout_time: {
      schema_name: "checkoutTime",
      schema_url: "https://schema.org/checkoutTime",
      comment_lines: ["The latest someone may check out of a lodging establishment."].freeze,
      ranges: ["DateTime", "Time"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    number_of_rooms: {
      schema_name: "numberOfRooms",
      schema_url: "https://schema.org/numberOfRooms",
      comment_lines: ["The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business.", "Typical unit code(s): ROM for room or C62 for no unit. The type of room can be put in the unitText property of the QuantitativeValue."].freeze,
      ranges: ["Number", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    pets_allowed: {
      schema_name: "petsAllowed",
      schema_url: "https://schema.org/petsAllowed",
      comment_lines: ["Indicates whether pets are allowed to enter the accommodation or lodging business. More detailed information can be put in a text value."].freeze,
      ranges: ["Boolean", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    star_rating: {
      schema_name: "starRating",
      schema_url: "https://schema.org/starRating",
      comment_lines: ["An official rating for a lodging business or food establishment, e.g. from national associations or standards bodies. Use the author property to indicate the rating organization, e.g. as an Organization with name such as (e.g. HOTREC, DEHOGA, WHR, or Hotelstars)."].freeze,
      ranges: ["Rating"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#amenity_featureObject

An amenity feature (e.g. a characteristic or service) of the Accommodation. This generic property does not make a statement about whether the feature is included in an offer for the main accommodation or available at extra costs.



97
98
99
# File 'lib/schema_org/mixins/lodging_business.rb', line 97

def amenity_feature
  read_property(:amenity_feature)
end

#amenity_feature=(value) ⇒ Object

An amenity feature (e.g. a characteristic or service) of the Accommodation. This generic property does not make a statement about whether the feature is included in an offer for the main accommodation or available at extra costs.



102
103
104
# File 'lib/schema_org/mixins/lodging_business.rb', line 102

def amenity_feature=(value)
  write_property(:amenity_feature, value)
end

#audienceObject

An intended audience, i.e. a group for whom something was created. Supersedes serviceAudience.



108
109
110
# File 'lib/schema_org/mixins/lodging_business.rb', line 108

def audience
  read_property(:audience)
end

#audience=(value) ⇒ Object

An intended audience, i.e. a group for whom something was created. Supersedes serviceAudience.



114
115
116
# File 'lib/schema_org/mixins/lodging_business.rb', line 114

def audience=(value)
  write_property(:audience, value)
end

#available_languageObject

A language someone may use with or at the item, service or place. Please use one of the language codes from the IETF BCP 47 standard. See also [[inLanguage]].



119
120
121
# File 'lib/schema_org/mixins/lodging_business.rb', line 119

def available_language
  read_property(:available_language)
end

#available_language=(value) ⇒ Object

A language someone may use with or at the item, service or place. Please use one of the language codes from the IETF BCP 47 standard. See also [[inLanguage]].



124
125
126
# File 'lib/schema_org/mixins/lodging_business.rb', line 124

def available_language=(value)
  write_property(:available_language, value)
end

#checkin_timeObject

The earliest someone may check into a lodging establishment.



129
130
131
# File 'lib/schema_org/mixins/lodging_business.rb', line 129

def checkin_time
  read_property(:checkin_time)
end

#checkin_time=(value) ⇒ Object

The earliest someone may check into a lodging establishment.



134
135
136
# File 'lib/schema_org/mixins/lodging_business.rb', line 134

def checkin_time=(value)
  write_property(:checkin_time, value)
end

#checkout_timeObject

The latest someone may check out of a lodging establishment.



139
140
141
# File 'lib/schema_org/mixins/lodging_business.rb', line 139

def checkout_time
  read_property(:checkout_time)
end

#checkout_time=(value) ⇒ Object

The latest someone may check out of a lodging establishment.



144
145
146
# File 'lib/schema_org/mixins/lodging_business.rb', line 144

def checkout_time=(value)
  write_property(:checkout_time, value)
end

#number_of_roomsObject

The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business. Typical unit code(s): ROM for room or C62 for no unit. The type of room can be put in the unitText property of the QuantitativeValue.



150
151
152
# File 'lib/schema_org/mixins/lodging_business.rb', line 150

def number_of_rooms
  read_property(:number_of_rooms)
end

#number_of_rooms=(value) ⇒ Object

The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business. Typical unit code(s): ROM for room or C62 for no unit. The type of room can be put in the unitText property of the QuantitativeValue.



156
157
158
# File 'lib/schema_org/mixins/lodging_business.rb', line 156

def number_of_rooms=(value)
  write_property(:number_of_rooms, value)
end

#pets_allowedObject

Indicates whether pets are allowed to enter the accommodation or lodging business. More detailed information can be put in a text value.



161
162
163
# File 'lib/schema_org/mixins/lodging_business.rb', line 161

def pets_allowed
  read_property(:pets_allowed)
end

#pets_allowed=(value) ⇒ Object

Indicates whether pets are allowed to enter the accommodation or lodging business. More detailed information can be put in a text value.



166
167
168
# File 'lib/schema_org/mixins/lodging_business.rb', line 166

def pets_allowed=(value)
  write_property(:pets_allowed, value)
end

#star_ratingObject

An official rating for a lodging business or food establishment, e.g. from national associations or standards bodies. Use the author property to indicate the rating organization, e.g. as an Organization with name such as (e.g. HOTREC, DEHOGA, WHR, or Hotelstars).



171
172
173
# File 'lib/schema_org/mixins/lodging_business.rb', line 171

def star_rating
  read_property(:star_rating)
end

#star_rating=(value) ⇒ Object

An official rating for a lodging business or food establishment, e.g. from national associations or standards bodies. Use the author property to indicate the rating organization, e.g. as an Organization with name such as (e.g. HOTREC, DEHOGA, WHR, or Hotelstars).



176
177
178
# File 'lib/schema_org/mixins/lodging_business.rb', line 176

def star_rating=(value)
  write_property(:star_rating, value)
end