Module: SchemaOrg::Mixins::LodgingReservation

Includes:
Reservation
Included in:
LodgingReservation
Defined in:
lib/schema_org/mixins/lodging_reservation.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Reservation

#booking_agent, #booking_agent=, #booking_time, #booking_time=, #broker, #broker=, #modified_time, #modified_time=, #price_currency, #price_currency=, #program_membership_used, #program_membership_used=, #provider, #provider=, #reservation_for, #reservation_for=, #reservation_id, #reservation_id=, #reservation_status, #reservation_status=, #reserved_ticket, #reserved_ticket=, #total_price, #total_price=, #under_name, #under_name=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/schema_org/mixins/lodging_reservation.rb', line 11

def self.schema_property_definitions
  {
    checkin_time: {
      schema_name: "checkinTime",
      schema_url: "https://schema.org/checkinTime",
      comment_lines: ["The earliest someone may check into a lodging establishment."].freeze,
      ranges: ["DateTime", "Time"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    checkout_time: {
      schema_name: "checkoutTime",
      schema_url: "https://schema.org/checkoutTime",
      comment_lines: ["The latest someone may check out of a lodging establishment."].freeze,
      ranges: ["DateTime", "Time"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    lodging_unit_description: {
      schema_name: "lodgingUnitDescription",
      schema_url: "https://schema.org/lodgingUnitDescription",
      comment_lines: ["A full description of the lodging unit."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    lodging_unit_type: {
      schema_name: "lodgingUnitType",
      schema_url: "https://schema.org/lodgingUnitType",
      comment_lines: ["Textual description of the unit type (including suite vs. room, size of bed, etc.)."].freeze,
      ranges: ["QualitativeValue", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    num_adults: {
      schema_name: "numAdults",
      schema_url: "https://schema.org/numAdults",
      comment_lines: ["The number of adults staying in the unit."].freeze,
      ranges: ["Integer", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    num_children: {
      schema_name: "numChildren",
      schema_url: "https://schema.org/numChildren",
      comment_lines: ["The number of children staying in the unit."].freeze,
      ranges: ["Integer", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#checkin_timeObject

The earliest someone may check into a lodging establishment.



77
78
79
# File 'lib/schema_org/mixins/lodging_reservation.rb', line 77

def checkin_time
  read_property(:checkin_time)
end

#checkin_time=(value) ⇒ Object

The earliest someone may check into a lodging establishment.



82
83
84
# File 'lib/schema_org/mixins/lodging_reservation.rb', line 82

def checkin_time=(value)
  write_property(:checkin_time, value)
end

#checkout_timeObject

The latest someone may check out of a lodging establishment.



87
88
89
# File 'lib/schema_org/mixins/lodging_reservation.rb', line 87

def checkout_time
  read_property(:checkout_time)
end

#checkout_time=(value) ⇒ Object

The latest someone may check out of a lodging establishment.



92
93
94
# File 'lib/schema_org/mixins/lodging_reservation.rb', line 92

def checkout_time=(value)
  write_property(:checkout_time, value)
end

#lodging_unit_descriptionObject

A full description of the lodging unit.



97
98
99
# File 'lib/schema_org/mixins/lodging_reservation.rb', line 97

def lodging_unit_description
  read_property(:lodging_unit_description)
end

#lodging_unit_description=(value) ⇒ Object

A full description of the lodging unit.



102
103
104
# File 'lib/schema_org/mixins/lodging_reservation.rb', line 102

def lodging_unit_description=(value)
  write_property(:lodging_unit_description, value)
end

#lodging_unit_typeObject

Textual description of the unit type (including suite vs. room, size of bed, etc.).



107
108
109
# File 'lib/schema_org/mixins/lodging_reservation.rb', line 107

def lodging_unit_type
  read_property(:lodging_unit_type)
end

#lodging_unit_type=(value) ⇒ Object

Textual description of the unit type (including suite vs. room, size of bed, etc.).



112
113
114
# File 'lib/schema_org/mixins/lodging_reservation.rb', line 112

def lodging_unit_type=(value)
  write_property(:lodging_unit_type, value)
end

#num_adultsObject

The number of adults staying in the unit.



117
118
119
# File 'lib/schema_org/mixins/lodging_reservation.rb', line 117

def num_adults
  read_property(:num_adults)
end

#num_adults=(value) ⇒ Object

The number of adults staying in the unit.



122
123
124
# File 'lib/schema_org/mixins/lodging_reservation.rb', line 122

def num_adults=(value)
  write_property(:num_adults, value)
end

#num_childrenObject

The number of children staying in the unit.



127
128
129
# File 'lib/schema_org/mixins/lodging_reservation.rb', line 127

def num_children
  read_property(:num_children)
end

#num_children=(value) ⇒ Object

The number of children staying in the unit.



132
133
134
# File 'lib/schema_org/mixins/lodging_reservation.rb', line 132

def num_children=(value)
  write_property(:num_children, value)
end