Module: SchemaOrg::Mixins::MediaSubscription

Includes:
Intangible
Included in:
SchemaOrg::MediaSubscription
Defined in:
lib/schema_org/mixins/media_subscription.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/schema_org/mixins/media_subscription.rb', line 11

def self.schema_property_definitions
  {
    authenticator: {
      schema_name: "authenticator",
      schema_url: "https://schema.org/authenticator",
      comment_lines: ["The Organization responsible for authenticating the user's subscription. For example, many media apps require a cable/satellite provider to authenticate your subscription before playing media."].freeze,
      ranges: ["Organization"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    expects_acceptance_of: {
      schema_name: "expectsAcceptanceOf",
      schema_url: "https://schema.org/expectsAcceptanceOf",
      comment_lines: ["An Offer which must be accepted before the user can perform the Action. For example, the user may need to buy a movie before being able to watch it."].freeze,
      ranges: ["Offer"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#authenticatorObject

The Organization responsible for authenticating the user's subscription. For example, many media apps require a cable/satellite provider to authenticate your subscription before playing media.



37
38
39
# File 'lib/schema_org/mixins/media_subscription.rb', line 37

def authenticator
  read_property(:authenticator)
end

#authenticator=(value) ⇒ Object

The Organization responsible for authenticating the user's subscription. For example, many media apps require a cable/satellite provider to authenticate your subscription before playing media.



42
43
44
# File 'lib/schema_org/mixins/media_subscription.rb', line 42

def authenticator=(value)
  write_property(:authenticator, value)
end

#expects_acceptance_ofObject

An Offer which must be accepted before the user can perform the Action. For example, the user may need to buy a movie before being able to watch it.



47
48
49
# File 'lib/schema_org/mixins/media_subscription.rb', line 47

def expects_acceptance_of
  read_property(:expects_acceptance_of)
end

#expects_acceptance_of=(value) ⇒ Object

An Offer which must be accepted before the user can perform the Action. For example, the user may need to buy a movie before being able to watch it.



52
53
54
# File 'lib/schema_org/mixins/media_subscription.rb', line 52

def expects_acceptance_of=(value)
  write_property(:expects_acceptance_of, value)
end