Module: SchemaOrg::Mixins::MedicalCode

Includes:
CategoryCode, MedicalIntangible
Included in:
SchemaOrg::MedicalCode
Defined in:
lib/schema_org/mixins/medical_code.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Methods included from CategoryCode

#in_code_set, #in_code_set=

Methods included from DefinedTerm

#about, #about=, #in_defined_term_set, #in_defined_term_set=, #term_code, #term_code=

Class Method Details

.schema_property_definitionsObject



12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
# File 'lib/schema_org/mixins/medical_code.rb', line 12

def self.schema_property_definitions
  {
    code_value: {
      schema_name: "codeValue",
      schema_url: "https://schema.org/codeValue",
      comment_lines: ["A short textual code that uniquely identifies the value."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    coding_system: {
      schema_name: "codingSystem",
      schema_url: "https://schema.org/codingSystem",
      comment_lines: ["The coding system, e.g. 'ICD-10'."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#code_valueObject

A short textual code that uniquely identifies the value.



38
39
40
# File 'lib/schema_org/mixins/medical_code.rb', line 38

def code_value
  read_property(:code_value)
end

#code_value=(value) ⇒ Object

A short textual code that uniquely identifies the value.



43
44
45
# File 'lib/schema_org/mixins/medical_code.rb', line 43

def code_value=(value)
  write_property(:code_value, value)
end

#coding_systemObject

The coding system, e.g. 'ICD-10'.



48
49
50
# File 'lib/schema_org/mixins/medical_code.rb', line 48

def coding_system
  read_property(:coding_system)
end

#coding_system=(value) ⇒ Object

The coding system, e.g. 'ICD-10'.



53
54
55
# File 'lib/schema_org/mixins/medical_code.rb', line 53

def coding_system=(value)
  write_property(:coding_system, value)
end