Module: SchemaOrg::Mixins::MedicalCondition

Includes:
MedicalEntity
Included in:
SchemaOrg::MedicalCondition, InfectiousDisease, MedicalSignOrSymptom
Defined in:
lib/schema_org/mixins/medical_condition.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/schema_org/mixins/medical_condition.rb', line 11

def self.schema_property_definitions
  {
    associated_anatomy: {
      schema_name: "associatedAnatomy",
      schema_url: "https://schema.org/associatedAnatomy",
      comment_lines: ["The anatomy of the underlying organ system or structures associated with this entity."].freeze,
      ranges: ["AnatomicalStructure", "AnatomicalSystem", "SuperficialAnatomy"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    cause: {
      schema_name: "cause",
      schema_url: "https://schema.org/cause",
      comment_lines: ["The cause of a medical condition."].freeze,
      ranges: ["MedicalCause"].freeze,
      external_ranges: [].freeze,
      inverse_of: "causeOf",
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    differential_diagnosis: {
      schema_name: "differentialDiagnosis",
      schema_url: "https://schema.org/differentialDiagnosis",
      comment_lines: ["One of a set of differential diagnoses for the condition. Specifically, a closely-related or competing diagnosis typically considered later in the cognitive process whereby this medical condition is distinguished from others most likely responsible for a similar collection of signs and symptoms to reach the most parsimonious diagnosis or diagnoses in a patient."].freeze,
      ranges: ["DDxElement"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    drug: {
      schema_name: "drug",
      schema_url: "https://schema.org/drug",
      comment_lines: ["Specifying a drug or medicine used in a medication procedure."].freeze,
      ranges: ["Drug"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    epidemiology: {
      schema_name: "epidemiology",
      schema_url: "https://schema.org/epidemiology",
      comment_lines: ["The characteristics of associated patients, such as age, gender, race etc."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    expected_prognosis: {
      schema_name: "expectedPrognosis",
      schema_url: "https://schema.org/expectedPrognosis",
      comment_lines: ["The likely outcome in either the short term or long term of the medical condition."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    natural_progression: {
      schema_name: "naturalProgression",
      schema_url: "https://schema.org/naturalProgression",
      comment_lines: ["The expected progression of the condition if it is not treated and allowed to progress naturally."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    pathophysiology: {
      schema_name: "pathophysiology",
      schema_url: "https://schema.org/pathophysiology",
      comment_lines: ["Changes in the normal mechanical, physical, and biochemical functions that are associated with this activity or condition."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    possible_complication: {
      schema_name: "possibleComplication",
      schema_url: "https://schema.org/possibleComplication",
      comment_lines: ["A possible unexpected and unfavorable evolution of a medical condition. Complications may include worsening of the signs or symptoms of the disease, extension of the condition to other organ systems, etc."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    possible_treatment: {
      schema_name: "possibleTreatment",
      schema_url: "https://schema.org/possibleTreatment",
      comment_lines: ["A possible treatment to address this condition, sign or symptom."].freeze,
      ranges: ["Drug", "DrugClass", "LifestyleModification", "MedicalTherapy"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    primary_prevention: {
      schema_name: "primaryPrevention",
      schema_url: "https://schema.org/primaryPrevention",
      comment_lines: ["A preventative therapy used to prevent an initial occurrence of the medical condition, such as vaccination."].freeze,
      ranges: ["MedicalTherapy"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    risk_factor: {
      schema_name: "riskFactor",
      schema_url: "https://schema.org/riskFactor",
      comment_lines: ["A modifiable or non-modifiable factor that increases the risk of a patient contracting this condition, e.g. age,  coexisting condition."].freeze,
      ranges: ["MedicalRiskFactor"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    secondary_prevention: {
      schema_name: "secondaryPrevention",
      schema_url: "https://schema.org/secondaryPrevention",
      comment_lines: ["A preventative therapy used to prevent reoccurrence of the medical condition after an initial episode of the condition."].freeze,
      ranges: ["Drug", "DrugClass", "LifestyleModification", "MedicalTherapy"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    sign_or_symptom: {
      schema_name: "signOrSymptom",
      schema_url: "https://schema.org/signOrSymptom",
      comment_lines: ["A sign or symptom of this condition. Signs are objective or physically observable manifestations of the medical condition while symptoms are the subjective experience of the medical condition."].freeze,
      ranges: ["MedicalSignOrSymptom"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    stage: {
      schema_name: "stage",
      schema_url: "https://schema.org/stage",
      comment_lines: ["The stage of the condition, if applicable."].freeze,
      ranges: ["MedicalConditionStage"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    status: {
      schema_name: "status",
      schema_url: "https://schema.org/status",
      comment_lines: ["The status of the study (enumerated)."].freeze,
      ranges: ["EventStatusType", "MedicalStudyStatus", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    typical_test: {
      schema_name: "typicalTest",
      schema_url: "https://schema.org/typicalTest",
      comment_lines: ["A medical test typically performed given this condition."].freeze,
      ranges: ["MedicalTest"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#associated_anatomyObject

The anatomy of the underlying organ system or structures associated with this entity.



187
188
189
# File 'lib/schema_org/mixins/medical_condition.rb', line 187

def associated_anatomy
  read_property(:associated_anatomy)
end

#associated_anatomy=(value) ⇒ Object

The anatomy of the underlying organ system or structures associated with this entity.



192
193
194
# File 'lib/schema_org/mixins/medical_condition.rb', line 192

def associated_anatomy=(value)
  write_property(:associated_anatomy, value)
end

#causeObject

The cause of a medical condition. Inverse-property: causeOf.



198
199
200
# File 'lib/schema_org/mixins/medical_condition.rb', line 198

def cause
  read_property(:cause)
end

#cause=(value) ⇒ Object

The cause of a medical condition. Inverse-property: causeOf.



204
205
206
# File 'lib/schema_org/mixins/medical_condition.rb', line 204

def cause=(value)
  write_property(:cause, value)
end

#differential_diagnosisObject

One of a set of differential diagnoses for the condition. Specifically, a closely-related or competing diagnosis typically considered later in the cognitive process whereby this medical condition is distinguished from others most likely responsible for a similar collection of signs and symptoms to reach the most parsimonious diagnosis or diagnoses in a patient.



209
210
211
# File 'lib/schema_org/mixins/medical_condition.rb', line 209

def differential_diagnosis
  read_property(:differential_diagnosis)
end

#differential_diagnosis=(value) ⇒ Object

One of a set of differential diagnoses for the condition. Specifically, a closely-related or competing diagnosis typically considered later in the cognitive process whereby this medical condition is distinguished from others most likely responsible for a similar collection of signs and symptoms to reach the most parsimonious diagnosis or diagnoses in a patient.



214
215
216
# File 'lib/schema_org/mixins/medical_condition.rb', line 214

def differential_diagnosis=(value)
  write_property(:differential_diagnosis, value)
end

#drugObject

Specifying a drug or medicine used in a medication procedure.



219
220
221
# File 'lib/schema_org/mixins/medical_condition.rb', line 219

def drug
  read_property(:drug)
end

#drug=(value) ⇒ Object

Specifying a drug or medicine used in a medication procedure.



224
225
226
# File 'lib/schema_org/mixins/medical_condition.rb', line 224

def drug=(value)
  write_property(:drug, value)
end

#epidemiologyObject

The characteristics of associated patients, such as age, gender, race etc.



229
230
231
# File 'lib/schema_org/mixins/medical_condition.rb', line 229

def epidemiology
  read_property(:epidemiology)
end

#epidemiology=(value) ⇒ Object

The characteristics of associated patients, such as age, gender, race etc.



234
235
236
# File 'lib/schema_org/mixins/medical_condition.rb', line 234

def epidemiology=(value)
  write_property(:epidemiology, value)
end

#expected_prognosisObject

The likely outcome in either the short term or long term of the medical condition.



239
240
241
# File 'lib/schema_org/mixins/medical_condition.rb', line 239

def expected_prognosis
  read_property(:expected_prognosis)
end

#expected_prognosis=(value) ⇒ Object

The likely outcome in either the short term or long term of the medical condition.



244
245
246
# File 'lib/schema_org/mixins/medical_condition.rb', line 244

def expected_prognosis=(value)
  write_property(:expected_prognosis, value)
end

#natural_progressionObject

The expected progression of the condition if it is not treated and allowed to progress naturally.



249
250
251
# File 'lib/schema_org/mixins/medical_condition.rb', line 249

def natural_progression
  read_property(:natural_progression)
end

#natural_progression=(value) ⇒ Object

The expected progression of the condition if it is not treated and allowed to progress naturally.



254
255
256
# File 'lib/schema_org/mixins/medical_condition.rb', line 254

def natural_progression=(value)
  write_property(:natural_progression, value)
end

#pathophysiologyObject

Changes in the normal mechanical, physical, and biochemical functions that are associated with this activity or condition.



259
260
261
# File 'lib/schema_org/mixins/medical_condition.rb', line 259

def pathophysiology
  read_property(:pathophysiology)
end

#pathophysiology=(value) ⇒ Object

Changes in the normal mechanical, physical, and biochemical functions that are associated with this activity or condition.



264
265
266
# File 'lib/schema_org/mixins/medical_condition.rb', line 264

def pathophysiology=(value)
  write_property(:pathophysiology, value)
end

#possible_complicationObject

A possible unexpected and unfavorable evolution of a medical condition. Complications may include worsening of the signs or symptoms of the disease, extension of the condition to other organ systems, etc.



269
270
271
# File 'lib/schema_org/mixins/medical_condition.rb', line 269

def possible_complication
  read_property(:possible_complication)
end

#possible_complication=(value) ⇒ Object

A possible unexpected and unfavorable evolution of a medical condition. Complications may include worsening of the signs or symptoms of the disease, extension of the condition to other organ systems, etc.



274
275
276
# File 'lib/schema_org/mixins/medical_condition.rb', line 274

def possible_complication=(value)
  write_property(:possible_complication, value)
end

#possible_treatmentObject

A possible treatment to address this condition, sign or symptom.



279
280
281
# File 'lib/schema_org/mixins/medical_condition.rb', line 279

def possible_treatment
  read_property(:possible_treatment)
end

#possible_treatment=(value) ⇒ Object

A possible treatment to address this condition, sign or symptom.



284
285
286
# File 'lib/schema_org/mixins/medical_condition.rb', line 284

def possible_treatment=(value)
  write_property(:possible_treatment, value)
end

#primary_preventionObject

A preventative therapy used to prevent an initial occurrence of the medical condition, such as vaccination.



289
290
291
# File 'lib/schema_org/mixins/medical_condition.rb', line 289

def primary_prevention
  read_property(:primary_prevention)
end

#primary_prevention=(value) ⇒ Object

A preventative therapy used to prevent an initial occurrence of the medical condition, such as vaccination.



294
295
296
# File 'lib/schema_org/mixins/medical_condition.rb', line 294

def primary_prevention=(value)
  write_property(:primary_prevention, value)
end

#risk_factorObject

A modifiable or non-modifiable factor that increases the risk of a patient contracting this condition, e.g. age, coexisting condition.



299
300
301
# File 'lib/schema_org/mixins/medical_condition.rb', line 299

def risk_factor
  read_property(:risk_factor)
end

#risk_factor=(value) ⇒ Object

A modifiable or non-modifiable factor that increases the risk of a patient contracting this condition, e.g. age, coexisting condition.



304
305
306
# File 'lib/schema_org/mixins/medical_condition.rb', line 304

def risk_factor=(value)
  write_property(:risk_factor, value)
end

#secondary_preventionObject

A preventative therapy used to prevent reoccurrence of the medical condition after an initial episode of the condition.



309
310
311
# File 'lib/schema_org/mixins/medical_condition.rb', line 309

def secondary_prevention
  read_property(:secondary_prevention)
end

#secondary_prevention=(value) ⇒ Object

A preventative therapy used to prevent reoccurrence of the medical condition after an initial episode of the condition.



314
315
316
# File 'lib/schema_org/mixins/medical_condition.rb', line 314

def secondary_prevention=(value)
  write_property(:secondary_prevention, value)
end

#sign_or_symptomObject

A sign or symptom of this condition. Signs are objective or physically observable manifestations of the medical condition while symptoms are the subjective experience of the medical condition.



319
320
321
# File 'lib/schema_org/mixins/medical_condition.rb', line 319

def sign_or_symptom
  read_property(:sign_or_symptom)
end

#sign_or_symptom=(value) ⇒ Object

A sign or symptom of this condition. Signs are objective or physically observable manifestations of the medical condition while symptoms are the subjective experience of the medical condition.



324
325
326
# File 'lib/schema_org/mixins/medical_condition.rb', line 324

def sign_or_symptom=(value)
  write_property(:sign_or_symptom, value)
end

#stageObject

The stage of the condition, if applicable.



329
330
331
# File 'lib/schema_org/mixins/medical_condition.rb', line 329

def stage
  read_property(:stage)
end

#stage=(value) ⇒ Object

The stage of the condition, if applicable.



334
335
336
# File 'lib/schema_org/mixins/medical_condition.rb', line 334

def stage=(value)
  write_property(:stage, value)
end

#statusObject

The status of the study (enumerated).



339
340
341
# File 'lib/schema_org/mixins/medical_condition.rb', line 339

def status
  read_property(:status)
end

#status=(value) ⇒ Object

The status of the study (enumerated).



344
345
346
# File 'lib/schema_org/mixins/medical_condition.rb', line 344

def status=(value)
  write_property(:status, value)
end

#typical_testObject

A medical test typically performed given this condition.



349
350
351
# File 'lib/schema_org/mixins/medical_condition.rb', line 349

def typical_test
  read_property(:typical_test)
end

#typical_test=(value) ⇒ Object

A medical test typically performed given this condition.



354
355
356
# File 'lib/schema_org/mixins/medical_condition.rb', line 354

def typical_test=(value)
  write_property(:typical_test, value)
end