Module: SchemaOrg::Mixins::MedicalGuideline

Includes:
MedicalEntity
Included in:
SchemaOrg::MedicalGuideline, MedicalGuidelineContraindication, MedicalGuidelineRecommendation
Defined in:
lib/schema_org/mixins/medical_guideline.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/schema_org/mixins/medical_guideline.rb', line 11

def self.schema_property_definitions
  {
    evidence_level: {
      schema_name: "evidenceLevel",
      schema_url: "https://schema.org/evidenceLevel",
      comment_lines: ["Strength of evidence of the data used to formulate the guideline (enumerated)."].freeze,
      ranges: ["MedicalEvidenceLevel"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    evidence_origin: {
      schema_name: "evidenceOrigin",
      schema_url: "https://schema.org/evidenceOrigin",
      comment_lines: ["Source of the data used to formulate the guidance, e.g. RCT, consensus opinion, etc."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    guideline_date: {
      schema_name: "guidelineDate",
      schema_url: "https://schema.org/guidelineDate",
      comment_lines: ["Date on which this guideline's recommendation was made."].freeze,
      ranges: ["Date"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    guideline_subject: {
      schema_name: "guidelineSubject",
      schema_url: "https://schema.org/guidelineSubject",
      comment_lines: ["The medical conditions, treatments, etc. that are the subject of the guideline."].freeze,
      ranges: ["MedicalEntity"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#evidence_levelObject

Strength of evidence of the data used to formulate the guideline (enumerated).



57
58
59
# File 'lib/schema_org/mixins/medical_guideline.rb', line 57

def evidence_level
  read_property(:evidence_level)
end

#evidence_level=(value) ⇒ Object

Strength of evidence of the data used to formulate the guideline (enumerated).



62
63
64
# File 'lib/schema_org/mixins/medical_guideline.rb', line 62

def evidence_level=(value)
  write_property(:evidence_level, value)
end

#evidence_originObject

Source of the data used to formulate the guidance, e.g. RCT, consensus opinion, etc.



67
68
69
# File 'lib/schema_org/mixins/medical_guideline.rb', line 67

def evidence_origin
  read_property(:evidence_origin)
end

#evidence_origin=(value) ⇒ Object

Source of the data used to formulate the guidance, e.g. RCT, consensus opinion, etc.



72
73
74
# File 'lib/schema_org/mixins/medical_guideline.rb', line 72

def evidence_origin=(value)
  write_property(:evidence_origin, value)
end

#guideline_dateObject

Date on which this guideline's recommendation was made.



77
78
79
# File 'lib/schema_org/mixins/medical_guideline.rb', line 77

def guideline_date
  read_property(:guideline_date)
end

#guideline_date=(value) ⇒ Object

Date on which this guideline's recommendation was made.



82
83
84
# File 'lib/schema_org/mixins/medical_guideline.rb', line 82

def guideline_date=(value)
  write_property(:guideline_date, value)
end

#guideline_subjectObject

The medical conditions, treatments, etc. that are the subject of the guideline.



87
88
89
# File 'lib/schema_org/mixins/medical_guideline.rb', line 87

def guideline_subject
  read_property(:guideline_subject)
end

#guideline_subject=(value) ⇒ Object

The medical conditions, treatments, etc. that are the subject of the guideline.



92
93
94
# File 'lib/schema_org/mixins/medical_guideline.rb', line 92

def guideline_subject=(value)
  write_property(:guideline_subject, value)
end