Module: SchemaOrg::Mixins::MedicalProcedure

Includes:
MedicalEntity
Included in:
SchemaOrg::MedicalProcedure, DiagnosticProcedure, PalliativeProcedure, PhysicalExam, SurgicalProcedure, TherapeuticProcedure
Defined in:
lib/schema_org/mixins/medical_procedure.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/schema_org/mixins/medical_procedure.rb', line 11

def self.schema_property_definitions
  {
    body_location: {
      schema_name: "bodyLocation",
      schema_url: "https://schema.org/bodyLocation",
      comment_lines: ["Location in the body of the anatomical structure."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    followup: {
      schema_name: "followup",
      schema_url: "https://schema.org/followup",
      comment_lines: ["Typical or recommended followup care after the procedure is performed."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    how_performed: {
      schema_name: "howPerformed",
      schema_url: "https://schema.org/howPerformed",
      comment_lines: ["How the procedure is performed."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    preparation: {
      schema_name: "preparation",
      schema_url: "https://schema.org/preparation",
      comment_lines: ["Typical preparation that a patient must undergo before having the procedure performed."].freeze,
      ranges: ["MedicalEntity", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    procedure_type: {
      schema_name: "procedureType",
      schema_url: "https://schema.org/procedureType",
      comment_lines: ["The type of procedure, for example Surgical, Noninvasive, or Percutaneous."].freeze,
      ranges: ["MedicalProcedureType"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    status: {
      schema_name: "status",
      schema_url: "https://schema.org/status",
      comment_lines: ["The status of the study (enumerated)."].freeze,
      ranges: ["EventStatusType", "MedicalStudyStatus", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#body_locationObject

Location in the body of the anatomical structure.



77
78
79
# File 'lib/schema_org/mixins/medical_procedure.rb', line 77

def body_location
  read_property(:body_location)
end

#body_location=(value) ⇒ Object

Location in the body of the anatomical structure.



82
83
84
# File 'lib/schema_org/mixins/medical_procedure.rb', line 82

def body_location=(value)
  write_property(:body_location, value)
end

#followupObject

Typical or recommended followup care after the procedure is performed.



87
88
89
# File 'lib/schema_org/mixins/medical_procedure.rb', line 87

def followup
  read_property(:followup)
end

#followup=(value) ⇒ Object

Typical or recommended followup care after the procedure is performed.



92
93
94
# File 'lib/schema_org/mixins/medical_procedure.rb', line 92

def followup=(value)
  write_property(:followup, value)
end

#how_performedObject

How the procedure is performed.



97
98
99
# File 'lib/schema_org/mixins/medical_procedure.rb', line 97

def how_performed
  read_property(:how_performed)
end

#how_performed=(value) ⇒ Object

How the procedure is performed.



102
103
104
# File 'lib/schema_org/mixins/medical_procedure.rb', line 102

def how_performed=(value)
  write_property(:how_performed, value)
end

#preparationObject

Typical preparation that a patient must undergo before having the procedure performed.



107
108
109
# File 'lib/schema_org/mixins/medical_procedure.rb', line 107

def preparation
  read_property(:preparation)
end

#preparation=(value) ⇒ Object

Typical preparation that a patient must undergo before having the procedure performed.



112
113
114
# File 'lib/schema_org/mixins/medical_procedure.rb', line 112

def preparation=(value)
  write_property(:preparation, value)
end

#procedure_typeObject

The type of procedure, for example Surgical, Noninvasive, or Percutaneous.



117
118
119
# File 'lib/schema_org/mixins/medical_procedure.rb', line 117

def procedure_type
  read_property(:procedure_type)
end

#procedure_type=(value) ⇒ Object

The type of procedure, for example Surgical, Noninvasive, or Percutaneous.



122
123
124
# File 'lib/schema_org/mixins/medical_procedure.rb', line 122

def procedure_type=(value)
  write_property(:procedure_type, value)
end

#statusObject

The status of the study (enumerated).



127
128
129
# File 'lib/schema_org/mixins/medical_procedure.rb', line 127

def status
  read_property(:status)
end

#status=(value) ⇒ Object

The status of the study (enumerated).



132
133
134
# File 'lib/schema_org/mixins/medical_procedure.rb', line 132

def status=(value)
  write_property(:status, value)
end