Module: SchemaOrg::Mixins::MedicalSignOrSymptom

Includes:
MedicalCondition
Included in:
SchemaOrg::MedicalSignOrSymptom, MedicalSign, MedicalSymptom
Defined in:
lib/schema_org/mixins/medical_sign_or_symptom.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from MedicalCondition

#associated_anatomy, #associated_anatomy=, #cause, #cause=, #differential_diagnosis, #differential_diagnosis=, #drug, #drug=, #epidemiology, #epidemiology=, #expected_prognosis, #expected_prognosis=, #natural_progression, #natural_progression=, #pathophysiology, #pathophysiology=, #possible_complication, #possible_complication=, #primary_prevention, #primary_prevention=, #risk_factor, #risk_factor=, #secondary_prevention, #secondary_prevention=, #sign_or_symptom, #sign_or_symptom=, #stage, #stage=, #status, #status=, #typical_test, #typical_test=

Methods included from MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
# File 'lib/schema_org/mixins/medical_sign_or_symptom.rb', line 11

def self.schema_property_definitions
  {
    possible_treatment: {
      schema_name: "possibleTreatment",
      schema_url: "https://schema.org/possibleTreatment",
      comment_lines: ["A possible treatment to address this condition, sign or symptom."].freeze,
      ranges: ["Drug", "DrugClass", "LifestyleModification", "MedicalTherapy"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#possible_treatmentObject

A possible treatment to address this condition, sign or symptom.



27
28
29
# File 'lib/schema_org/mixins/medical_sign_or_symptom.rb', line 27

def possible_treatment
  read_property(:possible_treatment)
end

#possible_treatment=(value) ⇒ Object

A possible treatment to address this condition, sign or symptom.



32
33
34
# File 'lib/schema_org/mixins/medical_sign_or_symptom.rb', line 32

def possible_treatment=(value)
  write_property(:possible_treatment, value)
end