Module: SchemaOrg::Mixins::MedicalStudy

Includes:
MedicalEntity
Included in:
SchemaOrg::MedicalStudy, MedicalObservationalStudy, MedicalTrial
Defined in:
lib/schema_org/mixins/medical_study.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/schema_org/mixins/medical_study.rb', line 11

def self.schema_property_definitions
  {
    health_condition: {
      schema_name: "healthCondition",
      schema_url: "https://schema.org/healthCondition",
      comment_lines: ["Specifying the health condition(s) of a patient, medical study, or other target audience."].freeze,
      ranges: ["MedicalCondition"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    sponsor: {
      schema_name: "sponsor",
      schema_url: "https://schema.org/sponsor",
      comment_lines: ["A person or organization that supports a thing through a pledge, promise, or financial contribution. E.g. a sponsor of a Medical Study or a corporate sponsor of an event."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    status: {
      schema_name: "status",
      schema_url: "https://schema.org/status",
      comment_lines: ["The status of the study (enumerated)."].freeze,
      ranges: ["EventStatusType", "MedicalStudyStatus", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    study_location: {
      schema_name: "studyLocation",
      schema_url: "https://schema.org/studyLocation",
      comment_lines: ["The location in which the study is taking/took place."].freeze,
      ranges: ["AdministrativeArea"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    study_subject: {
      schema_name: "studySubject",
      schema_url: "https://schema.org/studySubject",
      comment_lines: ["A subject of the study, i.e. one of the medical conditions, therapies, devices, drugs, etc. investigated by the study."].freeze,
      ranges: ["MedicalEntity"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#health_conditionObject

Specifying the health condition(s) of a patient, medical study, or other target audience.



67
68
69
# File 'lib/schema_org/mixins/medical_study.rb', line 67

def health_condition
  read_property(:health_condition)
end

#health_condition=(value) ⇒ Object

Specifying the health condition(s) of a patient, medical study, or other target audience.



72
73
74
# File 'lib/schema_org/mixins/medical_study.rb', line 72

def health_condition=(value)
  write_property(:health_condition, value)
end

A person or organization that supports a thing through a pledge, promise, or financial contribution. E.g. a sponsor of a Medical Study or a corporate sponsor of an event.



77
78
79
# File 'lib/schema_org/mixins/medical_study.rb', line 77

def sponsor
  read_property(:sponsor)
end

#sponsor=(value) ⇒ Object

A person or organization that supports a thing through a pledge, promise, or financial contribution. E.g. a sponsor of a Medical Study or a corporate sponsor of an event.



82
83
84
# File 'lib/schema_org/mixins/medical_study.rb', line 82

def sponsor=(value)
  write_property(:sponsor, value)
end

#statusObject

The status of the study (enumerated).



87
88
89
# File 'lib/schema_org/mixins/medical_study.rb', line 87

def status
  read_property(:status)
end

#status=(value) ⇒ Object

The status of the study (enumerated).



92
93
94
# File 'lib/schema_org/mixins/medical_study.rb', line 92

def status=(value)
  write_property(:status, value)
end

#study_locationObject

The location in which the study is taking/took place.



97
98
99
# File 'lib/schema_org/mixins/medical_study.rb', line 97

def study_location
  read_property(:study_location)
end

#study_location=(value) ⇒ Object

The location in which the study is taking/took place.



102
103
104
# File 'lib/schema_org/mixins/medical_study.rb', line 102

def study_location=(value)
  write_property(:study_location, value)
end

#study_subjectObject

A subject of the study, i.e. one of the medical conditions, therapies, devices, drugs, etc. investigated by the study.



107
108
109
# File 'lib/schema_org/mixins/medical_study.rb', line 107

def study_subject
  read_property(:study_subject)
end

#study_subject=(value) ⇒ Object

A subject of the study, i.e. one of the medical conditions, therapies, devices, drugs, etc. investigated by the study.



112
113
114
# File 'lib/schema_org/mixins/medical_study.rb', line 112

def study_subject=(value)
  write_property(:study_subject, value)
end