Module: SchemaOrg::Mixins::MedicalTest

Includes:
MedicalEntity
Included in:
SchemaOrg::MedicalTest, BloodTest, ImagingTest, MedicalTestPanel, PathologyTest
Defined in:
lib/schema_org/mixins/medical_test.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/schema_org/mixins/medical_test.rb', line 11

def self.schema_property_definitions
  {
    affected_by: {
      schema_name: "affectedBy",
      schema_url: "https://schema.org/affectedBy",
      comment_lines: ["Drugs that affect the test's results."].freeze,
      ranges: ["Drug"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    normal_range: {
      schema_name: "normalRange",
      schema_url: "https://schema.org/normalRange",
      comment_lines: ["Range of acceptable values for a typical patient, when applicable."].freeze,
      ranges: ["MedicalEnumeration", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    sign_detected: {
      schema_name: "signDetected",
      schema_url: "https://schema.org/signDetected",
      comment_lines: ["A sign detected by the test."].freeze,
      ranges: ["MedicalSign"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    used_to_diagnose: {
      schema_name: "usedToDiagnose",
      schema_url: "https://schema.org/usedToDiagnose",
      comment_lines: ["A condition the test is used to diagnose."].freeze,
      ranges: ["MedicalCondition"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    uses_device: {
      schema_name: "usesDevice",
      schema_url: "https://schema.org/usesDevice",
      comment_lines: ["Device used to perform the test."].freeze,
      ranges: ["MedicalDevice"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#affected_byObject

Drugs that affect the test's results.



67
68
69
# File 'lib/schema_org/mixins/medical_test.rb', line 67

def affected_by
  read_property(:affected_by)
end

#affected_by=(value) ⇒ Object

Drugs that affect the test's results.



72
73
74
# File 'lib/schema_org/mixins/medical_test.rb', line 72

def affected_by=(value)
  write_property(:affected_by, value)
end

#normal_rangeObject

Range of acceptable values for a typical patient, when applicable.



77
78
79
# File 'lib/schema_org/mixins/medical_test.rb', line 77

def normal_range
  read_property(:normal_range)
end

#normal_range=(value) ⇒ Object

Range of acceptable values for a typical patient, when applicable.



82
83
84
# File 'lib/schema_org/mixins/medical_test.rb', line 82

def normal_range=(value)
  write_property(:normal_range, value)
end

#sign_detectedObject

A sign detected by the test.



87
88
89
# File 'lib/schema_org/mixins/medical_test.rb', line 87

def sign_detected
  read_property(:sign_detected)
end

#sign_detected=(value) ⇒ Object

A sign detected by the test.



92
93
94
# File 'lib/schema_org/mixins/medical_test.rb', line 92

def sign_detected=(value)
  write_property(:sign_detected, value)
end

#used_to_diagnoseObject

A condition the test is used to diagnose.



97
98
99
# File 'lib/schema_org/mixins/medical_test.rb', line 97

def used_to_diagnose
  read_property(:used_to_diagnose)
end

#used_to_diagnose=(value) ⇒ Object

A condition the test is used to diagnose.



102
103
104
# File 'lib/schema_org/mixins/medical_test.rb', line 102

def used_to_diagnose=(value)
  write_property(:used_to_diagnose, value)
end

#uses_deviceObject

Device used to perform the test.



107
108
109
# File 'lib/schema_org/mixins/medical_test.rb', line 107

def uses_device
  read_property(:uses_device)
end

#uses_device=(value) ⇒ Object

Device used to perform the test.



112
113
114
# File 'lib/schema_org/mixins/medical_test.rb', line 112

def uses_device=(value)
  write_property(:uses_device, value)
end