Module: SchemaOrg::Mixins::MedicalTherapy

Includes:
TherapeuticProcedure
Included in:
SchemaOrg::MedicalTherapy, OccupationalTherapy, PalliativeProcedure, PhysicalTherapy, RadiationTherapy
Defined in:
lib/schema_org/mixins/medical_therapy.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from TherapeuticProcedure

#adverse_outcome, #adverse_outcome=, #dose_schedule, #dose_schedule=, #drug, #drug=

Methods included from MedicalProcedure

#body_location, #body_location=, #followup, #followup=, #how_performed, #how_performed=, #preparation, #preparation=, #procedure_type, #procedure_type=, #status, #status=

Methods included from MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/schema_org/mixins/medical_therapy.rb', line 11

def self.schema_property_definitions
  {
    contraindication: {
      schema_name: "contraindication",
      schema_url: "https://schema.org/contraindication",
      comment_lines: ["A contraindication for this therapy."].freeze,
      ranges: ["MedicalContraindication", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    duplicate_therapy: {
      schema_name: "duplicateTherapy",
      schema_url: "https://schema.org/duplicateTherapy",
      comment_lines: ["A therapy that duplicates or overlaps this one."].freeze,
      ranges: ["MedicalTherapy"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    serious_adverse_outcome: {
      schema_name: "seriousAdverseOutcome",
      schema_url: "https://schema.org/seriousAdverseOutcome",
      comment_lines: ["A possible serious complication and/or serious side effect of this therapy. Serious adverse outcomes include those that are life-threatening; result in death, disability, or permanent damage; require hospitalization or prolong existing hospitalization; cause congenital anomalies or birth defects; or jeopardize the patient and may require medical or surgical intervention to prevent one of the outcomes in this definition."].freeze,
      ranges: ["MedicalEntity"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#contraindicationObject

A contraindication for this therapy.



47
48
49
# File 'lib/schema_org/mixins/medical_therapy.rb', line 47

def contraindication
  read_property(:contraindication)
end

#contraindication=(value) ⇒ Object

A contraindication for this therapy.



52
53
54
# File 'lib/schema_org/mixins/medical_therapy.rb', line 52

def contraindication=(value)
  write_property(:contraindication, value)
end

#duplicate_therapyObject

A therapy that duplicates or overlaps this one.



57
58
59
# File 'lib/schema_org/mixins/medical_therapy.rb', line 57

def duplicate_therapy
  read_property(:duplicate_therapy)
end

#duplicate_therapy=(value) ⇒ Object

A therapy that duplicates or overlaps this one.



62
63
64
# File 'lib/schema_org/mixins/medical_therapy.rb', line 62

def duplicate_therapy=(value)
  write_property(:duplicate_therapy, value)
end

#serious_adverse_outcomeObject

A possible serious complication and/or serious side effect of this therapy. Serious adverse outcomes include those that are life-threatening; result in death, disability, or permanent damage; require hospitalization or prolong existing hospitalization; cause congenital anomalies or birth defects; or jeopardize the patient and may require medical or surgical intervention to prevent one of the outcomes in this definition.



67
68
69
# File 'lib/schema_org/mixins/medical_therapy.rb', line 67

def serious_adverse_outcome
  read_property(:serious_adverse_outcome)
end

#serious_adverse_outcome=(value) ⇒ Object

A possible serious complication and/or serious side effect of this therapy. Serious adverse outcomes include those that are life-threatening; result in death, disability, or permanent damage; require hospitalization or prolong existing hospitalization; cause congenital anomalies or birth defects; or jeopardize the patient and may require medical or surgical intervention to prevent one of the outcomes in this definition.



72
73
74
# File 'lib/schema_org/mixins/medical_therapy.rb', line 72

def serious_adverse_outcome=(value)
  write_property(:serious_adverse_outcome, value)
end