Module: SchemaOrg::Mixins::MerchantReturnPolicySeasonalOverride

Includes:
Intangible
Included in:
SchemaOrg::MerchantReturnPolicySeasonalOverride
Defined in:
lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 11

def self.schema_property_definitions
  {
    end_date: {
      schema_name: "endDate",
      schema_url: "https://schema.org/endDate",
      comment_lines: ["The end date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601))."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    merchant_return_days: {
      schema_name: "merchantReturnDays",
      schema_url: "https://schema.org/merchantReturnDays",
      comment_lines: ["Specifies either a fixed return date or the number of days (from the delivery date) that a product can be returned. Used when the [[returnPolicyCategory]] property is specified as [[MerchantReturnFiniteReturnWindow]]."].freeze,
      ranges: ["Date", "DateTime", "Integer"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["productReturnDays"].freeze
    }.freeze,
    refund_type: {
      schema_name: "refundType",
      schema_url: "https://schema.org/refundType",
      comment_lines: ["A refund type, from an enumerated list."].freeze,
      ranges: ["RefundTypeEnumeration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    restocking_fee: {
      schema_name: "restockingFee",
      schema_url: "https://schema.org/restockingFee",
      comment_lines: ["Use [[MonetaryAmount]] to specify a fixed restocking fee for product returns, or use [[Number]] to specify a percentage of the product price paid by the customer."].freeze,
      ranges: ["MonetaryAmount", "Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    return_fees: {
      schema_name: "returnFees",
      schema_url: "https://schema.org/returnFees",
      comment_lines: ["The type of return fees for purchased products (for any return reason)."].freeze,
      ranges: ["ReturnFeesEnumeration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    return_method: {
      schema_name: "returnMethod",
      schema_url: "https://schema.org/returnMethod",
      comment_lines: ["The type of return method offered, specified from an enumeration."].freeze,
      ranges: ["ReturnMethodEnumeration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    return_policy_category: {
      schema_name: "returnPolicyCategory",
      schema_url: "https://schema.org/returnPolicyCategory",
      comment_lines: ["Specifies an applicable return policy (from an enumeration)."].freeze,
      ranges: ["MerchantReturnEnumeration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    return_shipping_fees_amount: {
      schema_name: "returnShippingFeesAmount",
      schema_url: "https://schema.org/returnShippingFeesAmount",
      comment_lines: ["Amount of shipping costs for product returns (for any reason). Applicable when property [[returnFees]] equals [[ReturnShippingFees]]."].freeze,
      ranges: ["MonetaryAmount"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    start_date: {
      schema_name: "startDate",
      schema_url: "https://schema.org/startDate",
      comment_lines: ["The start date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601))."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#end_dateObject

The end date and time of the item (in ISO 8601 date format).



107
108
109
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 107

def end_date
  read_property(:end_date)
end

#end_date=(value) ⇒ Object

The end date and time of the item (in ISO 8601 date format).



112
113
114
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 112

def end_date=(value)
  write_property(:end_date, value)
end

#merchant_return_daysObject

Specifies either a fixed return date or the number of days (from the delivery date) that a product can be returned. Used when the [[returnPolicyCategory]] property is specified as [[MerchantReturnFiniteReturnWindow]]. Supersedes productReturnDays.



118
119
120
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 118

def merchant_return_days
  read_property(:merchant_return_days)
end

#merchant_return_days=(value) ⇒ Object

Specifies either a fixed return date or the number of days (from the delivery date) that a product can be returned. Used when the [[returnPolicyCategory]] property is specified as [[MerchantReturnFiniteReturnWindow]]. Supersedes productReturnDays.



124
125
126
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 124

def merchant_return_days=(value)
  write_property(:merchant_return_days, value)
end

#refund_typeObject

A refund type, from an enumerated list.



129
130
131
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 129

def refund_type
  read_property(:refund_type)
end

#refund_type=(value) ⇒ Object

A refund type, from an enumerated list.



134
135
136
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 134

def refund_type=(value)
  write_property(:refund_type, value)
end

#restocking_feeObject

Use [[MonetaryAmount]] to specify a fixed restocking fee for product returns, or use [[Number]] to specify a percentage of the product price paid by the customer.



139
140
141
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 139

def restocking_fee
  read_property(:restocking_fee)
end

#restocking_fee=(value) ⇒ Object

Use [[MonetaryAmount]] to specify a fixed restocking fee for product returns, or use [[Number]] to specify a percentage of the product price paid by the customer.



144
145
146
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 144

def restocking_fee=(value)
  write_property(:restocking_fee, value)
end

#return_feesObject

The type of return fees for purchased products (for any return reason).



149
150
151
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 149

def return_fees
  read_property(:return_fees)
end

#return_fees=(value) ⇒ Object

The type of return fees for purchased products (for any return reason).



154
155
156
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 154

def return_fees=(value)
  write_property(:return_fees, value)
end

#return_methodObject

The type of return method offered, specified from an enumeration.



159
160
161
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 159

def return_method
  read_property(:return_method)
end

#return_method=(value) ⇒ Object

The type of return method offered, specified from an enumeration.



164
165
166
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 164

def return_method=(value)
  write_property(:return_method, value)
end

#return_policy_categoryObject

Specifies an applicable return policy (from an enumeration).



169
170
171
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 169

def return_policy_category
  read_property(:return_policy_category)
end

#return_policy_category=(value) ⇒ Object

Specifies an applicable return policy (from an enumeration).



174
175
176
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 174

def return_policy_category=(value)
  write_property(:return_policy_category, value)
end

#return_shipping_fees_amountObject

Amount of shipping costs for product returns (for any reason). Applicable when property [[returnFees]] equals [[ReturnShippingFees]].



179
180
181
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 179

def return_shipping_fees_amount
  read_property(:return_shipping_fees_amount)
end

#return_shipping_fees_amount=(value) ⇒ Object

Amount of shipping costs for product returns (for any reason). Applicable when property [[returnFees]] equals [[ReturnShippingFees]].



184
185
186
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 184

def return_shipping_fees_amount=(value)
  write_property(:return_shipping_fees_amount, value)
end

#start_dateObject

The start date and time of the item (in ISO 8601 date format).



189
190
191
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 189

def start_date
  read_property(:start_date)
end

#start_date=(value) ⇒ Object

The start date and time of the item (in ISO 8601 date format).



194
195
196
# File 'lib/schema_org/mixins/merchant_return_policy_seasonal_override.rb', line 194

def start_date=(value)
  write_property(:start_date, value)
end