Module: SchemaOrg::Mixins::Message

Includes:
CreativeWork
Included in:
SchemaOrg::Message, EmailMessage
Defined in:
lib/schema_org/mixins/message.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from CreativeWork

#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/schema_org/mixins/message.rb', line 11

def self.schema_property_definitions
  {
    bcc_recipient: {
      schema_name: "bccRecipient",
      schema_url: "https://schema.org/bccRecipient",
      comment_lines: ["A sub property of recipient. The recipient blind copied on a message."].freeze,
      ranges: ["ContactPoint", "Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    cc_recipient: {
      schema_name: "ccRecipient",
      schema_url: "https://schema.org/ccRecipient",
      comment_lines: ["A sub property of recipient. The recipient copied on a message."].freeze,
      ranges: ["ContactPoint", "Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    date_read: {
      schema_name: "dateRead",
      schema_url: "https://schema.org/dateRead",
      comment_lines: ["The date/time at which the message has been read by the recipient if a single recipient exists."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    date_received: {
      schema_name: "dateReceived",
      schema_url: "https://schema.org/dateReceived",
      comment_lines: ["The date/time the message was received if a single recipient exists."].freeze,
      ranges: ["DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    date_sent: {
      schema_name: "dateSent",
      schema_url: "https://schema.org/dateSent",
      comment_lines: ["The date/time at which the message was sent."].freeze,
      ranges: ["DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    message_attachment: {
      schema_name: "messageAttachment",
      schema_url: "https://schema.org/messageAttachment",
      comment_lines: ["A CreativeWork attached to the message."].freeze,
      ranges: ["CreativeWork"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    recipient: {
      schema_name: "recipient",
      schema_url: "https://schema.org/recipient",
      comment_lines: ["A sub property of participant. The participant who is at the receiving end of the action."].freeze,
      ranges: ["Audience", "ContactPoint", "Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    sender: {
      schema_name: "sender",
      schema_url: "https://schema.org/sender",
      comment_lines: ["A sub property of participant. The participant who is at the sending end of the action."].freeze,
      ranges: ["Audience", "Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    to_recipient: {
      schema_name: "toRecipient",
      schema_url: "https://schema.org/toRecipient",
      comment_lines: ["A sub property of recipient. The recipient who was directly sent the message."].freeze,
      ranges: ["Audience", "ContactPoint", "Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#bcc_recipientObject

A sub property of recipient. The recipient blind copied on a message.



107
108
109
# File 'lib/schema_org/mixins/message.rb', line 107

def bcc_recipient
  read_property(:bcc_recipient)
end

#bcc_recipient=(value) ⇒ Object

A sub property of recipient. The recipient blind copied on a message.



112
113
114
# File 'lib/schema_org/mixins/message.rb', line 112

def bcc_recipient=(value)
  write_property(:bcc_recipient, value)
end

#cc_recipientObject

A sub property of recipient. The recipient copied on a message.



117
118
119
# File 'lib/schema_org/mixins/message.rb', line 117

def cc_recipient
  read_property(:cc_recipient)
end

#cc_recipient=(value) ⇒ Object

A sub property of recipient. The recipient copied on a message.



122
123
124
# File 'lib/schema_org/mixins/message.rb', line 122

def cc_recipient=(value)
  write_property(:cc_recipient, value)
end

#date_readObject

The date/time at which the message has been read by the recipient if a single recipient exists.



127
128
129
# File 'lib/schema_org/mixins/message.rb', line 127

def date_read
  read_property(:date_read)
end

#date_read=(value) ⇒ Object

The date/time at which the message has been read by the recipient if a single recipient exists.



132
133
134
# File 'lib/schema_org/mixins/message.rb', line 132

def date_read=(value)
  write_property(:date_read, value)
end

#date_receivedObject

The date/time the message was received if a single recipient exists.



137
138
139
# File 'lib/schema_org/mixins/message.rb', line 137

def date_received
  read_property(:date_received)
end

#date_received=(value) ⇒ Object

The date/time the message was received if a single recipient exists.



142
143
144
# File 'lib/schema_org/mixins/message.rb', line 142

def date_received=(value)
  write_property(:date_received, value)
end

#date_sentObject

The date/time at which the message was sent.



147
148
149
# File 'lib/schema_org/mixins/message.rb', line 147

def date_sent
  read_property(:date_sent)
end

#date_sent=(value) ⇒ Object

The date/time at which the message was sent.



152
153
154
# File 'lib/schema_org/mixins/message.rb', line 152

def date_sent=(value)
  write_property(:date_sent, value)
end

#message_attachmentObject

A CreativeWork attached to the message.



157
158
159
# File 'lib/schema_org/mixins/message.rb', line 157

def message_attachment
  read_property(:message_attachment)
end

#message_attachment=(value) ⇒ Object

A CreativeWork attached to the message.



162
163
164
# File 'lib/schema_org/mixins/message.rb', line 162

def message_attachment=(value)
  write_property(:message_attachment, value)
end

#recipientObject

A sub property of participant. The participant who is at the receiving end of the action.



167
168
169
# File 'lib/schema_org/mixins/message.rb', line 167

def recipient
  read_property(:recipient)
end

#recipient=(value) ⇒ Object

A sub property of participant. The participant who is at the receiving end of the action.



172
173
174
# File 'lib/schema_org/mixins/message.rb', line 172

def recipient=(value)
  write_property(:recipient, value)
end

#senderObject

A sub property of participant. The participant who is at the sending end of the action.



177
178
179
# File 'lib/schema_org/mixins/message.rb', line 177

def sender
  read_property(:sender)
end

#sender=(value) ⇒ Object

A sub property of participant. The participant who is at the sending end of the action.



182
183
184
# File 'lib/schema_org/mixins/message.rb', line 182

def sender=(value)
  write_property(:sender, value)
end

#to_recipientObject

A sub property of recipient. The recipient who was directly sent the message.



187
188
189
# File 'lib/schema_org/mixins/message.rb', line 187

def to_recipient
  read_property(:to_recipient)
end

#to_recipient=(value) ⇒ Object

A sub property of recipient. The recipient who was directly sent the message.



192
193
194
# File 'lib/schema_org/mixins/message.rb', line 192

def to_recipient=(value)
  write_property(:to_recipient, value)
end