Module: SchemaOrg::Mixins::MonetaryAmount

Includes:
StructuredValue
Included in:
SchemaOrg::MonetaryAmount
Defined in:
lib/schema_org/mixins/monetary_amount.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/schema_org/mixins/monetary_amount.rb', line 11

def self.schema_property_definitions
  {
    currency: {
      schema_name: "currency",
      schema_url: "https://schema.org/currency",
      comment_lines: ["The currency in which the monetary amount is expressed.\\n\\nUse standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. \"USD\"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. \"BTC\"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. \"Ithaca HOUR\"."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    max_value: {
      schema_name: "maxValue",
      schema_url: "https://schema.org/maxValue",
      comment_lines: ["The upper value of some characteristic or property."].freeze,
      ranges: ["Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    min_value: {
      schema_name: "minValue",
      schema_url: "https://schema.org/minValue",
      comment_lines: ["The lower value of some characteristic or property."].freeze,
      ranges: ["Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    valid_from: {
      schema_name: "validFrom",
      schema_url: "https://schema.org/validFrom",
      comment_lines: ["The date when the item becomes valid."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    valid_through: {
      schema_name: "validThrough",
      schema_url: "https://schema.org/validThrough",
      comment_lines: ["The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    value: {
      schema_name: "value",
      schema_url: "https://schema.org/value",
      comment_lines: ["The value of a [[QuantitativeValue]] (including [[Observation]]) or property value node.\\n\\n* For [[QuantitativeValue]] and [[MonetaryAmount]], the recommended type for values is 'Number'.\\n* For [[PropertyValue]], it can be 'Text', 'Number', 'Boolean', or 'StructuredValue'.\\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator."].freeze,
      ranges: ["Boolean", "Number", "StructuredValue", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#currencyObject

The currency in which the monetary amount is expressed.\n\nUse standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR".



77
78
79
# File 'lib/schema_org/mixins/monetary_amount.rb', line 77

def currency
  read_property(:currency)
end

#currency=(value) ⇒ Object

The currency in which the monetary amount is expressed.\n\nUse standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR".



82
83
84
# File 'lib/schema_org/mixins/monetary_amount.rb', line 82

def currency=(value)
  write_property(:currency, value)
end

#max_valueObject

The upper value of some characteristic or property.



87
88
89
# File 'lib/schema_org/mixins/monetary_amount.rb', line 87

def max_value
  read_property(:max_value)
end

#max_value=(value) ⇒ Object

The upper value of some characteristic or property.



92
93
94
# File 'lib/schema_org/mixins/monetary_amount.rb', line 92

def max_value=(value)
  write_property(:max_value, value)
end

#min_valueObject

The lower value of some characteristic or property.



97
98
99
# File 'lib/schema_org/mixins/monetary_amount.rb', line 97

def min_value
  read_property(:min_value)
end

#min_value=(value) ⇒ Object

The lower value of some characteristic or property.



102
103
104
# File 'lib/schema_org/mixins/monetary_amount.rb', line 102

def min_value=(value)
  write_property(:min_value, value)
end

#valid_fromObject

The date when the item becomes valid.



107
108
109
# File 'lib/schema_org/mixins/monetary_amount.rb', line 107

def valid_from
  read_property(:valid_from)
end

#valid_from=(value) ⇒ Object

The date when the item becomes valid.



112
113
114
# File 'lib/schema_org/mixins/monetary_amount.rb', line 112

def valid_from=(value)
  write_property(:valid_from, value)
end

#valid_throughObject

The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.



117
118
119
# File 'lib/schema_org/mixins/monetary_amount.rb', line 117

def valid_through
  read_property(:valid_through)
end

#valid_through=(value) ⇒ Object

The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.



122
123
124
# File 'lib/schema_org/mixins/monetary_amount.rb', line 122

def valid_through=(value)
  write_property(:valid_through, value)
end

#valueObject

The value of a [[QuantitativeValue]] (including [[Observation]]) or property value node.\n\n* For [[QuantitativeValue]] and [[MonetaryAmount]], the recommended type for values is 'Number'.\n* For [[PropertyValue]], it can be 'Text', 'Number', 'Boolean', or 'StructuredValue'.\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.



127
128
129
# File 'lib/schema_org/mixins/monetary_amount.rb', line 127

def value
  read_property(:value)
end

#value=(value) ⇒ Object

The value of a [[QuantitativeValue]] (including [[Observation]]) or property value node.\n\n* For [[QuantitativeValue]] and [[MonetaryAmount]], the recommended type for values is 'Number'.\n* For [[PropertyValue]], it can be 'Text', 'Number', 'Boolean', or 'StructuredValue'.\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.



132
133
134
# File 'lib/schema_org/mixins/monetary_amount.rb', line 132

def value=(value)
  write_property(:value, value)
end