Module: SchemaOrg::Mixins::MoneyTransfer
- Includes:
- TransferAction
- Included in:
- SchemaOrg::MoneyTransfer
- Defined in:
- lib/schema_org/mixins/money_transfer.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#amount ⇒ Object
The amount of money.
-
#amount=(value) ⇒ Object
The amount of money.
-
#beneficiary_bank ⇒ Object
A bank or bank’s branch, financial institution or international financial institution operating the beneficiary’s bank account or releasing funds for the beneficiary.
-
#beneficiary_bank=(value) ⇒ Object
A bank or bank’s branch, financial institution or international financial institution operating the beneficiary’s bank account or releasing funds for the beneficiary.
Methods included from TransferAction
#from_location, #from_location=, #to_location, #to_location=
Methods included from Action
#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, #start_time, #start_time=, #target, #target=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/schema_org/mixins/money_transfer.rb', line 11 def self.schema_property_definitions { amount: { schema_name: "amount", schema_url: "https://schema.org/amount", comment_lines: ["The amount of money."].freeze, ranges: ["MonetaryAmount", "Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, beneficiary_bank: { schema_name: "beneficiaryBank", schema_url: "https://schema.org/beneficiaryBank", comment_lines: ["A bank or bank’s branch, financial institution or international financial institution operating the beneficiary’s bank account or releasing funds for the beneficiary."].freeze, ranges: ["BankOrCreditUnion", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#amount ⇒ Object
The amount of money.
37 38 39 |
# File 'lib/schema_org/mixins/money_transfer.rb', line 37 def amount read_property(:amount) end |
#amount=(value) ⇒ Object
The amount of money.
42 43 44 |
# File 'lib/schema_org/mixins/money_transfer.rb', line 42 def amount=(value) write_property(:amount, value) end |
#beneficiary_bank ⇒ Object
A bank or bank’s branch, financial institution or international financial institution operating the beneficiary’s bank account or releasing funds for the beneficiary.
47 48 49 |
# File 'lib/schema_org/mixins/money_transfer.rb', line 47 def beneficiary_bank read_property(:beneficiary_bank) end |
#beneficiary_bank=(value) ⇒ Object
A bank or bank’s branch, financial institution or international financial institution operating the beneficiary’s bank account or releasing funds for the beneficiary.
52 53 54 |
# File 'lib/schema_org/mixins/money_transfer.rb', line 52 def beneficiary_bank=(value) write_property(:beneficiary_bank, value) end |