Module: SchemaOrg::Mixins::MortgageLoan

Includes:
LoanOrCredit
Included in:
SchemaOrg::MortgageLoan
Defined in:
lib/schema_org/mixins/mortgage_loan.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from LoanOrCredit

#amount, #amount=, #currency, #currency=, #grace_period, #grace_period=, #loan_repayment_form, #loan_repayment_form=, #loan_term, #loan_term=, #loan_type, #loan_type=, #recourse_loan, #recourse_loan=, #renegotiable_loan, #renegotiable_loan=, #required_collateral, #required_collateral=

Methods included from FinancialProduct

#annual_percentage_rate, #annual_percentage_rate=, #fees_and_commissions_specification, #fees_and_commissions_specification=, #interest_rate, #interest_rate=

Methods included from Service

#aggregate_rating, #aggregate_rating=, #area_served, #area_served=, #audience, #audience=, #available_channel, #available_channel=, #award, #award=, #brand, #brand=, #broker, #broker=, #category, #category=, #has_certification, #has_certification=, #has_offer_catalog, #has_offer_catalog=, #hours_available, #hours_available=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #logo, #logo=, #offers, #offers=, #produces, #produces=, #provider, #provider=, #provider_mobility, #provider_mobility=, #review, #review=, #service_area, #service_area=, #service_audience, #service_audience=, #service_output, #service_output=, #service_type, #service_type=, #slogan, #slogan=, #terms_of_service, #terms_of_service=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/schema_org/mixins/mortgage_loan.rb', line 11

def self.schema_property_definitions
  {
    domiciled_mortgage: {
      schema_name: "domiciledMortgage",
      schema_url: "https://schema.org/domiciledMortgage",
      comment_lines: ["Whether borrower is a resident of the jurisdiction where the property is located."].freeze,
      ranges: ["Boolean"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    loan_mortgage_mandate_amount: {
      schema_name: "loanMortgageMandateAmount",
      schema_url: "https://schema.org/loanMortgageMandateAmount",
      comment_lines: ["Amount of mortgage mandate that can be converted into a proper mortgage at a later stage."].freeze,
      ranges: ["MonetaryAmount"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#domiciled_mortgageObject

Whether borrower is a resident of the jurisdiction where the property is located.



37
38
39
# File 'lib/schema_org/mixins/mortgage_loan.rb', line 37

def domiciled_mortgage
  read_property(:domiciled_mortgage)
end

#domiciled_mortgage=(value) ⇒ Object

Whether borrower is a resident of the jurisdiction where the property is located.



42
43
44
# File 'lib/schema_org/mixins/mortgage_loan.rb', line 42

def domiciled_mortgage=(value)
  write_property(:domiciled_mortgage, value)
end

#loan_mortgage_mandate_amountObject

Amount of mortgage mandate that can be converted into a proper mortgage at a later stage.



47
48
49
# File 'lib/schema_org/mixins/mortgage_loan.rb', line 47

def loan_mortgage_mandate_amount
  read_property(:loan_mortgage_mandate_amount)
end

#loan_mortgage_mandate_amount=(value) ⇒ Object

Amount of mortgage mandate that can be converted into a proper mortgage at a later stage.



52
53
54
# File 'lib/schema_org/mixins/mortgage_loan.rb', line 52

def loan_mortgage_mandate_amount=(value)
  write_property(:loan_mortgage_mandate_amount, value)
end