Module: SchemaOrg::Mixins::Muscle

Includes:
AnatomicalStructure
Included in:
SchemaOrg::Muscle
Defined in:
lib/schema_org/mixins/muscle.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from AnatomicalStructure

#associated_pathophysiology, #associated_pathophysiology=, #body_location, #body_location=, #connected_to, #connected_to=, #diagram, #diagram=, #part_of_system, #part_of_system=, #related_condition, #related_condition=, #related_therapy, #related_therapy=, #sub_structure, #sub_structure=

Methods included from MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/schema_org/mixins/muscle.rb', line 11

def self.schema_property_definitions
  {
    antagonist: {
      schema_name: "antagonist",
      schema_url: "https://schema.org/antagonist",
      comment_lines: ["The muscle whose action counteracts the specified muscle."].freeze,
      ranges: ["Muscle"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    blood_supply: {
      schema_name: "bloodSupply",
      schema_url: "https://schema.org/bloodSupply",
      comment_lines: ["The blood vessel that carries blood from the heart to the muscle."].freeze,
      ranges: ["Vessel"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    insertion: {
      schema_name: "insertion",
      schema_url: "https://schema.org/insertion",
      comment_lines: ["The place of attachment of a muscle, or what the muscle moves."].freeze,
      ranges: ["AnatomicalStructure"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    muscle_action: {
      schema_name: "muscleAction",
      schema_url: "https://schema.org/muscleAction",
      comment_lines: ["The movement the muscle generates."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    nerve: {
      schema_name: "nerve",
      schema_url: "https://schema.org/nerve",
      comment_lines: ["The underlying innervation associated with the muscle."].freeze,
      ranges: ["Nerve"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#antagonistObject

The muscle whose action counteracts the specified muscle.



67
68
69
# File 'lib/schema_org/mixins/muscle.rb', line 67

def antagonist
  read_property(:antagonist)
end

#antagonist=(value) ⇒ Object

The muscle whose action counteracts the specified muscle.



72
73
74
# File 'lib/schema_org/mixins/muscle.rb', line 72

def antagonist=(value)
  write_property(:antagonist, value)
end

#blood_supplyObject

The blood vessel that carries blood from the heart to the muscle.



77
78
79
# File 'lib/schema_org/mixins/muscle.rb', line 77

def blood_supply
  read_property(:blood_supply)
end

#blood_supply=(value) ⇒ Object

The blood vessel that carries blood from the heart to the muscle.



82
83
84
# File 'lib/schema_org/mixins/muscle.rb', line 82

def blood_supply=(value)
  write_property(:blood_supply, value)
end

#insertionObject

The place of attachment of a muscle, or what the muscle moves.



87
88
89
# File 'lib/schema_org/mixins/muscle.rb', line 87

def insertion
  read_property(:insertion)
end

#insertion=(value) ⇒ Object

The place of attachment of a muscle, or what the muscle moves.



92
93
94
# File 'lib/schema_org/mixins/muscle.rb', line 92

def insertion=(value)
  write_property(:insertion, value)
end

#muscle_actionObject

The movement the muscle generates.



97
98
99
# File 'lib/schema_org/mixins/muscle.rb', line 97

def muscle_action
  read_property(:muscle_action)
end

#muscle_action=(value) ⇒ Object

The movement the muscle generates.



102
103
104
# File 'lib/schema_org/mixins/muscle.rb', line 102

def muscle_action=(value)
  write_property(:muscle_action, value)
end

#nerveObject

The underlying innervation associated with the muscle.



107
108
109
# File 'lib/schema_org/mixins/muscle.rb', line 107

def nerve
  read_property(:nerve)
end

#nerve=(value) ⇒ Object

The underlying innervation associated with the muscle.



112
113
114
# File 'lib/schema_org/mixins/muscle.rb', line 112

def nerve=(value)
  write_property(:nerve, value)
end