Module: SchemaOrg::Mixins::MusicComposition

Includes:
CreativeWork
Included in:
SchemaOrg::MusicComposition
Defined in:
lib/schema_org/mixins/music_composition.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from CreativeWork

#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/schema_org/mixins/music_composition.rb', line 11

def self.schema_property_definitions
  {
    composer: {
      schema_name: "composer",
      schema_url: "https://schema.org/composer",
      comment_lines: ["The person or organization who wrote a composition, or who is the composer of a work performed at some event."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    first_performance: {
      schema_name: "firstPerformance",
      schema_url: "https://schema.org/firstPerformance",
      comment_lines: ["The date and place the work was first performed."].freeze,
      ranges: ["Event"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    included_composition: {
      schema_name: "includedComposition",
      schema_url: "https://schema.org/includedComposition",
      comment_lines: ["Smaller compositions included in this work (e.g. a movement in a symphony)."].freeze,
      ranges: ["MusicComposition"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    iswc_code: {
      schema_name: "iswcCode",
      schema_url: "https://schema.org/iswcCode",
      comment_lines: ["The International Standard Musical Work Code for the composition."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    lyricist: {
      schema_name: "lyricist",
      schema_url: "https://schema.org/lyricist",
      comment_lines: ["The person who wrote the words."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    lyrics: {
      schema_name: "lyrics",
      schema_url: "https://schema.org/lyrics",
      comment_lines: ["The words in the song."].freeze,
      ranges: ["CreativeWork"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    music_arrangement: {
      schema_name: "musicArrangement",
      schema_url: "https://schema.org/musicArrangement",
      comment_lines: ["An arrangement derived from the composition."].freeze,
      ranges: ["MusicComposition"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    music_composition_form: {
      schema_name: "musicCompositionForm",
      schema_url: "https://schema.org/musicCompositionForm",
      comment_lines: ["The type of composition (e.g. overture, sonata, symphony, etc.)."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    musical_key: {
      schema_name: "musicalKey",
      schema_url: "https://schema.org/musicalKey",
      comment_lines: ["The key, mode, or scale this composition uses."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    recorded_as: {
      schema_name: "recordedAs",
      schema_url: "https://schema.org/recordedAs",
      comment_lines: ["An audio recording of the work."].freeze,
      ranges: ["MusicRecording"].freeze,
      external_ranges: [].freeze,
      inverse_of: "recordingOf",
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#composerObject

The person or organization who wrote a composition, or who is the composer of a work performed at some event.



117
118
119
# File 'lib/schema_org/mixins/music_composition.rb', line 117

def composer
  read_property(:composer)
end

#composer=(value) ⇒ Object

The person or organization who wrote a composition, or who is the composer of a work performed at some event.



122
123
124
# File 'lib/schema_org/mixins/music_composition.rb', line 122

def composer=(value)
  write_property(:composer, value)
end

#first_performanceObject

The date and place the work was first performed.



127
128
129
# File 'lib/schema_org/mixins/music_composition.rb', line 127

def first_performance
  read_property(:first_performance)
end

#first_performance=(value) ⇒ Object

The date and place the work was first performed.



132
133
134
# File 'lib/schema_org/mixins/music_composition.rb', line 132

def first_performance=(value)
  write_property(:first_performance, value)
end

#included_compositionObject

Smaller compositions included in this work (e.g. a movement in a symphony).



137
138
139
# File 'lib/schema_org/mixins/music_composition.rb', line 137

def included_composition
  read_property(:included_composition)
end

#included_composition=(value) ⇒ Object

Smaller compositions included in this work (e.g. a movement in a symphony).



142
143
144
# File 'lib/schema_org/mixins/music_composition.rb', line 142

def included_composition=(value)
  write_property(:included_composition, value)
end

#iswc_codeObject

The International Standard Musical Work Code for the composition.



147
148
149
# File 'lib/schema_org/mixins/music_composition.rb', line 147

def iswc_code
  read_property(:iswc_code)
end

#iswc_code=(value) ⇒ Object

The International Standard Musical Work Code for the composition.



152
153
154
# File 'lib/schema_org/mixins/music_composition.rb', line 152

def iswc_code=(value)
  write_property(:iswc_code, value)
end

#lyricistObject

The person who wrote the words.



157
158
159
# File 'lib/schema_org/mixins/music_composition.rb', line 157

def lyricist
  read_property(:lyricist)
end

#lyricist=(value) ⇒ Object

The person who wrote the words.



162
163
164
# File 'lib/schema_org/mixins/music_composition.rb', line 162

def lyricist=(value)
  write_property(:lyricist, value)
end

#lyricsObject

The words in the song.



167
168
169
# File 'lib/schema_org/mixins/music_composition.rb', line 167

def lyrics
  read_property(:lyrics)
end

#lyrics=(value) ⇒ Object

The words in the song.



172
173
174
# File 'lib/schema_org/mixins/music_composition.rb', line 172

def lyrics=(value)
  write_property(:lyrics, value)
end

#music_arrangementObject

An arrangement derived from the composition.



177
178
179
# File 'lib/schema_org/mixins/music_composition.rb', line 177

def music_arrangement
  read_property(:music_arrangement)
end

#music_arrangement=(value) ⇒ Object

An arrangement derived from the composition.



182
183
184
# File 'lib/schema_org/mixins/music_composition.rb', line 182

def music_arrangement=(value)
  write_property(:music_arrangement, value)
end

#music_composition_formObject

The type of composition (e.g. overture, sonata, symphony, etc.).



187
188
189
# File 'lib/schema_org/mixins/music_composition.rb', line 187

def music_composition_form
  read_property(:music_composition_form)
end

#music_composition_form=(value) ⇒ Object

The type of composition (e.g. overture, sonata, symphony, etc.).



192
193
194
# File 'lib/schema_org/mixins/music_composition.rb', line 192

def music_composition_form=(value)
  write_property(:music_composition_form, value)
end

#musical_keyObject

The key, mode, or scale this composition uses.



197
198
199
# File 'lib/schema_org/mixins/music_composition.rb', line 197

def musical_key
  read_property(:musical_key)
end

#musical_key=(value) ⇒ Object

The key, mode, or scale this composition uses.



202
203
204
# File 'lib/schema_org/mixins/music_composition.rb', line 202

def musical_key=(value)
  write_property(:musical_key, value)
end

#recorded_asObject

An audio recording of the work. Inverse-property: recordingOf.



208
209
210
# File 'lib/schema_org/mixins/music_composition.rb', line 208

def recorded_as
  read_property(:recorded_as)
end

#recorded_as=(value) ⇒ Object

An audio recording of the work. Inverse-property: recordingOf.



214
215
216
# File 'lib/schema_org/mixins/music_composition.rb', line 214

def recorded_as=(value)
  write_property(:recorded_as, value)
end