Module: SchemaOrg::Mixins::NewsMediaOrganization

Includes:
Organization
Included in:
NewsMediaOrganization
Defined in:
lib/schema_org/mixins/news_media_organization.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Organization

#accepted_payment_method, #accepted_payment_method=, #address, #address=, #agent_interaction_statistic, #agent_interaction_statistic=, #aggregate_rating, #aggregate_rating=, #alumni, #alumni=, #area_served, #area_served=, #award, #award=, #awards, #awards=, #brand, #brand=, #company_registration, #company_registration=, #contact_point, #contact_point=, #contact_points, #contact_points=, #department, #department=, #dissolution_date, #dissolution_date=, #duns, #duns=, #email, #email=, #employee, #employee=, #employees, #employees=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #founder, #founder=, #founders, #founders=, #founding_date, #founding_date=, #founding_location, #founding_location=, #funder, #funder=, #funding, #funding=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_credential, #has_credential=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_member_program, #has_member_program=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_offer_catalog, #has_offer_catalog=, #has_pos, #has_pos=, #has_product_return_policy, #has_product_return_policy=, #has_shipping_service, #has_shipping_service=, #interaction_statistic, #interaction_statistic=, #isic_v4, #isic_v4=, #iso6523_code, #iso6523_code=, #keywords, #keywords=, #knows_about, #knows_about=, #knows_language, #knows_language=, #legal_address, #legal_address=, #legal_name, #legal_name=, #legal_representative, #legal_representative=, #lei_code, #lei_code=, #location, #location=, #logo, #logo=, #makes_offer, #makes_offer=, #member, #member=, #member_of, #member_of=, #members, #members=, #naics, #naics=, #nonprofit_status, #nonprofit_status=, #number_of_employees, #number_of_employees=, #owns, #owns=, #parent_organization, #parent_organization=, #publishing_principles, #publishing_principles=, #review, #review=, #reviews, #reviews=, #seeks, #seeks=, #service_area, #service_area=, #skills, #skills=, #slogan, #slogan=, #sponsor, #sponsor=, #sub_organization, #sub_organization=, #tax_id, #tax_id=, #telephone, #telephone=, #vat_id, #vat_id=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/schema_org/mixins/news_media_organization.rb', line 11

def self.schema_property_definitions
  {
    actionable_feedback_policy: {
      schema_name: "actionableFeedbackPolicy",
      schema_url: "https://schema.org/actionableFeedbackPolicy",
      comment_lines: ["For a [[NewsMediaOrganization]] or other news-related [[Organization]], a statement about public engagement activities (for news media, the newsroom’s), including involving the public - digitally or otherwise -- in coverage decisions, reporting and activities after publication."].freeze,
      ranges: ["CreativeWork", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    corrections_policy: {
      schema_name: "correctionsPolicy",
      schema_url: "https://schema.org/correctionsPolicy",
      comment_lines: ["For an [[Organization]] (e.g. [[NewsMediaOrganization]]), a statement describing (in news media, the newsroom’s) disclosure and correction policy for errors."].freeze,
      ranges: ["CreativeWork", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    diversity_policy: {
      schema_name: "diversityPolicy",
      schema_url: "https://schema.org/diversityPolicy",
      comment_lines: ["Statement on diversity policy by an [[Organization]] e.g. a [[NewsMediaOrganization]]. For a [[NewsMediaOrganization]], a statement describing the newsroom’s diversity policy on both staffing and sources, typically providing staffing data."].freeze,
      ranges: ["CreativeWork", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    diversity_staffing_report: {
      schema_name: "diversityStaffingReport",
      schema_url: "https://schema.org/diversityStaffingReport",
      comment_lines: ["For an [[Organization]] (often but not necessarily a [[NewsMediaOrganization]]), a report on staffing diversity issues. In a news context this might be for example ASNE or RTDNA (US) reports, or self-reported."].freeze,
      ranges: ["Article", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    ethics_policy: {
      schema_name: "ethicsPolicy",
      schema_url: "https://schema.org/ethicsPolicy",
      comment_lines: ["Statement about ethics policy, e.g. of a [[NewsMediaOrganization]] regarding journalistic and publishing practices, or of a [[Restaurant]], a page describing food source policies. In the case of a [[NewsMediaOrganization]], an ethicsPolicy is typically a statement describing the personal, organizational, and corporate standards of behavior expected by the organization."].freeze,
      ranges: ["CreativeWork", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    masthead: {
      schema_name: "masthead",
      schema_url: "https://schema.org/masthead",
      comment_lines: ["For a [[NewsMediaOrganization]], a link to the masthead page or a page listing top editorial management."].freeze,
      ranges: ["CreativeWork", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    mission_coverage_priorities_policy: {
      schema_name: "missionCoveragePrioritiesPolicy",
      schema_url: "https://schema.org/missionCoveragePrioritiesPolicy",
      comment_lines: ["For a [[NewsMediaOrganization]], a statement on coverage priorities, including any public agenda or stance on issues."].freeze,
      ranges: ["CreativeWork", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    no_bylines_policy: {
      schema_name: "noBylinesPolicy",
      schema_url: "https://schema.org/noBylinesPolicy",
      comment_lines: ["For a [[NewsMediaOrganization]] or other news-related [[Organization]], a statement explaining when authors of articles are not named in bylines."].freeze,
      ranges: ["CreativeWork", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    ownership_funding_info: {
      schema_name: "ownershipFundingInfo",
      schema_url: "https://schema.org/ownershipFundingInfo",
      comment_lines: ["For an [[Organization]] (often but not necessarily a [[NewsMediaOrganization]]), a description of organizational ownership structure; funding and grants. In a news/media setting, this is with particular reference to editorial independence.   Note that the [[funder]] is also available and can be used to make basic funder information machine-readable."].freeze,
      ranges: ["AboutPage", "CreativeWork", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    unnamed_sources_policy: {
      schema_name: "unnamedSourcesPolicy",
      schema_url: "https://schema.org/unnamedSourcesPolicy",
      comment_lines: ["For an [[Organization]] (typically a [[NewsMediaOrganization]]), a statement about policy on use of unnamed sources and the decision process required."].freeze,
      ranges: ["CreativeWork", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    verification_fact_checking_policy: {
      schema_name: "verificationFactCheckingPolicy",
      schema_url: "https://schema.org/verificationFactCheckingPolicy",
      comment_lines: ["Disclosure about verification and fact-checking processes for a [[NewsMediaOrganization]] or other fact-checking [[Organization]]."].freeze,
      ranges: ["CreativeWork", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#actionable_feedback_policyObject

For a [[NewsMediaOrganization]] or other news-related [[Organization]], a statement about public engagement activities (for news media, the newsroom’s), including involving the public - digitally or otherwise -- in coverage decisions, reporting and activities after publication.



127
128
129
# File 'lib/schema_org/mixins/news_media_organization.rb', line 127

def actionable_feedback_policy
  read_property(:actionable_feedback_policy)
end

#actionable_feedback_policy=(value) ⇒ Object

For a [[NewsMediaOrganization]] or other news-related [[Organization]], a statement about public engagement activities (for news media, the newsroom’s), including involving the public - digitally or otherwise -- in coverage decisions, reporting and activities after publication.



132
133
134
# File 'lib/schema_org/mixins/news_media_organization.rb', line 132

def actionable_feedback_policy=(value)
  write_property(:actionable_feedback_policy, value)
end

#corrections_policyObject

For an [[Organization]] (e.g. [[NewsMediaOrganization]]), a statement describing (in news media, the newsroom’s) disclosure and correction policy for errors.



137
138
139
# File 'lib/schema_org/mixins/news_media_organization.rb', line 137

def corrections_policy
  read_property(:corrections_policy)
end

#corrections_policy=(value) ⇒ Object

For an [[Organization]] (e.g. [[NewsMediaOrganization]]), a statement describing (in news media, the newsroom’s) disclosure and correction policy for errors.



142
143
144
# File 'lib/schema_org/mixins/news_media_organization.rb', line 142

def corrections_policy=(value)
  write_property(:corrections_policy, value)
end

#diversity_policyObject

Statement on diversity policy by an [[Organization]] e.g. a [[NewsMediaOrganization]]. For a [[NewsMediaOrganization]], a statement describing the newsroom’s diversity policy on both staffing and sources, typically providing staffing data.



147
148
149
# File 'lib/schema_org/mixins/news_media_organization.rb', line 147

def diversity_policy
  read_property(:diversity_policy)
end

#diversity_policy=(value) ⇒ Object

Statement on diversity policy by an [[Organization]] e.g. a [[NewsMediaOrganization]]. For a [[NewsMediaOrganization]], a statement describing the newsroom’s diversity policy on both staffing and sources, typically providing staffing data.



152
153
154
# File 'lib/schema_org/mixins/news_media_organization.rb', line 152

def diversity_policy=(value)
  write_property(:diversity_policy, value)
end

#diversity_staffing_reportObject

For an [[Organization]] (often but not necessarily a [[NewsMediaOrganization]]), a report on staffing diversity issues. In a news context this might be for example ASNE or RTDNA (US) reports, or self-reported.



157
158
159
# File 'lib/schema_org/mixins/news_media_organization.rb', line 157

def diversity_staffing_report
  read_property(:diversity_staffing_report)
end

#diversity_staffing_report=(value) ⇒ Object

For an [[Organization]] (often but not necessarily a [[NewsMediaOrganization]]), a report on staffing diversity issues. In a news context this might be for example ASNE or RTDNA (US) reports, or self-reported.



162
163
164
# File 'lib/schema_org/mixins/news_media_organization.rb', line 162

def diversity_staffing_report=(value)
  write_property(:diversity_staffing_report, value)
end

#ethics_policyObject

Statement about ethics policy, e.g. of a [[NewsMediaOrganization]] regarding journalistic and publishing practices, or of a [[Restaurant]], a page describing food source policies. In the case of a [[NewsMediaOrganization]], an ethicsPolicy is typically a statement describing the personal, organizational, and corporate standards of behavior expected by the organization.



167
168
169
# File 'lib/schema_org/mixins/news_media_organization.rb', line 167

def ethics_policy
  read_property(:ethics_policy)
end

#ethics_policy=(value) ⇒ Object

Statement about ethics policy, e.g. of a [[NewsMediaOrganization]] regarding journalistic and publishing practices, or of a [[Restaurant]], a page describing food source policies. In the case of a [[NewsMediaOrganization]], an ethicsPolicy is typically a statement describing the personal, organizational, and corporate standards of behavior expected by the organization.



172
173
174
# File 'lib/schema_org/mixins/news_media_organization.rb', line 172

def ethics_policy=(value)
  write_property(:ethics_policy, value)
end

#mastheadObject

For a [[NewsMediaOrganization]], a link to the masthead page or a page listing top editorial management.



177
178
179
# File 'lib/schema_org/mixins/news_media_organization.rb', line 177

def masthead
  read_property(:masthead)
end

#masthead=(value) ⇒ Object

For a [[NewsMediaOrganization]], a link to the masthead page or a page listing top editorial management.



182
183
184
# File 'lib/schema_org/mixins/news_media_organization.rb', line 182

def masthead=(value)
  write_property(:masthead, value)
end

#mission_coverage_priorities_policyObject

For a [[NewsMediaOrganization]], a statement on coverage priorities, including any public agenda or stance on issues.



187
188
189
# File 'lib/schema_org/mixins/news_media_organization.rb', line 187

def mission_coverage_priorities_policy
  read_property(:mission_coverage_priorities_policy)
end

#mission_coverage_priorities_policy=(value) ⇒ Object

For a [[NewsMediaOrganization]], a statement on coverage priorities, including any public agenda or stance on issues.



192
193
194
# File 'lib/schema_org/mixins/news_media_organization.rb', line 192

def mission_coverage_priorities_policy=(value)
  write_property(:mission_coverage_priorities_policy, value)
end

#no_bylines_policyObject

For a [[NewsMediaOrganization]] or other news-related [[Organization]], a statement explaining when authors of articles are not named in bylines.



197
198
199
# File 'lib/schema_org/mixins/news_media_organization.rb', line 197

def 
  read_property(:no_bylines_policy)
end

#no_bylines_policy=(value) ⇒ Object

For a [[NewsMediaOrganization]] or other news-related [[Organization]], a statement explaining when authors of articles are not named in bylines.



202
203
204
# File 'lib/schema_org/mixins/news_media_organization.rb', line 202

def (value)
  write_property(:no_bylines_policy, value)
end

#ownership_funding_infoObject

For an [[Organization]] (often but not necessarily a [[NewsMediaOrganization]]), a description of organizational ownership structure; funding and grants. In a news/media setting, this is with particular reference to editorial independence. Note that the [[funder]] is also available and can be used to make basic funder information machine-readable.



207
208
209
# File 'lib/schema_org/mixins/news_media_organization.rb', line 207

def ownership_funding_info
  read_property(:ownership_funding_info)
end

#ownership_funding_info=(value) ⇒ Object

For an [[Organization]] (often but not necessarily a [[NewsMediaOrganization]]), a description of organizational ownership structure; funding and grants. In a news/media setting, this is with particular reference to editorial independence. Note that the [[funder]] is also available and can be used to make basic funder information machine-readable.



212
213
214
# File 'lib/schema_org/mixins/news_media_organization.rb', line 212

def ownership_funding_info=(value)
  write_property(:ownership_funding_info, value)
end

#unnamed_sources_policyObject

For an [[Organization]] (typically a [[NewsMediaOrganization]]), a statement about policy on use of unnamed sources and the decision process required.



217
218
219
# File 'lib/schema_org/mixins/news_media_organization.rb', line 217

def unnamed_sources_policy
  read_property(:unnamed_sources_policy)
end

#unnamed_sources_policy=(value) ⇒ Object

For an [[Organization]] (typically a [[NewsMediaOrganization]]), a statement about policy on use of unnamed sources and the decision process required.



222
223
224
# File 'lib/schema_org/mixins/news_media_organization.rb', line 222

def unnamed_sources_policy=(value)
  write_property(:unnamed_sources_policy, value)
end

#verification_fact_checking_policyObject

Disclosure about verification and fact-checking processes for a [[NewsMediaOrganization]] or other fact-checking [[Organization]].



227
228
229
# File 'lib/schema_org/mixins/news_media_organization.rb', line 227

def verification_fact_checking_policy
  read_property(:verification_fact_checking_policy)
end

#verification_fact_checking_policy=(value) ⇒ Object

Disclosure about verification and fact-checking processes for a [[NewsMediaOrganization]] or other fact-checking [[Organization]].



232
233
234
# File 'lib/schema_org/mixins/news_media_organization.rb', line 232

def verification_fact_checking_policy=(value)
  write_property(:verification_fact_checking_policy, value)
end