Module: SchemaOrg::Mixins::Observation

Includes:
Intangible, QuantitativeValue
Included in:
Observation
Defined in:
lib/schema_org/mixins/observation.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from QuantitativeValue

#additional_property, #additional_property=, #max_value, #max_value=, #min_value, #min_value=, #unit_code, #unit_code=, #unit_text, #unit_text=, #value, #value=, #value_reference, #value_reference=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/schema_org/mixins/observation.rb', line 12

def self.schema_property_definitions
  {
    margin_of_error: {
      schema_name: "marginOfError",
      schema_url: "https://schema.org/marginOfError",
      comment_lines: ["A [[marginOfError]] for an [[Observation]]."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    measured_property: {
      schema_name: "measuredProperty",
      schema_url: "https://schema.org/measuredProperty",
      comment_lines: ["The measuredProperty of an [[Observation]], typically via its [[StatisticalVariable]]. There are various kinds of applicable [[Property]]: a schema.org property, a property from other RDF-compatible systems, e.g. W3C RDF Data Cube, Data Commons, Wikidata, or schema.org extensions such as [GS1's](https://www.gs1.org/voc/?show=properties)."].freeze,
      ranges: [].freeze,
      external_ranges: ["Property"].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    measurement_denominator: {
      schema_name: "measurementDenominator",
      schema_url: "https://schema.org/measurementDenominator",
      comment_lines: ["Identifies the denominator variable when an observation represents a ratio or percentage."].freeze,
      ranges: ["StatisticalVariable"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    measurement_method: {
      schema_name: "measurementMethod",
      schema_url: "https://schema.org/measurementMethod",
      comment_lines: ["A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]]."].freeze,
      ranges: ["DefinedTerm", "MeasurementMethodEnum", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    measurement_qualifier: {
      schema_name: "measurementQualifier",
      schema_url: "https://schema.org/measurementQualifier",
      comment_lines: ["Provides additional qualification to an observation. For example, a GDP observation measures the Nominal value."].freeze,
      ranges: ["Enumeration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    measurement_technique: {
      schema_name: "measurementTechnique",
      schema_url: "https://schema.org/measurementTechnique",
      comment_lines: ["A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]). Often but not necessarily each [[variableMeasured]] will have an explicit representation as (or mapping to) an property such as those defined in Schema.org, or other RDF vocabularies and \"knowledge graphs\". In that case the subproperty of [[variableMeasured]] called [[measuredProperty]] is applicable.", "", "The [[measurementTechnique]] property helps when extra clarification is needed about how a [[measuredProperty]] was measured. This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but can often serve as a high level summary for dataset discovery.", "", "For example, if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]] could be: \"mass spectrometry\" or \"nmr spectroscopy\" or \"colorimetry\" or \"immunofluorescence\". If the [[variableMeasured]] is \"depression rating\", the [[measurementTechnique]] could be \"Zung Scale\" or \"HAM-D\" or \"Beck Depression Inventory\".", "", "If there are several [[variableMeasured]] properties recorded for some given data object, use a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]]. The value can also be from an enumeration, organized as a [[MeasurementMethodEnum]]."].freeze,
      ranges: ["DefinedTerm", "MeasurementMethodEnum", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    observation_about: {
      schema_name: "observationAbout",
      schema_url: "https://schema.org/observationAbout",
      comment_lines: ["The [[observationAbout]] property identifies an entity, often a [[Place]], associated with an [[Observation]]."].freeze,
      ranges: ["Place", "Thing"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    observation_date: {
      schema_name: "observationDate",
      schema_url: "https://schema.org/observationDate",
      comment_lines: ["The observationDate of an [[Observation]]."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    observation_period: {
      schema_name: "observationPeriod",
      schema_url: "https://schema.org/observationPeriod",
      comment_lines: ["The length of time an Observation took place over. The format follows `P[0-9]*[Y|M|D|h|m|s]`. For example, P1Y is Period 1 Year, P3M is Period 3 Months, P3h is Period 3 hours."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    variable_measured: {
      schema_name: "variableMeasured",
      schema_url: "https://schema.org/variableMeasured",
      comment_lines: ["The variableMeasured property can indicate (repeated as necessary) the  variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue, or more explicitly as a [[StatisticalVariable]]."].freeze,
      ranges: ["PropertyValue", "StatisticalVariable", "Text"].freeze,
      external_ranges: ["Property"].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#margin_of_errorObject

A [[marginOfError]] for an [[Observation]].



118
119
120
# File 'lib/schema_org/mixins/observation.rb', line 118

def margin_of_error
  read_property(:margin_of_error)
end

#margin_of_error=(value) ⇒ Object

A [[marginOfError]] for an [[Observation]].



123
124
125
# File 'lib/schema_org/mixins/observation.rb', line 123

def margin_of_error=(value)
  write_property(:margin_of_error, value)
end

#measured_propertyObject

The measuredProperty of an [[Observation]], typically via its [[StatisticalVariable]]. There are various kinds of applicable [[Property]]: a schema.org property, a property from other RDF-compatible systems, e.g. W3C RDF Data Cube, Data Commons, Wikidata, or schema.org extensions such as GS1's.



128
129
130
# File 'lib/schema_org/mixins/observation.rb', line 128

def measured_property
  read_property(:measured_property)
end

#measured_property=(value) ⇒ Object

The measuredProperty of an [[Observation]], typically via its [[StatisticalVariable]]. There are various kinds of applicable [[Property]]: a schema.org property, a property from other RDF-compatible systems, e.g. W3C RDF Data Cube, Data Commons, Wikidata, or schema.org extensions such as GS1's.



133
134
135
# File 'lib/schema_org/mixins/observation.rb', line 133

def measured_property=(value)
  write_property(:measured_property, value)
end

#measurement_denominatorObject

Identifies the denominator variable when an observation represents a ratio or percentage.



138
139
140
# File 'lib/schema_org/mixins/observation.rb', line 138

def measurement_denominator
  read_property(:measurement_denominator)
end

#measurement_denominator=(value) ⇒ Object

Identifies the denominator variable when an observation represents a ratio or percentage.



143
144
145
# File 'lib/schema_org/mixins/observation.rb', line 143

def measurement_denominator=(value)
  write_property(:measurement_denominator, value)
end

#measurement_methodObject

A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].



148
149
150
# File 'lib/schema_org/mixins/observation.rb', line 148

def measurement_method
  read_property(:measurement_method)
end

#measurement_method=(value) ⇒ Object

A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].



153
154
155
# File 'lib/schema_org/mixins/observation.rb', line 153

def measurement_method=(value)
  write_property(:measurement_method, value)
end

#measurement_qualifierObject

Provides additional qualification to an observation. For example, a GDP observation measures the Nominal value.



158
159
160
# File 'lib/schema_org/mixins/observation.rb', line 158

def measurement_qualifier
  read_property(:measurement_qualifier)
end

#measurement_qualifier=(value) ⇒ Object

Provides additional qualification to an observation. For example, a GDP observation measures the Nominal value.



163
164
165
# File 'lib/schema_org/mixins/observation.rb', line 163

def measurement_qualifier=(value)
  write_property(:measurement_qualifier, value)
end

#measurement_techniqueObject

A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]). Often but not necessarily each [[variableMeasured]] will have an explicit representation as (or mapping to) an property such as those defined in Schema.org, or other RDF vocabularies and "knowledge graphs". In that case the subproperty of [[variableMeasured]] called [[measuredProperty]] is applicable.

The [[measurementTechnique]] property helps when extra clarification is needed about how a [[measuredProperty]] was measured. This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but can often serve as a high level summary for dataset discovery.

For example, if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]] could be: "mass spectrometry" or "nmr spectroscopy" or "colorimetry" or "immunofluorescence". If the [[variableMeasured]] is "depression rating", the [[measurementTechnique]] could be "Zung Scale" or "HAM-D" or "Beck Depression Inventory".

If there are several [[variableMeasured]] properties recorded for some given data object, use a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]]. The value can also be from an enumeration, organized as a [[MeasurementMethodEnum]].



174
175
176
# File 'lib/schema_org/mixins/observation.rb', line 174

def measurement_technique
  read_property(:measurement_technique)
end

#measurement_technique=(value) ⇒ Object

A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]). Often but not necessarily each [[variableMeasured]] will have an explicit representation as (or mapping to) an property such as those defined in Schema.org, or other RDF vocabularies and "knowledge graphs". In that case the subproperty of [[variableMeasured]] called [[measuredProperty]] is applicable.

The [[measurementTechnique]] property helps when extra clarification is needed about how a [[measuredProperty]] was measured. This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but can often serve as a high level summary for dataset discovery.

For example, if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]] could be: "mass spectrometry" or "nmr spectroscopy" or "colorimetry" or "immunofluorescence". If the [[variableMeasured]] is "depression rating", the [[measurementTechnique]] could be "Zung Scale" or "HAM-D" or "Beck Depression Inventory".

If there are several [[variableMeasured]] properties recorded for some given data object, use a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]]. The value can also be from an enumeration, organized as a [[MeasurementMethodEnum]].



185
186
187
# File 'lib/schema_org/mixins/observation.rb', line 185

def measurement_technique=(value)
  write_property(:measurement_technique, value)
end

#observation_aboutObject

The [[observationAbout]] property identifies an entity, often a [[Place]], associated with an [[Observation]].



190
191
192
# File 'lib/schema_org/mixins/observation.rb', line 190

def observation_about
  read_property(:observation_about)
end

#observation_about=(value) ⇒ Object

The [[observationAbout]] property identifies an entity, often a [[Place]], associated with an [[Observation]].



195
196
197
# File 'lib/schema_org/mixins/observation.rb', line 195

def observation_about=(value)
  write_property(:observation_about, value)
end

#observation_dateObject

The observationDate of an [[Observation]].



200
201
202
# File 'lib/schema_org/mixins/observation.rb', line 200

def observation_date
  read_property(:observation_date)
end

#observation_date=(value) ⇒ Object

The observationDate of an [[Observation]].



205
206
207
# File 'lib/schema_org/mixins/observation.rb', line 205

def observation_date=(value)
  write_property(:observation_date, value)
end

#observation_periodObject

The length of time an Observation took place over. The format follows P[0-9]*[Y|M|D|h|m|s]. For example, P1Y is Period 1 Year, P3M is Period 3 Months, P3h is Period 3 hours.



210
211
212
# File 'lib/schema_org/mixins/observation.rb', line 210

def observation_period
  read_property(:observation_period)
end

#observation_period=(value) ⇒ Object

The length of time an Observation took place over. The format follows P[0-9]*[Y|M|D|h|m|s]. For example, P1Y is Period 1 Year, P3M is Period 3 Months, P3h is Period 3 hours.



215
216
217
# File 'lib/schema_org/mixins/observation.rb', line 215

def observation_period=(value)
  write_property(:observation_period, value)
end

#variable_measuredObject

The variableMeasured property can indicate (repeated as necessary) the variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue, or more explicitly as a [[StatisticalVariable]].



220
221
222
# File 'lib/schema_org/mixins/observation.rb', line 220

def variable_measured
  read_property(:variable_measured)
end

#variable_measured=(value) ⇒ Object

The variableMeasured property can indicate (repeated as necessary) the variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue, or more explicitly as a [[StatisticalVariable]].



225
226
227
# File 'lib/schema_org/mixins/observation.rb', line 225

def variable_measured=(value)
  write_property(:variable_measured, value)
end