Module: SchemaOrg::Mixins::Occupation

Includes:
Intangible
Included in:
Occupation
Defined in:
lib/schema_org/mixins/occupation.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/schema_org/mixins/occupation.rb', line 11

def self.schema_property_definitions
  {
    education_requirements: {
      schema_name: "educationRequirements",
      schema_url: "https://schema.org/educationRequirements",
      comment_lines: ["Educational background needed for the position or Occupation."].freeze,
      ranges: ["EducationalOccupationalCredential", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    estimated_salary: {
      schema_name: "estimatedSalary",
      schema_url: "https://schema.org/estimatedSalary",
      comment_lines: ["An estimated salary for a job posting or occupation, based on a variety of variables including, but not limited to industry, job title, and location. Estimated salaries  are often computed by outside organizations rather than the hiring organization, who may not have committed to the estimated value."].freeze,
      ranges: ["MonetaryAmount", "MonetaryAmountDistribution", "Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    experience_requirements: {
      schema_name: "experienceRequirements",
      schema_url: "https://schema.org/experienceRequirements",
      comment_lines: ["Description of skills and experience needed for the position or Occupation."].freeze,
      ranges: ["OccupationalExperienceRequirements", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    occupation_location: {
      schema_name: "occupationLocation",
      schema_url: "https://schema.org/occupationLocation",
      comment_lines: ["The region/country for which this occupational description is appropriate. Note that educational requirements and qualifications can vary between jurisdictions."].freeze,
      ranges: ["AdministrativeArea"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    occupational_category: {
      schema_name: "occupationalCategory",
      schema_url: "https://schema.org/occupationalCategory",
      comment_lines: ["A category describing the job, preferably using a term from a taxonomy such as [BLS O*NET-SOC](http://www.onetcenter.org/taxonomy.html), [ISCO-08](https://www.ilo.org/public/english/bureau/stat/isco/isco08/) or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided.\\n", "Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC."].freeze,
      ranges: ["CategoryCode", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    qualifications: {
      schema_name: "qualifications",
      schema_url: "https://schema.org/qualifications",
      comment_lines: ["Specific qualifications required for this role or Occupation."].freeze,
      ranges: ["Credential", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    responsibilities: {
      schema_name: "responsibilities",
      schema_url: "https://schema.org/responsibilities",
      comment_lines: ["Responsibilities associated with this role or Occupation."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    skills: {
      schema_name: "skills",
      schema_url: "https://schema.org/skills",
      comment_lines: ["A statement of knowledge, skill, ability, task or any other assertion expressing a competency that is either claimed by a person, an organization or desired or required to fulfill a role or to work in an occupation."].freeze,
      ranges: ["DefinedTerm", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#education_requirementsObject

Educational background needed for the position or Occupation.



97
98
99
# File 'lib/schema_org/mixins/occupation.rb', line 97

def education_requirements
  read_property(:education_requirements)
end

#education_requirements=(value) ⇒ Object

Educational background needed for the position or Occupation.



102
103
104
# File 'lib/schema_org/mixins/occupation.rb', line 102

def education_requirements=(value)
  write_property(:education_requirements, value)
end

#estimated_salaryObject

An estimated salary for a job posting or occupation, based on a variety of variables including, but not limited to industry, job title, and location. Estimated salaries are often computed by outside organizations rather than the hiring organization, who may not have committed to the estimated value.



107
108
109
# File 'lib/schema_org/mixins/occupation.rb', line 107

def estimated_salary
  read_property(:estimated_salary)
end

#estimated_salary=(value) ⇒ Object

An estimated salary for a job posting or occupation, based on a variety of variables including, but not limited to industry, job title, and location. Estimated salaries are often computed by outside organizations rather than the hiring organization, who may not have committed to the estimated value.



112
113
114
# File 'lib/schema_org/mixins/occupation.rb', line 112

def estimated_salary=(value)
  write_property(:estimated_salary, value)
end

#experience_requirementsObject

Description of skills and experience needed for the position or Occupation.



117
118
119
# File 'lib/schema_org/mixins/occupation.rb', line 117

def experience_requirements
  read_property(:experience_requirements)
end

#experience_requirements=(value) ⇒ Object

Description of skills and experience needed for the position or Occupation.



122
123
124
# File 'lib/schema_org/mixins/occupation.rb', line 122

def experience_requirements=(value)
  write_property(:experience_requirements, value)
end

#occupation_locationObject

The region/country for which this occupational description is appropriate. Note that educational requirements and qualifications can vary between jurisdictions.



127
128
129
# File 'lib/schema_org/mixins/occupation.rb', line 127

def occupation_location
  read_property(:occupation_location)
end

#occupation_location=(value) ⇒ Object

The region/country for which this occupational description is appropriate. Note that educational requirements and qualifications can vary between jurisdictions.



132
133
134
# File 'lib/schema_org/mixins/occupation.rb', line 132

def occupation_location=(value)
  write_property(:occupation_location, value)
end

#occupational_categoryObject

A category describing the job, preferably using a term from a taxonomy such as BLS O*NET-SOC, ISCO-08 or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided.\n Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC.



138
139
140
# File 'lib/schema_org/mixins/occupation.rb', line 138

def occupational_category
  read_property(:occupational_category)
end

#occupational_category=(value) ⇒ Object

A category describing the job, preferably using a term from a taxonomy such as BLS O*NET-SOC, ISCO-08 or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided.\n Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC.



144
145
146
# File 'lib/schema_org/mixins/occupation.rb', line 144

def occupational_category=(value)
  write_property(:occupational_category, value)
end

#qualificationsObject

Specific qualifications required for this role or Occupation.



149
150
151
# File 'lib/schema_org/mixins/occupation.rb', line 149

def qualifications
  read_property(:qualifications)
end

#qualifications=(value) ⇒ Object

Specific qualifications required for this role or Occupation.



154
155
156
# File 'lib/schema_org/mixins/occupation.rb', line 154

def qualifications=(value)
  write_property(:qualifications, value)
end

#responsibilitiesObject

Responsibilities associated with this role or Occupation.



159
160
161
# File 'lib/schema_org/mixins/occupation.rb', line 159

def responsibilities
  read_property(:responsibilities)
end

#responsibilities=(value) ⇒ Object

Responsibilities associated with this role or Occupation.



164
165
166
# File 'lib/schema_org/mixins/occupation.rb', line 164

def responsibilities=(value)
  write_property(:responsibilities, value)
end

#skillsObject

A statement of knowledge, skill, ability, task or any other assertion expressing a competency that is either claimed by a person, an organization or desired or required to fulfill a role or to work in an occupation.



169
170
171
# File 'lib/schema_org/mixins/occupation.rb', line 169

def skills
  read_property(:skills)
end

#skills=(value) ⇒ Object

A statement of knowledge, skill, ability, task or any other assertion expressing a competency that is either claimed by a person, an organization or desired or required to fulfill a role or to work in an occupation.



174
175
176
# File 'lib/schema_org/mixins/occupation.rb', line 174

def skills=(value)
  write_property(:skills, value)
end