Module: SchemaOrg::Mixins::OpeningHoursSpecification

Includes:
StructuredValue
Included in:
OpeningHoursSpecification
Defined in:
lib/schema_org/mixins/opening_hours_specification.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/schema_org/mixins/opening_hours_specification.rb', line 11

def self.schema_property_definitions
  {
    closes: {
      schema_name: "closes",
      schema_url: "https://schema.org/closes",
      comment_lines: ["The closing hour of the place or service on the given day(s) of the week."].freeze,
      ranges: ["Time"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    day_of_week: {
      schema_name: "dayOfWeek",
      schema_url: "https://schema.org/dayOfWeek",
      comment_lines: ["The day of the week for which these opening hours are valid."].freeze,
      ranges: ["DayOfWeek"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    opens: {
      schema_name: "opens",
      schema_url: "https://schema.org/opens",
      comment_lines: ["The opening hour of the place or service on the given day(s) of the week."].freeze,
      ranges: ["Time"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    valid_from: {
      schema_name: "validFrom",
      schema_url: "https://schema.org/validFrom",
      comment_lines: ["The date when the item becomes valid."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    valid_through: {
      schema_name: "validThrough",
      schema_url: "https://schema.org/validThrough",
      comment_lines: ["The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#closesObject

The closing hour of the place or service on the given day(s) of the week.



67
68
69
# File 'lib/schema_org/mixins/opening_hours_specification.rb', line 67

def closes
  read_property(:closes)
end

#closes=(value) ⇒ Object

The closing hour of the place or service on the given day(s) of the week.



72
73
74
# File 'lib/schema_org/mixins/opening_hours_specification.rb', line 72

def closes=(value)
  write_property(:closes, value)
end

#day_of_weekObject

The day of the week for which these opening hours are valid.



77
78
79
# File 'lib/schema_org/mixins/opening_hours_specification.rb', line 77

def day_of_week
  read_property(:day_of_week)
end

#day_of_week=(value) ⇒ Object

The day of the week for which these opening hours are valid.



82
83
84
# File 'lib/schema_org/mixins/opening_hours_specification.rb', line 82

def day_of_week=(value)
  write_property(:day_of_week, value)
end

#opensObject

The opening hour of the place or service on the given day(s) of the week.



87
88
89
# File 'lib/schema_org/mixins/opening_hours_specification.rb', line 87

def opens
  read_property(:opens)
end

#opens=(value) ⇒ Object

The opening hour of the place or service on the given day(s) of the week.



92
93
94
# File 'lib/schema_org/mixins/opening_hours_specification.rb', line 92

def opens=(value)
  write_property(:opens, value)
end

#valid_fromObject

The date when the item becomes valid.



97
98
99
# File 'lib/schema_org/mixins/opening_hours_specification.rb', line 97

def valid_from
  read_property(:valid_from)
end

#valid_from=(value) ⇒ Object

The date when the item becomes valid.



102
103
104
# File 'lib/schema_org/mixins/opening_hours_specification.rb', line 102

def valid_from=(value)
  write_property(:valid_from, value)
end

#valid_throughObject

The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.



107
108
109
# File 'lib/schema_org/mixins/opening_hours_specification.rb', line 107

def valid_through
  read_property(:valid_through)
end

#valid_through=(value) ⇒ Object

The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.



112
113
114
# File 'lib/schema_org/mixins/opening_hours_specification.rb', line 112

def valid_through=(value)
  write_property(:valid_through, value)
end