Module: SchemaOrg::Mixins::Order

Includes:
Intangible
Included in:
Order
Defined in:
lib/schema_org/mixins/order.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/schema_org/mixins/order.rb', line 11

def self.schema_property_definitions
  {
    accepted_offer: {
      schema_name: "acceptedOffer",
      schema_url: "https://schema.org/acceptedOffer",
      comment_lines: ["The offer(s) -- e.g., product, quantity and price combinations -- included in the order."].freeze,
      ranges: ["Offer"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    billing_address: {
      schema_name: "billingAddress",
      schema_url: "https://schema.org/billingAddress",
      comment_lines: ["The billing address for the order."].freeze,
      ranges: ["PostalAddress"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    broker: {
      schema_name: "broker",
      schema_url: "https://schema.org/broker",
      comment_lines: ["An entity that arranges for an exchange between a buyer and a seller.  In most cases a broker never acquires or releases ownership of a product or service involved in an exchange.  If it is not clear whether an entity is a broker, seller, or buyer, the latter two terms are preferred."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["bookingAgent"].freeze
    }.freeze,
    confirmation_number: {
      schema_name: "confirmationNumber",
      schema_url: "https://schema.org/confirmationNumber",
      comment_lines: ["A number that confirms the given order or payment has been received."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    customer: {
      schema_name: "customer",
      schema_url: "https://schema.org/customer",
      comment_lines: ["Party placing the order or paying the invoice."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    discount: {
      schema_name: "discount",
      schema_url: "https://schema.org/discount",
      comment_lines: ["Any discount applied (to an Order)."].freeze,
      ranges: ["Number", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    discount_code: {
      schema_name: "discountCode",
      schema_url: "https://schema.org/discountCode",
      comment_lines: ["Code used to redeem a discount."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    discount_currency: {
      schema_name: "discountCurrency",
      schema_url: "https://schema.org/discountCurrency",
      comment_lines: ["The currency of the discount.\\n\\nUse standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. \"USD\"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. \"BTC\"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. \"Ithaca HOUR\"."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    is_gift: {
      schema_name: "isGift",
      schema_url: "https://schema.org/isGift",
      comment_lines: ["Indicates whether the offer was accepted as a gift for someone other than the buyer."].freeze,
      ranges: ["Boolean"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    merchant: {
      schema_name: "merchant",
      schema_url: "https://schema.org/merchant",
      comment_lines: ["'merchant' is an out-dated term for 'seller'."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "seller",
      supersedes: nil
    }.freeze,
    order_date: {
      schema_name: "orderDate",
      schema_url: "https://schema.org/orderDate",
      comment_lines: ["Date order was placed."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    order_delivery: {
      schema_name: "orderDelivery",
      schema_url: "https://schema.org/orderDelivery",
      comment_lines: ["The delivery of the parcel related to this order or order item."].freeze,
      ranges: ["ParcelDelivery"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    order_number: {
      schema_name: "orderNumber",
      schema_url: "https://schema.org/orderNumber",
      comment_lines: ["The identifier of the transaction."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    order_status: {
      schema_name: "orderStatus",
      schema_url: "https://schema.org/orderStatus",
      comment_lines: ["The current status of the order."].freeze,
      ranges: ["OrderStatus"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    ordered_item: {
      schema_name: "orderedItem",
      schema_url: "https://schema.org/orderedItem",
      comment_lines: ["The item ordered."].freeze,
      ranges: ["OrderItem", "Product", "Service"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    part_of_invoice: {
      schema_name: "partOfInvoice",
      schema_url: "https://schema.org/partOfInvoice",
      comment_lines: ["The order is being paid as part of the referenced Invoice."].freeze,
      ranges: ["Invoice"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    payment_due: {
      schema_name: "paymentDue",
      schema_url: "https://schema.org/paymentDue",
      comment_lines: ["The date that payment is due."].freeze,
      ranges: ["DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "paymentDueDate",
      supersedes: nil
    }.freeze,
    payment_due_date: {
      schema_name: "paymentDueDate",
      schema_url: "https://schema.org/paymentDueDate",
      comment_lines: ["The date that payment is due."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["paymentDue"].freeze
    }.freeze,
    payment_method: {
      schema_name: "paymentMethod",
      schema_url: "https://schema.org/paymentMethod",
      comment_lines: ["The name of the credit card or other method of payment for the order."].freeze,
      ranges: ["PaymentMethod", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    payment_method_id: {
      schema_name: "paymentMethodId",
      schema_url: "https://schema.org/paymentMethodId",
      comment_lines: ["An identifier for the method of payment used (e.g. the last 4 digits of the credit card)."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    payment_url: {
      schema_name: "paymentUrl",
      schema_url: "https://schema.org/paymentUrl",
      comment_lines: ["The URL for sending a payment."].freeze,
      ranges: ["URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    seller: {
      schema_name: "seller",
      schema_url: "https://schema.org/seller",
      comment_lines: ["An entity which offers (sells / leases / lends / loans) the services / goods.  A seller may also be a provider."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["merchant", "vendor"].freeze
    }.freeze
  }.freeze
end

Instance Method Details

#accepted_offerObject

The offer(s) -- e.g., product, quantity and price combinations -- included in the order.



237
238
239
# File 'lib/schema_org/mixins/order.rb', line 237

def accepted_offer
  read_property(:accepted_offer)
end

#accepted_offer=(value) ⇒ Object

The offer(s) -- e.g., product, quantity and price combinations -- included in the order.



242
243
244
# File 'lib/schema_org/mixins/order.rb', line 242

def accepted_offer=(value)
  write_property(:accepted_offer, value)
end

#billing_addressObject

The billing address for the order.



247
248
249
# File 'lib/schema_org/mixins/order.rb', line 247

def billing_address
  read_property(:billing_address)
end

#billing_address=(value) ⇒ Object

The billing address for the order.



252
253
254
# File 'lib/schema_org/mixins/order.rb', line 252

def billing_address=(value)
  write_property(:billing_address, value)
end

#brokerObject

An entity that arranges for an exchange between a buyer and a seller. In most cases a broker never acquires or releases ownership of a product or service involved in an exchange. If it is not clear whether an entity is a broker, seller, or buyer, the latter two terms are preferred. Supersedes bookingAgent.



258
259
260
# File 'lib/schema_org/mixins/order.rb', line 258

def broker
  read_property(:broker)
end

#broker=(value) ⇒ Object

An entity that arranges for an exchange between a buyer and a seller. In most cases a broker never acquires or releases ownership of a product or service involved in an exchange. If it is not clear whether an entity is a broker, seller, or buyer, the latter two terms are preferred. Supersedes bookingAgent.



264
265
266
# File 'lib/schema_org/mixins/order.rb', line 264

def broker=(value)
  write_property(:broker, value)
end

#confirmation_numberObject

A number that confirms the given order or payment has been received.



269
270
271
# File 'lib/schema_org/mixins/order.rb', line 269

def confirmation_number
  read_property(:confirmation_number)
end

#confirmation_number=(value) ⇒ Object

A number that confirms the given order or payment has been received.



274
275
276
# File 'lib/schema_org/mixins/order.rb', line 274

def confirmation_number=(value)
  write_property(:confirmation_number, value)
end

#customerObject

Party placing the order or paying the invoice.



279
280
281
# File 'lib/schema_org/mixins/order.rb', line 279

def customer
  read_property(:customer)
end

#customer=(value) ⇒ Object

Party placing the order or paying the invoice.



284
285
286
# File 'lib/schema_org/mixins/order.rb', line 284

def customer=(value)
  write_property(:customer, value)
end

#discountObject

Any discount applied (to an Order).



289
290
291
# File 'lib/schema_org/mixins/order.rb', line 289

def discount
  read_property(:discount)
end

#discount=(value) ⇒ Object

Any discount applied (to an Order).



294
295
296
# File 'lib/schema_org/mixins/order.rb', line 294

def discount=(value)
  write_property(:discount, value)
end

#discount_codeObject

Code used to redeem a discount.



299
300
301
# File 'lib/schema_org/mixins/order.rb', line 299

def discount_code
  read_property(:discount_code)
end

#discount_code=(value) ⇒ Object

Code used to redeem a discount.



304
305
306
# File 'lib/schema_org/mixins/order.rb', line 304

def discount_code=(value)
  write_property(:discount_code, value)
end

#discount_currencyObject

The currency of the discount.\n\nUse standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR".



309
310
311
# File 'lib/schema_org/mixins/order.rb', line 309

def discount_currency
  read_property(:discount_currency)
end

#discount_currency=(value) ⇒ Object

The currency of the discount.\n\nUse standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR".



314
315
316
# File 'lib/schema_org/mixins/order.rb', line 314

def discount_currency=(value)
  write_property(:discount_currency, value)
end

#is_giftObject

Indicates whether the offer was accepted as a gift for someone other than the buyer.



319
320
321
# File 'lib/schema_org/mixins/order.rb', line 319

def is_gift
  read_property(:is_gift)
end

#is_gift=(value) ⇒ Object

Indicates whether the offer was accepted as a gift for someone other than the buyer.



324
325
326
# File 'lib/schema_org/mixins/order.rb', line 324

def is_gift=(value)
  write_property(:is_gift, value)
end

#merchantObject

'merchant' is an out-dated term for 'seller'. Superseded by seller.



330
331
332
# File 'lib/schema_org/mixins/order.rb', line 330

def merchant
  read_property(:merchant)
end

#merchant=(value) ⇒ Object

'merchant' is an out-dated term for 'seller'. Superseded by seller.



336
337
338
# File 'lib/schema_org/mixins/order.rb', line 336

def merchant=(value)
  write_property(:merchant, value)
end

#order_dateObject

Date order was placed.



341
342
343
# File 'lib/schema_org/mixins/order.rb', line 341

def order_date
  read_property(:order_date)
end

#order_date=(value) ⇒ Object

Date order was placed.



346
347
348
# File 'lib/schema_org/mixins/order.rb', line 346

def order_date=(value)
  write_property(:order_date, value)
end

#order_deliveryObject

The delivery of the parcel related to this order or order item.



351
352
353
# File 'lib/schema_org/mixins/order.rb', line 351

def order_delivery
  read_property(:order_delivery)
end

#order_delivery=(value) ⇒ Object

The delivery of the parcel related to this order or order item.



356
357
358
# File 'lib/schema_org/mixins/order.rb', line 356

def order_delivery=(value)
  write_property(:order_delivery, value)
end

#order_numberObject

The identifier of the transaction.



361
362
363
# File 'lib/schema_org/mixins/order.rb', line 361

def order_number
  read_property(:order_number)
end

#order_number=(value) ⇒ Object

The identifier of the transaction.



366
367
368
# File 'lib/schema_org/mixins/order.rb', line 366

def order_number=(value)
  write_property(:order_number, value)
end

#order_statusObject

The current status of the order.



371
372
373
# File 'lib/schema_org/mixins/order.rb', line 371

def order_status
  read_property(:order_status)
end

#order_status=(value) ⇒ Object

The current status of the order.



376
377
378
# File 'lib/schema_org/mixins/order.rb', line 376

def order_status=(value)
  write_property(:order_status, value)
end

#ordered_itemObject

The item ordered.



381
382
383
# File 'lib/schema_org/mixins/order.rb', line 381

def ordered_item
  read_property(:ordered_item)
end

#ordered_item=(value) ⇒ Object

The item ordered.



386
387
388
# File 'lib/schema_org/mixins/order.rb', line 386

def ordered_item=(value)
  write_property(:ordered_item, value)
end

#part_of_invoiceObject

The order is being paid as part of the referenced Invoice.



391
392
393
# File 'lib/schema_org/mixins/order.rb', line 391

def part_of_invoice
  read_property(:part_of_invoice)
end

#part_of_invoice=(value) ⇒ Object

The order is being paid as part of the referenced Invoice.



396
397
398
# File 'lib/schema_org/mixins/order.rb', line 396

def part_of_invoice=(value)
  write_property(:part_of_invoice, value)
end

#payment_dueObject

The date that payment is due. Superseded by paymentDueDate.



402
403
404
# File 'lib/schema_org/mixins/order.rb', line 402

def payment_due
  read_property(:payment_due)
end

#payment_due=(value) ⇒ Object

The date that payment is due. Superseded by paymentDueDate.



408
409
410
# File 'lib/schema_org/mixins/order.rb', line 408

def payment_due=(value)
  write_property(:payment_due, value)
end

#payment_due_dateObject

The date that payment is due. Supersedes paymentDue.



414
415
416
# File 'lib/schema_org/mixins/order.rb', line 414

def payment_due_date
  read_property(:payment_due_date)
end

#payment_due_date=(value) ⇒ Object

The date that payment is due. Supersedes paymentDue.



420
421
422
# File 'lib/schema_org/mixins/order.rb', line 420

def payment_due_date=(value)
  write_property(:payment_due_date, value)
end

#payment_methodObject

The name of the credit card or other method of payment for the order.



425
426
427
# File 'lib/schema_org/mixins/order.rb', line 425

def payment_method
  read_property(:payment_method)
end

#payment_method=(value) ⇒ Object

The name of the credit card or other method of payment for the order.



430
431
432
# File 'lib/schema_org/mixins/order.rb', line 430

def payment_method=(value)
  write_property(:payment_method, value)
end

#payment_method_idObject

An identifier for the method of payment used (e.g. the last 4 digits of the credit card).



435
436
437
# File 'lib/schema_org/mixins/order.rb', line 435

def payment_method_id
  read_property(:payment_method_id)
end

#payment_method_id=(value) ⇒ Object

An identifier for the method of payment used (e.g. the last 4 digits of the credit card).



440
441
442
# File 'lib/schema_org/mixins/order.rb', line 440

def payment_method_id=(value)
  write_property(:payment_method_id, value)
end

#payment_urlObject

The URL for sending a payment.



445
446
447
# File 'lib/schema_org/mixins/order.rb', line 445

def payment_url
  read_property(:payment_url)
end

#payment_url=(value) ⇒ Object

The URL for sending a payment.



450
451
452
# File 'lib/schema_org/mixins/order.rb', line 450

def payment_url=(value)
  write_property(:payment_url, value)
end

#sellerObject

An entity which offers (sells / leases / lends / loans) the services / goods. A seller may also be a provider. Supersedes merchant. Supersedes vendor.



457
458
459
# File 'lib/schema_org/mixins/order.rb', line 457

def seller
  read_property(:seller)
end

#seller=(value) ⇒ Object

An entity which offers (sells / leases / lends / loans) the services / goods. A seller may also be a provider. Supersedes merchant. Supersedes vendor.



464
465
466
# File 'lib/schema_org/mixins/order.rb', line 464

def seller=(value)
  write_property(:seller, value)
end