Module: SchemaOrg::Mixins::PaymentCard

Includes:
FinancialProduct, PaymentMethod
Included in:
CreditCard, PaymentCard
Defined in:
lib/schema_org/mixins/payment_card.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from PaymentMethod

#payment_method_type, #payment_method_type=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Methods included from FinancialProduct

#annual_percentage_rate, #annual_percentage_rate=, #fees_and_commissions_specification, #fees_and_commissions_specification=, #interest_rate, #interest_rate=

Methods included from Service

#aggregate_rating, #aggregate_rating=, #area_served, #area_served=, #audience, #audience=, #available_channel, #available_channel=, #award, #award=, #brand, #brand=, #broker, #broker=, #category, #category=, #has_certification, #has_certification=, #has_offer_catalog, #has_offer_catalog=, #hours_available, #hours_available=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #logo, #logo=, #offers, #offers=, #produces, #produces=, #provider, #provider=, #provider_mobility, #provider_mobility=, #review, #review=, #service_area, #service_area=, #service_audience, #service_audience=, #service_output, #service_output=, #service_type, #service_type=, #slogan, #slogan=, #terms_of_service, #terms_of_service=

Class Method Details

.schema_property_definitionsObject



12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/schema_org/mixins/payment_card.rb', line 12

def self.schema_property_definitions
  {
    cash_back: {
      schema_name: "cashBack",
      schema_url: "https://schema.org/cashBack",
      comment_lines: ["A cardholder benefit that pays the cardholder a small percentage of their net expenditures."].freeze,
      ranges: ["Boolean", "Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    contactless_payment: {
      schema_name: "contactlessPayment",
      schema_url: "https://schema.org/contactlessPayment",
      comment_lines: ["A secure method for consumers to purchase products or services via debit, credit or smartcards by using RFID or NFC technology."].freeze,
      ranges: ["Boolean"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    floor_limit: {
      schema_name: "floorLimit",
      schema_url: "https://schema.org/floorLimit",
      comment_lines: ["A floor limit is the amount of money above which credit card transactions must be authorized."].freeze,
      ranges: ["MonetaryAmount"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    monthly_minimum_repayment_amount: {
      schema_name: "monthlyMinimumRepaymentAmount",
      schema_url: "https://schema.org/monthlyMinimumRepaymentAmount",
      comment_lines: ["The minimum payment is the lowest amount of money that one is required to pay on a credit card statement each month."].freeze,
      ranges: ["MonetaryAmount", "Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#cash_backObject

A cardholder benefit that pays the cardholder a small percentage of their net expenditures.



58
59
60
# File 'lib/schema_org/mixins/payment_card.rb', line 58

def cash_back
  read_property(:cash_back)
end

#cash_back=(value) ⇒ Object

A cardholder benefit that pays the cardholder a small percentage of their net expenditures.



63
64
65
# File 'lib/schema_org/mixins/payment_card.rb', line 63

def cash_back=(value)
  write_property(:cash_back, value)
end

#contactless_paymentObject

A secure method for consumers to purchase products or services via debit, credit or smartcards by using RFID or NFC technology.



68
69
70
# File 'lib/schema_org/mixins/payment_card.rb', line 68

def contactless_payment
  read_property(:contactless_payment)
end

#contactless_payment=(value) ⇒ Object

A secure method for consumers to purchase products or services via debit, credit or smartcards by using RFID or NFC technology.



73
74
75
# File 'lib/schema_org/mixins/payment_card.rb', line 73

def contactless_payment=(value)
  write_property(:contactless_payment, value)
end

#floor_limitObject

A floor limit is the amount of money above which credit card transactions must be authorized.



78
79
80
# File 'lib/schema_org/mixins/payment_card.rb', line 78

def floor_limit
  read_property(:floor_limit)
end

#floor_limit=(value) ⇒ Object

A floor limit is the amount of money above which credit card transactions must be authorized.



83
84
85
# File 'lib/schema_org/mixins/payment_card.rb', line 83

def floor_limit=(value)
  write_property(:floor_limit, value)
end

#monthly_minimum_repayment_amountObject

The minimum payment is the lowest amount of money that one is required to pay on a credit card statement each month.



88
89
90
# File 'lib/schema_org/mixins/payment_card.rb', line 88

def monthly_minimum_repayment_amount
  read_property(:monthly_minimum_repayment_amount)
end

#monthly_minimum_repayment_amount=(value) ⇒ Object

The minimum payment is the lowest amount of money that one is required to pay on a credit card statement each month.



93
94
95
# File 'lib/schema_org/mixins/payment_card.rb', line 93

def monthly_minimum_repayment_amount=(value)
  write_property(:monthly_minimum_repayment_amount, value)
end