Module: SchemaOrg::Mixins::PaymentChargeSpecification
- Includes:
- PriceSpecification
- Included in:
- PaymentChargeSpecification
- Defined in:
- lib/schema_org/mixins/payment_charge_specification.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#applies_to_delivery_method ⇒ Object
The delivery method(s) to which the delivery charge or payment charge specification applies.
-
#applies_to_delivery_method=(value) ⇒ Object
The delivery method(s) to which the delivery charge or payment charge specification applies.
-
#applies_to_payment_method ⇒ Object
The payment method(s) to which the payment charge specification applies.
-
#applies_to_payment_method=(value) ⇒ Object
The payment method(s) to which the payment charge specification applies.
Methods included from PriceSpecification
#eligible_quantity, #eligible_quantity=, #eligible_transaction_volume, #eligible_transaction_volume=, #max_price, #max_price=, #membership_points_earned, #membership_points_earned=, #min_price, #min_price=, #price, #price=, #price_currency, #price_currency=, #valid_for_member_tier, #valid_for_member_tier=, #valid_from, #valid_from=, #valid_through, #valid_through=, #value_added_tax_included, #value_added_tax_included=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/schema_org/mixins/payment_charge_specification.rb', line 11 def self.schema_property_definitions { applies_to_delivery_method: { schema_name: "appliesToDeliveryMethod", schema_url: "https://schema.org/appliesToDeliveryMethod", comment_lines: ["The delivery method(s) to which the delivery charge or payment charge specification applies."].freeze, ranges: ["DeliveryMethod"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, applies_to_payment_method: { schema_name: "appliesToPaymentMethod", schema_url: "https://schema.org/appliesToPaymentMethod", comment_lines: ["The payment method(s) to which the payment charge specification applies."].freeze, ranges: ["PaymentMethod"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#applies_to_delivery_method ⇒ Object
The delivery method(s) to which the delivery charge or payment charge specification applies.
37 38 39 |
# File 'lib/schema_org/mixins/payment_charge_specification.rb', line 37 def applies_to_delivery_method read_property(:applies_to_delivery_method) end |
#applies_to_delivery_method=(value) ⇒ Object
The delivery method(s) to which the delivery charge or payment charge specification applies.
42 43 44 |
# File 'lib/schema_org/mixins/payment_charge_specification.rb', line 42 def applies_to_delivery_method=(value) write_property(:applies_to_delivery_method, value) end |
#applies_to_payment_method ⇒ Object
The payment method(s) to which the payment charge specification applies.
47 48 49 |
# File 'lib/schema_org/mixins/payment_charge_specification.rb', line 47 def applies_to_payment_method read_property(:applies_to_payment_method) end |
#applies_to_payment_method=(value) ⇒ Object
The payment method(s) to which the payment charge specification applies.
52 53 54 |
# File 'lib/schema_org/mixins/payment_charge_specification.rb', line 52 def applies_to_payment_method=(value) write_property(:applies_to_payment_method, value) end |