Module: SchemaOrg::Mixins::PerformanceRole

Includes:
Role
Included in:
PerformanceRole
Defined in:
lib/schema_org/mixins/performance_role.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Role

#end_date, #end_date=, #named_position, #named_position=, #role_name, #role_name=, #start_date, #start_date=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
# File 'lib/schema_org/mixins/performance_role.rb', line 11

def self.schema_property_definitions
  {
    character_name: {
      schema_name: "characterName",
      schema_url: "https://schema.org/characterName",
      comment_lines: ["The name of a character played in some acting or performing role, i.e. in a PerformanceRole."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#character_nameObject

The name of a character played in some acting or performing role, i.e. in a PerformanceRole.



27
28
29
# File 'lib/schema_org/mixins/performance_role.rb', line 27

def character_name
  read_property(:character_name)
end

#character_name=(value) ⇒ Object

The name of a character played in some acting or performing role, i.e. in a PerformanceRole.



32
33
34
# File 'lib/schema_org/mixins/performance_role.rb', line 32

def character_name=(value)
  write_property(:character_name, value)
end