Module: SchemaOrg::Mixins::PhysicalActivity

Includes:
LifestyleModification
Included in:
ExercisePlan, PhysicalActivity
Defined in:
lib/schema_org/mixins/physical_activity.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/schema_org/mixins/physical_activity.rb', line 11

def self.schema_property_definitions
  {
    associated_anatomy: {
      schema_name: "associatedAnatomy",
      schema_url: "https://schema.org/associatedAnatomy",
      comment_lines: ["The anatomy of the underlying organ system or structures associated with this entity."].freeze,
      ranges: ["AnatomicalStructure", "AnatomicalSystem", "SuperficialAnatomy"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    category: {
      schema_name: "category",
      schema_url: "https://schema.org/category",
      comment_lines: ["A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy."].freeze,
      ranges: ["CategoryCode", "PhysicalActivityCategory", "Text", "Thing", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    epidemiology: {
      schema_name: "epidemiology",
      schema_url: "https://schema.org/epidemiology",
      comment_lines: ["The characteristics of associated patients, such as age, gender, race etc."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    pathophysiology: {
      schema_name: "pathophysiology",
      schema_url: "https://schema.org/pathophysiology",
      comment_lines: ["Changes in the normal mechanical, physical, and biochemical functions that are associated with this activity or condition."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#associated_anatomyObject

The anatomy of the underlying organ system or structures associated with this entity.



57
58
59
# File 'lib/schema_org/mixins/physical_activity.rb', line 57

def associated_anatomy
  read_property(:associated_anatomy)
end

#associated_anatomy=(value) ⇒ Object

The anatomy of the underlying organ system or structures associated with this entity.



62
63
64
# File 'lib/schema_org/mixins/physical_activity.rb', line 62

def associated_anatomy=(value)
  write_property(:associated_anatomy, value)
end

#categoryObject

A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.



67
68
69
# File 'lib/schema_org/mixins/physical_activity.rb', line 67

def category
  read_property(:category)
end

#category=(value) ⇒ Object

A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.



72
73
74
# File 'lib/schema_org/mixins/physical_activity.rb', line 72

def category=(value)
  write_property(:category, value)
end

#epidemiologyObject

The characteristics of associated patients, such as age, gender, race etc.



77
78
79
# File 'lib/schema_org/mixins/physical_activity.rb', line 77

def epidemiology
  read_property(:epidemiology)
end

#epidemiology=(value) ⇒ Object

The characteristics of associated patients, such as age, gender, race etc.



82
83
84
# File 'lib/schema_org/mixins/physical_activity.rb', line 82

def epidemiology=(value)
  write_property(:epidemiology, value)
end

#pathophysiologyObject

Changes in the normal mechanical, physical, and biochemical functions that are associated with this activity or condition.



87
88
89
# File 'lib/schema_org/mixins/physical_activity.rb', line 87

def pathophysiology
  read_property(:pathophysiology)
end

#pathophysiology=(value) ⇒ Object

Changes in the normal mechanical, physical, and biochemical functions that are associated with this activity or condition.



92
93
94
# File 'lib/schema_org/mixins/physical_activity.rb', line 92

def pathophysiology=(value)
  write_property(:pathophysiology, value)
end