Module: SchemaOrg::Mixins::Place

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
# File 'lib/schema_org/mixins/place.rb', line 11

def self.schema_property_definitions
  {
    additional_property: {
      schema_name: "additionalProperty",
      schema_url: "https://schema.org/additionalProperty",
      comment_lines: ["A property-value pair representing an additional characteristic of the entity, e.g. a product feature or another characteristic for which there is no matching property in schema.org.\\n\\nNote: Publishers should be aware that applications designed to use specific schema.org properties (e.g. https://schema.org/width, https://schema.org/color, https://schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism."].freeze,
      ranges: ["PropertyValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    address: {
      schema_name: "address",
      schema_url: "https://schema.org/address",
      comment_lines: ["Physical address of the item."].freeze,
      ranges: ["PostalAddress", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    aggregate_rating: {
      schema_name: "aggregateRating",
      schema_url: "https://schema.org/aggregateRating",
      comment_lines: ["The overall rating, based on a collection of reviews or ratings, of the item."].freeze,
      ranges: ["AggregateRating"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    amenity_feature: {
      schema_name: "amenityFeature",
      schema_url: "https://schema.org/amenityFeature",
      comment_lines: ["An amenity feature (e.g. a characteristic or service) of the Accommodation. This generic property does not make a statement about whether the feature is included in an offer for the main accommodation or available at extra costs."].freeze,
      ranges: ["LocationFeatureSpecification"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    branch_code: {
      schema_name: "branchCode",
      schema_url: "https://schema.org/branchCode",
      comment_lines: ["A short textual code (also called \"store code\") that uniquely identifies a place of business. The code is typically assigned by the parentOrganization and used in structured URLs.\\n\\nFor example, in the URL http://www.starbucks.co.uk/store-locator/etc/detail/3047 the code \"3047\" is a branchCode for a particular branch."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    contained_in: {
      schema_name: "containedIn",
      schema_url: "https://schema.org/containedIn",
      comment_lines: ["The basic containment relation between a place and one that contains it."].freeze,
      ranges: ["Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "containedInPlace",
      supersedes: nil
    }.freeze,
    contained_in_place: {
      schema_name: "containedInPlace",
      schema_url: "https://schema.org/containedInPlace",
      comment_lines: ["The basic containment relation between a place and one that contains it."].freeze,
      ranges: ["Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: "containsPlace",
      superseded_by: nil,
      supersedes: ["containedIn"].freeze
    }.freeze,
    contains_place: {
      schema_name: "containsPlace",
      schema_url: "https://schema.org/containsPlace",
      comment_lines: ["The basic containment relation between a place and another that it contains."].freeze,
      ranges: ["Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: "containedInPlace",
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    event: {
      schema_name: "event",
      schema_url: "https://schema.org/event",
      comment_lines: ["Upcoming or past event associated with this place, organization, or action."].freeze,
      ranges: ["Event"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["events"].freeze
    }.freeze,
    events: {
      schema_name: "events",
      schema_url: "https://schema.org/events",
      comment_lines: ["Upcoming or past events associated with this place or organization."].freeze,
      ranges: ["Event"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "event",
      supersedes: nil
    }.freeze,
    fax_number: {
      schema_name: "faxNumber",
      schema_url: "https://schema.org/faxNumber",
      comment_lines: ["The fax number."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    geo: {
      schema_name: "geo",
      schema_url: "https://schema.org/geo",
      comment_lines: ["The geo coordinates of the place."].freeze,
      ranges: ["GeoCoordinates", "GeoShape"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    geo_contains: {
      schema_name: "geoContains",
      schema_url: "https://schema.org/geoContains",
      comment_lines: ["Represents a relationship between two geometries (or the places they represent), relating a containing geometry to a contained geometry. \"a contains b iff no points of b lie in the exterior of a, and at least one point of the interior of b lies in the interior of a\". As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM)."].freeze,
      ranges: ["GeospatialGeometry", "Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    geo_covered_by: {
      schema_name: "geoCoveredBy",
      schema_url: "https://schema.org/geoCoveredBy",
      comment_lines: ["Represents a relationship between two geometries (or the places they represent), relating a geometry to another that covers it. As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM)."].freeze,
      ranges: ["GeospatialGeometry", "Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    geo_covers: {
      schema_name: "geoCovers",
      schema_url: "https://schema.org/geoCovers",
      comment_lines: ["Represents a relationship between two geometries (or the places they represent), relating a covering geometry to a covered geometry. \"Every point of b is a point of (the interior or boundary of) a\". As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM)."].freeze,
      ranges: ["GeospatialGeometry", "Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    geo_crosses: {
      schema_name: "geoCrosses",
      schema_url: "https://schema.org/geoCrosses",
      comment_lines: ["Represents a relationship between two geometries (or the places they represent), relating a geometry to another that crosses it: \"a crosses b: they have some but not all interior points in common, and the dimension of the intersection is less than that of at least one of them\". As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM)."].freeze,
      ranges: ["GeospatialGeometry", "Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    geo_disjoint: {
      schema_name: "geoDisjoint",
      schema_url: "https://schema.org/geoDisjoint",
      comment_lines: ["Represents spatial relations in which two geometries (or the places they represent) are topologically disjoint: \"they have no point in common. They form a set of disconnected geometries.\" (A symmetric relationship, as defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).)"].freeze,
      ranges: ["GeospatialGeometry", "Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    geo_equals: {
      schema_name: "geoEquals",
      schema_url: "https://schema.org/geoEquals",
      comment_lines: ["Represents spatial relations in which two geometries (or the places they represent) are topologically equal, as defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM). \"Two geometries are topologically equal if their interiors intersect and no part of the interior or boundary of one geometry intersects the exterior of the other\" (a symmetric relationship)."].freeze,
      ranges: ["GeospatialGeometry", "Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    geo_intersects: {
      schema_name: "geoIntersects",
      schema_url: "https://schema.org/geoIntersects",
      comment_lines: ["Represents spatial relations in which two geometries (or the places they represent) have at least one point in common. As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM)."].freeze,
      ranges: ["GeospatialGeometry", "Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    geo_overlaps: {
      schema_name: "geoOverlaps",
      schema_url: "https://schema.org/geoOverlaps",
      comment_lines: ["Represents a relationship between two geometries (or the places they represent), relating a geometry to another that geospatially overlaps it, i.e. they have some but not all points in common. As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM)."].freeze,
      ranges: ["GeospatialGeometry", "Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    geo_touches: {
      schema_name: "geoTouches",
      schema_url: "https://schema.org/geoTouches",
      comment_lines: ["Represents spatial relations in which two geometries (or the places they represent) touch: \"they have at least one boundary point in common, but no interior points.\" (A symmetric relationship, as defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).)"].freeze,
      ranges: ["GeospatialGeometry", "Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    geo_within: {
      schema_name: "geoWithin",
      schema_url: "https://schema.org/geoWithin",
      comment_lines: ["Represents a relationship between two geometries (or the places they represent), relating a geometry to one that contains it, i.e. it is inside (i.e. within) its interior. As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM)."].freeze,
      ranges: ["GeospatialGeometry", "Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    global_location_number: {
      schema_name: "globalLocationNumber",
      schema_url: "https://schema.org/globalLocationNumber",
      comment_lines: ["The [Global Location Number](http://www.gs1.org/gln) (GLN, sometimes also referred to as International Location Number or ILN) of the respective organization, person, or place. The GLN is a 13-digit number used to identify parties and physical locations."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    has_certification: {
      schema_name: "hasCertification",
      schema_url: "https://schema.org/hasCertification",
      comment_lines: ["Certification information about a product, organization, service, place, or person."].freeze,
      ranges: ["Certification"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    has_drive_through_service: {
      schema_name: "hasDriveThroughService",
      schema_url: "https://schema.org/hasDriveThroughService",
      comment_lines: ["Indicates whether some facility (e.g. [[FoodEstablishment]], [[CovidTestingFacility]]) offers a service that can be used by driving through in a car. In the case of [[CovidTestingFacility]] such facilities could potentially help with social distancing from other potentially-infected users."].freeze,
      ranges: ["Boolean"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    has_gs1_digital_link: {
      schema_name: "hasGS1DigitalLink",
      schema_url: "https://schema.org/hasGS1DigitalLink",
      comment_lines: ["The <a href=\"https://www.gs1.org/standards/gs1-digital-link\">GS1 digital link</a> associated with the object. This URL should conform to the particular requirements of digital links. The link should only contain the Application Identifiers (AIs) that are relevant for the entity being annotated, for instance a [[Product]] or an [[Organization]], and for the correct granularity. In particular, for products:<ul><li>A Digital Link that contains a serial number (AI <code>21</code>) should only be present on instances of [[IndividualProduct]]</li><li>A Digital Link that contains a lot number (AI <code>10</code>) should be annotated as [[SomeProducts]] if only products from that lot are sold, or [[IndividualProduct]] if there is only a specific product.</li><li>A Digital Link that contains a global model number (AI <code>8013</code>) should be attached to a [[Product]] or a [[ProductModel]].</li></ul> Other item types should be adapted similarly."].freeze,
      ranges: ["URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    has_map: {
      schema_name: "hasMap",
      schema_url: "https://schema.org/hasMap",
      comment_lines: ["A URL to a map of the place."].freeze,
      ranges: ["Map", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["map", "maps"].freeze
    }.freeze,
    is_accessible_for_free: {
      schema_name: "isAccessibleForFree",
      schema_url: "https://schema.org/isAccessibleForFree",
      comment_lines: ["A flag to signal that the item, event, or place is accessible for free."].freeze,
      ranges: ["Boolean"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["free"].freeze
    }.freeze,
    isic_v4: {
      schema_name: "isicV4",
      schema_url: "https://schema.org/isicV4",
      comment_lines: ["The International Standard of Industrial Classification of All Economic Activities (ISIC), Revision 4 code for a particular organization, business person, or place."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    keywords: {
      schema_name: "keywords",
      schema_url: "https://schema.org/keywords",
      comment_lines: ["Keywords or tags used to describe some item. Multiple textual entries in a keywords list are typically delimited by commas, or by repeating the property."].freeze,
      ranges: ["DefinedTerm", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    latitude: {
      schema_name: "latitude",
      schema_url: "https://schema.org/latitude",
      comment_lines: ["The latitude of a location. For example ```37.42242``` ([WGS 84](https://en.wikipedia.org/wiki/World_Geodetic_System))."].freeze,
      ranges: ["Number", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    logo: {
      schema_name: "logo",
      schema_url: "https://schema.org/logo",
      comment_lines: ["An associated logo."].freeze,
      ranges: ["ImageObject", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    longitude: {
      schema_name: "longitude",
      schema_url: "https://schema.org/longitude",
      comment_lines: ["The longitude of a location. For example ```-122.08585``` ([WGS 84](https://en.wikipedia.org/wiki/World_Geodetic_System))."].freeze,
      ranges: ["Number", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    map: {
      schema_name: "map",
      schema_url: "https://schema.org/map",
      comment_lines: ["A URL to a map of the place."].freeze,
      ranges: ["URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "hasMap",
      supersedes: nil
    }.freeze,
    maps: {
      schema_name: "maps",
      schema_url: "https://schema.org/maps",
      comment_lines: ["A URL to a map of the place."].freeze,
      ranges: ["URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "hasMap",
      supersedes: nil
    }.freeze,
    maximum_attendee_capacity: {
      schema_name: "maximumAttendeeCapacity",
      schema_url: "https://schema.org/maximumAttendeeCapacity",
      comment_lines: ["The total number of individuals that may attend an event or venue."].freeze,
      ranges: ["Integer"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    opening_hours_specification: {
      schema_name: "openingHoursSpecification",
      schema_url: "https://schema.org/openingHoursSpecification",
      comment_lines: ["The opening hours of a certain place."].freeze,
      ranges: ["OpeningHoursSpecification"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    photo: {
      schema_name: "photo",
      schema_url: "https://schema.org/photo",
      comment_lines: ["A photograph of this place."].freeze,
      ranges: ["ImageObject", "Photograph"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["photos"].freeze
    }.freeze,
    photos: {
      schema_name: "photos",
      schema_url: "https://schema.org/photos",
      comment_lines: ["Photographs of this place."].freeze,
      ranges: ["ImageObject", "Photograph"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "photo",
      supersedes: nil
    }.freeze,
    public_access: {
      schema_name: "publicAccess",
      schema_url: "https://schema.org/publicAccess",
      comment_lines: ["A flag to signal that the [[Place]] is open to public visitors.  If this property is omitted there is no assumed default boolean value."].freeze,
      ranges: ["Boolean"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    review: {
      schema_name: "review",
      schema_url: "https://schema.org/review",
      comment_lines: ["A review of the item."].freeze,
      ranges: ["Review"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["reviews"].freeze
    }.freeze,
    reviews: {
      schema_name: "reviews",
      schema_url: "https://schema.org/reviews",
      comment_lines: ["Review of the item."].freeze,
      ranges: ["Review"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "review",
      supersedes: nil
    }.freeze,
    slogan: {
      schema_name: "slogan",
      schema_url: "https://schema.org/slogan",
      comment_lines: ["A slogan or motto associated with the item."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    smoking_allowed: {
      schema_name: "smokingAllowed",
      schema_url: "https://schema.org/smokingAllowed",
      comment_lines: ["Indicates whether it is allowed to smoke in the place, e.g. in the restaurant, hotel or hotel room."].freeze,
      ranges: ["Boolean"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    special_opening_hours_specification: {
      schema_name: "specialOpeningHoursSpecification",
      schema_url: "https://schema.org/specialOpeningHoursSpecification",
      comment_lines: ["The special opening hours of a certain place.\\n\\nUse this to explicitly override general opening hours brought in scope by [[openingHoursSpecification]] or [[openingHours]]."].freeze,
      ranges: ["OpeningHoursSpecification"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    telephone: {
      schema_name: "telephone",
      schema_url: "https://schema.org/telephone",
      comment_lines: ["The telephone number."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    tour_booking_page: {
      schema_name: "tourBookingPage",
      schema_url: "https://schema.org/tourBookingPage",
      comment_lines: ["A page providing information on how to book a tour of some [[Place]], such as an [[Accommodation]] or [[ApartmentComplex]] in a real estate setting, as well as other kinds of tours as appropriate."].freeze,
      ranges: ["URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#additional_propertyObject

A property-value pair representing an additional characteristic of the entity, e.g. a product feature or another characteristic for which there is no matching property in schema.org.\n\nNote: Publishers should be aware that applications designed to use specific schema.org properties (e.g. https://schema.org/width, https://schema.org/color, https://schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism.



487
488
489
# File 'lib/schema_org/mixins/place.rb', line 487

def additional_property
  read_property(:additional_property)
end

#additional_property=(value) ⇒ Object

A property-value pair representing an additional characteristic of the entity, e.g. a product feature or another characteristic for which there is no matching property in schema.org.\n\nNote: Publishers should be aware that applications designed to use specific schema.org properties (e.g. https://schema.org/width, https://schema.org/color, https://schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism.



492
493
494
# File 'lib/schema_org/mixins/place.rb', line 492

def additional_property=(value)
  write_property(:additional_property, value)
end

#addressObject

Physical address of the item.



497
498
499
# File 'lib/schema_org/mixins/place.rb', line 497

def address
  read_property(:address)
end

#address=(value) ⇒ Object

Physical address of the item.



502
503
504
# File 'lib/schema_org/mixins/place.rb', line 502

def address=(value)
  write_property(:address, value)
end

#aggregate_ratingObject

The overall rating, based on a collection of reviews or ratings, of the item.



507
508
509
# File 'lib/schema_org/mixins/place.rb', line 507

def aggregate_rating
  read_property(:aggregate_rating)
end

#aggregate_rating=(value) ⇒ Object

The overall rating, based on a collection of reviews or ratings, of the item.



512
513
514
# File 'lib/schema_org/mixins/place.rb', line 512

def aggregate_rating=(value)
  write_property(:aggregate_rating, value)
end

#amenity_featureObject

An amenity feature (e.g. a characteristic or service) of the Accommodation. This generic property does not make a statement about whether the feature is included in an offer for the main accommodation or available at extra costs.



517
518
519
# File 'lib/schema_org/mixins/place.rb', line 517

def amenity_feature
  read_property(:amenity_feature)
end

#amenity_feature=(value) ⇒ Object

An amenity feature (e.g. a characteristic or service) of the Accommodation. This generic property does not make a statement about whether the feature is included in an offer for the main accommodation or available at extra costs.



522
523
524
# File 'lib/schema_org/mixins/place.rb', line 522

def amenity_feature=(value)
  write_property(:amenity_feature, value)
end

#branch_codeObject

A short textual code (also called "store code") that uniquely identifies a place of business. The code is typically assigned by the parentOrganization and used in structured URLs.\n\nFor example, in the URL http://www.starbucks.co.uk/store-locator/etc/detail/3047 the code "3047" is a branchCode for a particular branch.



527
528
529
# File 'lib/schema_org/mixins/place.rb', line 527

def branch_code
  read_property(:branch_code)
end

#branch_code=(value) ⇒ Object

A short textual code (also called "store code") that uniquely identifies a place of business. The code is typically assigned by the parentOrganization and used in structured URLs.\n\nFor example, in the URL http://www.starbucks.co.uk/store-locator/etc/detail/3047 the code "3047" is a branchCode for a particular branch.



532
533
534
# File 'lib/schema_org/mixins/place.rb', line 532

def branch_code=(value)
  write_property(:branch_code, value)
end

#contained_inObject

The basic containment relation between a place and one that contains it. Superseded by containedInPlace.



538
539
540
# File 'lib/schema_org/mixins/place.rb', line 538

def contained_in
  read_property(:contained_in)
end

#contained_in=(value) ⇒ Object

The basic containment relation between a place and one that contains it. Superseded by containedInPlace.



544
545
546
# File 'lib/schema_org/mixins/place.rb', line 544

def contained_in=(value)
  write_property(:contained_in, value)
end

#contained_in_placeObject

The basic containment relation between a place and one that contains it. Supersedes containedIn. Inverse-property: containsPlace.



551
552
553
# File 'lib/schema_org/mixins/place.rb', line 551

def contained_in_place
  read_property(:contained_in_place)
end

#contained_in_place=(value) ⇒ Object

The basic containment relation between a place and one that contains it. Supersedes containedIn. Inverse-property: containsPlace.



558
559
560
# File 'lib/schema_org/mixins/place.rb', line 558

def contained_in_place=(value)
  write_property(:contained_in_place, value)
end

#contains_placeObject

The basic containment relation between a place and another that it contains. Inverse-property: containedInPlace.



564
565
566
# File 'lib/schema_org/mixins/place.rb', line 564

def contains_place
  read_property(:contains_place)
end

#contains_place=(value) ⇒ Object

The basic containment relation between a place and another that it contains. Inverse-property: containedInPlace.



570
571
572
# File 'lib/schema_org/mixins/place.rb', line 570

def contains_place=(value)
  write_property(:contains_place, value)
end

#eventObject

Upcoming or past event associated with this place, organization, or action. Supersedes events.



576
577
578
# File 'lib/schema_org/mixins/place.rb', line 576

def event
  read_property(:event)
end

#event=(value) ⇒ Object

Upcoming or past event associated with this place, organization, or action. Supersedes events.



582
583
584
# File 'lib/schema_org/mixins/place.rb', line 582

def event=(value)
  write_property(:event, value)
end

#eventsObject

Upcoming or past events associated with this place or organization. Superseded by event.



588
589
590
# File 'lib/schema_org/mixins/place.rb', line 588

def events
  read_property(:events)
end

#events=(value) ⇒ Object

Upcoming or past events associated with this place or organization. Superseded by event.



594
595
596
# File 'lib/schema_org/mixins/place.rb', line 594

def events=(value)
  write_property(:events, value)
end

#fax_numberObject

The fax number.



599
600
601
# File 'lib/schema_org/mixins/place.rb', line 599

def fax_number
  read_property(:fax_number)
end

#fax_number=(value) ⇒ Object

The fax number.



604
605
606
# File 'lib/schema_org/mixins/place.rb', line 604

def fax_number=(value)
  write_property(:fax_number, value)
end

#geoObject

The geo coordinates of the place.



609
610
611
# File 'lib/schema_org/mixins/place.rb', line 609

def geo
  read_property(:geo)
end

#geo=(value) ⇒ Object

The geo coordinates of the place.



614
615
616
# File 'lib/schema_org/mixins/place.rb', line 614

def geo=(value)
  write_property(:geo, value)
end

#geo_containsObject

Represents a relationship between two geometries (or the places they represent), relating a containing geometry to a contained geometry. "a contains b iff no points of b lie in the exterior of a, and at least one point of the interior of b lies in the interior of a". As defined in DE-9IM.



619
620
621
# File 'lib/schema_org/mixins/place.rb', line 619

def geo_contains
  read_property(:geo_contains)
end

#geo_contains=(value) ⇒ Object

Represents a relationship between two geometries (or the places they represent), relating a containing geometry to a contained geometry. "a contains b iff no points of b lie in the exterior of a, and at least one point of the interior of b lies in the interior of a". As defined in DE-9IM.



624
625
626
# File 'lib/schema_org/mixins/place.rb', line 624

def geo_contains=(value)
  write_property(:geo_contains, value)
end

#geo_covered_byObject

Represents a relationship between two geometries (or the places they represent), relating a geometry to another that covers it. As defined in DE-9IM.



629
630
631
# File 'lib/schema_org/mixins/place.rb', line 629

def geo_covered_by
  read_property(:geo_covered_by)
end

#geo_covered_by=(value) ⇒ Object

Represents a relationship between two geometries (or the places they represent), relating a geometry to another that covers it. As defined in DE-9IM.



634
635
636
# File 'lib/schema_org/mixins/place.rb', line 634

def geo_covered_by=(value)
  write_property(:geo_covered_by, value)
end

#geo_coversObject

Represents a relationship between two geometries (or the places they represent), relating a covering geometry to a covered geometry. "Every point of b is a point of (the interior or boundary of) a". As defined in DE-9IM.



639
640
641
# File 'lib/schema_org/mixins/place.rb', line 639

def geo_covers
  read_property(:geo_covers)
end

#geo_covers=(value) ⇒ Object

Represents a relationship between two geometries (or the places they represent), relating a covering geometry to a covered geometry. "Every point of b is a point of (the interior or boundary of) a". As defined in DE-9IM.



644
645
646
# File 'lib/schema_org/mixins/place.rb', line 644

def geo_covers=(value)
  write_property(:geo_covers, value)
end

#geo_crossesObject

Represents a relationship between two geometries (or the places they represent), relating a geometry to another that crosses it: "a crosses b: they have some but not all interior points in common, and the dimension of the intersection is less than that of at least one of them". As defined in DE-9IM.



649
650
651
# File 'lib/schema_org/mixins/place.rb', line 649

def geo_crosses
  read_property(:geo_crosses)
end

#geo_crosses=(value) ⇒ Object

Represents a relationship between two geometries (or the places they represent), relating a geometry to another that crosses it: "a crosses b: they have some but not all interior points in common, and the dimension of the intersection is less than that of at least one of them". As defined in DE-9IM.



654
655
656
# File 'lib/schema_org/mixins/place.rb', line 654

def geo_crosses=(value)
  write_property(:geo_crosses, value)
end

#geo_disjointObject

Represents spatial relations in which two geometries (or the places they represent) are topologically disjoint: "they have no point in common. They form a set of disconnected geometries." (A symmetric relationship, as defined in DE-9IM.)



659
660
661
# File 'lib/schema_org/mixins/place.rb', line 659

def geo_disjoint
  read_property(:geo_disjoint)
end

#geo_disjoint=(value) ⇒ Object

Represents spatial relations in which two geometries (or the places they represent) are topologically disjoint: "they have no point in common. They form a set of disconnected geometries." (A symmetric relationship, as defined in DE-9IM.)



664
665
666
# File 'lib/schema_org/mixins/place.rb', line 664

def geo_disjoint=(value)
  write_property(:geo_disjoint, value)
end

#geo_equalsObject

Represents spatial relations in which two geometries (or the places they represent) are topologically equal, as defined in DE-9IM. "Two geometries are topologically equal if their interiors intersect and no part of the interior or boundary of one geometry intersects the exterior of the other" (a symmetric relationship).



669
670
671
# File 'lib/schema_org/mixins/place.rb', line 669

def geo_equals
  read_property(:geo_equals)
end

#geo_equals=(value) ⇒ Object

Represents spatial relations in which two geometries (or the places they represent) are topologically equal, as defined in DE-9IM. "Two geometries are topologically equal if their interiors intersect and no part of the interior or boundary of one geometry intersects the exterior of the other" (a symmetric relationship).



674
675
676
# File 'lib/schema_org/mixins/place.rb', line 674

def geo_equals=(value)
  write_property(:geo_equals, value)
end

#geo_intersectsObject

Represents spatial relations in which two geometries (or the places they represent) have at least one point in common. As defined in DE-9IM.



679
680
681
# File 'lib/schema_org/mixins/place.rb', line 679

def geo_intersects
  read_property(:geo_intersects)
end

#geo_intersects=(value) ⇒ Object

Represents spatial relations in which two geometries (or the places they represent) have at least one point in common. As defined in DE-9IM.



684
685
686
# File 'lib/schema_org/mixins/place.rb', line 684

def geo_intersects=(value)
  write_property(:geo_intersects, value)
end

#geo_overlapsObject

Represents a relationship between two geometries (or the places they represent), relating a geometry to another that geospatially overlaps it, i.e. they have some but not all points in common. As defined in DE-9IM.



689
690
691
# File 'lib/schema_org/mixins/place.rb', line 689

def geo_overlaps
  read_property(:geo_overlaps)
end

#geo_overlaps=(value) ⇒ Object

Represents a relationship between two geometries (or the places they represent), relating a geometry to another that geospatially overlaps it, i.e. they have some but not all points in common. As defined in DE-9IM.



694
695
696
# File 'lib/schema_org/mixins/place.rb', line 694

def geo_overlaps=(value)
  write_property(:geo_overlaps, value)
end

#geo_touchesObject

Represents spatial relations in which two geometries (or the places they represent) touch: "they have at least one boundary point in common, but no interior points." (A symmetric relationship, as defined in DE-9IM.)



699
700
701
# File 'lib/schema_org/mixins/place.rb', line 699

def geo_touches
  read_property(:geo_touches)
end

#geo_touches=(value) ⇒ Object

Represents spatial relations in which two geometries (or the places they represent) touch: "they have at least one boundary point in common, but no interior points." (A symmetric relationship, as defined in DE-9IM.)



704
705
706
# File 'lib/schema_org/mixins/place.rb', line 704

def geo_touches=(value)
  write_property(:geo_touches, value)
end

#geo_withinObject

Represents a relationship between two geometries (or the places they represent), relating a geometry to one that contains it, i.e. it is inside (i.e. within) its interior. As defined in DE-9IM.



709
710
711
# File 'lib/schema_org/mixins/place.rb', line 709

def geo_within
  read_property(:geo_within)
end

#geo_within=(value) ⇒ Object

Represents a relationship between two geometries (or the places they represent), relating a geometry to one that contains it, i.e. it is inside (i.e. within) its interior. As defined in DE-9IM.



714
715
716
# File 'lib/schema_org/mixins/place.rb', line 714

def geo_within=(value)
  write_property(:geo_within, value)
end

#global_location_numberObject

The Global Location Number (GLN, sometimes also referred to as International Location Number or ILN) of the respective organization, person, or place. The GLN is a 13-digit number used to identify parties and physical locations.



719
720
721
# File 'lib/schema_org/mixins/place.rb', line 719

def global_location_number
  read_property(:global_location_number)
end

#global_location_number=(value) ⇒ Object

The Global Location Number (GLN, sometimes also referred to as International Location Number or ILN) of the respective organization, person, or place. The GLN is a 13-digit number used to identify parties and physical locations.



724
725
726
# File 'lib/schema_org/mixins/place.rb', line 724

def global_location_number=(value)
  write_property(:global_location_number, value)
end

#has_certificationObject

Certification information about a product, organization, service, place, or person.



729
730
731
# File 'lib/schema_org/mixins/place.rb', line 729

def has_certification
  read_property(:has_certification)
end

#has_certification=(value) ⇒ Object

Certification information about a product, organization, service, place, or person.



734
735
736
# File 'lib/schema_org/mixins/place.rb', line 734

def has_certification=(value)
  write_property(:has_certification, value)
end

#has_drive_through_serviceObject

Indicates whether some facility (e.g. [[FoodEstablishment]], [[CovidTestingFacility]]) offers a service that can be used by driving through in a car. In the case of [[CovidTestingFacility]] such facilities could potentially help with social distancing from other potentially-infected users.



739
740
741
# File 'lib/schema_org/mixins/place.rb', line 739

def has_drive_through_service
  read_property(:has_drive_through_service)
end

#has_drive_through_service=(value) ⇒ Object

Indicates whether some facility (e.g. [[FoodEstablishment]], [[CovidTestingFacility]]) offers a service that can be used by driving through in a car. In the case of [[CovidTestingFacility]] such facilities could potentially help with social distancing from other potentially-infected users.



744
745
746
# File 'lib/schema_org/mixins/place.rb', line 744

def has_drive_through_service=(value)
  write_property(:has_drive_through_service, value)
end

The GS1 digital link associated with the object. This URL should conform to the particular requirements of digital links. The link should only contain the Application Identifiers (AIs) that are relevant for the entity being annotated, for instance a [[Product]] or an [[Organization]], and for the correct granularity. In particular, for products:

  • A Digital Link that contains a serial number (AI 21) should only be present on instances of [[IndividualProduct]]
  • A Digital Link that contains a lot number (AI 10) should be annotated as [[SomeProducts]] if only products from that lot are sold, or [[IndividualProduct]] if there is only a specific product.
  • A Digital Link that contains a global model number (AI 8013) should be attached to a [[Product]] or a [[ProductModel]].
Other item types should be adapted similarly.



749
750
751
# File 'lib/schema_org/mixins/place.rb', line 749

def has_gs1_digital_link
  read_property(:has_gs1_digital_link)
end

#has_gs1_digital_link=(value) ⇒ Object

The GS1 digital link associated with the object. This URL should conform to the particular requirements of digital links. The link should only contain the Application Identifiers (AIs) that are relevant for the entity being annotated, for instance a [[Product]] or an [[Organization]], and for the correct granularity. In particular, for products:

  • A Digital Link that contains a serial number (AI 21) should only be present on instances of [[IndividualProduct]]
  • A Digital Link that contains a lot number (AI 10) should be annotated as [[SomeProducts]] if only products from that lot are sold, or [[IndividualProduct]] if there is only a specific product.
  • A Digital Link that contains a global model number (AI 8013) should be attached to a [[Product]] or a [[ProductModel]].
Other item types should be adapted similarly.



754
755
756
# File 'lib/schema_org/mixins/place.rb', line 754

def has_gs1_digital_link=(value)
  write_property(:has_gs1_digital_link, value)
end

#has_mapObject

A URL to a map of the place. Supersedes map. Supersedes maps.



761
762
763
# File 'lib/schema_org/mixins/place.rb', line 761

def has_map
  read_property(:has_map)
end

#has_map=(value) ⇒ Object

A URL to a map of the place. Supersedes map. Supersedes maps.



768
769
770
# File 'lib/schema_org/mixins/place.rb', line 768

def has_map=(value)
  write_property(:has_map, value)
end

#is_accessible_for_freeObject

A flag to signal that the item, event, or place is accessible for free. Supersedes free.



774
775
776
# File 'lib/schema_org/mixins/place.rb', line 774

def is_accessible_for_free
  read_property(:is_accessible_for_free)
end

#is_accessible_for_free=(value) ⇒ Object

A flag to signal that the item, event, or place is accessible for free. Supersedes free.



780
781
782
# File 'lib/schema_org/mixins/place.rb', line 780

def is_accessible_for_free=(value)
  write_property(:is_accessible_for_free, value)
end

#isic_v4Object

The International Standard of Industrial Classification of All Economic Activities (ISIC), Revision 4 code for a particular organization, business person, or place.



785
786
787
# File 'lib/schema_org/mixins/place.rb', line 785

def isic_v4
  read_property(:isic_v4)
end

#isic_v4=(value) ⇒ Object

The International Standard of Industrial Classification of All Economic Activities (ISIC), Revision 4 code for a particular organization, business person, or place.



790
791
792
# File 'lib/schema_org/mixins/place.rb', line 790

def isic_v4=(value)
  write_property(:isic_v4, value)
end

#keywordsObject

Keywords or tags used to describe some item. Multiple textual entries in a keywords list are typically delimited by commas, or by repeating the property.



795
796
797
# File 'lib/schema_org/mixins/place.rb', line 795

def keywords
  read_property(:keywords)
end

#keywords=(value) ⇒ Object

Keywords or tags used to describe some item. Multiple textual entries in a keywords list are typically delimited by commas, or by repeating the property.



800
801
802
# File 'lib/schema_org/mixins/place.rb', line 800

def keywords=(value)
  write_property(:keywords, value)
end

#latitudeObject

The latitude of a location. For example 37.42242 (WGS 84).



805
806
807
# File 'lib/schema_org/mixins/place.rb', line 805

def latitude
  read_property(:latitude)
end

#latitude=(value) ⇒ Object

The latitude of a location. For example 37.42242 (WGS 84).



810
811
812
# File 'lib/schema_org/mixins/place.rb', line 810

def latitude=(value)
  write_property(:latitude, value)
end

#logoObject

An associated logo.



815
816
817
# File 'lib/schema_org/mixins/place.rb', line 815

def 
  read_property(:logo)
end

#logo=(value) ⇒ Object

An associated logo.



820
821
822
# File 'lib/schema_org/mixins/place.rb', line 820

def logo=(value)
  write_property(:logo, value)
end

#longitudeObject

The longitude of a location. For example -122.08585 (WGS 84).



825
826
827
# File 'lib/schema_org/mixins/place.rb', line 825

def longitude
  read_property(:longitude)
end

#longitude=(value) ⇒ Object

The longitude of a location. For example -122.08585 (WGS 84).



830
831
832
# File 'lib/schema_org/mixins/place.rb', line 830

def longitude=(value)
  write_property(:longitude, value)
end

#mapObject

A URL to a map of the place. Superseded by hasMap.



836
837
838
# File 'lib/schema_org/mixins/place.rb', line 836

def map
  read_property(:map)
end

#map=(value) ⇒ Object

A URL to a map of the place. Superseded by hasMap.



842
843
844
# File 'lib/schema_org/mixins/place.rb', line 842

def map=(value)
  write_property(:map, value)
end

#mapsObject

A URL to a map of the place. Superseded by hasMap.



848
849
850
# File 'lib/schema_org/mixins/place.rb', line 848

def maps
  read_property(:maps)
end

#maps=(value) ⇒ Object

A URL to a map of the place. Superseded by hasMap.



854
855
856
# File 'lib/schema_org/mixins/place.rb', line 854

def maps=(value)
  write_property(:maps, value)
end

#maximum_attendee_capacityObject

The total number of individuals that may attend an event or venue.



859
860
861
# File 'lib/schema_org/mixins/place.rb', line 859

def maximum_attendee_capacity
  read_property(:maximum_attendee_capacity)
end

#maximum_attendee_capacity=(value) ⇒ Object

The total number of individuals that may attend an event or venue.



864
865
866
# File 'lib/schema_org/mixins/place.rb', line 864

def maximum_attendee_capacity=(value)
  write_property(:maximum_attendee_capacity, value)
end

#opening_hours_specificationObject

The opening hours of a certain place.



869
870
871
# File 'lib/schema_org/mixins/place.rb', line 869

def opening_hours_specification
  read_property(:opening_hours_specification)
end

#opening_hours_specification=(value) ⇒ Object

The opening hours of a certain place.



874
875
876
# File 'lib/schema_org/mixins/place.rb', line 874

def opening_hours_specification=(value)
  write_property(:opening_hours_specification, value)
end

#photoObject

A photograph of this place. Supersedes photos.



880
881
882
# File 'lib/schema_org/mixins/place.rb', line 880

def photo
  read_property(:photo)
end

#photo=(value) ⇒ Object

A photograph of this place. Supersedes photos.



886
887
888
# File 'lib/schema_org/mixins/place.rb', line 886

def photo=(value)
  write_property(:photo, value)
end

#photosObject

Photographs of this place. Superseded by photo.



892
893
894
# File 'lib/schema_org/mixins/place.rb', line 892

def photos
  read_property(:photos)
end

#photos=(value) ⇒ Object

Photographs of this place. Superseded by photo.



898
899
900
# File 'lib/schema_org/mixins/place.rb', line 898

def photos=(value)
  write_property(:photos, value)
end

#public_accessObject

A flag to signal that the [[Place]] is open to public visitors. If this property is omitted there is no assumed default boolean value.



903
904
905
# File 'lib/schema_org/mixins/place.rb', line 903

def public_access
  read_property(:public_access)
end

#public_access=(value) ⇒ Object

A flag to signal that the [[Place]] is open to public visitors. If this property is omitted there is no assumed default boolean value.



908
909
910
# File 'lib/schema_org/mixins/place.rb', line 908

def public_access=(value)
  write_property(:public_access, value)
end

#reviewObject

A review of the item. Supersedes reviews.



914
915
916
# File 'lib/schema_org/mixins/place.rb', line 914

def review
  read_property(:review)
end

#review=(value) ⇒ Object

A review of the item. Supersedes reviews.



920
921
922
# File 'lib/schema_org/mixins/place.rb', line 920

def review=(value)
  write_property(:review, value)
end

#reviewsObject

Review of the item. Superseded by review.



926
927
928
# File 'lib/schema_org/mixins/place.rb', line 926

def reviews
  read_property(:reviews)
end

#reviews=(value) ⇒ Object

Review of the item. Superseded by review.



932
933
934
# File 'lib/schema_org/mixins/place.rb', line 932

def reviews=(value)
  write_property(:reviews, value)
end

#sloganObject

A slogan or motto associated with the item.



937
938
939
# File 'lib/schema_org/mixins/place.rb', line 937

def slogan
  read_property(:slogan)
end

#slogan=(value) ⇒ Object

A slogan or motto associated with the item.



942
943
944
# File 'lib/schema_org/mixins/place.rb', line 942

def slogan=(value)
  write_property(:slogan, value)
end

#smoking_allowedObject

Indicates whether it is allowed to smoke in the place, e.g. in the restaurant, hotel or hotel room.



947
948
949
# File 'lib/schema_org/mixins/place.rb', line 947

def smoking_allowed
  read_property(:smoking_allowed)
end

#smoking_allowed=(value) ⇒ Object

Indicates whether it is allowed to smoke in the place, e.g. in the restaurant, hotel or hotel room.



952
953
954
# File 'lib/schema_org/mixins/place.rb', line 952

def smoking_allowed=(value)
  write_property(:smoking_allowed, value)
end

#special_opening_hours_specificationObject

The special opening hours of a certain place.\n\nUse this to explicitly override general opening hours brought in scope by [[openingHoursSpecification]] or [[openingHours]].



957
958
959
# File 'lib/schema_org/mixins/place.rb', line 957

def special_opening_hours_specification
  read_property(:special_opening_hours_specification)
end

#special_opening_hours_specification=(value) ⇒ Object

The special opening hours of a certain place.\n\nUse this to explicitly override general opening hours brought in scope by [[openingHoursSpecification]] or [[openingHours]].



962
963
964
# File 'lib/schema_org/mixins/place.rb', line 962

def special_opening_hours_specification=(value)
  write_property(:special_opening_hours_specification, value)
end

#telephoneObject

The telephone number.



967
968
969
# File 'lib/schema_org/mixins/place.rb', line 967

def telephone
  read_property(:telephone)
end

#telephone=(value) ⇒ Object

The telephone number.



972
973
974
# File 'lib/schema_org/mixins/place.rb', line 972

def telephone=(value)
  write_property(:telephone, value)
end

#tour_booking_pageObject

A page providing information on how to book a tour of some [[Place]], such as an [[Accommodation]] or [[ApartmentComplex]] in a real estate setting, as well as other kinds of tours as appropriate.



977
978
979
# File 'lib/schema_org/mixins/place.rb', line 977

def tour_booking_page
  read_property(:tour_booking_page)
end

#tour_booking_page=(value) ⇒ Object

A page providing information on how to book a tour of some [[Place]], such as an [[Accommodation]] or [[ApartmentComplex]] in a real estate setting, as well as other kinds of tours as appropriate.



982
983
984
# File 'lib/schema_org/mixins/place.rb', line 982

def tour_booking_page=(value)
  write_property(:tour_booking_page, value)
end