Module: SchemaOrg::Mixins::PlayAction
- Includes:
- Action
- Included in:
- ExerciseAction, PerformAction, PlayAction
- Defined in:
- lib/schema_org/mixins/play_action.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#audience ⇒ Object
An intended audience, i.e.
-
#audience=(value) ⇒ Object
An intended audience, i.e.
-
#event ⇒ Object
Upcoming or past event associated with this place, organization, or action.
-
#event=(value) ⇒ Object
Upcoming or past event associated with this place, organization, or action.
Methods included from Action
#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, #start_time, #start_time=, #target, #target=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/schema_org/mixins/play_action.rb', line 11 def self.schema_property_definitions { audience: { schema_name: "audience", schema_url: "https://schema.org/audience", comment_lines: ["An intended audience, i.e. a group for whom something was created."].freeze, ranges: ["Audience"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["serviceAudience"].freeze }.freeze, event: { schema_name: "event", schema_url: "https://schema.org/event", comment_lines: ["Upcoming or past event associated with this place, organization, or action."].freeze, ranges: ["Event"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["events"].freeze }.freeze }.freeze end |
Instance Method Details
#audience ⇒ Object
An intended audience, i.e. a group for whom something was created.
Supersedes serviceAudience.
38 39 40 |
# File 'lib/schema_org/mixins/play_action.rb', line 38 def audience read_property(:audience) end |
#audience=(value) ⇒ Object
An intended audience, i.e. a group for whom something was created.
Supersedes serviceAudience.
44 45 46 |
# File 'lib/schema_org/mixins/play_action.rb', line 44 def audience=(value) write_property(:audience, value) end |
#event ⇒ Object
Upcoming or past event associated with this place, organization, or action.
Supersedes events.
50 51 52 |
# File 'lib/schema_org/mixins/play_action.rb', line 50 def event read_property(:event) end |
#event=(value) ⇒ Object
Upcoming or past event associated with this place, organization, or action.
Supersedes events.
56 57 58 |
# File 'lib/schema_org/mixins/play_action.rb', line 56 def event=(value) write_property(:event, value) end |