Module: SchemaOrg::Mixins::PriceSpecification

Includes:
StructuredValue
Included in:
CompoundPriceSpecification, DeliveryChargeSpecification, PaymentChargeSpecification, UnitPriceSpecification, PriceSpecification
Defined in:
lib/schema_org/mixins/price_specification.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/schema_org/mixins/price_specification.rb', line 11

def self.schema_property_definitions
  {
    eligible_quantity: {
      schema_name: "eligibleQuantity",
      schema_url: "https://schema.org/eligibleQuantity",
      comment_lines: ["The interval and unit of measurement of ordering quantities for which the offer or price specification is valid. This allows e.g. specifying that a certain freight charge is valid only for a certain quantity."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    eligible_transaction_volume: {
      schema_name: "eligibleTransactionVolume",
      schema_url: "https://schema.org/eligibleTransactionVolume",
      comment_lines: ["The transaction volume, in a monetary unit, for which the offer or price specification is valid, e.g. for indicating a minimal purchasing volume, to express free shipping above a certain order volume, or to limit the acceptance of credit cards to purchases to a certain minimal amount."].freeze,
      ranges: ["PriceSpecification"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    max_price: {
      schema_name: "maxPrice",
      schema_url: "https://schema.org/maxPrice",
      comment_lines: ["The highest price if the price is a range."].freeze,
      ranges: ["Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    membership_points_earned: {
      schema_name: "membershipPointsEarned",
      schema_url: "https://schema.org/membershipPointsEarned",
      comment_lines: ["The number of membership points earned by the member. If necessary, the unitText can be used to express the units the points are issued in. (E.g. stars, miles, etc.)"].freeze,
      ranges: ["Number", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    min_price: {
      schema_name: "minPrice",
      schema_url: "https://schema.org/minPrice",
      comment_lines: ["The lowest price if the price is a range."].freeze,
      ranges: ["Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    price: {
      schema_name: "price",
      schema_url: "https://schema.org/price",
      comment_lines: ["The offer price of a product, or of a price component when attached to PriceSpecification and its subtypes.\\n\\nUsage guidelines:\\n\\n* Use the [[priceCurrency]] property (with standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. \"USD\"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. \"BTC\"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. \"Ithaca HOUR\") instead of including [ambiguous symbols](http://en.wikipedia.org/wiki/Dollar_sign#Currencies_that_use_the_dollar_or_peso_sign) such as '$' in the value.\\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.\\n* Note that both [RDFa](http://www.w3.org/TR/xhtml-rdfa-primer/#using-the-content-attribute) and Microdata syntax allow the use of a \"content=\" attribute for publishing simple machine-readable values alongside more human-friendly formatting.\\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols."].freeze,
      ranges: ["Number", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    price_currency: {
      schema_name: "priceCurrency",
      schema_url: "https://schema.org/priceCurrency",
      comment_lines: ["The currency of the price, or a price component when attached to [[PriceSpecification]] and its subtypes.\\n\\nUse standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. \"USD\"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. \"BTC\"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. \"Ithaca HOUR\"."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    valid_for_member_tier: {
      schema_name: "validForMemberTier",
      schema_url: "https://schema.org/validForMemberTier",
      comment_lines: ["The membership program tier(s) an Offer (or a PriceSpecification, OfferShippingDetails, or MerchantReturnPolicy under an Offer) is valid for."].freeze,
      ranges: ["MemberProgramTier"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    valid_from: {
      schema_name: "validFrom",
      schema_url: "https://schema.org/validFrom",
      comment_lines: ["The date when the item becomes valid."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    valid_through: {
      schema_name: "validThrough",
      schema_url: "https://schema.org/validThrough",
      comment_lines: ["The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    value_added_tax_included: {
      schema_name: "valueAddedTaxIncluded",
      schema_url: "https://schema.org/valueAddedTaxIncluded",
      comment_lines: ["Specifies whether the applicable value-added tax (VAT) is included in the price specification or not."].freeze,
      ranges: ["Boolean"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#eligible_quantityObject

The interval and unit of measurement of ordering quantities for which the offer or price specification is valid. This allows e.g. specifying that a certain freight charge is valid only for a certain quantity.



127
128
129
# File 'lib/schema_org/mixins/price_specification.rb', line 127

def eligible_quantity
  read_property(:eligible_quantity)
end

#eligible_quantity=(value) ⇒ Object

The interval and unit of measurement of ordering quantities for which the offer or price specification is valid. This allows e.g. specifying that a certain freight charge is valid only for a certain quantity.



132
133
134
# File 'lib/schema_org/mixins/price_specification.rb', line 132

def eligible_quantity=(value)
  write_property(:eligible_quantity, value)
end

#eligible_transaction_volumeObject

The transaction volume, in a monetary unit, for which the offer or price specification is valid, e.g. for indicating a minimal purchasing volume, to express free shipping above a certain order volume, or to limit the acceptance of credit cards to purchases to a certain minimal amount.



137
138
139
# File 'lib/schema_org/mixins/price_specification.rb', line 137

def eligible_transaction_volume
  read_property(:eligible_transaction_volume)
end

#eligible_transaction_volume=(value) ⇒ Object

The transaction volume, in a monetary unit, for which the offer or price specification is valid, e.g. for indicating a minimal purchasing volume, to express free shipping above a certain order volume, or to limit the acceptance of credit cards to purchases to a certain minimal amount.



142
143
144
# File 'lib/schema_org/mixins/price_specification.rb', line 142

def eligible_transaction_volume=(value)
  write_property(:eligible_transaction_volume, value)
end

#max_priceObject

The highest price if the price is a range.



147
148
149
# File 'lib/schema_org/mixins/price_specification.rb', line 147

def max_price
  read_property(:max_price)
end

#max_price=(value) ⇒ Object

The highest price if the price is a range.



152
153
154
# File 'lib/schema_org/mixins/price_specification.rb', line 152

def max_price=(value)
  write_property(:max_price, value)
end

#membership_points_earnedObject

The number of membership points earned by the member. If necessary, the unitText can be used to express the units the points are issued in. (E.g. stars, miles, etc.)



157
158
159
# File 'lib/schema_org/mixins/price_specification.rb', line 157

def membership_points_earned
  read_property(:membership_points_earned)
end

#membership_points_earned=(value) ⇒ Object

The number of membership points earned by the member. If necessary, the unitText can be used to express the units the points are issued in. (E.g. stars, miles, etc.)



162
163
164
# File 'lib/schema_org/mixins/price_specification.rb', line 162

def membership_points_earned=(value)
  write_property(:membership_points_earned, value)
end

#min_priceObject

The lowest price if the price is a range.



167
168
169
# File 'lib/schema_org/mixins/price_specification.rb', line 167

def min_price
  read_property(:min_price)
end

#min_price=(value) ⇒ Object

The lowest price if the price is a range.



172
173
174
# File 'lib/schema_org/mixins/price_specification.rb', line 172

def min_price=(value)
  write_property(:min_price, value)
end

#priceObject

The offer price of a product, or of a price component when attached to PriceSpecification and its subtypes.\n\nUsage guidelines:\n\n* Use the [[priceCurrency]] property (with standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR") instead of including ambiguous symbols such as '$' in the value.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.\n* Note that both RDFa and Microdata syntax allow the use of a "content=" attribute for publishing simple machine-readable values alongside more human-friendly formatting.\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.



177
178
179
# File 'lib/schema_org/mixins/price_specification.rb', line 177

def price
  read_property(:price)
end

#price=(value) ⇒ Object

The offer price of a product, or of a price component when attached to PriceSpecification and its subtypes.\n\nUsage guidelines:\n\n* Use the [[priceCurrency]] property (with standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR") instead of including ambiguous symbols such as '$' in the value.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.\n* Note that both RDFa and Microdata syntax allow the use of a "content=" attribute for publishing simple machine-readable values alongside more human-friendly formatting.\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.



182
183
184
# File 'lib/schema_org/mixins/price_specification.rb', line 182

def price=(value)
  write_property(:price, value)
end

#price_currencyObject

The currency of the price, or a price component when attached to [[PriceSpecification]] and its subtypes.\n\nUse standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR".



187
188
189
# File 'lib/schema_org/mixins/price_specification.rb', line 187

def price_currency
  read_property(:price_currency)
end

#price_currency=(value) ⇒ Object

The currency of the price, or a price component when attached to [[PriceSpecification]] and its subtypes.\n\nUse standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR".



192
193
194
# File 'lib/schema_org/mixins/price_specification.rb', line 192

def price_currency=(value)
  write_property(:price_currency, value)
end

#valid_for_member_tierObject

The membership program tier(s) an Offer (or a PriceSpecification, OfferShippingDetails, or MerchantReturnPolicy under an Offer) is valid for.



197
198
199
# File 'lib/schema_org/mixins/price_specification.rb', line 197

def valid_for_member_tier
  read_property(:valid_for_member_tier)
end

#valid_for_member_tier=(value) ⇒ Object

The membership program tier(s) an Offer (or a PriceSpecification, OfferShippingDetails, or MerchantReturnPolicy under an Offer) is valid for.



202
203
204
# File 'lib/schema_org/mixins/price_specification.rb', line 202

def valid_for_member_tier=(value)
  write_property(:valid_for_member_tier, value)
end

#valid_fromObject

The date when the item becomes valid.



207
208
209
# File 'lib/schema_org/mixins/price_specification.rb', line 207

def valid_from
  read_property(:valid_from)
end

#valid_from=(value) ⇒ Object

The date when the item becomes valid.



212
213
214
# File 'lib/schema_org/mixins/price_specification.rb', line 212

def valid_from=(value)
  write_property(:valid_from, value)
end

#valid_throughObject

The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.



217
218
219
# File 'lib/schema_org/mixins/price_specification.rb', line 217

def valid_through
  read_property(:valid_through)
end

#valid_through=(value) ⇒ Object

The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.



222
223
224
# File 'lib/schema_org/mixins/price_specification.rb', line 222

def valid_through=(value)
  write_property(:valid_through, value)
end

#value_added_tax_includedObject

Specifies whether the applicable value-added tax (VAT) is included in the price specification or not.



227
228
229
# File 'lib/schema_org/mixins/price_specification.rb', line 227

def value_added_tax_included
  read_property(:value_added_tax_included)
end

#value_added_tax_included=(value) ⇒ Object

Specifies whether the applicable value-added tax (VAT) is included in the price specification or not.



232
233
234
# File 'lib/schema_org/mixins/price_specification.rb', line 232

def value_added_tax_included=(value)
  write_property(:value_added_tax_included, value)
end