Module: SchemaOrg::Mixins::ProgramMembership

Includes:
Intangible
Included in:
ProgramMembership
Defined in:
lib/schema_org/mixins/program_membership.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/schema_org/mixins/program_membership.rb', line 11

def self.schema_property_definitions
  {
    hosting_organization: {
      schema_name: "hostingOrganization",
      schema_url: "https://schema.org/hostingOrganization",
      comment_lines: ["The Organization (airline, travelers' club, retailer, etc.) the membership is made with or which offers the  MemberProgram."].freeze,
      ranges: ["Organization"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    member: {
      schema_name: "member",
      schema_url: "https://schema.org/member",
      comment_lines: ["A member of an Organization or a ProgramMembership. Organizations can be members of organizations; ProgramMembership is typically for individuals."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: "memberOf",
      superseded_by: nil,
      supersedes: ["members", "musicGroupMember"].freeze
    }.freeze,
    members: {
      schema_name: "members",
      schema_url: "https://schema.org/members",
      comment_lines: ["A member of this organization."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "member",
      supersedes: nil
    }.freeze,
    membership_number: {
      schema_name: "membershipNumber",
      schema_url: "https://schema.org/membershipNumber",
      comment_lines: ["A unique identifier for the membership."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    membership_points_earned: {
      schema_name: "membershipPointsEarned",
      schema_url: "https://schema.org/membershipPointsEarned",
      comment_lines: ["The number of membership points earned by the member. If necessary, the unitText can be used to express the units the points are issued in. (E.g. stars, miles, etc.)"].freeze,
      ranges: ["Number", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    program: {
      schema_name: "program",
      schema_url: "https://schema.org/program",
      comment_lines: ["The [MemberProgram](https://schema.org/MemberProgram) associated with a [ProgramMembership](https://schema.org/ProgramMembership)."].freeze,
      ranges: ["MemberProgram"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    program_name: {
      schema_name: "programName",
      schema_url: "https://schema.org/programName",
      comment_lines: ["The program providing the membership. It is preferable to use [:program](https://schema.org/program) instead."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#hosting_organizationObject

The Organization (airline, travelers' club, retailer, etc.) the membership is made with or which offers the MemberProgram.



87
88
89
# File 'lib/schema_org/mixins/program_membership.rb', line 87

def hosting_organization
  read_property(:hosting_organization)
end

#hosting_organization=(value) ⇒ Object

The Organization (airline, travelers' club, retailer, etc.) the membership is made with or which offers the MemberProgram.



92
93
94
# File 'lib/schema_org/mixins/program_membership.rb', line 92

def hosting_organization=(value)
  write_property(:hosting_organization, value)
end

#memberObject

A member of an Organization or a ProgramMembership. Organizations can be members of organizations; ProgramMembership is typically for individuals. Supersedes members. Supersedes musicGroupMember. Inverse-property: memberOf.



100
101
102
# File 'lib/schema_org/mixins/program_membership.rb', line 100

def member
  read_property(:member)
end

#member=(value) ⇒ Object

A member of an Organization or a ProgramMembership. Organizations can be members of organizations; ProgramMembership is typically for individuals. Supersedes members. Supersedes musicGroupMember. Inverse-property: memberOf.



108
109
110
# File 'lib/schema_org/mixins/program_membership.rb', line 108

def member=(value)
  write_property(:member, value)
end

#membersObject

A member of this organization. Superseded by member.



114
115
116
# File 'lib/schema_org/mixins/program_membership.rb', line 114

def members
  read_property(:members)
end

#members=(value) ⇒ Object

A member of this organization. Superseded by member.



120
121
122
# File 'lib/schema_org/mixins/program_membership.rb', line 120

def members=(value)
  write_property(:members, value)
end

#membership_numberObject

A unique identifier for the membership.



125
126
127
# File 'lib/schema_org/mixins/program_membership.rb', line 125

def membership_number
  read_property(:membership_number)
end

#membership_number=(value) ⇒ Object

A unique identifier for the membership.



130
131
132
# File 'lib/schema_org/mixins/program_membership.rb', line 130

def membership_number=(value)
  write_property(:membership_number, value)
end

#membership_points_earnedObject

The number of membership points earned by the member. If necessary, the unitText can be used to express the units the points are issued in. (E.g. stars, miles, etc.)



135
136
137
# File 'lib/schema_org/mixins/program_membership.rb', line 135

def membership_points_earned
  read_property(:membership_points_earned)
end

#membership_points_earned=(value) ⇒ Object

The number of membership points earned by the member. If necessary, the unitText can be used to express the units the points are issued in. (E.g. stars, miles, etc.)



140
141
142
# File 'lib/schema_org/mixins/program_membership.rb', line 140

def membership_points_earned=(value)
  write_property(:membership_points_earned, value)
end

#programObject

The MemberProgram associated with a ProgramMembership.



145
146
147
# File 'lib/schema_org/mixins/program_membership.rb', line 145

def program
  read_property(:program)
end

#program=(value) ⇒ Object

The MemberProgram associated with a ProgramMembership.



150
151
152
# File 'lib/schema_org/mixins/program_membership.rb', line 150

def program=(value)
  write_property(:program, value)
end

#program_nameObject

The program providing the membership. It is preferable to use :program instead.



155
156
157
# File 'lib/schema_org/mixins/program_membership.rb', line 155

def program_name
  read_property(:program_name)
end

#program_name=(value) ⇒ Object

The program providing the membership. It is preferable to use :program instead.



160
161
162
# File 'lib/schema_org/mixins/program_membership.rb', line 160

def program_name=(value)
  write_property(:program_name, value)
end