Module: SchemaOrg::Mixins::PublicationEvent

Includes:
Event
Included in:
BroadcastEvent, OnDemandEvent, PublicationEvent
Defined in:
lib/schema_org/mixins/publication_event.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Event

#about, #about=, #actor, #actor=, #aggregate_rating, #aggregate_rating=, #attendee, #attendee=, #attendees, #attendees=, #audience, #audience=, #composer, #composer=, #contributor, #contributor=, #director, #director=, #door_time, #door_time=, #duration, #duration=, #end_date, #end_date=, #event_attendance_mode, #event_attendance_mode=, #event_schedule, #event_schedule=, #event_status, #event_status=, #funder, #funder=, #funding, #funding=, #has_participation_offer, #has_participation_offer=, #has_sponsorship_offer, #has_sponsorship_offer=, #in_language, #in_language=, #is_accessible_for_free, #is_accessible_for_free=, #keywords, #keywords=, #location, #location=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #maximum_physical_attendee_capacity, #maximum_physical_attendee_capacity=, #maximum_virtual_attendee_capacity, #maximum_virtual_attendee_capacity=, #offers, #offers=, #organizer, #organizer=, #performer, #performer=, #performers, #performers=, #previous_start_date, #previous_start_date=, #recorded_in, #recorded_in=, #remaining_attendee_capacity, #remaining_attendee_capacity=, #review, #review=, #sponsor, #sponsor=, #start_date, #start_date=, #sub_event, #sub_event=, #sub_events, #sub_events=, #super_event, #super_event=, #translator, #translator=, #typical_age_range, #typical_age_range=, #work_featured, #work_featured=, #work_performed, #work_performed=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/schema_org/mixins/publication_event.rb', line 11

def self.schema_property_definitions
  {
    free: {
      schema_name: "free",
      schema_url: "https://schema.org/free",
      comment_lines: ["A flag to signal that the item, event, or place is accessible for free."].freeze,
      ranges: ["Boolean"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "isAccessibleForFree",
      supersedes: nil
    }.freeze,
    published_by: {
      schema_name: "publishedBy",
      schema_url: "https://schema.org/publishedBy",
      comment_lines: ["An agent associated with the publication event."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    published_on: {
      schema_name: "publishedOn",
      schema_url: "https://schema.org/publishedOn",
      comment_lines: ["A broadcast service associated with the publication event."].freeze,
      ranges: ["BroadcastService"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#freeObject

A flag to signal that the item, event, or place is accessible for free. Superseded by isAccessibleForFree.



48
49
50
# File 'lib/schema_org/mixins/publication_event.rb', line 48

def free
  read_property(:free)
end

#free=(value) ⇒ Object

A flag to signal that the item, event, or place is accessible for free. Superseded by isAccessibleForFree.



54
55
56
# File 'lib/schema_org/mixins/publication_event.rb', line 54

def free=(value)
  write_property(:free, value)
end

#published_byObject

An agent associated with the publication event.



59
60
61
# File 'lib/schema_org/mixins/publication_event.rb', line 59

def published_by
  read_property(:published_by)
end

#published_by=(value) ⇒ Object

An agent associated with the publication event.



64
65
66
# File 'lib/schema_org/mixins/publication_event.rb', line 64

def published_by=(value)
  write_property(:published_by, value)
end

#published_onObject

A broadcast service associated with the publication event.



69
70
71
# File 'lib/schema_org/mixins/publication_event.rb', line 69

def published_on
  read_property(:published_on)
end

#published_on=(value) ⇒ Object

A broadcast service associated with the publication event.



74
75
76
# File 'lib/schema_org/mixins/publication_event.rb', line 74

def published_on=(value)
  write_property(:published_on, value)
end