Module: SchemaOrg::Mixins::RadioSeries

Includes:
CreativeWorkSeries
Included in:
RadioSeries
Defined in:
lib/schema_org/mixins/radio_series.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from CreativeWorkSeries

#end_date, #end_date=, #issn, #issn=, #start_date, #start_date=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Methods included from CreativeWork

#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/schema_org/mixins/radio_series.rb', line 11

def self.schema_property_definitions
  {
    actor: {
      schema_name: "actor",
      schema_url: "https://schema.org/actor",
      comment_lines: ["An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip."].freeze,
      ranges: ["PerformingGroup", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["actors"].freeze
    }.freeze,
    actors: {
      schema_name: "actors",
      schema_url: "https://schema.org/actors",
      comment_lines: ["An actor, e.g. in TV, radio, movie, video games etc. Actors can be associated with individual items or with a series, episode, clip."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "actor",
      supersedes: nil
    }.freeze,
    contains_season: {
      schema_name: "containsSeason",
      schema_url: "https://schema.org/containsSeason",
      comment_lines: ["A season that is part of the media series."].freeze,
      ranges: ["CreativeWorkSeason"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["season"].freeze
    }.freeze,
    director: {
      schema_name: "director",
      schema_url: "https://schema.org/director",
      comment_lines: ["A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["directors"].freeze
    }.freeze,
    directors: {
      schema_name: "directors",
      schema_url: "https://schema.org/directors",
      comment_lines: ["A director of e.g. TV, radio, movie, video games etc. content. Directors can be associated with individual items or with a series, episode, clip."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "director",
      supersedes: nil
    }.freeze,
    episode: {
      schema_name: "episode",
      schema_url: "https://schema.org/episode",
      comment_lines: ["An episode of a TV, radio or game media within a series or season."].freeze,
      ranges: ["Episode"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["episodes"].freeze
    }.freeze,
    episodes: {
      schema_name: "episodes",
      schema_url: "https://schema.org/episodes",
      comment_lines: ["An episode of a TV/radio series or season."].freeze,
      ranges: ["Episode"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "episode",
      supersedes: nil
    }.freeze,
    music_by: {
      schema_name: "musicBy",
      schema_url: "https://schema.org/musicBy",
      comment_lines: ["The composer of the soundtrack."].freeze,
      ranges: ["MusicGroup", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    number_of_episodes: {
      schema_name: "numberOfEpisodes",
      schema_url: "https://schema.org/numberOfEpisodes",
      comment_lines: ["The number of episodes in this season or series."].freeze,
      ranges: ["Integer"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    number_of_seasons: {
      schema_name: "numberOfSeasons",
      schema_url: "https://schema.org/numberOfSeasons",
      comment_lines: ["The number of seasons in this series."].freeze,
      ranges: ["Integer"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    production_company: {
      schema_name: "productionCompany",
      schema_url: "https://schema.org/productionCompany",
      comment_lines: ["The production company or studio responsible for the item, e.g. series, video game, episode etc."].freeze,
      ranges: ["Organization"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    season: {
      schema_name: "season",
      schema_url: "https://schema.org/season",
      comment_lines: ["A season in a media series."].freeze,
      ranges: ["CreativeWorkSeason", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "containsSeason",
      supersedes: ["seasons"].freeze
    }.freeze,
    seasons: {
      schema_name: "seasons",
      schema_url: "https://schema.org/seasons",
      comment_lines: ["A season in a media series."].freeze,
      ranges: ["CreativeWorkSeason"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "season",
      supersedes: nil
    }.freeze,
    trailer: {
      schema_name: "trailer",
      schema_url: "https://schema.org/trailer",
      comment_lines: ["The trailer of a movie or TV/radio series, season, episode, etc."].freeze,
      ranges: ["VideoObject"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#actorObject

An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip. Supersedes actors.



158
159
160
# File 'lib/schema_org/mixins/radio_series.rb', line 158

def actor
  read_property(:actor)
end

#actor=(value) ⇒ Object

An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip. Supersedes actors.



164
165
166
# File 'lib/schema_org/mixins/radio_series.rb', line 164

def actor=(value)
  write_property(:actor, value)
end

#actorsObject

An actor, e.g. in TV, radio, movie, video games etc. Actors can be associated with individual items or with a series, episode, clip. Superseded by actor.



170
171
172
# File 'lib/schema_org/mixins/radio_series.rb', line 170

def actors
  read_property(:actors)
end

#actors=(value) ⇒ Object

An actor, e.g. in TV, radio, movie, video games etc. Actors can be associated with individual items or with a series, episode, clip. Superseded by actor.



176
177
178
# File 'lib/schema_org/mixins/radio_series.rb', line 176

def actors=(value)
  write_property(:actors, value)
end

#contains_seasonObject

A season that is part of the media series. Supersedes season.



182
183
184
# File 'lib/schema_org/mixins/radio_series.rb', line 182

def contains_season
  read_property(:contains_season)
end

#contains_season=(value) ⇒ Object

A season that is part of the media series. Supersedes season.



188
189
190
# File 'lib/schema_org/mixins/radio_series.rb', line 188

def contains_season=(value)
  write_property(:contains_season, value)
end

#directorObject

A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip. Supersedes directors.



194
195
196
# File 'lib/schema_org/mixins/radio_series.rb', line 194

def director
  read_property(:director)
end

#director=(value) ⇒ Object

A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip. Supersedes directors.



200
201
202
# File 'lib/schema_org/mixins/radio_series.rb', line 200

def director=(value)
  write_property(:director, value)
end

#directorsObject

A director of e.g. TV, radio, movie, video games etc. content. Directors can be associated with individual items or with a series, episode, clip. Superseded by director.



206
207
208
# File 'lib/schema_org/mixins/radio_series.rb', line 206

def directors
  read_property(:directors)
end

#directors=(value) ⇒ Object

A director of e.g. TV, radio, movie, video games etc. content. Directors can be associated with individual items or with a series, episode, clip. Superseded by director.



212
213
214
# File 'lib/schema_org/mixins/radio_series.rb', line 212

def directors=(value)
  write_property(:directors, value)
end

#episodeObject

An episode of a TV, radio or game media within a series or season. Supersedes episodes.



218
219
220
# File 'lib/schema_org/mixins/radio_series.rb', line 218

def episode
  read_property(:episode)
end

#episode=(value) ⇒ Object

An episode of a TV, radio or game media within a series or season. Supersedes episodes.



224
225
226
# File 'lib/schema_org/mixins/radio_series.rb', line 224

def episode=(value)
  write_property(:episode, value)
end

#episodesObject

An episode of a TV/radio series or season. Superseded by episode.



230
231
232
# File 'lib/schema_org/mixins/radio_series.rb', line 230

def episodes
  read_property(:episodes)
end

#episodes=(value) ⇒ Object

An episode of a TV/radio series or season. Superseded by episode.



236
237
238
# File 'lib/schema_org/mixins/radio_series.rb', line 236

def episodes=(value)
  write_property(:episodes, value)
end

#music_byObject

The composer of the soundtrack.



241
242
243
# File 'lib/schema_org/mixins/radio_series.rb', line 241

def music_by
  read_property(:music_by)
end

#music_by=(value) ⇒ Object

The composer of the soundtrack.



246
247
248
# File 'lib/schema_org/mixins/radio_series.rb', line 246

def music_by=(value)
  write_property(:music_by, value)
end

#number_of_episodesObject

The number of episodes in this season or series.



251
252
253
# File 'lib/schema_org/mixins/radio_series.rb', line 251

def number_of_episodes
  read_property(:number_of_episodes)
end

#number_of_episodes=(value) ⇒ Object

The number of episodes in this season or series.



256
257
258
# File 'lib/schema_org/mixins/radio_series.rb', line 256

def number_of_episodes=(value)
  write_property(:number_of_episodes, value)
end

#number_of_seasonsObject

The number of seasons in this series.



261
262
263
# File 'lib/schema_org/mixins/radio_series.rb', line 261

def number_of_seasons
  read_property(:number_of_seasons)
end

#number_of_seasons=(value) ⇒ Object

The number of seasons in this series.



266
267
268
# File 'lib/schema_org/mixins/radio_series.rb', line 266

def number_of_seasons=(value)
  write_property(:number_of_seasons, value)
end

#production_companyObject

The production company or studio responsible for the item, e.g. series, video game, episode etc.



271
272
273
# File 'lib/schema_org/mixins/radio_series.rb', line 271

def production_company
  read_property(:production_company)
end

#production_company=(value) ⇒ Object

The production company or studio responsible for the item, e.g. series, video game, episode etc.



276
277
278
# File 'lib/schema_org/mixins/radio_series.rb', line 276

def production_company=(value)
  write_property(:production_company, value)
end

#seasonObject

A season in a media series. Supersedes seasons. Superseded by containsSeason.



283
284
285
# File 'lib/schema_org/mixins/radio_series.rb', line 283

def season
  read_property(:season)
end

#season=(value) ⇒ Object

A season in a media series. Supersedes seasons. Superseded by containsSeason.



290
291
292
# File 'lib/schema_org/mixins/radio_series.rb', line 290

def season=(value)
  write_property(:season, value)
end

#seasonsObject

A season in a media series. Superseded by season.



296
297
298
# File 'lib/schema_org/mixins/radio_series.rb', line 296

def seasons
  read_property(:seasons)
end

#seasons=(value) ⇒ Object

A season in a media series. Superseded by season.



302
303
304
# File 'lib/schema_org/mixins/radio_series.rb', line 302

def seasons=(value)
  write_property(:seasons, value)
end

#trailerObject

The trailer of a movie or TV/radio series, season, episode, etc.



307
308
309
# File 'lib/schema_org/mixins/radio_series.rb', line 307

def trailer
  read_property(:trailer)
end

#trailer=(value) ⇒ Object

The trailer of a movie or TV/radio series, season, episode, etc.



312
313
314
# File 'lib/schema_org/mixins/radio_series.rb', line 312

def trailer=(value)
  write_property(:trailer, value)
end