Module: SchemaOrg::Mixins::ReceiveAction

Includes:
TransferAction
Included in:
ReceiveAction
Defined in:
lib/schema_org/mixins/receive_action.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from TransferAction

#from_location, #from_location=, #to_location, #to_location=

Methods included from Action

#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, #start_time, #start_time=, #target, #target=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/schema_org/mixins/receive_action.rb', line 11

def self.schema_property_definitions
  {
    delivery_method: {
      schema_name: "deliveryMethod",
      schema_url: "https://schema.org/deliveryMethod",
      comment_lines: ["A sub property of instrument. The method of delivery."].freeze,
      ranges: ["DeliveryMethod"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    sender: {
      schema_name: "sender",
      schema_url: "https://schema.org/sender",
      comment_lines: ["A sub property of participant. The participant who is at the sending end of the action."].freeze,
      ranges: ["Audience", "Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#delivery_methodObject

A sub property of instrument. The method of delivery.



37
38
39
# File 'lib/schema_org/mixins/receive_action.rb', line 37

def delivery_method
  read_property(:delivery_method)
end

#delivery_method=(value) ⇒ Object

A sub property of instrument. The method of delivery.



42
43
44
# File 'lib/schema_org/mixins/receive_action.rb', line 42

def delivery_method=(value)
  write_property(:delivery_method, value)
end

#senderObject

A sub property of participant. The participant who is at the sending end of the action.



47
48
49
# File 'lib/schema_org/mixins/receive_action.rb', line 47

def sender
  read_property(:sender)
end

#sender=(value) ⇒ Object

A sub property of participant. The participant who is at the sending end of the action.



52
53
54
# File 'lib/schema_org/mixins/receive_action.rb', line 52

def sender=(value)
  write_property(:sender, value)
end