Module: SchemaOrg::Mixins::Recipe

Includes:
HowTo
Included in:
Recipe
Defined in:
lib/schema_org/mixins/recipe.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from HowTo

#estimated_cost, #estimated_cost=, #perform_time, #perform_time=, #prep_time, #prep_time=, #step, #step=, #steps, #steps=, #supply, #supply=, #tool, #tool=, #total_time, #total_time=, #yield, #yield=

Methods included from CreativeWork

#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/schema_org/mixins/recipe.rb', line 11

def self.schema_property_definitions
  {
    cook_time: {
      schema_name: "cookTime",
      schema_url: "https://schema.org/cookTime",
      comment_lines: ["The time it takes to actually cook the dish, in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601)."].freeze,
      ranges: ["Duration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    cooking_method: {
      schema_name: "cookingMethod",
      schema_url: "https://schema.org/cookingMethod",
      comment_lines: ["The method of cooking, such as Frying, Steaming, ..."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    ingredients: {
      schema_name: "ingredients",
      schema_url: "https://schema.org/ingredients",
      comment_lines: ["A single ingredient used in the recipe, e.g. sugar, flour or garlic."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "recipeIngredient",
      supersedes: nil
    }.freeze,
    nutrition: {
      schema_name: "nutrition",
      schema_url: "https://schema.org/nutrition",
      comment_lines: ["Nutrition information about the recipe or menu item."].freeze,
      ranges: ["NutritionInformation"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    recipe_category: {
      schema_name: "recipeCategory",
      schema_url: "https://schema.org/recipeCategory",
      comment_lines: ["The category of the recipe—for example, appetizer, entree, etc."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    recipe_cuisine: {
      schema_name: "recipeCuisine",
      schema_url: "https://schema.org/recipeCuisine",
      comment_lines: ["The cuisine of the recipe (for example, French or Ethiopian)."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    recipe_ingredient: {
      schema_name: "recipeIngredient",
      schema_url: "https://schema.org/recipeIngredient",
      comment_lines: ["An ingredient or ordered list of ingredients and potentially quantities used in the recipe, e.g. 1 cup of sugar, flour or garlic.  The ingredients can be represented as free text or more structured values."].freeze,
      ranges: ["ItemList", "PropertyValue", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["ingredients"].freeze
    }.freeze,
    recipe_instructions: {
      schema_name: "recipeInstructions",
      schema_url: "https://schema.org/recipeInstructions",
      comment_lines: ["A step in making the recipe, in the form of a single item (document, video, etc.) or an ordered list with HowToStep and/or HowToSection items."].freeze,
      ranges: ["CreativeWork", "ItemList", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    recipe_yield: {
      schema_name: "recipeYield",
      schema_url: "https://schema.org/recipeYield",
      comment_lines: ["The quantity produced by the recipe (for example, number of people served, number of servings, etc)."].freeze,
      ranges: ["QuantitativeValue", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    suitable_for_diet: {
      schema_name: "suitableForDiet",
      schema_url: "https://schema.org/suitableForDiet",
      comment_lines: ["Indicates a dietary restriction or guideline for which this recipe or menu item is suitable, e.g. diabetic, halal etc."].freeze,
      ranges: ["Diet", "RestrictedDiet"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#cook_timeObject

The time it takes to actually cook the dish, in ISO 8601 duration format.



117
118
119
# File 'lib/schema_org/mixins/recipe.rb', line 117

def cook_time
  read_property(:cook_time)
end

#cook_time=(value) ⇒ Object

The time it takes to actually cook the dish, in ISO 8601 duration format.



122
123
124
# File 'lib/schema_org/mixins/recipe.rb', line 122

def cook_time=(value)
  write_property(:cook_time, value)
end

#cooking_methodObject

The method of cooking, such as Frying, Steaming, ...



127
128
129
# File 'lib/schema_org/mixins/recipe.rb', line 127

def cooking_method
  read_property(:cooking_method)
end

#cooking_method=(value) ⇒ Object

The method of cooking, such as Frying, Steaming, ...



132
133
134
# File 'lib/schema_org/mixins/recipe.rb', line 132

def cooking_method=(value)
  write_property(:cooking_method, value)
end

#ingredientsObject

A single ingredient used in the recipe, e.g. sugar, flour or garlic. Superseded by recipeIngredient.



138
139
140
# File 'lib/schema_org/mixins/recipe.rb', line 138

def ingredients
  read_property(:ingredients)
end

#ingredients=(value) ⇒ Object

A single ingredient used in the recipe, e.g. sugar, flour or garlic. Superseded by recipeIngredient.



144
145
146
# File 'lib/schema_org/mixins/recipe.rb', line 144

def ingredients=(value)
  write_property(:ingredients, value)
end

#nutritionObject

Nutrition information about the recipe or menu item.



149
150
151
# File 'lib/schema_org/mixins/recipe.rb', line 149

def nutrition
  read_property(:nutrition)
end

#nutrition=(value) ⇒ Object

Nutrition information about the recipe or menu item.



154
155
156
# File 'lib/schema_org/mixins/recipe.rb', line 154

def nutrition=(value)
  write_property(:nutrition, value)
end

#recipe_categoryObject

The category of the recipe—for example, appetizer, entree, etc.



159
160
161
# File 'lib/schema_org/mixins/recipe.rb', line 159

def recipe_category
  read_property(:recipe_category)
end

#recipe_category=(value) ⇒ Object

The category of the recipe—for example, appetizer, entree, etc.



164
165
166
# File 'lib/schema_org/mixins/recipe.rb', line 164

def recipe_category=(value)
  write_property(:recipe_category, value)
end

#recipe_cuisineObject

The cuisine of the recipe (for example, French or Ethiopian).



169
170
171
# File 'lib/schema_org/mixins/recipe.rb', line 169

def recipe_cuisine
  read_property(:recipe_cuisine)
end

#recipe_cuisine=(value) ⇒ Object

The cuisine of the recipe (for example, French or Ethiopian).



174
175
176
# File 'lib/schema_org/mixins/recipe.rb', line 174

def recipe_cuisine=(value)
  write_property(:recipe_cuisine, value)
end

#recipe_ingredientObject

An ingredient or ordered list of ingredients and potentially quantities used in the recipe, e.g. 1 cup of sugar, flour or garlic. The ingredients can be represented as free text or more structured values. Supersedes ingredients.



180
181
182
# File 'lib/schema_org/mixins/recipe.rb', line 180

def recipe_ingredient
  read_property(:recipe_ingredient)
end

#recipe_ingredient=(value) ⇒ Object

An ingredient or ordered list of ingredients and potentially quantities used in the recipe, e.g. 1 cup of sugar, flour or garlic. The ingredients can be represented as free text or more structured values. Supersedes ingredients.



186
187
188
# File 'lib/schema_org/mixins/recipe.rb', line 186

def recipe_ingredient=(value)
  write_property(:recipe_ingredient, value)
end

#recipe_instructionsObject

A step in making the recipe, in the form of a single item (document, video, etc.) or an ordered list with HowToStep and/or HowToSection items.



191
192
193
# File 'lib/schema_org/mixins/recipe.rb', line 191

def recipe_instructions
  read_property(:recipe_instructions)
end

#recipe_instructions=(value) ⇒ Object

A step in making the recipe, in the form of a single item (document, video, etc.) or an ordered list with HowToStep and/or HowToSection items.



196
197
198
# File 'lib/schema_org/mixins/recipe.rb', line 196

def recipe_instructions=(value)
  write_property(:recipe_instructions, value)
end

#recipe_yieldObject

The quantity produced by the recipe (for example, number of people served, number of servings, etc).



201
202
203
# File 'lib/schema_org/mixins/recipe.rb', line 201

def recipe_yield
  read_property(:recipe_yield)
end

#recipe_yield=(value) ⇒ Object

The quantity produced by the recipe (for example, number of people served, number of servings, etc).



206
207
208
# File 'lib/schema_org/mixins/recipe.rb', line 206

def recipe_yield=(value)
  write_property(:recipe_yield, value)
end

#suitable_for_dietObject

Indicates a dietary restriction or guideline for which this recipe or menu item is suitable, e.g. diabetic, halal etc.



211
212
213
# File 'lib/schema_org/mixins/recipe.rb', line 211

def suitable_for_diet
  read_property(:suitable_for_diet)
end

#suitable_for_diet=(value) ⇒ Object

Indicates a dietary restriction or guideline for which this recipe or menu item is suitable, e.g. diabetic, halal etc.



216
217
218
# File 'lib/schema_org/mixins/recipe.rb', line 216

def suitable_for_diet=(value)
  write_property(:suitable_for_diet, value)
end