Module: SchemaOrg::Mixins::RepaymentSpecification

Includes:
StructuredValue
Included in:
RepaymentSpecification
Defined in:
lib/schema_org/mixins/repayment_specification.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/schema_org/mixins/repayment_specification.rb', line 11

def self.schema_property_definitions
  {
    down_payment: {
      schema_name: "downPayment",
      schema_url: "https://schema.org/downPayment",
      comment_lines: ["a type of payment made in cash during the onset of the purchase of an expensive good/service. The payment typically represents only a percentage of the full purchase price."].freeze,
      ranges: ["MonetaryAmount", "Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    early_prepayment_penalty: {
      schema_name: "earlyPrepaymentPenalty",
      schema_url: "https://schema.org/earlyPrepaymentPenalty",
      comment_lines: ["The amount to be paid as a penalty in the event of early payment of the loan."].freeze,
      ranges: ["MonetaryAmount"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    loan_payment_amount: {
      schema_name: "loanPaymentAmount",
      schema_url: "https://schema.org/loanPaymentAmount",
      comment_lines: ["The amount of money to pay in a single payment."].freeze,
      ranges: ["MonetaryAmount"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    loan_payment_frequency: {
      schema_name: "loanPaymentFrequency",
      schema_url: "https://schema.org/loanPaymentFrequency",
      comment_lines: ["Frequency of payments due, i.e. number of months between payments. This is defined as a frequency, i.e. the reciprocal of a period of time."].freeze,
      ranges: ["Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    number_of_loan_payments: {
      schema_name: "numberOfLoanPayments",
      schema_url: "https://schema.org/numberOfLoanPayments",
      comment_lines: ["The number of payments contractually required at origination to repay the loan. For monthly paying loans this is the number of months from the contractual first payment date to the maturity date."].freeze,
      ranges: ["Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#down_paymentObject

a type of payment made in cash during the onset of the purchase of an expensive good/service. The payment typically represents only a percentage of the full purchase price.



67
68
69
# File 'lib/schema_org/mixins/repayment_specification.rb', line 67

def down_payment
  read_property(:down_payment)
end

#down_payment=(value) ⇒ Object

a type of payment made in cash during the onset of the purchase of an expensive good/service. The payment typically represents only a percentage of the full purchase price.



72
73
74
# File 'lib/schema_org/mixins/repayment_specification.rb', line 72

def down_payment=(value)
  write_property(:down_payment, value)
end

#early_prepayment_penaltyObject

The amount to be paid as a penalty in the event of early payment of the loan.



77
78
79
# File 'lib/schema_org/mixins/repayment_specification.rb', line 77

def early_prepayment_penalty
  read_property(:early_prepayment_penalty)
end

#early_prepayment_penalty=(value) ⇒ Object

The amount to be paid as a penalty in the event of early payment of the loan.



82
83
84
# File 'lib/schema_org/mixins/repayment_specification.rb', line 82

def early_prepayment_penalty=(value)
  write_property(:early_prepayment_penalty, value)
end

#loan_payment_amountObject

The amount of money to pay in a single payment.



87
88
89
# File 'lib/schema_org/mixins/repayment_specification.rb', line 87

def loan_payment_amount
  read_property(:loan_payment_amount)
end

#loan_payment_amount=(value) ⇒ Object

The amount of money to pay in a single payment.



92
93
94
# File 'lib/schema_org/mixins/repayment_specification.rb', line 92

def loan_payment_amount=(value)
  write_property(:loan_payment_amount, value)
end

#loan_payment_frequencyObject

Frequency of payments due, i.e. number of months between payments. This is defined as a frequency, i.e. the reciprocal of a period of time.



97
98
99
# File 'lib/schema_org/mixins/repayment_specification.rb', line 97

def loan_payment_frequency
  read_property(:loan_payment_frequency)
end

#loan_payment_frequency=(value) ⇒ Object

Frequency of payments due, i.e. number of months between payments. This is defined as a frequency, i.e. the reciprocal of a period of time.



102
103
104
# File 'lib/schema_org/mixins/repayment_specification.rb', line 102

def loan_payment_frequency=(value)
  write_property(:loan_payment_frequency, value)
end

#number_of_loan_paymentsObject

The number of payments contractually required at origination to repay the loan. For monthly paying loans this is the number of months from the contractual first payment date to the maturity date.



107
108
109
# File 'lib/schema_org/mixins/repayment_specification.rb', line 107

def number_of_loan_payments
  read_property(:number_of_loan_payments)
end

#number_of_loan_payments=(value) ⇒ Object

The number of payments contractually required at origination to repay the loan. For monthly paying loans this is the number of months from the contractual first payment date to the maturity date.



112
113
114
# File 'lib/schema_org/mixins/repayment_specification.rb', line 112

def number_of_loan_payments=(value)
  write_property(:number_of_loan_payments, value)
end