Module: SchemaOrg::Mixins::ReplyAction

Includes:
CommunicateAction
Included in:
ReplyAction
Defined in:
lib/schema_org/mixins/reply_action.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from CommunicateAction

#about, #about=, #in_language, #in_language=, #language, #language=, #recipient, #recipient=

Methods included from Action

#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, #start_time, #start_time=, #target, #target=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
# File 'lib/schema_org/mixins/reply_action.rb', line 11

def self.schema_property_definitions
  {
    result_comment: {
      schema_name: "resultComment",
      schema_url: "https://schema.org/resultComment",
      comment_lines: ["A sub property of result. The Comment created or sent as a result of this action."].freeze,
      ranges: ["Comment"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#result_commentObject

A sub property of result. The Comment created or sent as a result of this action.



27
28
29
# File 'lib/schema_org/mixins/reply_action.rb', line 27

def result_comment
  read_property(:result_comment)
end

#result_comment=(value) ⇒ Object

A sub property of result. The Comment created or sent as a result of this action.



32
33
34
# File 'lib/schema_org/mixins/reply_action.rb', line 32

def result_comment=(value)
  write_property(:result_comment, value)
end