Module: SchemaOrg::Mixins::Role

Includes:
Intangible
Included in:
LinkRole, OrganizationRole, PerformanceRole, Role
Defined in:
lib/schema_org/mixins/role.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/schema_org/mixins/role.rb', line 11

def self.schema_property_definitions
  {
    end_date: {
      schema_name: "endDate",
      schema_url: "https://schema.org/endDate",
      comment_lines: ["The end date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601))."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    named_position: {
      schema_name: "namedPosition",
      schema_url: "https://schema.org/namedPosition",
      comment_lines: ["A position played, performed or filled by a person or organization, as part of an organization. For example, an athlete in a SportsTeam might play in the position named 'Quarterback'."].freeze,
      ranges: ["Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "roleName",
      supersedes: nil
    }.freeze,
    role_name: {
      schema_name: "roleName",
      schema_url: "https://schema.org/roleName",
      comment_lines: ["A role played, performed or filled by a person or organization. For example, the team of creators for a comic book might fill the roles named 'inker', 'penciller', and 'letterer'; or an athlete in a SportsTeam might play in the position named 'Quarterback'."].freeze,
      ranges: ["Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["namedPosition"].freeze
    }.freeze,
    start_date: {
      schema_name: "startDate",
      schema_url: "https://schema.org/startDate",
      comment_lines: ["The start date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601))."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#end_dateObject

The end date and time of the item (in ISO 8601 date format).



57
58
59
# File 'lib/schema_org/mixins/role.rb', line 57

def end_date
  read_property(:end_date)
end

#end_date=(value) ⇒ Object

The end date and time of the item (in ISO 8601 date format).



62
63
64
# File 'lib/schema_org/mixins/role.rb', line 62

def end_date=(value)
  write_property(:end_date, value)
end

#named_positionObject

A position played, performed or filled by a person or organization, as part of an organization. For example, an athlete in a SportsTeam might play in the position named 'Quarterback'. Superseded by roleName.



68
69
70
# File 'lib/schema_org/mixins/role.rb', line 68

def named_position
  read_property(:named_position)
end

#named_position=(value) ⇒ Object

A position played, performed or filled by a person or organization, as part of an organization. For example, an athlete in a SportsTeam might play in the position named 'Quarterback'. Superseded by roleName.



74
75
76
# File 'lib/schema_org/mixins/role.rb', line 74

def named_position=(value)
  write_property(:named_position, value)
end

#role_nameObject

A role played, performed or filled by a person or organization. For example, the team of creators for a comic book might fill the roles named 'inker', 'penciller', and 'letterer'; or an athlete in a SportsTeam might play in the position named 'Quarterback'. Supersedes namedPosition.



80
81
82
# File 'lib/schema_org/mixins/role.rb', line 80

def role_name
  read_property(:role_name)
end

#role_name=(value) ⇒ Object

A role played, performed or filled by a person or organization. For example, the team of creators for a comic book might fill the roles named 'inker', 'penciller', and 'letterer'; or an athlete in a SportsTeam might play in the position named 'Quarterback'. Supersedes namedPosition.



86
87
88
# File 'lib/schema_org/mixins/role.rb', line 86

def role_name=(value)
  write_property(:role_name, value)
end

#start_dateObject

The start date and time of the item (in ISO 8601 date format).



91
92
93
# File 'lib/schema_org/mixins/role.rb', line 91

def start_date
  read_property(:start_date)
end

#start_date=(value) ⇒ Object

The start date and time of the item (in ISO 8601 date format).



96
97
98
# File 'lib/schema_org/mixins/role.rb', line 96

def start_date=(value)
  write_property(:start_date, value)
end