Module: SchemaOrg::Mixins::ScreeningEvent

Includes:
Event
Included in:
ScreeningEvent
Defined in:
lib/schema_org/mixins/screening_event.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Event

#about, #about=, #actor, #actor=, #aggregate_rating, #aggregate_rating=, #attendee, #attendee=, #attendees, #attendees=, #audience, #audience=, #composer, #composer=, #contributor, #contributor=, #director, #director=, #door_time, #door_time=, #duration, #duration=, #end_date, #end_date=, #event_attendance_mode, #event_attendance_mode=, #event_schedule, #event_schedule=, #event_status, #event_status=, #funder, #funder=, #funding, #funding=, #has_participation_offer, #has_participation_offer=, #has_sponsorship_offer, #has_sponsorship_offer=, #in_language, #in_language=, #is_accessible_for_free, #is_accessible_for_free=, #keywords, #keywords=, #location, #location=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #maximum_physical_attendee_capacity, #maximum_physical_attendee_capacity=, #maximum_virtual_attendee_capacity, #maximum_virtual_attendee_capacity=, #offers, #offers=, #organizer, #organizer=, #performer, #performer=, #performers, #performers=, #previous_start_date, #previous_start_date=, #recorded_in, #recorded_in=, #remaining_attendee_capacity, #remaining_attendee_capacity=, #review, #review=, #sponsor, #sponsor=, #start_date, #start_date=, #sub_event, #sub_event=, #sub_events, #sub_events=, #super_event, #super_event=, #translator, #translator=, #typical_age_range, #typical_age_range=, #work_featured, #work_featured=, #work_performed, #work_performed=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/schema_org/mixins/screening_event.rb', line 11

def self.schema_property_definitions
  {
    subtitle_language: {
      schema_name: "subtitleLanguage",
      schema_url: "https://schema.org/subtitleLanguage",
      comment_lines: ["Languages in which subtitles/captions are available, in [IETF BCP 47 standard format](http://tools.ietf.org/html/bcp47)."].freeze,
      ranges: ["Language", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    video_format: {
      schema_name: "videoFormat",
      schema_url: "https://schema.org/videoFormat",
      comment_lines: ["The type of screening or video broadcast used (e.g. IMAX, 3D, SD, HD, etc.)."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    work_presented: {
      schema_name: "workPresented",
      schema_url: "https://schema.org/workPresented",
      comment_lines: ["The movie presented during this event."].freeze,
      ranges: ["Movie"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#subtitle_languageObject

Languages in which subtitles/captions are available, in IETF BCP 47 standard format.



47
48
49
# File 'lib/schema_org/mixins/screening_event.rb', line 47

def subtitle_language
  read_property(:subtitle_language)
end

#subtitle_language=(value) ⇒ Object

Languages in which subtitles/captions are available, in IETF BCP 47 standard format.



52
53
54
# File 'lib/schema_org/mixins/screening_event.rb', line 52

def subtitle_language=(value)
  write_property(:subtitle_language, value)
end

#video_formatObject

The type of screening or video broadcast used (e.g. IMAX, 3D, SD, HD, etc.).



57
58
59
# File 'lib/schema_org/mixins/screening_event.rb', line 57

def video_format
  read_property(:video_format)
end

#video_format=(value) ⇒ Object

The type of screening or video broadcast used (e.g. IMAX, 3D, SD, HD, etc.).



62
63
64
# File 'lib/schema_org/mixins/screening_event.rb', line 62

def video_format=(value)
  write_property(:video_format, value)
end

#work_presentedObject

The movie presented during this event.



67
68
69
# File 'lib/schema_org/mixins/screening_event.rb', line 67

def work_presented
  read_property(:work_presented)
end

#work_presented=(value) ⇒ Object

The movie presented during this event.



72
73
74
# File 'lib/schema_org/mixins/screening_event.rb', line 72

def work_presented=(value)
  write_property(:work_presented, value)
end