Module: SchemaOrg::Mixins::ServiceChannel

Includes:
Intangible
Included in:
ServiceChannel
Defined in:
lib/schema_org/mixins/service_channel.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/schema_org/mixins/service_channel.rb', line 11

def self.schema_property_definitions
  {
    available_language: {
      schema_name: "availableLanguage",
      schema_url: "https://schema.org/availableLanguage",
      comment_lines: ["A language someone may use with or at the item, service or place. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[inLanguage]]."].freeze,
      ranges: ["Language", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    processing_time: {
      schema_name: "processingTime",
      schema_url: "https://schema.org/processingTime",
      comment_lines: ["Estimated processing time for the service using this channel."].freeze,
      ranges: ["Duration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    provides_service: {
      schema_name: "providesService",
      schema_url: "https://schema.org/providesService",
      comment_lines: ["The service provided by this channel."].freeze,
      ranges: ["Service"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    service_location: {
      schema_name: "serviceLocation",
      schema_url: "https://schema.org/serviceLocation",
      comment_lines: ["The location (e.g. civic structure, local business, etc.) where a person can go to access the service."].freeze,
      ranges: ["Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    service_phone: {
      schema_name: "servicePhone",
      schema_url: "https://schema.org/servicePhone",
      comment_lines: ["The phone number to use to access the service."].freeze,
      ranges: ["ContactPoint"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    service_postal_address: {
      schema_name: "servicePostalAddress",
      schema_url: "https://schema.org/servicePostalAddress",
      comment_lines: ["The address for accessing the service by mail."].freeze,
      ranges: ["PostalAddress"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    service_sms_number: {
      schema_name: "serviceSmsNumber",
      schema_url: "https://schema.org/serviceSmsNumber",
      comment_lines: ["The number to access the service by text message."].freeze,
      ranges: ["ContactPoint"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    service_url: {
      schema_name: "serviceUrl",
      schema_url: "https://schema.org/serviceUrl",
      comment_lines: ["The website to access the service."].freeze,
      ranges: ["URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#available_languageObject

A language someone may use with or at the item, service or place. Please use one of the language codes from the IETF BCP 47 standard. See also [[inLanguage]].



97
98
99
# File 'lib/schema_org/mixins/service_channel.rb', line 97

def available_language
  read_property(:available_language)
end

#available_language=(value) ⇒ Object

A language someone may use with or at the item, service or place. Please use one of the language codes from the IETF BCP 47 standard. See also [[inLanguage]].



102
103
104
# File 'lib/schema_org/mixins/service_channel.rb', line 102

def available_language=(value)
  write_property(:available_language, value)
end

#processing_timeObject

Estimated processing time for the service using this channel.



107
108
109
# File 'lib/schema_org/mixins/service_channel.rb', line 107

def processing_time
  read_property(:processing_time)
end

#processing_time=(value) ⇒ Object

Estimated processing time for the service using this channel.



112
113
114
# File 'lib/schema_org/mixins/service_channel.rb', line 112

def processing_time=(value)
  write_property(:processing_time, value)
end

#provides_serviceObject

The service provided by this channel.



117
118
119
# File 'lib/schema_org/mixins/service_channel.rb', line 117

def provides_service
  read_property(:provides_service)
end

#provides_service=(value) ⇒ Object

The service provided by this channel.



122
123
124
# File 'lib/schema_org/mixins/service_channel.rb', line 122

def provides_service=(value)
  write_property(:provides_service, value)
end

#service_locationObject

The location (e.g. civic structure, local business, etc.) where a person can go to access the service.



127
128
129
# File 'lib/schema_org/mixins/service_channel.rb', line 127

def service_location
  read_property(:service_location)
end

#service_location=(value) ⇒ Object

The location (e.g. civic structure, local business, etc.) where a person can go to access the service.



132
133
134
# File 'lib/schema_org/mixins/service_channel.rb', line 132

def service_location=(value)
  write_property(:service_location, value)
end

#service_phoneObject

The phone number to use to access the service.



137
138
139
# File 'lib/schema_org/mixins/service_channel.rb', line 137

def service_phone
  read_property(:service_phone)
end

#service_phone=(value) ⇒ Object

The phone number to use to access the service.



142
143
144
# File 'lib/schema_org/mixins/service_channel.rb', line 142

def service_phone=(value)
  write_property(:service_phone, value)
end

#service_postal_addressObject

The address for accessing the service by mail.



147
148
149
# File 'lib/schema_org/mixins/service_channel.rb', line 147

def service_postal_address
  read_property(:service_postal_address)
end

#service_postal_address=(value) ⇒ Object

The address for accessing the service by mail.



152
153
154
# File 'lib/schema_org/mixins/service_channel.rb', line 152

def service_postal_address=(value)
  write_property(:service_postal_address, value)
end

#service_sms_numberObject

The number to access the service by text message.



157
158
159
# File 'lib/schema_org/mixins/service_channel.rb', line 157

def service_sms_number
  read_property(:service_sms_number)
end

#service_sms_number=(value) ⇒ Object

The number to access the service by text message.



162
163
164
# File 'lib/schema_org/mixins/service_channel.rb', line 162

def service_sms_number=(value)
  write_property(:service_sms_number, value)
end

#service_urlObject

The website to access the service.



167
168
169
# File 'lib/schema_org/mixins/service_channel.rb', line 167

def service_url
  read_property(:service_url)
end

#service_url=(value) ⇒ Object

The website to access the service.



172
173
174
# File 'lib/schema_org/mixins/service_channel.rb', line 172

def service_url=(value)
  write_property(:service_url, value)
end