Module: SchemaOrg::Mixins::ServicePeriod

Includes:
StructuredValue
Included in:
ServicePeriod
Defined in:
lib/schema_org/mixins/service_period.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/schema_org/mixins/service_period.rb', line 11

def self.schema_property_definitions
  {
    business_days: {
      schema_name: "businessDays",
      schema_url: "https://schema.org/businessDays",
      comment_lines: ["Days of the week when the merchant typically operates, indicated via opening hours markup."].freeze,
      ranges: ["DayOfWeek", "OpeningHoursSpecification"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    cutoff_time: {
      schema_name: "cutoffTime",
      schema_url: "https://schema.org/cutoffTime",
      comment_lines: ["Order cutoff time allows merchants to describe the time after which they will no longer process orders received on that day. For orders processed after cutoff time, one day gets added to the delivery time estimate. This property is expected to be most typically used via the [[ShippingRateSettings]] publication pattern. The time is indicated using the ISO-8601 Time format, e.g. \"23:30:00-05:00\" would represent 6:30 pm Eastern Standard Time (EST) which is 5 hours behind Coordinated Universal Time (UTC)."].freeze,
      ranges: ["Time"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    duration: {
      schema_name: "duration",
      schema_url: "https://schema.org/duration",
      comment_lines: ["The duration of the item (movie, audio recording, event, etc.) in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601)."].freeze,
      ranges: ["Duration", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#business_daysObject

Days of the week when the merchant typically operates, indicated via opening hours markup.



47
48
49
# File 'lib/schema_org/mixins/service_period.rb', line 47

def business_days
  read_property(:business_days)
end

#business_days=(value) ⇒ Object

Days of the week when the merchant typically operates, indicated via opening hours markup.



52
53
54
# File 'lib/schema_org/mixins/service_period.rb', line 52

def business_days=(value)
  write_property(:business_days, value)
end

#cutoff_timeObject

Order cutoff time allows merchants to describe the time after which they will no longer process orders received on that day. For orders processed after cutoff time, one day gets added to the delivery time estimate. This property is expected to be most typically used via the [[ShippingRateSettings]] publication pattern. The time is indicated using the ISO-8601 Time format, e.g. "23:30:00-05:00" would represent 6:30 pm Eastern Standard Time (EST) which is 5 hours behind Coordinated Universal Time (UTC).



57
58
59
# File 'lib/schema_org/mixins/service_period.rb', line 57

def cutoff_time
  read_property(:cutoff_time)
end

#cutoff_time=(value) ⇒ Object

Order cutoff time allows merchants to describe the time after which they will no longer process orders received on that day. For orders processed after cutoff time, one day gets added to the delivery time estimate. This property is expected to be most typically used via the [[ShippingRateSettings]] publication pattern. The time is indicated using the ISO-8601 Time format, e.g. "23:30:00-05:00" would represent 6:30 pm Eastern Standard Time (EST) which is 5 hours behind Coordinated Universal Time (UTC).



62
63
64
# File 'lib/schema_org/mixins/service_period.rb', line 62

def cutoff_time=(value)
  write_property(:cutoff_time, value)
end

#durationObject

The duration of the item (movie, audio recording, event, etc.) in ISO 8601 duration format.



67
68
69
# File 'lib/schema_org/mixins/service_period.rb', line 67

def duration
  read_property(:duration)
end

#duration=(value) ⇒ Object

The duration of the item (movie, audio recording, event, etc.) in ISO 8601 duration format.



72
73
74
# File 'lib/schema_org/mixins/service_period.rb', line 72

def duration=(value)
  write_property(:duration, value)
end