Module: SchemaOrg::Mixins::ShippingDeliveryTime

Includes:
StructuredValue
Included in:
ShippingDeliveryTime
Defined in:
lib/schema_org/mixins/shipping_delivery_time.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/schema_org/mixins/shipping_delivery_time.rb', line 11

def self.schema_property_definitions
  {
    business_days: {
      schema_name: "businessDays",
      schema_url: "https://schema.org/businessDays",
      comment_lines: ["Days of the week when the merchant typically operates, indicated via opening hours markup."].freeze,
      ranges: ["DayOfWeek", "OpeningHoursSpecification"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    cutoff_time: {
      schema_name: "cutoffTime",
      schema_url: "https://schema.org/cutoffTime",
      comment_lines: ["Order cutoff time allows merchants to describe the time after which they will no longer process orders received on that day. For orders processed after cutoff time, one day gets added to the delivery time estimate. This property is expected to be most typically used via the [[ShippingRateSettings]] publication pattern. The time is indicated using the ISO-8601 Time format, e.g. \"23:30:00-05:00\" would represent 6:30 pm Eastern Standard Time (EST) which is 5 hours behind Coordinated Universal Time (UTC)."].freeze,
      ranges: ["Time"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    handling_time: {
      schema_name: "handlingTime",
      schema_url: "https://schema.org/handlingTime",
      comment_lines: ["The typical delay between the receipt of the order and the goods either leaving the warehouse or being prepared for pickup, in case the delivery method is on site pickup.", "", "In the context of [[ShippingDeliveryTime]], Typical properties: minValue, maxValue, unitCode (d for DAY).  This is by common convention assumed to mean business days (if a unitCode is used, coded as \"d\"), i.e. only counting days when the business normally operates.", "", "In the context of [[ShippingService]], use the [[ServicePeriod]] format, that contains the same information in a structured form, with cut-off time, business days and duration."].freeze,
      ranges: ["QuantitativeValue", "ServicePeriod"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    transit_time: {
      schema_name: "transitTime",
      schema_url: "https://schema.org/transitTime",
      comment_lines: ["The typical delay the order has been sent for delivery and the goods reach the final customer.", "", "  In the context of [[ShippingDeliveryTime]], use the [[QuantitativeValue]]. Typical properties: minValue, maxValue, unitCode (d for DAY).", "", "  In the context of [[ShippingConditions]], use the [[ServicePeriod]]. It has a duration (as a [[QuantitativeValue]]) and also business days and a cut-off time."].freeze,
      ranges: ["QuantitativeValue", "ServicePeriod"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#business_daysObject

Days of the week when the merchant typically operates, indicated via opening hours markup.



57
58
59
# File 'lib/schema_org/mixins/shipping_delivery_time.rb', line 57

def business_days
  read_property(:business_days)
end

#business_days=(value) ⇒ Object

Days of the week when the merchant typically operates, indicated via opening hours markup.



62
63
64
# File 'lib/schema_org/mixins/shipping_delivery_time.rb', line 62

def business_days=(value)
  write_property(:business_days, value)
end

#cutoff_timeObject

Order cutoff time allows merchants to describe the time after which they will no longer process orders received on that day. For orders processed after cutoff time, one day gets added to the delivery time estimate. This property is expected to be most typically used via the [[ShippingRateSettings]] publication pattern. The time is indicated using the ISO-8601 Time format, e.g. "23:30:00-05:00" would represent 6:30 pm Eastern Standard Time (EST) which is 5 hours behind Coordinated Universal Time (UTC).



67
68
69
# File 'lib/schema_org/mixins/shipping_delivery_time.rb', line 67

def cutoff_time
  read_property(:cutoff_time)
end

#cutoff_time=(value) ⇒ Object

Order cutoff time allows merchants to describe the time after which they will no longer process orders received on that day. For orders processed after cutoff time, one day gets added to the delivery time estimate. This property is expected to be most typically used via the [[ShippingRateSettings]] publication pattern. The time is indicated using the ISO-8601 Time format, e.g. "23:30:00-05:00" would represent 6:30 pm Eastern Standard Time (EST) which is 5 hours behind Coordinated Universal Time (UTC).



72
73
74
# File 'lib/schema_org/mixins/shipping_delivery_time.rb', line 72

def cutoff_time=(value)
  write_property(:cutoff_time, value)
end

#handling_timeObject

The typical delay between the receipt of the order and the goods either leaving the warehouse or being prepared for pickup, in case the delivery method is on site pickup.

In the context of [[ShippingDeliveryTime]], Typical properties: minValue, maxValue, unitCode (d for DAY). This is by common convention assumed to mean business days (if a unitCode is used, coded as "d"), i.e. only counting days when the business normally operates.

In the context of [[ShippingService]], use the [[ServicePeriod]] format, that contains the same information in a structured form, with cut-off time, business days and duration.



81
82
83
# File 'lib/schema_org/mixins/shipping_delivery_time.rb', line 81

def handling_time
  read_property(:handling_time)
end

#handling_time=(value) ⇒ Object

The typical delay between the receipt of the order and the goods either leaving the warehouse or being prepared for pickup, in case the delivery method is on site pickup.

In the context of [[ShippingDeliveryTime]], Typical properties: minValue, maxValue, unitCode (d for DAY). This is by common convention assumed to mean business days (if a unitCode is used, coded as "d"), i.e. only counting days when the business normally operates.

In the context of [[ShippingService]], use the [[ServicePeriod]] format, that contains the same information in a structured form, with cut-off time, business days and duration.



90
91
92
# File 'lib/schema_org/mixins/shipping_delivery_time.rb', line 90

def handling_time=(value)
  write_property(:handling_time, value)
end

#transit_timeObject

The typical delay the order has been sent for delivery and the goods reach the final customer.

In the context of [[ShippingDeliveryTime]], use the [[QuantitativeValue]]. Typical properties: minValue, maxValue, unitCode (d for DAY).

In the context of [[ShippingConditions]], use the [[ServicePeriod]]. It has a duration (as a [[QuantitativeValue]]) and also business days and a cut-off time.


99
100
101
# File 'lib/schema_org/mixins/shipping_delivery_time.rb', line 99

def transit_time
  read_property(:transit_time)
end

#transit_time=(value) ⇒ Object

The typical delay the order has been sent for delivery and the goods reach the final customer.

In the context of [[ShippingDeliveryTime]], use the [[QuantitativeValue]]. Typical properties: minValue, maxValue, unitCode (d for DAY).

In the context of [[ShippingConditions]], use the [[ServicePeriod]]. It has a duration (as a [[QuantitativeValue]]) and also business days and a cut-off time.


108
109
110
# File 'lib/schema_org/mixins/shipping_delivery_time.rb', line 108

def transit_time=(value)
  write_property(:transit_time, value)
end