Module: SchemaOrg::Mixins::ShippingService

Includes:
StructuredValue
Included in:
ShippingService
Defined in:
lib/schema_org/mixins/shipping_service.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/schema_org/mixins/shipping_service.rb', line 11

def self.schema_property_definitions
  {
    fulfillment_type: {
      schema_name: "fulfillmentType",
      schema_url: "https://schema.org/fulfillmentType",
      comment_lines: ["Type of fulfillment applicable to the [[ShippingService]]."].freeze,
      ranges: ["FulfillmentTypeEnumeration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    handling_time: {
      schema_name: "handlingTime",
      schema_url: "https://schema.org/handlingTime",
      comment_lines: ["The typical delay between the receipt of the order and the goods either leaving the warehouse or being prepared for pickup, in case the delivery method is on site pickup.", "", "In the context of [[ShippingDeliveryTime]], Typical properties: minValue, maxValue, unitCode (d for DAY).  This is by common convention assumed to mean business days (if a unitCode is used, coded as \"d\"), i.e. only counting days when the business normally operates.", "", "In the context of [[ShippingService]], use the [[ServicePeriod]] format, that contains the same information in a structured form, with cut-off time, business days and duration."].freeze,
      ranges: ["QuantitativeValue", "ServicePeriod"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    shipping_conditions: {
      schema_name: "shippingConditions",
      schema_url: "https://schema.org/shippingConditions",
      comment_lines: ["The conditions (constraints, price) applicable to the [[ShippingService]]."].freeze,
      ranges: ["ShippingConditions"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    valid_for_member_tier: {
      schema_name: "validForMemberTier",
      schema_url: "https://schema.org/validForMemberTier",
      comment_lines: ["The membership program tier(s) an Offer (or a PriceSpecification, OfferShippingDetails, or MerchantReturnPolicy under an Offer) is valid for."].freeze,
      ranges: ["MemberProgramTier"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#fulfillment_typeObject

Type of fulfillment applicable to the [[ShippingService]].



57
58
59
# File 'lib/schema_org/mixins/shipping_service.rb', line 57

def fulfillment_type
  read_property(:fulfillment_type)
end

#fulfillment_type=(value) ⇒ Object

Type of fulfillment applicable to the [[ShippingService]].



62
63
64
# File 'lib/schema_org/mixins/shipping_service.rb', line 62

def fulfillment_type=(value)
  write_property(:fulfillment_type, value)
end

#handling_timeObject

The typical delay between the receipt of the order and the goods either leaving the warehouse or being prepared for pickup, in case the delivery method is on site pickup.

In the context of [[ShippingDeliveryTime]], Typical properties: minValue, maxValue, unitCode (d for DAY). This is by common convention assumed to mean business days (if a unitCode is used, coded as "d"), i.e. only counting days when the business normally operates.

In the context of [[ShippingService]], use the [[ServicePeriod]] format, that contains the same information in a structured form, with cut-off time, business days and duration.



71
72
73
# File 'lib/schema_org/mixins/shipping_service.rb', line 71

def handling_time
  read_property(:handling_time)
end

#handling_time=(value) ⇒ Object

The typical delay between the receipt of the order and the goods either leaving the warehouse or being prepared for pickup, in case the delivery method is on site pickup.

In the context of [[ShippingDeliveryTime]], Typical properties: minValue, maxValue, unitCode (d for DAY). This is by common convention assumed to mean business days (if a unitCode is used, coded as "d"), i.e. only counting days when the business normally operates.

In the context of [[ShippingService]], use the [[ServicePeriod]] format, that contains the same information in a structured form, with cut-off time, business days and duration.



80
81
82
# File 'lib/schema_org/mixins/shipping_service.rb', line 80

def handling_time=(value)
  write_property(:handling_time, value)
end

#shipping_conditionsObject

The conditions (constraints, price) applicable to the [[ShippingService]].



85
86
87
# File 'lib/schema_org/mixins/shipping_service.rb', line 85

def shipping_conditions
  read_property(:shipping_conditions)
end

#shipping_conditions=(value) ⇒ Object

The conditions (constraints, price) applicable to the [[ShippingService]].



90
91
92
# File 'lib/schema_org/mixins/shipping_service.rb', line 90

def shipping_conditions=(value)
  write_property(:shipping_conditions, value)
end

#valid_for_member_tierObject

The membership program tier(s) an Offer (or a PriceSpecification, OfferShippingDetails, or MerchantReturnPolicy under an Offer) is valid for.



95
96
97
# File 'lib/schema_org/mixins/shipping_service.rb', line 95

def valid_for_member_tier
  read_property(:valid_for_member_tier)
end

#valid_for_member_tier=(value) ⇒ Object

The membership program tier(s) an Offer (or a PriceSpecification, OfferShippingDetails, or MerchantReturnPolicy under an Offer) is valid for.



100
101
102
# File 'lib/schema_org/mixins/shipping_service.rb', line 100

def valid_for_member_tier=(value)
  write_property(:valid_for_member_tier, value)
end