Module: SchemaOrg::Mixins::SpecialAnnouncement

Includes:
CreativeWork
Included in:
SpecialAnnouncement
Defined in:
lib/schema_org/mixins/special_announcement.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from CreativeWork

#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/schema_org/mixins/special_announcement.rb', line 11

def self.schema_property_definitions
  {
    announcement_location: {
      schema_name: "announcementLocation",
      schema_url: "https://schema.org/announcementLocation",
      comment_lines: ["Indicates a specific [[CivicStructure]] or [[LocalBusiness]] associated with the SpecialAnnouncement. For example, a specific testing facility or business with special opening hours. For a larger geographic region like a quarantine of an entire region, use [[spatialCoverage]]."].freeze,
      ranges: ["CivicStructure", "LocalBusiness"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    category: {
      schema_name: "category",
      schema_url: "https://schema.org/category",
      comment_lines: ["A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy."].freeze,
      ranges: ["CategoryCode", "PhysicalActivityCategory", "Text", "Thing", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    date_posted: {
      schema_name: "datePosted",
      schema_url: "https://schema.org/datePosted",
      comment_lines: ["Publication date of an online listing."].freeze,
      ranges: ["Date", "DateTime"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    disease_prevention_info: {
      schema_name: "diseasePreventionInfo",
      schema_url: "https://schema.org/diseasePreventionInfo",
      comment_lines: ["Information about disease prevention."].freeze,
      ranges: ["URL", "WebContent"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    disease_spread_statistics: {
      schema_name: "diseaseSpreadStatistics",
      schema_url: "https://schema.org/diseaseSpreadStatistics",
      comment_lines: ["Statistical information about the spread of a disease, either as [[WebContent]], or", "  described directly as a [[Dataset]], or the specific [[Observation]]s in the dataset. When a [[WebContent]] URL is", "  provided, the page indicated might also contain more such markup."].freeze,
      ranges: ["Dataset", "Observation", "URL", "WebContent"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    getting_tested_info: {
      schema_name: "gettingTestedInfo",
      schema_url: "https://schema.org/gettingTestedInfo",
      comment_lines: ["Information about getting tested (for a [[MedicalCondition]]), e.g. in the context of a pandemic."].freeze,
      ranges: ["URL", "WebContent"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    government_benefits_info: {
      schema_name: "governmentBenefitsInfo",
      schema_url: "https://schema.org/governmentBenefitsInfo",
      comment_lines: ["governmentBenefitsInfo provides information about government benefits associated with a SpecialAnnouncement."].freeze,
      ranges: ["GovernmentService"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    news_updates_and_guidelines: {
      schema_name: "newsUpdatesAndGuidelines",
      schema_url: "https://schema.org/newsUpdatesAndGuidelines",
      comment_lines: ["Indicates a page with news updates and guidelines. This could often be (but is not required to be) the main page containing [[SpecialAnnouncement]] markup on a site."].freeze,
      ranges: ["URL", "WebContent"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    public_transport_closures_info: {
      schema_name: "publicTransportClosuresInfo",
      schema_url: "https://schema.org/publicTransportClosuresInfo",
      comment_lines: ["Information about public transport closures."].freeze,
      ranges: ["URL", "WebContent"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    quarantine_guidelines: {
      schema_name: "quarantineGuidelines",
      schema_url: "https://schema.org/quarantineGuidelines",
      comment_lines: ["Guidelines about quarantine rules, e.g. in the context of a pandemic."].freeze,
      ranges: ["URL", "WebContent"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    school_closures_info: {
      schema_name: "schoolClosuresInfo",
      schema_url: "https://schema.org/schoolClosuresInfo",
      comment_lines: ["Information about school closures."].freeze,
      ranges: ["URL", "WebContent"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    travel_bans: {
      schema_name: "travelBans",
      schema_url: "https://schema.org/travelBans",
      comment_lines: ["Information about travel bans, e.g. in the context of a pandemic."].freeze,
      ranges: ["URL", "WebContent"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    web_feed: {
      schema_name: "webFeed",
      schema_url: "https://schema.org/webFeed",
      comment_lines: ["The URL for a feed, e.g. associated with a podcast series, blog, or series of date-stamped updates. This is usually RSS or Atom."].freeze,
      ranges: ["DataFeed", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#announcement_locationObject

Indicates a specific [[CivicStructure]] or [[LocalBusiness]] associated with the SpecialAnnouncement. For example, a specific testing facility or business with special opening hours. For a larger geographic region like a quarantine of an entire region, use [[spatialCoverage]].



147
148
149
# File 'lib/schema_org/mixins/special_announcement.rb', line 147

def announcement_location
  read_property(:announcement_location)
end

#announcement_location=(value) ⇒ Object

Indicates a specific [[CivicStructure]] or [[LocalBusiness]] associated with the SpecialAnnouncement. For example, a specific testing facility or business with special opening hours. For a larger geographic region like a quarantine of an entire region, use [[spatialCoverage]].



152
153
154
# File 'lib/schema_org/mixins/special_announcement.rb', line 152

def announcement_location=(value)
  write_property(:announcement_location, value)
end

#categoryObject

A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.



157
158
159
# File 'lib/schema_org/mixins/special_announcement.rb', line 157

def category
  read_property(:category)
end

#category=(value) ⇒ Object

A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.



162
163
164
# File 'lib/schema_org/mixins/special_announcement.rb', line 162

def category=(value)
  write_property(:category, value)
end

#date_postedObject

Publication date of an online listing.



167
168
169
# File 'lib/schema_org/mixins/special_announcement.rb', line 167

def date_posted
  read_property(:date_posted)
end

#date_posted=(value) ⇒ Object

Publication date of an online listing.



172
173
174
# File 'lib/schema_org/mixins/special_announcement.rb', line 172

def date_posted=(value)
  write_property(:date_posted, value)
end

#disease_prevention_infoObject

Information about disease prevention.



177
178
179
# File 'lib/schema_org/mixins/special_announcement.rb', line 177

def disease_prevention_info
  read_property(:disease_prevention_info)
end

#disease_prevention_info=(value) ⇒ Object

Information about disease prevention.



182
183
184
# File 'lib/schema_org/mixins/special_announcement.rb', line 182

def disease_prevention_info=(value)
  write_property(:disease_prevention_info, value)
end

#disease_spread_statisticsObject

Statistical information about the spread of a disease, either as [[WebContent]], or described directly as a [[Dataset]], or the specific [[Observation]]s in the dataset. When a [[WebContent]] URL is provided, the page indicated might also contain more such markup.



189
190
191
# File 'lib/schema_org/mixins/special_announcement.rb', line 189

def disease_spread_statistics
  read_property(:disease_spread_statistics)
end

#disease_spread_statistics=(value) ⇒ Object

Statistical information about the spread of a disease, either as [[WebContent]], or described directly as a [[Dataset]], or the specific [[Observation]]s in the dataset. When a [[WebContent]] URL is provided, the page indicated might also contain more such markup.



196
197
198
# File 'lib/schema_org/mixins/special_announcement.rb', line 196

def disease_spread_statistics=(value)
  write_property(:disease_spread_statistics, value)
end

#getting_tested_infoObject

Information about getting tested (for a [[MedicalCondition]]), e.g. in the context of a pandemic.



201
202
203
# File 'lib/schema_org/mixins/special_announcement.rb', line 201

def getting_tested_info
  read_property(:getting_tested_info)
end

#getting_tested_info=(value) ⇒ Object

Information about getting tested (for a [[MedicalCondition]]), e.g. in the context of a pandemic.



206
207
208
# File 'lib/schema_org/mixins/special_announcement.rb', line 206

def getting_tested_info=(value)
  write_property(:getting_tested_info, value)
end

#government_benefits_infoObject

governmentBenefitsInfo provides information about government benefits associated with a SpecialAnnouncement.



211
212
213
# File 'lib/schema_org/mixins/special_announcement.rb', line 211

def government_benefits_info
  read_property(:government_benefits_info)
end

#government_benefits_info=(value) ⇒ Object

governmentBenefitsInfo provides information about government benefits associated with a SpecialAnnouncement.



216
217
218
# File 'lib/schema_org/mixins/special_announcement.rb', line 216

def government_benefits_info=(value)
  write_property(:government_benefits_info, value)
end

#news_updates_and_guidelinesObject

Indicates a page with news updates and guidelines. This could often be (but is not required to be) the main page containing [[SpecialAnnouncement]] markup on a site.



221
222
223
# File 'lib/schema_org/mixins/special_announcement.rb', line 221

def news_updates_and_guidelines
  read_property(:news_updates_and_guidelines)
end

#news_updates_and_guidelines=(value) ⇒ Object

Indicates a page with news updates and guidelines. This could often be (but is not required to be) the main page containing [[SpecialAnnouncement]] markup on a site.



226
227
228
# File 'lib/schema_org/mixins/special_announcement.rb', line 226

def news_updates_and_guidelines=(value)
  write_property(:news_updates_and_guidelines, value)
end

#public_transport_closures_infoObject

Information about public transport closures.



231
232
233
# File 'lib/schema_org/mixins/special_announcement.rb', line 231

def public_transport_closures_info
  read_property(:public_transport_closures_info)
end

#public_transport_closures_info=(value) ⇒ Object

Information about public transport closures.



236
237
238
# File 'lib/schema_org/mixins/special_announcement.rb', line 236

def public_transport_closures_info=(value)
  write_property(:public_transport_closures_info, value)
end

#quarantine_guidelinesObject

Guidelines about quarantine rules, e.g. in the context of a pandemic.



241
242
243
# File 'lib/schema_org/mixins/special_announcement.rb', line 241

def quarantine_guidelines
  read_property(:quarantine_guidelines)
end

#quarantine_guidelines=(value) ⇒ Object

Guidelines about quarantine rules, e.g. in the context of a pandemic.



246
247
248
# File 'lib/schema_org/mixins/special_announcement.rb', line 246

def quarantine_guidelines=(value)
  write_property(:quarantine_guidelines, value)
end

#school_closures_infoObject

Information about school closures.



251
252
253
# File 'lib/schema_org/mixins/special_announcement.rb', line 251

def school_closures_info
  read_property(:school_closures_info)
end

#school_closures_info=(value) ⇒ Object

Information about school closures.



256
257
258
# File 'lib/schema_org/mixins/special_announcement.rb', line 256

def school_closures_info=(value)
  write_property(:school_closures_info, value)
end

#travel_bansObject

Information about travel bans, e.g. in the context of a pandemic.



261
262
263
# File 'lib/schema_org/mixins/special_announcement.rb', line 261

def travel_bans
  read_property(:travel_bans)
end

#travel_bans=(value) ⇒ Object

Information about travel bans, e.g. in the context of a pandemic.



266
267
268
# File 'lib/schema_org/mixins/special_announcement.rb', line 266

def travel_bans=(value)
  write_property(:travel_bans, value)
end

#web_feedObject

The URL for a feed, e.g. associated with a podcast series, blog, or series of date-stamped updates. This is usually RSS or Atom.



271
272
273
# File 'lib/schema_org/mixins/special_announcement.rb', line 271

def web_feed
  read_property(:web_feed)
end

#web_feed=(value) ⇒ Object

The URL for a feed, e.g. associated with a podcast series, blog, or series of date-stamped updates. This is usually RSS or Atom.



276
277
278
# File 'lib/schema_org/mixins/special_announcement.rb', line 276

def web_feed=(value)
  write_property(:web_feed, value)
end