Module: SchemaOrg::Mixins::SportsTeam

Includes:
SportsOrganization
Included in:
SportsTeam
Defined in:
lib/schema_org/mixins/sports_team.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from SportsOrganization

#sport, #sport=

Methods included from Organization

#accepted_payment_method, #accepted_payment_method=, #actionable_feedback_policy, #actionable_feedback_policy=, #address, #address=, #agent_interaction_statistic, #agent_interaction_statistic=, #aggregate_rating, #aggregate_rating=, #alumni, #alumni=, #area_served, #area_served=, #award, #award=, #awards, #awards=, #brand, #brand=, #company_registration, #company_registration=, #contact_point, #contact_point=, #contact_points, #contact_points=, #corrections_policy, #corrections_policy=, #department, #department=, #dissolution_date, #dissolution_date=, #diversity_policy, #diversity_policy=, #diversity_staffing_report, #diversity_staffing_report=, #duns, #duns=, #email, #email=, #employee, #employee=, #employees, #employees=, #ethics_policy, #ethics_policy=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #founder, #founder=, #founders, #founders=, #founding_date, #founding_date=, #founding_location, #founding_location=, #funder, #funder=, #funding, #funding=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_credential, #has_credential=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_member_program, #has_member_program=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_offer_catalog, #has_offer_catalog=, #has_pos, #has_pos=, #has_product_return_policy, #has_product_return_policy=, #has_shipping_service, #has_shipping_service=, #interaction_statistic, #interaction_statistic=, #isic_v4, #isic_v4=, #iso6523_code, #iso6523_code=, #keywords, #keywords=, #knows_about, #knows_about=, #knows_language, #knows_language=, #legal_address, #legal_address=, #legal_name, #legal_name=, #legal_representative, #legal_representative=, #lei_code, #lei_code=, #location, #location=, #logo, #logo=, #makes_offer, #makes_offer=, #member, #member=, #member_of, #member_of=, #members, #members=, #naics, #naics=, #nonprofit_status, #nonprofit_status=, #number_of_employees, #number_of_employees=, #ownership_funding_info, #ownership_funding_info=, #owns, #owns=, #parent_organization, #parent_organization=, #publishing_principles, #publishing_principles=, #review, #review=, #reviews, #reviews=, #seeks, #seeks=, #service_area, #service_area=, #skills, #skills=, #slogan, #slogan=, #sponsor, #sponsor=, #sub_organization, #sub_organization=, #tax_id, #tax_id=, #telephone, #telephone=, #unnamed_sources_policy, #unnamed_sources_policy=, #vat_id, #vat_id=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/schema_org/mixins/sports_team.rb', line 11

def self.schema_property_definitions
  {
    athlete: {
      schema_name: "athlete",
      schema_url: "https://schema.org/athlete",
      comment_lines: ["A person that acts as performing member of a sports team; a player as opposed to a coach."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    coach: {
      schema_name: "coach",
      schema_url: "https://schema.org/coach",
      comment_lines: ["A person that acts in a coaching role for a sports team."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    gender: {
      schema_name: "gender",
      schema_url: "https://schema.org/gender",
      comment_lines: ["Gender of something, typically a [[Person]], but possibly also fictional characters, animals, etc. While https://schema.org/Male and https://schema.org/Female may be used, text strings are also acceptable for people who are not a binary gender. The [[gender]] property can also be used in an extended sense to cover e.g. the gender of sports teams. As with the gender of individuals, we do not try to enumerate all possibilities. A mixed-gender [[SportsTeam]] can be indicated with a text value of \"Mixed\"."].freeze,
      ranges: ["GenderType", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#athleteObject

A person that acts as performing member of a sports team; a player as opposed to a coach.



47
48
49
# File 'lib/schema_org/mixins/sports_team.rb', line 47

def athlete
  read_property(:athlete)
end

#athlete=(value) ⇒ Object

A person that acts as performing member of a sports team; a player as opposed to a coach.



52
53
54
# File 'lib/schema_org/mixins/sports_team.rb', line 52

def athlete=(value)
  write_property(:athlete, value)
end

#coachObject

A person that acts in a coaching role for a sports team.



57
58
59
# File 'lib/schema_org/mixins/sports_team.rb', line 57

def coach
  read_property(:coach)
end

#coach=(value) ⇒ Object

A person that acts in a coaching role for a sports team.



62
63
64
# File 'lib/schema_org/mixins/sports_team.rb', line 62

def coach=(value)
  write_property(:coach, value)
end

#genderObject

Gender of something, typically a [[Person]], but possibly also fictional characters, animals, etc. While https://schema.org/Male and https://schema.org/Female may be used, text strings are also acceptable for people who are not a binary gender. The [[gender]] property can also be used in an extended sense to cover e.g. the gender of sports teams. As with the gender of individuals, we do not try to enumerate all possibilities. A mixed-gender [[SportsTeam]] can be indicated with a text value of "Mixed".



67
68
69
# File 'lib/schema_org/mixins/sports_team.rb', line 67

def gender
  read_property(:gender)
end

#gender=(value) ⇒ Object

Gender of something, typically a [[Person]], but possibly also fictional characters, animals, etc. While https://schema.org/Male and https://schema.org/Female may be used, text strings are also acceptable for people who are not a binary gender. The [[gender]] property can also be used in an extended sense to cover e.g. the gender of sports teams. As with the gender of individuals, we do not try to enumerate all possibilities. A mixed-gender [[SportsTeam]] can be indicated with a text value of "Mixed".



72
73
74
# File 'lib/schema_org/mixins/sports_team.rb', line 72

def gender=(value)
  write_property(:gender, value)
end