Module: SchemaOrg::Mixins::StatisticalPopulation

Includes:
Intangible
Included in:
StatisticalPopulation
Defined in:
lib/schema_org/mixins/statistical_population.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
# File 'lib/schema_org/mixins/statistical_population.rb', line 11

def self.schema_property_definitions
  {
    population_type: {
      schema_name: "populationType",
      schema_url: "https://schema.org/populationType",
      comment_lines: ["Indicates the populationType common to all members of a [[StatisticalPopulation]] or all cases within the scope of a [[StatisticalVariable]]."].freeze,
      ranges: [].freeze,
      external_ranges: ["Class"].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#population_typeObject

Indicates the populationType common to all members of a [[StatisticalPopulation]] or all cases within the scope of a [[StatisticalVariable]].



27
28
29
# File 'lib/schema_org/mixins/statistical_population.rb', line 27

def population_type
  read_property(:population_type)
end

#population_type=(value) ⇒ Object

Indicates the populationType common to all members of a [[StatisticalPopulation]] or all cases within the scope of a [[StatisticalVariable]].



32
33
34
# File 'lib/schema_org/mixins/statistical_population.rb', line 32

def population_type=(value)
  write_property(:population_type, value)
end