Module: SchemaOrg::Mixins::TherapeuticProcedure

Includes:
MedicalProcedure
Included in:
MedicalTherapy, PsychologicalTreatment, TherapeuticProcedure
Defined in:
lib/schema_org/mixins/therapeutic_procedure.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from MedicalProcedure

#body_location, #body_location=, #followup, #followup=, #how_performed, #how_performed=, #preparation, #preparation=, #procedure_type, #procedure_type=, #status, #status=

Methods included from MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/schema_org/mixins/therapeutic_procedure.rb', line 11

def self.schema_property_definitions
  {
    adverse_outcome: {
      schema_name: "adverseOutcome",
      schema_url: "https://schema.org/adverseOutcome",
      comment_lines: ["A possible complication and/or side effect of this therapy. If it is known that an adverse outcome is serious (resulting in death, disability, or permanent damage; requiring hospitalization; or otherwise life-threatening or requiring immediate medical attention), tag it as a seriousAdverseOutcome instead."].freeze,
      ranges: ["MedicalEntity"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    dose_schedule: {
      schema_name: "doseSchedule",
      schema_url: "https://schema.org/doseSchedule",
      comment_lines: ["A dosing schedule for the drug for a given population, either observed, recommended, or maximum dose based on the type used."].freeze,
      ranges: ["DoseSchedule"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    drug: {
      schema_name: "drug",
      schema_url: "https://schema.org/drug",
      comment_lines: ["Specifying a drug or medicine used in a medication procedure."].freeze,
      ranges: ["Drug"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#adverse_outcomeObject

A possible complication and/or side effect of this therapy. If it is known that an adverse outcome is serious (resulting in death, disability, or permanent damage; requiring hospitalization; or otherwise life-threatening or requiring immediate medical attention), tag it as a seriousAdverseOutcome instead.



47
48
49
# File 'lib/schema_org/mixins/therapeutic_procedure.rb', line 47

def adverse_outcome
  read_property(:adverse_outcome)
end

#adverse_outcome=(value) ⇒ Object

A possible complication and/or side effect of this therapy. If it is known that an adverse outcome is serious (resulting in death, disability, or permanent damage; requiring hospitalization; or otherwise life-threatening or requiring immediate medical attention), tag it as a seriousAdverseOutcome instead.



52
53
54
# File 'lib/schema_org/mixins/therapeutic_procedure.rb', line 52

def adverse_outcome=(value)
  write_property(:adverse_outcome, value)
end

#dose_scheduleObject

A dosing schedule for the drug for a given population, either observed, recommended, or maximum dose based on the type used.



57
58
59
# File 'lib/schema_org/mixins/therapeutic_procedure.rb', line 57

def dose_schedule
  read_property(:dose_schedule)
end

#dose_schedule=(value) ⇒ Object

A dosing schedule for the drug for a given population, either observed, recommended, or maximum dose based on the type used.



62
63
64
# File 'lib/schema_org/mixins/therapeutic_procedure.rb', line 62

def dose_schedule=(value)
  write_property(:dose_schedule, value)
end

#drugObject

Specifying a drug or medicine used in a medication procedure.



67
68
69
# File 'lib/schema_org/mixins/therapeutic_procedure.rb', line 67

def drug
  read_property(:drug)
end

#drug=(value) ⇒ Object

Specifying a drug or medicine used in a medication procedure.



72
73
74
# File 'lib/schema_org/mixins/therapeutic_procedure.rb', line 72

def drug=(value)
  write_property(:drug, value)
end