Module: SchemaOrg::Mixins::Thing

Included in:
Action, BioChemEntity, CreativeWork, Event, Intangible, MedicalEntity, Organization, Person, Place, Product, StupidType, Taxon, Thing
Defined in:
lib/schema_org/mixins/thing.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.schema_property_definitionsObject



9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/schema_org/mixins/thing.rb', line 9

def self.schema_property_definitions
  {
    additional_type: {
      schema_name: "additionalType",
      schema_url: "https://schema.org/additionalType",
      comment_lines: ["An additional type for the item, typically used for adding more specific types from external vocabularies in microdata syntax. This is a relationship between something and a class that the thing is in. Typically the value is a URI-identified RDF class, and in this case corresponds to the", "    use of rdf:type in RDF. Text values can be used sparingly, for cases where useful information can be added without their being an appropriate schema to reference. In the case of text values, the class label should follow the schema.org <a href=\"https://schema.org/docs/styleguide.html\">style guide</a>."].freeze,
      ranges: ["Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    alternate_name: {
      schema_name: "alternateName",
      schema_url: "https://schema.org/alternateName",
      comment_lines: ["An alias for the item."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    description: {
      schema_name: "description",
      schema_url: "https://schema.org/description",
      comment_lines: ["A description of the item."].freeze,
      ranges: ["Text", "TextObject"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    disambiguating_description: {
      schema_name: "disambiguatingDescription",
      schema_url: "https://schema.org/disambiguatingDescription",
      comment_lines: ["A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    identifier: {
      schema_name: "identifier",
      schema_url: "https://schema.org/identifier",
      comment_lines: ["The identifier property represents any kind of identifier for any kind of [[Thing]], such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See [background notes](/docs/datamodel.html#identifierBg) for more details."].freeze,
      ranges: ["PropertyValue", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    image: {
      schema_name: "image",
      schema_url: "https://schema.org/image",
      comment_lines: ["An image of the item. This can be a [[URL]] or a fully described [[ImageObject]]."].freeze,
      ranges: ["ImageObject", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    main_entity_of_page: {
      schema_name: "mainEntityOfPage",
      schema_url: "https://schema.org/mainEntityOfPage",
      comment_lines: ["Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See [background notes](/docs/datamodel.html#mainEntityBackground) for details."].freeze,
      ranges: ["CreativeWork", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: "mainEntity",
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    name: {
      schema_name: "name",
      schema_url: "https://schema.org/name",
      comment_lines: ["The name of the item."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    owner: {
      schema_name: "owner",
      schema_url: "https://schema.org/owner",
      comment_lines: ["A person or organization who owns this Thing."].freeze,
      ranges: ["Organization", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: "owns",
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    potential_action: {
      schema_name: "potentialAction",
      schema_url: "https://schema.org/potentialAction",
      comment_lines: ["Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role."].freeze,
      ranges: ["Action"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    same_as: {
      schema_name: "sameAs",
      schema_url: "https://schema.org/sameAs",
      comment_lines: ["URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website."].freeze,
      ranges: ["URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    subject_of: {
      schema_name: "subjectOf",
      schema_url: "https://schema.org/subjectOf",
      comment_lines: ["A CreativeWork or Event about this Thing."].freeze,
      ranges: ["CreativeWork", "Event"].freeze,
      external_ranges: [].freeze,
      inverse_of: "about",
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    url: {
      schema_name: "url",
      schema_url: "https://schema.org/url",
      comment_lines: ["URL of the item."].freeze,
      ranges: ["URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#additional_typeObject

An additional type for the item, typically used for adding more specific types from external vocabularies in microdata syntax. This is a relationship between something and a class that the thing is in. Typically the value is a URI-identified RDF class, and in this case corresponds to the use of rdf:type in RDF. Text values can be used sparingly, for cases where useful information can be added without their being an appropriate schema to reference. In the case of text values, the class label should follow the schema.org style guide.



146
147
148
# File 'lib/schema_org/mixins/thing.rb', line 146

def additional_type
  read_property(:additional_type)
end

#additional_type=(value) ⇒ Object

An additional type for the item, typically used for adding more specific types from external vocabularies in microdata syntax. This is a relationship between something and a class that the thing is in. Typically the value is a URI-identified RDF class, and in this case corresponds to the use of rdf:type in RDF. Text values can be used sparingly, for cases where useful information can be added without their being an appropriate schema to reference. In the case of text values, the class label should follow the schema.org style guide.



152
153
154
# File 'lib/schema_org/mixins/thing.rb', line 152

def additional_type=(value)
  write_property(:additional_type, value)
end

#alternate_nameObject

An alias for the item.



157
158
159
# File 'lib/schema_org/mixins/thing.rb', line 157

def alternate_name
  read_property(:alternate_name)
end

#alternate_name=(value) ⇒ Object

An alias for the item.



162
163
164
# File 'lib/schema_org/mixins/thing.rb', line 162

def alternate_name=(value)
  write_property(:alternate_name, value)
end

#descriptionObject

A description of the item.



167
168
169
# File 'lib/schema_org/mixins/thing.rb', line 167

def description
  read_property(:description)
end

#description=(value) ⇒ Object

A description of the item.



172
173
174
# File 'lib/schema_org/mixins/thing.rb', line 172

def description=(value)
  write_property(:description, value)
end

#disambiguating_descriptionObject

A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.



177
178
179
# File 'lib/schema_org/mixins/thing.rb', line 177

def disambiguating_description
  read_property(:disambiguating_description)
end

#disambiguating_description=(value) ⇒ Object

A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.



182
183
184
# File 'lib/schema_org/mixins/thing.rb', line 182

def disambiguating_description=(value)
  write_property(:disambiguating_description, value)
end

#identifierObject

The identifier property represents any kind of identifier for any kind of [[Thing]], such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.



187
188
189
# File 'lib/schema_org/mixins/thing.rb', line 187

def identifier
  read_property(:identifier)
end

#identifier=(value) ⇒ Object

The identifier property represents any kind of identifier for any kind of [[Thing]], such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.



192
193
194
# File 'lib/schema_org/mixins/thing.rb', line 192

def identifier=(value)
  write_property(:identifier, value)
end

#imageObject

An image of the item. This can be a [[URL]] or a fully described [[ImageObject]].



197
198
199
# File 'lib/schema_org/mixins/thing.rb', line 197

def image
  read_property(:image)
end

#image=(value) ⇒ Object

An image of the item. This can be a [[URL]] or a fully described [[ImageObject]].



202
203
204
# File 'lib/schema_org/mixins/thing.rb', line 202

def image=(value)
  write_property(:image, value)
end

#main_entity_of_pageObject

Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details. Inverse-property: mainEntity.



208
209
210
# File 'lib/schema_org/mixins/thing.rb', line 208

def main_entity_of_page
  read_property(:main_entity_of_page)
end

#main_entity_of_page=(value) ⇒ Object

Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details. Inverse-property: mainEntity.



214
215
216
# File 'lib/schema_org/mixins/thing.rb', line 214

def main_entity_of_page=(value)
  write_property(:main_entity_of_page, value)
end

#nameObject

The name of the item.



219
220
221
# File 'lib/schema_org/mixins/thing.rb', line 219

def name
  read_property(:name)
end

#name=(value) ⇒ Object

The name of the item.



224
225
226
# File 'lib/schema_org/mixins/thing.rb', line 224

def name=(value)
  write_property(:name, value)
end

#ownerObject

A person or organization who owns this Thing. Inverse-property: owns.



230
231
232
# File 'lib/schema_org/mixins/thing.rb', line 230

def owner
  read_property(:owner)
end

#owner=(value) ⇒ Object

A person or organization who owns this Thing. Inverse-property: owns.



236
237
238
# File 'lib/schema_org/mixins/thing.rb', line 236

def owner=(value)
  write_property(:owner, value)
end

#potential_actionObject

Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.



241
242
243
# File 'lib/schema_org/mixins/thing.rb', line 241

def potential_action
  read_property(:potential_action)
end

#potential_action=(value) ⇒ Object

Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.



246
247
248
# File 'lib/schema_org/mixins/thing.rb', line 246

def potential_action=(value)
  write_property(:potential_action, value)
end

#same_asObject

URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.



251
252
253
# File 'lib/schema_org/mixins/thing.rb', line 251

def same_as
  read_property(:same_as)
end

#same_as=(value) ⇒ Object

URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.



256
257
258
# File 'lib/schema_org/mixins/thing.rb', line 256

def same_as=(value)
  write_property(:same_as, value)
end

#subject_ofObject

A CreativeWork or Event about this Thing. Inverse-property: about.



262
263
264
# File 'lib/schema_org/mixins/thing.rb', line 262

def subject_of
  read_property(:subject_of)
end

#subject_of=(value) ⇒ Object

A CreativeWork or Event about this Thing. Inverse-property: about.



268
269
270
# File 'lib/schema_org/mixins/thing.rb', line 268

def subject_of=(value)
  write_property(:subject_of, value)
end

#urlObject

URL of the item.



273
274
275
# File 'lib/schema_org/mixins/thing.rb', line 273

def url
  read_property(:url)
end

#url=(value) ⇒ Object

URL of the item.



278
279
280
# File 'lib/schema_org/mixins/thing.rb', line 278

def url=(value)
  write_property(:url, value)
end