Module: SchemaOrg::Mixins::TipAction
Class Method Summary collapse
Instance Method Summary collapse
-
#recipient ⇒ Object
A sub property of participant.
-
#recipient=(value) ⇒ Object
A sub property of participant.
Methods included from TradeAction
#price, #price=, #price_currency, #price_currency=, #price_specification, #price_specification=
Methods included from Action
#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, #start_time, #start_time=, #target, #target=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 |
# File 'lib/schema_org/mixins/tip_action.rb', line 11 def self.schema_property_definitions { recipient: { schema_name: "recipient", schema_url: "https://schema.org/recipient", comment_lines: ["A sub property of participant. The participant who is at the receiving end of the action."].freeze, ranges: ["Audience", "ContactPoint", "Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#recipient ⇒ Object
A sub property of participant. The participant who is at the receiving end of the action.
27 28 29 |
# File 'lib/schema_org/mixins/tip_action.rb', line 27 def recipient read_property(:recipient) end |
#recipient=(value) ⇒ Object
A sub property of participant. The participant who is at the receiving end of the action.
32 33 34 |
# File 'lib/schema_org/mixins/tip_action.rb', line 32 def recipient=(value) write_property(:recipient, value) end |