Module: SchemaOrg::Mixins::TouristAttraction

Includes:
Place
Included in:
TouristAttraction
Defined in:
lib/schema_org/mixins/tourist_attraction.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Place

#additional_property, #additional_property=, #address, #address=, #aggregate_rating, #aggregate_rating=, #amenity_feature, #amenity_feature=, #branch_code, #branch_code=, #contained_in, #contained_in=, #contained_in_place, #contained_in_place=, #contains_place, #contains_place=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #geo, #geo=, #geo_contains, #geo_contains=, #geo_covered_by, #geo_covered_by=, #geo_covers, #geo_covers=, #geo_crosses, #geo_crosses=, #geo_disjoint, #geo_disjoint=, #geo_equals, #geo_equals=, #geo_intersects, #geo_intersects=, #geo_overlaps, #geo_overlaps=, #geo_touches, #geo_touches=, #geo_within, #geo_within=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_drive_through_service, #has_drive_through_service=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_map, #has_map=, #is_accessible_for_free, #is_accessible_for_free=, #isic_v4, #isic_v4=, #keywords, #keywords=, #latitude, #latitude=, #logo, #logo=, #longitude, #longitude=, #map, #map=, #maps, #maps=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #opening_hours_specification, #opening_hours_specification=, #photo, #photo=, #photos, #photos=, #public_access, #public_access=, #review, #review=, #reviews, #reviews=, #slogan, #slogan=, #smoking_allowed, #smoking_allowed=, #special_opening_hours_specification, #special_opening_hours_specification=, #telephone, #telephone=, #tour_booking_page, #tour_booking_page=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/schema_org/mixins/tourist_attraction.rb', line 11

def self.schema_property_definitions
  {
    available_language: {
      schema_name: "availableLanguage",
      schema_url: "https://schema.org/availableLanguage",
      comment_lines: ["A language someone may use with or at the item, service or place. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[inLanguage]]."].freeze,
      ranges: ["Language", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    tourist_type: {
      schema_name: "touristType",
      schema_url: "https://schema.org/touristType",
      comment_lines: ["Attraction suitable for type(s) of tourist. E.g. children, visitors from a particular country, etc."].freeze,
      ranges: ["Audience", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#available_languageObject

A language someone may use with or at the item, service or place. Please use one of the language codes from the IETF BCP 47 standard. See also [[inLanguage]].



37
38
39
# File 'lib/schema_org/mixins/tourist_attraction.rb', line 37

def available_language
  read_property(:available_language)
end

#available_language=(value) ⇒ Object

A language someone may use with or at the item, service or place. Please use one of the language codes from the IETF BCP 47 standard. See also [[inLanguage]].



42
43
44
# File 'lib/schema_org/mixins/tourist_attraction.rb', line 42

def available_language=(value)
  write_property(:available_language, value)
end

#tourist_typeObject

Attraction suitable for type(s) of tourist. E.g. children, visitors from a particular country, etc.



47
48
49
# File 'lib/schema_org/mixins/tourist_attraction.rb', line 47

def tourist_type
  read_property(:tourist_type)
end

#tourist_type=(value) ⇒ Object

Attraction suitable for type(s) of tourist. E.g. children, visitors from a particular country, etc.



52
53
54
# File 'lib/schema_org/mixins/tourist_attraction.rb', line 52

def tourist_type=(value)
  write_property(:tourist_type, value)
end