Module: SchemaOrg::Mixins::TransferAction

Includes:
Action
Included in:
BorrowAction, DonateAction, DownloadAction, GiveAction, LendAction, MoneyTransfer, ReceiveAction, ReturnAction, SendAction, TakeAction, TransferAction
Defined in:
lib/schema_org/mixins/transfer_action.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Action

#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, #start_time, #start_time=, #target, #target=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/schema_org/mixins/transfer_action.rb', line 11

def self.schema_property_definitions
  {
    from_location: {
      schema_name: "fromLocation",
      schema_url: "https://schema.org/fromLocation",
      comment_lines: ["A sub property of location. The original location of the object or the agent before the action."].freeze,
      ranges: ["Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    to_location: {
      schema_name: "toLocation",
      schema_url: "https://schema.org/toLocation",
      comment_lines: ["A sub property of location. The final location of the object or the agent after the action."].freeze,
      ranges: ["Place"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#from_locationObject

A sub property of location. The original location of the object or the agent before the action.



37
38
39
# File 'lib/schema_org/mixins/transfer_action.rb', line 37

def from_location
  read_property(:from_location)
end

#from_location=(value) ⇒ Object

A sub property of location. The original location of the object or the agent before the action.



42
43
44
# File 'lib/schema_org/mixins/transfer_action.rb', line 42

def from_location=(value)
  write_property(:from_location, value)
end

#to_locationObject

A sub property of location. The final location of the object or the agent after the action.



47
48
49
# File 'lib/schema_org/mixins/transfer_action.rb', line 47

def to_location
  read_property(:to_location)
end

#to_location=(value) ⇒ Object

A sub property of location. The final location of the object or the agent after the action.



52
53
54
# File 'lib/schema_org/mixins/transfer_action.rb', line 52

def to_location=(value)
  write_property(:to_location, value)
end