Module: SchemaOrg::Mixins::UnitPriceSpecification

Includes:
PriceSpecification
Included in:
UnitPriceSpecification
Defined in:
lib/schema_org/mixins/unit_price_specification.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from PriceSpecification

#eligible_quantity, #eligible_quantity=, #eligible_transaction_volume, #eligible_transaction_volume=, #max_price, #max_price=, #membership_points_earned, #membership_points_earned=, #min_price, #min_price=, #price, #price=, #price_currency, #price_currency=, #valid_for_member_tier, #valid_for_member_tier=, #valid_from, #valid_from=, #valid_through, #valid_through=, #value_added_tax_included, #value_added_tax_included=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/schema_org/mixins/unit_price_specification.rb', line 11

def self.schema_property_definitions
  {
    billing_duration: {
      schema_name: "billingDuration",
      schema_url: "https://schema.org/billingDuration",
      comment_lines: ["Specifies for how long this price (or price component) will be billed. Can be used, for example, to model the contractual duration of a subscription or payment plan. Type can be either a Duration or a Number (in which case the unit of measurement, for example month, is specified by the unitCode property)."].freeze,
      ranges: ["Duration", "Number", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    billing_increment: {
      schema_name: "billingIncrement",
      schema_url: "https://schema.org/billingIncrement",
      comment_lines: ["This property specifies the minimal quantity and rounding increment that will be the basis for the billing. The unit of measurement is specified by the unitCode property."].freeze,
      ranges: ["Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    billing_start: {
      schema_name: "billingStart",
      schema_url: "https://schema.org/billingStart",
      comment_lines: ["Specifies after how much time this price (or price component) becomes valid and billing starts. Can be used, for example, to model a price increase after the first year of a subscription. The unit of measurement is specified by the unitCode property."].freeze,
      ranges: ["Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    price_component_type: {
      schema_name: "priceComponentType",
      schema_url: "https://schema.org/priceComponentType",
      comment_lines: ["Identifies a price component (for example, a line item on an invoice), part of the total price for an offer."].freeze,
      ranges: ["PriceComponentTypeEnumeration"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    price_type: {
      schema_name: "priceType",
      schema_url: "https://schema.org/priceType",
      comment_lines: ["Defines the type of a price specified for an offered product, for example a list price, a (temporary) sale price or a manufacturer suggested retail price. If multiple prices are specified for an offer the [[priceType]] property can be used to identify the type of each such specified price. The value of priceType can be specified as a value from enumeration PriceTypeEnumeration or, a UN/EDIFACT 5387 code, or as a free form text string for price types that are not already predefined in PriceTypeEnumeration."].freeze,
      ranges: ["PriceTypeEnumeration", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    reference_quantity: {
      schema_name: "referenceQuantity",
      schema_url: "https://schema.org/referenceQuantity",
      comment_lines: ["The reference quantity for which a certain price applies, e.g. 1 EUR per 4 kWh of electricity. This property is a replacement for unitOfMeasurement for the advanced cases where the price does not relate to a standard unit."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    unit_code: {
      schema_name: "unitCode",
      schema_url: "https://schema.org/unitCode",
      comment_lines: ["The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL. Other codes than the UN/CEFACT Common Code may be used with a prefix followed by a colon."].freeze,
      ranges: ["Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    unit_text: {
      schema_name: "unitText",
      schema_url: "https://schema.org/unitText",
      comment_lines: ["A string or text indicating the unit of measurement. Useful if you cannot provide a standard unit code for", "<a href='unitCode'>unitCode</a>."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#billing_durationObject

Specifies for how long this price (or price component) will be billed. Can be used, for example, to model the contractual duration of a subscription or payment plan. Type can be either a Duration or a Number (in which case the unit of measurement, for example month, is specified by the unitCode property).



97
98
99
# File 'lib/schema_org/mixins/unit_price_specification.rb', line 97

def billing_duration
  read_property(:billing_duration)
end

#billing_duration=(value) ⇒ Object

Specifies for how long this price (or price component) will be billed. Can be used, for example, to model the contractual duration of a subscription or payment plan. Type can be either a Duration or a Number (in which case the unit of measurement, for example month, is specified by the unitCode property).



102
103
104
# File 'lib/schema_org/mixins/unit_price_specification.rb', line 102

def billing_duration=(value)
  write_property(:billing_duration, value)
end

#billing_incrementObject

This property specifies the minimal quantity and rounding increment that will be the basis for the billing. The unit of measurement is specified by the unitCode property.



107
108
109
# File 'lib/schema_org/mixins/unit_price_specification.rb', line 107

def billing_increment
  read_property(:billing_increment)
end

#billing_increment=(value) ⇒ Object

This property specifies the minimal quantity and rounding increment that will be the basis for the billing. The unit of measurement is specified by the unitCode property.



112
113
114
# File 'lib/schema_org/mixins/unit_price_specification.rb', line 112

def billing_increment=(value)
  write_property(:billing_increment, value)
end

#billing_startObject

Specifies after how much time this price (or price component) becomes valid and billing starts. Can be used, for example, to model a price increase after the first year of a subscription. The unit of measurement is specified by the unitCode property.



117
118
119
# File 'lib/schema_org/mixins/unit_price_specification.rb', line 117

def billing_start
  read_property(:billing_start)
end

#billing_start=(value) ⇒ Object

Specifies after how much time this price (or price component) becomes valid and billing starts. Can be used, for example, to model a price increase after the first year of a subscription. The unit of measurement is specified by the unitCode property.



122
123
124
# File 'lib/schema_org/mixins/unit_price_specification.rb', line 122

def billing_start=(value)
  write_property(:billing_start, value)
end

#price_component_typeObject

Identifies a price component (for example, a line item on an invoice), part of the total price for an offer.



127
128
129
# File 'lib/schema_org/mixins/unit_price_specification.rb', line 127

def price_component_type
  read_property(:price_component_type)
end

#price_component_type=(value) ⇒ Object

Identifies a price component (for example, a line item on an invoice), part of the total price for an offer.



132
133
134
# File 'lib/schema_org/mixins/unit_price_specification.rb', line 132

def price_component_type=(value)
  write_property(:price_component_type, value)
end

#price_typeObject

Defines the type of a price specified for an offered product, for example a list price, a (temporary) sale price or a manufacturer suggested retail price. If multiple prices are specified for an offer the [[priceType]] property can be used to identify the type of each such specified price. The value of priceType can be specified as a value from enumeration PriceTypeEnumeration or, a UN/EDIFACT 5387 code, or as a free form text string for price types that are not already predefined in PriceTypeEnumeration.



137
138
139
# File 'lib/schema_org/mixins/unit_price_specification.rb', line 137

def price_type
  read_property(:price_type)
end

#price_type=(value) ⇒ Object

Defines the type of a price specified for an offered product, for example a list price, a (temporary) sale price or a manufacturer suggested retail price. If multiple prices are specified for an offer the [[priceType]] property can be used to identify the type of each such specified price. The value of priceType can be specified as a value from enumeration PriceTypeEnumeration or, a UN/EDIFACT 5387 code, or as a free form text string for price types that are not already predefined in PriceTypeEnumeration.



142
143
144
# File 'lib/schema_org/mixins/unit_price_specification.rb', line 142

def price_type=(value)
  write_property(:price_type, value)
end

#reference_quantityObject

The reference quantity for which a certain price applies, e.g. 1 EUR per 4 kWh of electricity. This property is a replacement for unitOfMeasurement for the advanced cases where the price does not relate to a standard unit.



147
148
149
# File 'lib/schema_org/mixins/unit_price_specification.rb', line 147

def reference_quantity
  read_property(:reference_quantity)
end

#reference_quantity=(value) ⇒ Object

The reference quantity for which a certain price applies, e.g. 1 EUR per 4 kWh of electricity. This property is a replacement for unitOfMeasurement for the advanced cases where the price does not relate to a standard unit.



152
153
154
# File 'lib/schema_org/mixins/unit_price_specification.rb', line 152

def reference_quantity=(value)
  write_property(:reference_quantity, value)
end

#unit_codeObject

The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL. Other codes than the UN/CEFACT Common Code may be used with a prefix followed by a colon.



157
158
159
# File 'lib/schema_org/mixins/unit_price_specification.rb', line 157

def unit_code
  read_property(:unit_code)
end

#unit_code=(value) ⇒ Object

The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL. Other codes than the UN/CEFACT Common Code may be used with a prefix followed by a colon.



162
163
164
# File 'lib/schema_org/mixins/unit_price_specification.rb', line 162

def unit_code=(value)
  write_property(:unit_code, value)
end

#unit_textObject

A string or text indicating the unit of measurement. Useful if you cannot provide a standard unit code for unitCode.



168
169
170
# File 'lib/schema_org/mixins/unit_price_specification.rb', line 168

def unit_text
  read_property(:unit_text)
end

#unit_text=(value) ⇒ Object

A string or text indicating the unit of measurement. Useful if you cannot provide a standard unit code for unitCode.



174
175
176
# File 'lib/schema_org/mixins/unit_price_specification.rb', line 174

def unit_text=(value)
  write_property(:unit_text, value)
end