Module: SchemaOrg::Mixins::Vehicle

Includes:
Product
Included in:
BusOrCoach, Car, Motorcycle, MotorizedBicycle, Vehicle
Defined in:
lib/schema_org/mixins/vehicle.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Product

#additional_property, #additional_property=, #aggregate_rating, #aggregate_rating=, #asin, #asin=, #audience, #audience=, #award, #award=, #awards, #awards=, #brand, #brand=, #category, #category=, #color, #color=, #color_swatch, #color_swatch=, #country_of_assembly, #country_of_assembly=, #country_of_last_processing, #country_of_last_processing=, #country_of_origin, #country_of_origin=, #depth, #depth=, #display_location, #display_location=, #funding, #funding=, #gtin, #gtin12, #gtin12=, #gtin13, #gtin13=, #gtin14, #gtin14=, #gtin8, #gtin8=, #gtin=, #has_adult_consideration, #has_adult_consideration=, #has_certification, #has_certification=, #has_energy_consumption_details, #has_energy_consumption_details=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_measurement, #has_measurement=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_product_return_policy, #has_product_return_policy=, #height, #height=, #in_product_group_with_id, #in_product_group_with_id=, #is_accessory_or_spare_part_for, #is_accessory_or_spare_part_for=, #is_consumable_for, #is_consumable_for=, #is_family_friendly, #is_family_friendly=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #is_variant_of, #is_variant_of=, #item_condition, #item_condition=, #keywords, #keywords=, #logo, #logo=, #manufacturer, #manufacturer=, #material, #material=, #mobile_url, #mobile_url=, #model, #model=, #mpn, #mpn=, #negative_notes, #negative_notes=, #nsn, #nsn=, #offers, #offers=, #pattern, #pattern=, #positive_notes, #positive_notes=, #product_id, #product_id=, #release_date, #release_date=, #review, #review=, #reviews, #reviews=, #size, #size=, #sku, #sku=, #slogan, #slogan=, #weight, #weight=, #width, #width=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/schema_org/mixins/vehicle.rb', line 11

def self.schema_property_definitions
  {
    acceleration_time: {
      schema_name: "accelerationTime",
      schema_url: "https://schema.org/accelerationTime",
      comment_lines: ["The time needed to accelerate the vehicle from a given start velocity to a given target velocity.\\n\\nTypical unit code(s): SEC for seconds\\n\\n* Note: There are unfortunately no standard unit codes for seconds/0..100 km/h or seconds/0..60 mph. Simply use \"SEC\" for seconds and indicate the velocities in the [[name]] of the [[QuantitativeValue]], or use [[valueReference]] with a [[QuantitativeValue]] of 0..60 mph or 0..100 km/h to specify the reference speeds."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    body_type: {
      schema_name: "bodyType",
      schema_url: "https://schema.org/bodyType",
      comment_lines: ["Indicates the design and body style of the vehicle (e.g. station wagon, hatchback, etc.)."].freeze,
      ranges: ["QualitativeValue", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    call_sign: {
      schema_name: "callSign",
      schema_url: "https://schema.org/callSign",
      comment_lines: ["A [callsign](https://en.wikipedia.org/wiki/Call_sign), as used in broadcasting and radio communications to identify people, radio and TV stations, or vehicles."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    cargo_volume: {
      schema_name: "cargoVolume",
      schema_url: "https://schema.org/cargoVolume",
      comment_lines: ["The available volume for cargo or luggage. For automobiles, this is usually the trunk volume.\\n\\nTypical unit code(s): LTR for liters, FTQ for cubic foot/feet\\n\\nNote: You can use [[minValue]] and [[maxValue]] to indicate ranges."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    date_vehicle_first_registered: {
      schema_name: "dateVehicleFirstRegistered",
      schema_url: "https://schema.org/dateVehicleFirstRegistered",
      comment_lines: ["The date of the first registration of the vehicle with the respective public authorities."].freeze,
      ranges: ["Date"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    drive_wheel_configuration: {
      schema_name: "driveWheelConfiguration",
      schema_url: "https://schema.org/driveWheelConfiguration",
      comment_lines: ["The drive wheel configuration, i.e. which roadwheels will receive torque from the vehicle's engine via the drivetrain."].freeze,
      ranges: ["DriveWheelConfigurationValue", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    emissions_co2: {
      schema_name: "emissionsCO2",
      schema_url: "https://schema.org/emissionsCO2",
      comment_lines: ["The CO2 emissions in g/km. When used in combination with a QuantitativeValue, put \"g/km\" into the unitText property of that value, since there is no UN/CEFACT Common Code for \"g/km\"."].freeze,
      ranges: ["Number"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    fuel_capacity: {
      schema_name: "fuelCapacity",
      schema_url: "https://schema.org/fuelCapacity",
      comment_lines: ["The capacity of the fuel tank or in the case of electric cars, the battery. If there are multiple components for storage, this should indicate the total of all storage of the same type.\\n\\nTypical unit code(s): LTR for liters, GLL of US gallons, GLI for UK / imperial gallons, AMH for ampere-hours (for electrical vehicles)."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    fuel_consumption: {
      schema_name: "fuelConsumption",
      schema_url: "https://schema.org/fuelConsumption",
      comment_lines: ["The amount of fuel consumed for traveling a particular distance or temporal duration with the given vehicle (e.g. liters per 100 km).\\n\\n* Note 1: There are unfortunately no standard unit codes for liters per 100 km.  Use [[unitText]] to indicate the unit of measurement, e.g. L/100 km.\\n* Note 2: There are two ways of indicating the fuel consumption, [[fuelConsumption]] (e.g. 8 liters per 100 km) and [[fuelEfficiency]] (e.g. 30 miles per gallon). They are reciprocal.\\n* Note 3: Often, the absolute value is useful only when related to driving speed (\"at 80 km/h\") or usage pattern (\"city traffic\"). You can use [[valueReference]] to link the value for the fuel consumption to another value."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    fuel_efficiency: {
      schema_name: "fuelEfficiency",
      schema_url: "https://schema.org/fuelEfficiency",
      comment_lines: ["The distance traveled per unit of fuel used; most commonly miles per gallon (mpg) or kilometers per liter (km/L).\\n\\n* Note 1: There are unfortunately no standard unit codes for miles per gallon or kilometers per liter. Use [[unitText]] to indicate the unit of measurement, e.g. mpg or km/L.\\n* Note 2: There are two ways of indicating the fuel consumption, [[fuelConsumption]] (e.g. 8 liters per 100 km) and [[fuelEfficiency]] (e.g. 30 miles per gallon). They are reciprocal.\\n* Note 3: Often, the absolute value is useful only when related to driving speed (\"at 80 km/h\") or usage pattern (\"city traffic\"). You can use [[valueReference]] to link the value for the fuel economy to another value."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    fuel_type: {
      schema_name: "fuelType",
      schema_url: "https://schema.org/fuelType",
      comment_lines: ["The type of fuel suitable for the engine or engines of the vehicle. If the vehicle has only one engine, this property can be attached directly to the vehicle."].freeze,
      ranges: ["QualitativeValue", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    known_vehicle_damages: {
      schema_name: "knownVehicleDamages",
      schema_url: "https://schema.org/knownVehicleDamages",
      comment_lines: ["A textual description of known damages, both repaired and unrepaired."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    meets_emission_standard: {
      schema_name: "meetsEmissionStandard",
      schema_url: "https://schema.org/meetsEmissionStandard",
      comment_lines: ["Indicates that the vehicle meets the respective emission standard."].freeze,
      ranges: ["QualitativeValue", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    mileage_from_odometer: {
      schema_name: "mileageFromOdometer",
      schema_url: "https://schema.org/mileageFromOdometer",
      comment_lines: ["The total distance travelled by the particular vehicle since its initial production, as read from its odometer.\\n\\nTypical unit code(s): KMT for kilometers, SMI for statute miles."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    model_date: {
      schema_name: "modelDate",
      schema_url: "https://schema.org/modelDate",
      comment_lines: ["The release date of a vehicle model (often used to differentiate versions of the same make and model)."].freeze,
      ranges: ["Date"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    number_of_airbags: {
      schema_name: "numberOfAirbags",
      schema_url: "https://schema.org/numberOfAirbags",
      comment_lines: ["The number or type of airbags in the vehicle."].freeze,
      ranges: ["Number", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    number_of_axles: {
      schema_name: "numberOfAxles",
      schema_url: "https://schema.org/numberOfAxles",
      comment_lines: ["The number of axles.\\n\\nTypical unit code(s): C62."].freeze,
      ranges: ["Number", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    number_of_doors: {
      schema_name: "numberOfDoors",
      schema_url: "https://schema.org/numberOfDoors",
      comment_lines: ["The number of doors.\\n\\nTypical unit code(s): C62."].freeze,
      ranges: ["Number", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    number_of_forward_gears: {
      schema_name: "numberOfForwardGears",
      schema_url: "https://schema.org/numberOfForwardGears",
      comment_lines: ["The total number of forward gears available for the transmission system of the vehicle.\\n\\nTypical unit code(s): C62."].freeze,
      ranges: ["Number", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    number_of_previous_owners: {
      schema_name: "numberOfPreviousOwners",
      schema_url: "https://schema.org/numberOfPreviousOwners",
      comment_lines: ["The number of owners of the vehicle, including the current one.\\n\\nTypical unit code(s): C62."].freeze,
      ranges: ["Number", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    payload: {
      schema_name: "payload",
      schema_url: "https://schema.org/payload",
      comment_lines: ["The permitted weight of passengers and cargo, EXCLUDING the weight of the empty vehicle.\\n\\nTypical unit code(s): KGM for kilogram, LBR for pound\\n\\n* Note 1: Many databases specify the permitted TOTAL weight instead, which is the sum of [[weight]] and [[payload]]\\n* Note 2: You can indicate additional information in the [[name]] of the [[QuantitativeValue]] node.\\n* Note 3: You may also link to a [[QualitativeValue]] node that provides additional information using [[valueReference]].\\n* Note 4: Note that you can use [[minValue]] and [[maxValue]] to indicate ranges."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    production_date: {
      schema_name: "productionDate",
      schema_url: "https://schema.org/productionDate",
      comment_lines: ["The date of production of the item, e.g. vehicle."].freeze,
      ranges: ["Date"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    purchase_date: {
      schema_name: "purchaseDate",
      schema_url: "https://schema.org/purchaseDate",
      comment_lines: ["The date the item, e.g. vehicle, was purchased by the current owner."].freeze,
      ranges: ["Date"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    seating_capacity: {
      schema_name: "seatingCapacity",
      schema_url: "https://schema.org/seatingCapacity",
      comment_lines: ["The number of persons that can be seated (e.g. in a vehicle), both in terms of the physical space available, and in terms of limitations set by law.\\n\\nTypical unit code(s): C62 for persons."].freeze,
      ranges: ["Number", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    speed: {
      schema_name: "speed",
      schema_url: "https://schema.org/speed",
      comment_lines: ["The speed range of the vehicle. If the vehicle is powered by an engine, the upper limit of the speed range (indicated by [[maxValue]]) should be the maximum speed achievable under regular conditions.\\n\\nTypical unit code(s): KMH for km/h, HM for mile per hour (0.447 04 m/s), KNT for knot\\n\\n*Note 1: Use [[minValue]] and [[maxValue]] to indicate the range. Typically, the minimal value is zero.\\n* Note 2: There are many different ways of measuring the speed range. You can link to information about how the given value has been determined using the [[valueReference]] property."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    steering_position: {
      schema_name: "steeringPosition",
      schema_url: "https://schema.org/steeringPosition",
      comment_lines: ["The position of the steering wheel or similar device (mostly for cars)."].freeze,
      ranges: ["SteeringPositionValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    stupid_property: {
      schema_name: "stupidProperty",
      schema_url: "https://schema.org/stupidProperty",
      comment_lines: ["This is a StupidProperty! - for testing only."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    tongue_weight: {
      schema_name: "tongueWeight",
      schema_url: "https://schema.org/tongueWeight",
      comment_lines: ["The permitted vertical load (TWR) of a trailer attached to the vehicle. Also referred to as Tongue Load Rating (TLR) or Vertical Load Rating (VLR).\\n\\nTypical unit code(s): KGM for kilogram, LBR for pound\\n\\n* Note 1: You can indicate additional information in the [[name]] of the [[QuantitativeValue]] node.\\n* Note 2: You may also link to a [[QualitativeValue]] node that provides additional information using [[valueReference]].\\n* Note 3: Note that you can use [[minValue]] and [[maxValue]] to indicate ranges."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    trailer_weight: {
      schema_name: "trailerWeight",
      schema_url: "https://schema.org/trailerWeight",
      comment_lines: ["The permitted weight of a trailer attached to the vehicle.\\n\\nTypical unit code(s): KGM for kilogram, LBR for pound\\n* Note 1: You can indicate additional information in the [[name]] of the [[QuantitativeValue]] node.\\n* Note 2: You may also link to a [[QualitativeValue]] node that provides additional information using [[valueReference]].\\n* Note 3: Note that you can use [[minValue]] and [[maxValue]] to indicate ranges."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    vehicle_configuration: {
      schema_name: "vehicleConfiguration",
      schema_url: "https://schema.org/vehicleConfiguration",
      comment_lines: ["A short text indicating the configuration of the vehicle, e.g. '5dr hatchback ST 2.5 MT 225 hp' or 'limited edition'."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    vehicle_engine: {
      schema_name: "vehicleEngine",
      schema_url: "https://schema.org/vehicleEngine",
      comment_lines: ["Information about the engine or engines of the vehicle."].freeze,
      ranges: ["EngineSpecification"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    vehicle_identification_number: {
      schema_name: "vehicleIdentificationNumber",
      schema_url: "https://schema.org/vehicleIdentificationNumber",
      comment_lines: ["The Vehicle Identification Number (VIN) is a unique serial number used by the automotive industry to identify individual motor vehicles."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    vehicle_interior_color: {
      schema_name: "vehicleInteriorColor",
      schema_url: "https://schema.org/vehicleInteriorColor",
      comment_lines: ["The color or color combination of the interior of the vehicle."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    vehicle_interior_type: {
      schema_name: "vehicleInteriorType",
      schema_url: "https://schema.org/vehicleInteriorType",
      comment_lines: ["The type or material of the interior of the vehicle (e.g. synthetic fabric, leather, wood, etc.). While most interior types are characterized by the material used, an interior type can also be based on vehicle usage or target audience."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    vehicle_model_date: {
      schema_name: "vehicleModelDate",
      schema_url: "https://schema.org/vehicleModelDate",
      comment_lines: ["The release date of a vehicle model (often used to differentiate versions of the same make and model)."].freeze,
      ranges: ["Date"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    vehicle_seating_capacity: {
      schema_name: "vehicleSeatingCapacity",
      schema_url: "https://schema.org/vehicleSeatingCapacity",
      comment_lines: ["The number of passengers that can be seated in the vehicle, both in terms of the physical space available, and in terms of limitations set by law.\\n\\nTypical unit code(s): C62 for persons."].freeze,
      ranges: ["Number", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    vehicle_special_usage: {
      schema_name: "vehicleSpecialUsage",
      schema_url: "https://schema.org/vehicleSpecialUsage",
      comment_lines: ["Indicates whether the vehicle has been used for special purposes, like commercial rental, driving school, or as a taxi. The legislation in many countries requires this information to be revealed when offering a car for sale."].freeze,
      ranges: ["CarUsageType", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    vehicle_transmission: {
      schema_name: "vehicleTransmission",
      schema_url: "https://schema.org/vehicleTransmission",
      comment_lines: ["The type of component used for transmitting the power from a rotating power source to the wheels or other relevant component(s) (\"gearbox\" for cars)."].freeze,
      ranges: ["QualitativeValue", "Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    weight_total: {
      schema_name: "weightTotal",
      schema_url: "https://schema.org/weightTotal",
      comment_lines: ["The permitted total weight of the loaded vehicle, including passengers and cargo and the weight of the empty vehicle.\\n\\nTypical unit code(s): KGM for kilogram, LBR for pound\\n\\n* Note 1: You can indicate additional information in the [[name]] of the [[QuantitativeValue]] node.\\n* Note 2: You may also link to a [[QualitativeValue]] node that provides additional information using [[valueReference]].\\n* Note 3: Note that you can use [[minValue]] and [[maxValue]] to indicate ranges."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    wheelbase: {
      schema_name: "wheelbase",
      schema_url: "https://schema.org/wheelbase",
      comment_lines: ["The distance between the centers of the front and rear wheels.\\n\\nTypical unit code(s): CMT for centimeters, MTR for meters, INH for inches, FOT for foot/feet."].freeze,
      ranges: ["QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#acceleration_timeObject

The time needed to accelerate the vehicle from a given start velocity to a given target velocity.\n\nTypical unit code(s): SEC for seconds\n\n* Note: There are unfortunately no standard unit codes for seconds/0..100 km/h or seconds/0..60 mph. Simply use "SEC" for seconds and indicate the velocities in the [[name]] of the [[QuantitativeValue]], or use [[valueReference]] with a [[QuantitativeValue]] of 0..60 mph or 0..100 km/h to specify the reference speeds.



417
418
419
# File 'lib/schema_org/mixins/vehicle.rb', line 417

def acceleration_time
  read_property(:acceleration_time)
end

#acceleration_time=(value) ⇒ Object

The time needed to accelerate the vehicle from a given start velocity to a given target velocity.\n\nTypical unit code(s): SEC for seconds\n\n* Note: There are unfortunately no standard unit codes for seconds/0..100 km/h or seconds/0..60 mph. Simply use "SEC" for seconds and indicate the velocities in the [[name]] of the [[QuantitativeValue]], or use [[valueReference]] with a [[QuantitativeValue]] of 0..60 mph or 0..100 km/h to specify the reference speeds.



422
423
424
# File 'lib/schema_org/mixins/vehicle.rb', line 422

def acceleration_time=(value)
  write_property(:acceleration_time, value)
end

#body_typeObject

Indicates the design and body style of the vehicle (e.g. station wagon, hatchback, etc.).



427
428
429
# File 'lib/schema_org/mixins/vehicle.rb', line 427

def body_type
  read_property(:body_type)
end

#body_type=(value) ⇒ Object

Indicates the design and body style of the vehicle (e.g. station wagon, hatchback, etc.).



432
433
434
# File 'lib/schema_org/mixins/vehicle.rb', line 432

def body_type=(value)
  write_property(:body_type, value)
end

#call_signObject

A callsign, as used in broadcasting and radio communications to identify people, radio and TV stations, or vehicles.



437
438
439
# File 'lib/schema_org/mixins/vehicle.rb', line 437

def call_sign
  read_property(:call_sign)
end

#call_sign=(value) ⇒ Object

A callsign, as used in broadcasting and radio communications to identify people, radio and TV stations, or vehicles.



442
443
444
# File 'lib/schema_org/mixins/vehicle.rb', line 442

def call_sign=(value)
  write_property(:call_sign, value)
end

#cargo_volumeObject

The available volume for cargo or luggage. For automobiles, this is usually the trunk volume.\n\nTypical unit code(s): LTR for liters, FTQ for cubic foot/feet\n\nNote: You can use [[minValue]] and [[maxValue]] to indicate ranges.



447
448
449
# File 'lib/schema_org/mixins/vehicle.rb', line 447

def cargo_volume
  read_property(:cargo_volume)
end

#cargo_volume=(value) ⇒ Object

The available volume for cargo or luggage. For automobiles, this is usually the trunk volume.\n\nTypical unit code(s): LTR for liters, FTQ for cubic foot/feet\n\nNote: You can use [[minValue]] and [[maxValue]] to indicate ranges.



452
453
454
# File 'lib/schema_org/mixins/vehicle.rb', line 452

def cargo_volume=(value)
  write_property(:cargo_volume, value)
end

#date_vehicle_first_registeredObject

The date of the first registration of the vehicle with the respective public authorities.



457
458
459
# File 'lib/schema_org/mixins/vehicle.rb', line 457

def date_vehicle_first_registered
  read_property(:date_vehicle_first_registered)
end

#date_vehicle_first_registered=(value) ⇒ Object

The date of the first registration of the vehicle with the respective public authorities.



462
463
464
# File 'lib/schema_org/mixins/vehicle.rb', line 462

def date_vehicle_first_registered=(value)
  write_property(:date_vehicle_first_registered, value)
end

#drive_wheel_configurationObject

The drive wheel configuration, i.e. which roadwheels will receive torque from the vehicle's engine via the drivetrain.



467
468
469
# File 'lib/schema_org/mixins/vehicle.rb', line 467

def drive_wheel_configuration
  read_property(:drive_wheel_configuration)
end

#drive_wheel_configuration=(value) ⇒ Object

The drive wheel configuration, i.e. which roadwheels will receive torque from the vehicle's engine via the drivetrain.



472
473
474
# File 'lib/schema_org/mixins/vehicle.rb', line 472

def drive_wheel_configuration=(value)
  write_property(:drive_wheel_configuration, value)
end

#emissions_co2Object

The CO2 emissions in g/km. When used in combination with a QuantitativeValue, put "g/km" into the unitText property of that value, since there is no UN/CEFACT Common Code for "g/km".



477
478
479
# File 'lib/schema_org/mixins/vehicle.rb', line 477

def emissions_co2
  read_property(:emissions_co2)
end

#emissions_co2=(value) ⇒ Object

The CO2 emissions in g/km. When used in combination with a QuantitativeValue, put "g/km" into the unitText property of that value, since there is no UN/CEFACT Common Code for "g/km".



482
483
484
# File 'lib/schema_org/mixins/vehicle.rb', line 482

def emissions_co2=(value)
  write_property(:emissions_co2, value)
end

#fuel_capacityObject

The capacity of the fuel tank or in the case of electric cars, the battery. If there are multiple components for storage, this should indicate the total of all storage of the same type.\n\nTypical unit code(s): LTR for liters, GLL of US gallons, GLI for UK / imperial gallons, AMH for ampere-hours (for electrical vehicles).



487
488
489
# File 'lib/schema_org/mixins/vehicle.rb', line 487

def fuel_capacity
  read_property(:fuel_capacity)
end

#fuel_capacity=(value) ⇒ Object

The capacity of the fuel tank or in the case of electric cars, the battery. If there are multiple components for storage, this should indicate the total of all storage of the same type.\n\nTypical unit code(s): LTR for liters, GLL of US gallons, GLI for UK / imperial gallons, AMH for ampere-hours (for electrical vehicles).



492
493
494
# File 'lib/schema_org/mixins/vehicle.rb', line 492

def fuel_capacity=(value)
  write_property(:fuel_capacity, value)
end

#fuel_consumptionObject

The amount of fuel consumed for traveling a particular distance or temporal duration with the given vehicle (e.g. liters per 100 km).\n\n* Note 1: There are unfortunately no standard unit codes for liters per 100 km. Use [[unitText]] to indicate the unit of measurement, e.g. L/100 km.\n* Note 2: There are two ways of indicating the fuel consumption, [[fuelConsumption]] (e.g. 8 liters per 100 km) and [[fuelEfficiency]] (e.g. 30 miles per gallon). They are reciprocal.\n* Note 3: Often, the absolute value is useful only when related to driving speed ("at 80 km/h") or usage pattern ("city traffic"). You can use [[valueReference]] to link the value for the fuel consumption to another value.



497
498
499
# File 'lib/schema_org/mixins/vehicle.rb', line 497

def fuel_consumption
  read_property(:fuel_consumption)
end

#fuel_consumption=(value) ⇒ Object

The amount of fuel consumed for traveling a particular distance or temporal duration with the given vehicle (e.g. liters per 100 km).\n\n* Note 1: There are unfortunately no standard unit codes for liters per 100 km. Use [[unitText]] to indicate the unit of measurement, e.g. L/100 km.\n* Note 2: There are two ways of indicating the fuel consumption, [[fuelConsumption]] (e.g. 8 liters per 100 km) and [[fuelEfficiency]] (e.g. 30 miles per gallon). They are reciprocal.\n* Note 3: Often, the absolute value is useful only when related to driving speed ("at 80 km/h") or usage pattern ("city traffic"). You can use [[valueReference]] to link the value for the fuel consumption to another value.



502
503
504
# File 'lib/schema_org/mixins/vehicle.rb', line 502

def fuel_consumption=(value)
  write_property(:fuel_consumption, value)
end

#fuel_efficiencyObject

The distance traveled per unit of fuel used; most commonly miles per gallon (mpg) or kilometers per liter (km/L).\n\n* Note 1: There are unfortunately no standard unit codes for miles per gallon or kilometers per liter. Use [[unitText]] to indicate the unit of measurement, e.g. mpg or km/L.\n* Note 2: There are two ways of indicating the fuel consumption, [[fuelConsumption]] (e.g. 8 liters per 100 km) and [[fuelEfficiency]] (e.g. 30 miles per gallon). They are reciprocal.\n* Note 3: Often, the absolute value is useful only when related to driving speed ("at 80 km/h") or usage pattern ("city traffic"). You can use [[valueReference]] to link the value for the fuel economy to another value.



507
508
509
# File 'lib/schema_org/mixins/vehicle.rb', line 507

def fuel_efficiency
  read_property(:fuel_efficiency)
end

#fuel_efficiency=(value) ⇒ Object

The distance traveled per unit of fuel used; most commonly miles per gallon (mpg) or kilometers per liter (km/L).\n\n* Note 1: There are unfortunately no standard unit codes for miles per gallon or kilometers per liter. Use [[unitText]] to indicate the unit of measurement, e.g. mpg or km/L.\n* Note 2: There are two ways of indicating the fuel consumption, [[fuelConsumption]] (e.g. 8 liters per 100 km) and [[fuelEfficiency]] (e.g. 30 miles per gallon). They are reciprocal.\n* Note 3: Often, the absolute value is useful only when related to driving speed ("at 80 km/h") or usage pattern ("city traffic"). You can use [[valueReference]] to link the value for the fuel economy to another value.



512
513
514
# File 'lib/schema_org/mixins/vehicle.rb', line 512

def fuel_efficiency=(value)
  write_property(:fuel_efficiency, value)
end

#fuel_typeObject

The type of fuel suitable for the engine or engines of the vehicle. If the vehicle has only one engine, this property can be attached directly to the vehicle.



517
518
519
# File 'lib/schema_org/mixins/vehicle.rb', line 517

def fuel_type
  read_property(:fuel_type)
end

#fuel_type=(value) ⇒ Object

The type of fuel suitable for the engine or engines of the vehicle. If the vehicle has only one engine, this property can be attached directly to the vehicle.



522
523
524
# File 'lib/schema_org/mixins/vehicle.rb', line 522

def fuel_type=(value)
  write_property(:fuel_type, value)
end

#known_vehicle_damagesObject

A textual description of known damages, both repaired and unrepaired.



527
528
529
# File 'lib/schema_org/mixins/vehicle.rb', line 527

def known_vehicle_damages
  read_property(:known_vehicle_damages)
end

#known_vehicle_damages=(value) ⇒ Object

A textual description of known damages, both repaired and unrepaired.



532
533
534
# File 'lib/schema_org/mixins/vehicle.rb', line 532

def known_vehicle_damages=(value)
  write_property(:known_vehicle_damages, value)
end

#meets_emission_standardObject

Indicates that the vehicle meets the respective emission standard.



537
538
539
# File 'lib/schema_org/mixins/vehicle.rb', line 537

def meets_emission_standard
  read_property(:meets_emission_standard)
end

#meets_emission_standard=(value) ⇒ Object

Indicates that the vehicle meets the respective emission standard.



542
543
544
# File 'lib/schema_org/mixins/vehicle.rb', line 542

def meets_emission_standard=(value)
  write_property(:meets_emission_standard, value)
end

#mileage_from_odometerObject

The total distance travelled by the particular vehicle since its initial production, as read from its odometer.\n\nTypical unit code(s): KMT for kilometers, SMI for statute miles.



547
548
549
# File 'lib/schema_org/mixins/vehicle.rb', line 547

def mileage_from_odometer
  read_property(:mileage_from_odometer)
end

#mileage_from_odometer=(value) ⇒ Object

The total distance travelled by the particular vehicle since its initial production, as read from its odometer.\n\nTypical unit code(s): KMT for kilometers, SMI for statute miles.



552
553
554
# File 'lib/schema_org/mixins/vehicle.rb', line 552

def mileage_from_odometer=(value)
  write_property(:mileage_from_odometer, value)
end

#model_dateObject

The release date of a vehicle model (often used to differentiate versions of the same make and model).



557
558
559
# File 'lib/schema_org/mixins/vehicle.rb', line 557

def model_date
  read_property(:model_date)
end

#model_date=(value) ⇒ Object

The release date of a vehicle model (often used to differentiate versions of the same make and model).



562
563
564
# File 'lib/schema_org/mixins/vehicle.rb', line 562

def model_date=(value)
  write_property(:model_date, value)
end

#number_of_airbagsObject

The number or type of airbags in the vehicle.



567
568
569
# File 'lib/schema_org/mixins/vehicle.rb', line 567

def number_of_airbags
  read_property(:number_of_airbags)
end

#number_of_airbags=(value) ⇒ Object

The number or type of airbags in the vehicle.



572
573
574
# File 'lib/schema_org/mixins/vehicle.rb', line 572

def number_of_airbags=(value)
  write_property(:number_of_airbags, value)
end

#number_of_axlesObject

The number of axles.\n\nTypical unit code(s): C62.



577
578
579
# File 'lib/schema_org/mixins/vehicle.rb', line 577

def number_of_axles
  read_property(:number_of_axles)
end

#number_of_axles=(value) ⇒ Object

The number of axles.\n\nTypical unit code(s): C62.



582
583
584
# File 'lib/schema_org/mixins/vehicle.rb', line 582

def number_of_axles=(value)
  write_property(:number_of_axles, value)
end

#number_of_doorsObject

The number of doors.\n\nTypical unit code(s): C62.



587
588
589
# File 'lib/schema_org/mixins/vehicle.rb', line 587

def number_of_doors
  read_property(:number_of_doors)
end

#number_of_doors=(value) ⇒ Object

The number of doors.\n\nTypical unit code(s): C62.



592
593
594
# File 'lib/schema_org/mixins/vehicle.rb', line 592

def number_of_doors=(value)
  write_property(:number_of_doors, value)
end

#number_of_forward_gearsObject

The total number of forward gears available for the transmission system of the vehicle.\n\nTypical unit code(s): C62.



597
598
599
# File 'lib/schema_org/mixins/vehicle.rb', line 597

def number_of_forward_gears
  read_property(:number_of_forward_gears)
end

#number_of_forward_gears=(value) ⇒ Object

The total number of forward gears available for the transmission system of the vehicle.\n\nTypical unit code(s): C62.



602
603
604
# File 'lib/schema_org/mixins/vehicle.rb', line 602

def number_of_forward_gears=(value)
  write_property(:number_of_forward_gears, value)
end

#number_of_previous_ownersObject

The number of owners of the vehicle, including the current one.\n\nTypical unit code(s): C62.



607
608
609
# File 'lib/schema_org/mixins/vehicle.rb', line 607

def number_of_previous_owners
  read_property(:number_of_previous_owners)
end

#number_of_previous_owners=(value) ⇒ Object

The number of owners of the vehicle, including the current one.\n\nTypical unit code(s): C62.



612
613
614
# File 'lib/schema_org/mixins/vehicle.rb', line 612

def number_of_previous_owners=(value)
  write_property(:number_of_previous_owners, value)
end

#payloadObject

The permitted weight of passengers and cargo, EXCLUDING the weight of the empty vehicle.\n\nTypical unit code(s): KGM for kilogram, LBR for pound\n\n* Note 1: Many databases specify the permitted TOTAL weight instead, which is the sum of [[weight]] and [[payload]]\n* Note 2: You can indicate additional information in the [[name]] of the [[QuantitativeValue]] node.\n* Note 3: You may also link to a [[QualitativeValue]] node that provides additional information using [[valueReference]].\n* Note 4: Note that you can use [[minValue]] and [[maxValue]] to indicate ranges.



617
618
619
# File 'lib/schema_org/mixins/vehicle.rb', line 617

def payload
  read_property(:payload)
end

#payload=(value) ⇒ Object

The permitted weight of passengers and cargo, EXCLUDING the weight of the empty vehicle.\n\nTypical unit code(s): KGM for kilogram, LBR for pound\n\n* Note 1: Many databases specify the permitted TOTAL weight instead, which is the sum of [[weight]] and [[payload]]\n* Note 2: You can indicate additional information in the [[name]] of the [[QuantitativeValue]] node.\n* Note 3: You may also link to a [[QualitativeValue]] node that provides additional information using [[valueReference]].\n* Note 4: Note that you can use [[minValue]] and [[maxValue]] to indicate ranges.



622
623
624
# File 'lib/schema_org/mixins/vehicle.rb', line 622

def payload=(value)
  write_property(:payload, value)
end

#production_dateObject

The date of production of the item, e.g. vehicle.



627
628
629
# File 'lib/schema_org/mixins/vehicle.rb', line 627

def production_date
  read_property(:production_date)
end

#production_date=(value) ⇒ Object

The date of production of the item, e.g. vehicle.



632
633
634
# File 'lib/schema_org/mixins/vehicle.rb', line 632

def production_date=(value)
  write_property(:production_date, value)
end

#purchase_dateObject

The date the item, e.g. vehicle, was purchased by the current owner.



637
638
639
# File 'lib/schema_org/mixins/vehicle.rb', line 637

def purchase_date
  read_property(:purchase_date)
end

#purchase_date=(value) ⇒ Object

The date the item, e.g. vehicle, was purchased by the current owner.



642
643
644
# File 'lib/schema_org/mixins/vehicle.rb', line 642

def purchase_date=(value)
  write_property(:purchase_date, value)
end

#seating_capacityObject

The number of persons that can be seated (e.g. in a vehicle), both in terms of the physical space available, and in terms of limitations set by law.\n\nTypical unit code(s): C62 for persons.



647
648
649
# File 'lib/schema_org/mixins/vehicle.rb', line 647

def seating_capacity
  read_property(:seating_capacity)
end

#seating_capacity=(value) ⇒ Object

The number of persons that can be seated (e.g. in a vehicle), both in terms of the physical space available, and in terms of limitations set by law.\n\nTypical unit code(s): C62 for persons.



652
653
654
# File 'lib/schema_org/mixins/vehicle.rb', line 652

def seating_capacity=(value)
  write_property(:seating_capacity, value)
end

#speedObject

The speed range of the vehicle. If the vehicle is powered by an engine, the upper limit of the speed range (indicated by [[maxValue]]) should be the maximum speed achievable under regular conditions.\n\nTypical unit code(s): KMH for km/h, HM for mile per hour (0.447 04 m/s), KNT for knot\n\nNote 1: Use [[minValue]] and [[maxValue]] to indicate the range. Typically, the minimal value is zero.\n Note 2: There are many different ways of measuring the speed range. You can link to information about how the given value has been determined using the [[valueReference]] property.



657
658
659
# File 'lib/schema_org/mixins/vehicle.rb', line 657

def speed
  read_property(:speed)
end

#speed=(value) ⇒ Object

The speed range of the vehicle. If the vehicle is powered by an engine, the upper limit of the speed range (indicated by [[maxValue]]) should be the maximum speed achievable under regular conditions.\n\nTypical unit code(s): KMH for km/h, HM for mile per hour (0.447 04 m/s), KNT for knot\n\nNote 1: Use [[minValue]] and [[maxValue]] to indicate the range. Typically, the minimal value is zero.\n Note 2: There are many different ways of measuring the speed range. You can link to information about how the given value has been determined using the [[valueReference]] property.



662
663
664
# File 'lib/schema_org/mixins/vehicle.rb', line 662

def speed=(value)
  write_property(:speed, value)
end

#steering_positionObject

The position of the steering wheel or similar device (mostly for cars).



667
668
669
# File 'lib/schema_org/mixins/vehicle.rb', line 667

def steering_position
  read_property(:steering_position)
end

#steering_position=(value) ⇒ Object

The position of the steering wheel or similar device (mostly for cars).



672
673
674
# File 'lib/schema_org/mixins/vehicle.rb', line 672

def steering_position=(value)
  write_property(:steering_position, value)
end

#stupid_propertyObject

This is a StupidProperty! - for testing only.



677
678
679
# File 'lib/schema_org/mixins/vehicle.rb', line 677

def stupid_property
  read_property(:stupid_property)
end

#stupid_property=(value) ⇒ Object

This is a StupidProperty! - for testing only.



682
683
684
# File 'lib/schema_org/mixins/vehicle.rb', line 682

def stupid_property=(value)
  write_property(:stupid_property, value)
end

#tongue_weightObject

The permitted vertical load (TWR) of a trailer attached to the vehicle. Also referred to as Tongue Load Rating (TLR) or Vertical Load Rating (VLR).\n\nTypical unit code(s): KGM for kilogram, LBR for pound\n\n* Note 1: You can indicate additional information in the [[name]] of the [[QuantitativeValue]] node.\n* Note 2: You may also link to a [[QualitativeValue]] node that provides additional information using [[valueReference]].\n* Note 3: Note that you can use [[minValue]] and [[maxValue]] to indicate ranges.



687
688
689
# File 'lib/schema_org/mixins/vehicle.rb', line 687

def tongue_weight
  read_property(:tongue_weight)
end

#tongue_weight=(value) ⇒ Object

The permitted vertical load (TWR) of a trailer attached to the vehicle. Also referred to as Tongue Load Rating (TLR) or Vertical Load Rating (VLR).\n\nTypical unit code(s): KGM for kilogram, LBR for pound\n\n* Note 1: You can indicate additional information in the [[name]] of the [[QuantitativeValue]] node.\n* Note 2: You may also link to a [[QualitativeValue]] node that provides additional information using [[valueReference]].\n* Note 3: Note that you can use [[minValue]] and [[maxValue]] to indicate ranges.



692
693
694
# File 'lib/schema_org/mixins/vehicle.rb', line 692

def tongue_weight=(value)
  write_property(:tongue_weight, value)
end

#trailer_weightObject

The permitted weight of a trailer attached to the vehicle.\n\nTypical unit code(s): KGM for kilogram, LBR for pound\n* Note 1: You can indicate additional information in the [[name]] of the [[QuantitativeValue]] node.\n* Note 2: You may also link to a [[QualitativeValue]] node that provides additional information using [[valueReference]].\n* Note 3: Note that you can use [[minValue]] and [[maxValue]] to indicate ranges.



697
698
699
# File 'lib/schema_org/mixins/vehicle.rb', line 697

def trailer_weight
  read_property(:trailer_weight)
end

#trailer_weight=(value) ⇒ Object

The permitted weight of a trailer attached to the vehicle.\n\nTypical unit code(s): KGM for kilogram, LBR for pound\n* Note 1: You can indicate additional information in the [[name]] of the [[QuantitativeValue]] node.\n* Note 2: You may also link to a [[QualitativeValue]] node that provides additional information using [[valueReference]].\n* Note 3: Note that you can use [[minValue]] and [[maxValue]] to indicate ranges.



702
703
704
# File 'lib/schema_org/mixins/vehicle.rb', line 702

def trailer_weight=(value)
  write_property(:trailer_weight, value)
end

#vehicle_configurationObject

A short text indicating the configuration of the vehicle, e.g. '5dr hatchback ST 2.5 MT 225 hp' or 'limited edition'.



707
708
709
# File 'lib/schema_org/mixins/vehicle.rb', line 707

def vehicle_configuration
  read_property(:vehicle_configuration)
end

#vehicle_configuration=(value) ⇒ Object

A short text indicating the configuration of the vehicle, e.g. '5dr hatchback ST 2.5 MT 225 hp' or 'limited edition'.



712
713
714
# File 'lib/schema_org/mixins/vehicle.rb', line 712

def vehicle_configuration=(value)
  write_property(:vehicle_configuration, value)
end

#vehicle_engineObject

Information about the engine or engines of the vehicle.



717
718
719
# File 'lib/schema_org/mixins/vehicle.rb', line 717

def vehicle_engine
  read_property(:vehicle_engine)
end

#vehicle_engine=(value) ⇒ Object

Information about the engine or engines of the vehicle.



722
723
724
# File 'lib/schema_org/mixins/vehicle.rb', line 722

def vehicle_engine=(value)
  write_property(:vehicle_engine, value)
end

#vehicle_identification_numberObject

The Vehicle Identification Number (VIN) is a unique serial number used by the automotive industry to identify individual motor vehicles.



727
728
729
# File 'lib/schema_org/mixins/vehicle.rb', line 727

def vehicle_identification_number
  read_property(:vehicle_identification_number)
end

#vehicle_identification_number=(value) ⇒ Object

The Vehicle Identification Number (VIN) is a unique serial number used by the automotive industry to identify individual motor vehicles.



732
733
734
# File 'lib/schema_org/mixins/vehicle.rb', line 732

def vehicle_identification_number=(value)
  write_property(:vehicle_identification_number, value)
end

#vehicle_interior_colorObject

The color or color combination of the interior of the vehicle.



737
738
739
# File 'lib/schema_org/mixins/vehicle.rb', line 737

def vehicle_interior_color
  read_property(:vehicle_interior_color)
end

#vehicle_interior_color=(value) ⇒ Object

The color or color combination of the interior of the vehicle.



742
743
744
# File 'lib/schema_org/mixins/vehicle.rb', line 742

def vehicle_interior_color=(value)
  write_property(:vehicle_interior_color, value)
end

#vehicle_interior_typeObject

The type or material of the interior of the vehicle (e.g. synthetic fabric, leather, wood, etc.). While most interior types are characterized by the material used, an interior type can also be based on vehicle usage or target audience.



747
748
749
# File 'lib/schema_org/mixins/vehicle.rb', line 747

def vehicle_interior_type
  read_property(:vehicle_interior_type)
end

#vehicle_interior_type=(value) ⇒ Object

The type or material of the interior of the vehicle (e.g. synthetic fabric, leather, wood, etc.). While most interior types are characterized by the material used, an interior type can also be based on vehicle usage or target audience.



752
753
754
# File 'lib/schema_org/mixins/vehicle.rb', line 752

def vehicle_interior_type=(value)
  write_property(:vehicle_interior_type, value)
end

#vehicle_model_dateObject

The release date of a vehicle model (often used to differentiate versions of the same make and model).



757
758
759
# File 'lib/schema_org/mixins/vehicle.rb', line 757

def vehicle_model_date
  read_property(:vehicle_model_date)
end

#vehicle_model_date=(value) ⇒ Object

The release date of a vehicle model (often used to differentiate versions of the same make and model).



762
763
764
# File 'lib/schema_org/mixins/vehicle.rb', line 762

def vehicle_model_date=(value)
  write_property(:vehicle_model_date, value)
end

#vehicle_seating_capacityObject

The number of passengers that can be seated in the vehicle, both in terms of the physical space available, and in terms of limitations set by law.\n\nTypical unit code(s): C62 for persons.



767
768
769
# File 'lib/schema_org/mixins/vehicle.rb', line 767

def vehicle_seating_capacity
  read_property(:vehicle_seating_capacity)
end

#vehicle_seating_capacity=(value) ⇒ Object

The number of passengers that can be seated in the vehicle, both in terms of the physical space available, and in terms of limitations set by law.\n\nTypical unit code(s): C62 for persons.



772
773
774
# File 'lib/schema_org/mixins/vehicle.rb', line 772

def vehicle_seating_capacity=(value)
  write_property(:vehicle_seating_capacity, value)
end

#vehicle_special_usageObject

Indicates whether the vehicle has been used for special purposes, like commercial rental, driving school, or as a taxi. The legislation in many countries requires this information to be revealed when offering a car for sale.



777
778
779
# File 'lib/schema_org/mixins/vehicle.rb', line 777

def vehicle_special_usage
  read_property(:vehicle_special_usage)
end

#vehicle_special_usage=(value) ⇒ Object

Indicates whether the vehicle has been used for special purposes, like commercial rental, driving school, or as a taxi. The legislation in many countries requires this information to be revealed when offering a car for sale.



782
783
784
# File 'lib/schema_org/mixins/vehicle.rb', line 782

def vehicle_special_usage=(value)
  write_property(:vehicle_special_usage, value)
end

#vehicle_transmissionObject

The type of component used for transmitting the power from a rotating power source to the wheels or other relevant component(s) ("gearbox" for cars).



787
788
789
# File 'lib/schema_org/mixins/vehicle.rb', line 787

def vehicle_transmission
  read_property(:vehicle_transmission)
end

#vehicle_transmission=(value) ⇒ Object

The type of component used for transmitting the power from a rotating power source to the wheels or other relevant component(s) ("gearbox" for cars).



792
793
794
# File 'lib/schema_org/mixins/vehicle.rb', line 792

def vehicle_transmission=(value)
  write_property(:vehicle_transmission, value)
end

#weight_totalObject

The permitted total weight of the loaded vehicle, including passengers and cargo and the weight of the empty vehicle.\n\nTypical unit code(s): KGM for kilogram, LBR for pound\n\n* Note 1: You can indicate additional information in the [[name]] of the [[QuantitativeValue]] node.\n* Note 2: You may also link to a [[QualitativeValue]] node that provides additional information using [[valueReference]].\n* Note 3: Note that you can use [[minValue]] and [[maxValue]] to indicate ranges.



797
798
799
# File 'lib/schema_org/mixins/vehicle.rb', line 797

def weight_total
  read_property(:weight_total)
end

#weight_total=(value) ⇒ Object

The permitted total weight of the loaded vehicle, including passengers and cargo and the weight of the empty vehicle.\n\nTypical unit code(s): KGM for kilogram, LBR for pound\n\n* Note 1: You can indicate additional information in the [[name]] of the [[QuantitativeValue]] node.\n* Note 2: You may also link to a [[QualitativeValue]] node that provides additional information using [[valueReference]].\n* Note 3: Note that you can use [[minValue]] and [[maxValue]] to indicate ranges.



802
803
804
# File 'lib/schema_org/mixins/vehicle.rb', line 802

def weight_total=(value)
  write_property(:weight_total, value)
end

#wheelbaseObject

The distance between the centers of the front and rear wheels.\n\nTypical unit code(s): CMT for centimeters, MTR for meters, INH for inches, FOT for foot/feet.



807
808
809
# File 'lib/schema_org/mixins/vehicle.rb', line 807

def wheelbase
  read_property(:wheelbase)
end

#wheelbase=(value) ⇒ Object

The distance between the centers of the front and rear wheels.\n\nTypical unit code(s): CMT for centimeters, MTR for meters, INH for inches, FOT for foot/feet.



812
813
814
# File 'lib/schema_org/mixins/vehicle.rb', line 812

def wheelbase=(value)
  write_property(:wheelbase, value)
end