Module: SchemaOrg::Mixins::VideoGame

Includes:
Game, SoftwareApplication
Included in:
VideoGame
Defined in:
lib/schema_org/mixins/video_game.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from SoftwareApplication

#application_category, #application_category=, #application_sub_category, #application_sub_category=, #application_suite, #application_suite=, #available_on_device, #available_on_device=, #countries_not_supported, #countries_not_supported=, #countries_supported, #countries_supported=, #device, #device=, #download_url, #download_url=, #feature_list, #feature_list=, #file_size, #file_size=, #install_url, #install_url=, #memory_requirements, #memory_requirements=, #operating_system, #operating_system=, #permissions, #permissions=, #processor_requirements, #processor_requirements=, #release_notes, #release_notes=, #requirements, #requirements=, #runtime_platform, #runtime_platform=, #screenshot, #screenshot=, #software_add_on, #software_add_on=, #software_help, #software_help=, #software_requirements, #software_requirements=, #software_version, #software_version=, #storage_requirements, #storage_requirements=, #supporting_data, #supporting_data=

Methods included from CreativeWork

#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Methods included from Game

#character_attribute, #character_attribute=, #game_item, #game_item=, #game_location, #game_location=, #number_of_players, #number_of_players=, #quest, #quest=

Class Method Details

.schema_property_definitionsObject



12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/schema_org/mixins/video_game.rb', line 12

def self.schema_property_definitions
  {
    actor: {
      schema_name: "actor",
      schema_url: "https://schema.org/actor",
      comment_lines: ["An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip."].freeze,
      ranges: ["PerformingGroup", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["actors"].freeze
    }.freeze,
    actors: {
      schema_name: "actors",
      schema_url: "https://schema.org/actors",
      comment_lines: ["An actor, e.g. in TV, radio, movie, video games etc. Actors can be associated with individual items or with a series, episode, clip."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "actor",
      supersedes: nil
    }.freeze,
    cheat_code: {
      schema_name: "cheatCode",
      schema_url: "https://schema.org/cheatCode",
      comment_lines: ["Cheat codes to the game."].freeze,
      ranges: ["CreativeWork"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    director: {
      schema_name: "director",
      schema_url: "https://schema.org/director",
      comment_lines: ["A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["directors"].freeze
    }.freeze,
    directors: {
      schema_name: "directors",
      schema_url: "https://schema.org/directors",
      comment_lines: ["A director of e.g. TV, radio, movie, video games etc. content. Directors can be associated with individual items or with a series, episode, clip."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "director",
      supersedes: nil
    }.freeze,
    game_edition: {
      schema_name: "gameEdition",
      schema_url: "https://schema.org/gameEdition",
      comment_lines: ["The edition of a video game."].freeze,
      ranges: ["Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    game_platform: {
      schema_name: "gamePlatform",
      schema_url: "https://schema.org/gamePlatform",
      comment_lines: ["The electronic systems used to play <a href=\"http://en.wikipedia.org/wiki/Category:Video_game_platforms\">video games</a>."].freeze,
      ranges: ["Text", "Thing", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    game_server: {
      schema_name: "gameServer",
      schema_url: "https://schema.org/gameServer",
      comment_lines: ["The server on which  it is possible to play the game."].freeze,
      ranges: ["GameServer"].freeze,
      external_ranges: [].freeze,
      inverse_of: "game",
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    game_tip: {
      schema_name: "gameTip",
      schema_url: "https://schema.org/gameTip",
      comment_lines: ["Links to tips, tactics, etc."].freeze,
      ranges: ["CreativeWork"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    music_by: {
      schema_name: "musicBy",
      schema_url: "https://schema.org/musicBy",
      comment_lines: ["The composer of the soundtrack."].freeze,
      ranges: ["MusicGroup", "Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    play_mode: {
      schema_name: "playMode",
      schema_url: "https://schema.org/playMode",
      comment_lines: ["Indicates whether this game is multi-player, co-op or single-player.  The game can be marked as multi-player, co-op and single-player at the same time."].freeze,
      ranges: ["GamePlayMode"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    trailer: {
      schema_name: "trailer",
      schema_url: "https://schema.org/trailer",
      comment_lines: ["The trailer of a movie or TV/radio series, season, episode, etc."].freeze,
      ranges: ["VideoObject"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#actorObject

An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip. Supersedes actors.



139
140
141
# File 'lib/schema_org/mixins/video_game.rb', line 139

def actor
  read_property(:actor)
end

#actor=(value) ⇒ Object

An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip. Supersedes actors.



145
146
147
# File 'lib/schema_org/mixins/video_game.rb', line 145

def actor=(value)
  write_property(:actor, value)
end

#actorsObject

An actor, e.g. in TV, radio, movie, video games etc. Actors can be associated with individual items or with a series, episode, clip. Superseded by actor.



151
152
153
# File 'lib/schema_org/mixins/video_game.rb', line 151

def actors
  read_property(:actors)
end

#actors=(value) ⇒ Object

An actor, e.g. in TV, radio, movie, video games etc. Actors can be associated with individual items or with a series, episode, clip. Superseded by actor.



157
158
159
# File 'lib/schema_org/mixins/video_game.rb', line 157

def actors=(value)
  write_property(:actors, value)
end

#cheat_codeObject

Cheat codes to the game.



162
163
164
# File 'lib/schema_org/mixins/video_game.rb', line 162

def cheat_code
  read_property(:cheat_code)
end

#cheat_code=(value) ⇒ Object

Cheat codes to the game.



167
168
169
# File 'lib/schema_org/mixins/video_game.rb', line 167

def cheat_code=(value)
  write_property(:cheat_code, value)
end

#directorObject

A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip. Supersedes directors.



173
174
175
# File 'lib/schema_org/mixins/video_game.rb', line 173

def director
  read_property(:director)
end

#director=(value) ⇒ Object

A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip. Supersedes directors.



179
180
181
# File 'lib/schema_org/mixins/video_game.rb', line 179

def director=(value)
  write_property(:director, value)
end

#directorsObject

A director of e.g. TV, radio, movie, video games etc. content. Directors can be associated with individual items or with a series, episode, clip. Superseded by director.



185
186
187
# File 'lib/schema_org/mixins/video_game.rb', line 185

def directors
  read_property(:directors)
end

#directors=(value) ⇒ Object

A director of e.g. TV, radio, movie, video games etc. content. Directors can be associated with individual items or with a series, episode, clip. Superseded by director.



191
192
193
# File 'lib/schema_org/mixins/video_game.rb', line 191

def directors=(value)
  write_property(:directors, value)
end

#game_editionObject

The edition of a video game.



196
197
198
# File 'lib/schema_org/mixins/video_game.rb', line 196

def game_edition
  read_property(:game_edition)
end

#game_edition=(value) ⇒ Object

The edition of a video game.



201
202
203
# File 'lib/schema_org/mixins/video_game.rb', line 201

def game_edition=(value)
  write_property(:game_edition, value)
end

#game_platformObject

The electronic systems used to play video games.



206
207
208
# File 'lib/schema_org/mixins/video_game.rb', line 206

def game_platform
  read_property(:game_platform)
end

#game_platform=(value) ⇒ Object

The electronic systems used to play video games.



211
212
213
# File 'lib/schema_org/mixins/video_game.rb', line 211

def game_platform=(value)
  write_property(:game_platform, value)
end

#game_serverObject

The server on which it is possible to play the game. Inverse-property: game.



217
218
219
# File 'lib/schema_org/mixins/video_game.rb', line 217

def game_server
  read_property(:game_server)
end

#game_server=(value) ⇒ Object

The server on which it is possible to play the game. Inverse-property: game.



223
224
225
# File 'lib/schema_org/mixins/video_game.rb', line 223

def game_server=(value)
  write_property(:game_server, value)
end

#game_tipObject

Links to tips, tactics, etc.



228
229
230
# File 'lib/schema_org/mixins/video_game.rb', line 228

def game_tip
  read_property(:game_tip)
end

#game_tip=(value) ⇒ Object

Links to tips, tactics, etc.



233
234
235
# File 'lib/schema_org/mixins/video_game.rb', line 233

def game_tip=(value)
  write_property(:game_tip, value)
end

#music_byObject

The composer of the soundtrack.



238
239
240
# File 'lib/schema_org/mixins/video_game.rb', line 238

def music_by
  read_property(:music_by)
end

#music_by=(value) ⇒ Object

The composer of the soundtrack.



243
244
245
# File 'lib/schema_org/mixins/video_game.rb', line 243

def music_by=(value)
  write_property(:music_by, value)
end

#play_modeObject

Indicates whether this game is multi-player, co-op or single-player. The game can be marked as multi-player, co-op and single-player at the same time.



248
249
250
# File 'lib/schema_org/mixins/video_game.rb', line 248

def play_mode
  read_property(:play_mode)
end

#play_mode=(value) ⇒ Object

Indicates whether this game is multi-player, co-op or single-player. The game can be marked as multi-player, co-op and single-player at the same time.



253
254
255
# File 'lib/schema_org/mixins/video_game.rb', line 253

def play_mode=(value)
  write_property(:play_mode, value)
end

#trailerObject

The trailer of a movie or TV/radio series, season, episode, etc.



258
259
260
# File 'lib/schema_org/mixins/video_game.rb', line 258

def trailer
  read_property(:trailer)
end

#trailer=(value) ⇒ Object

The trailer of a movie or TV/radio series, season, episode, etc.



263
264
265
# File 'lib/schema_org/mixins/video_game.rb', line 263

def trailer=(value)
  write_property(:trailer, value)
end