Module: SchemaOrg::Mixins::VisualArtwork

Includes:
CreativeWork
Included in:
CoverArt, SequentialArt, VisualArtwork
Defined in:
lib/schema_org/mixins/visual_artwork.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from CreativeWork

#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/schema_org/mixins/visual_artwork.rb', line 11

def self.schema_property_definitions
  {
    art_edition: {
      schema_name: "artEdition",
      schema_url: "https://schema.org/artEdition",
      comment_lines: ["The number of copies when multiple copies of a piece of artwork are produced - e.g. for a limited edition of 20 prints, 'artEdition' refers to the total number of copies (in this example \"20\")."].freeze,
      ranges: ["Integer", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    art_medium: {
      schema_name: "artMedium",
      schema_url: "https://schema.org/artMedium",
      comment_lines: ["The material used. (E.g. Oil, Watercolour, Acrylic, Linoprint, Marble, Cyanotype, Digital, Lithograph, DryPoint, Intaglio, Pastel, Woodcut, Pencil, Mixed Media, etc.)"].freeze,
      ranges: ["Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    artform: {
      schema_name: "artform",
      schema_url: "https://schema.org/artform",
      comment_lines: ["e.g. Painting, Drawing, Sculpture, Print, Photograph, Assemblage, Collage, etc."].freeze,
      ranges: ["Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    artist: {
      schema_name: "artist",
      schema_url: "https://schema.org/artist",
      comment_lines: ["The primary artist for a work", "    \tin a medium other than pencils or digital line art--for example, if the", "    \tprimary artwork is done in watercolors or digital paints."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    artwork_surface: {
      schema_name: "artworkSurface",
      schema_url: "https://schema.org/artworkSurface",
      comment_lines: ["The supporting materials for the artwork, e.g. Canvas, Paper, Wood, Board, etc."].freeze,
      ranges: ["Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["surface"].freeze
    }.freeze,
    colorist: {
      schema_name: "colorist",
      schema_url: "https://schema.org/colorist",
      comment_lines: ["The individual who adds color to inked drawings."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    depth: {
      schema_name: "depth",
      schema_url: "https://schema.org/depth",
      comment_lines: ["The depth of the item."].freeze,
      ranges: ["Distance", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    height: {
      schema_name: "height",
      schema_url: "https://schema.org/height",
      comment_lines: ["The height of the item."].freeze,
      ranges: ["Distance", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    inker: {
      schema_name: "inker",
      schema_url: "https://schema.org/inker",
      comment_lines: ["The individual who traces over the pencil drawings in ink after pencils are complete."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    letterer: {
      schema_name: "letterer",
      schema_url: "https://schema.org/letterer",
      comment_lines: ["The individual who adds lettering, including speech balloons and sound effects, to artwork."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    penciler: {
      schema_name: "penciler",
      schema_url: "https://schema.org/penciler",
      comment_lines: ["The individual who draws the primary narrative artwork."].freeze,
      ranges: ["Person"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    surface: {
      schema_name: "surface",
      schema_url: "https://schema.org/surface",
      comment_lines: ["A material used as a surface in some artwork, e.g. Canvas, Paper, Wood, Board, etc."].freeze,
      ranges: ["Text", "URL"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "artworkSurface",
      supersedes: nil
    }.freeze,
    weight: {
      schema_name: "weight",
      schema_url: "https://schema.org/weight",
      comment_lines: ["The weight of the product or person."].freeze,
      ranges: ["Mass", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    width: {
      schema_name: "width",
      schema_url: "https://schema.org/width",
      comment_lines: ["The width of the item."].freeze,
      ranges: ["Distance", "QuantitativeValue"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#art_editionObject

The number of copies when multiple copies of a piece of artwork are produced - e.g. for a limited edition of 20 prints, 'artEdition' refers to the total number of copies (in this example "20").



157
158
159
# File 'lib/schema_org/mixins/visual_artwork.rb', line 157

def art_edition
  read_property(:art_edition)
end

#art_edition=(value) ⇒ Object

The number of copies when multiple copies of a piece of artwork are produced - e.g. for a limited edition of 20 prints, 'artEdition' refers to the total number of copies (in this example "20").



162
163
164
# File 'lib/schema_org/mixins/visual_artwork.rb', line 162

def art_edition=(value)
  write_property(:art_edition, value)
end

#art_mediumObject

The material used. (E.g. Oil, Watercolour, Acrylic, Linoprint, Marble, Cyanotype, Digital, Lithograph, DryPoint, Intaglio, Pastel, Woodcut, Pencil, Mixed Media, etc.)



167
168
169
# File 'lib/schema_org/mixins/visual_artwork.rb', line 167

def art_medium
  read_property(:art_medium)
end

#art_medium=(value) ⇒ Object

The material used. (E.g. Oil, Watercolour, Acrylic, Linoprint, Marble, Cyanotype, Digital, Lithograph, DryPoint, Intaglio, Pastel, Woodcut, Pencil, Mixed Media, etc.)



172
173
174
# File 'lib/schema_org/mixins/visual_artwork.rb', line 172

def art_medium=(value)
  write_property(:art_medium, value)
end

#artformObject

e.g. Painting, Drawing, Sculpture, Print, Photograph, Assemblage, Collage, etc.



177
178
179
# File 'lib/schema_org/mixins/visual_artwork.rb', line 177

def artform
  read_property(:artform)
end

#artform=(value) ⇒ Object

e.g. Painting, Drawing, Sculpture, Print, Photograph, Assemblage, Collage, etc.



182
183
184
# File 'lib/schema_org/mixins/visual_artwork.rb', line 182

def artform=(value)
  write_property(:artform, value)
end

#artistObject

The primary artist for a work in a medium other than pencils or digital line art--for example, if the primary artwork is done in watercolors or digital paints.



189
190
191
# File 'lib/schema_org/mixins/visual_artwork.rb', line 189

def artist
  read_property(:artist)
end

#artist=(value) ⇒ Object

The primary artist for a work in a medium other than pencils or digital line art--for example, if the primary artwork is done in watercolors or digital paints.



196
197
198
# File 'lib/schema_org/mixins/visual_artwork.rb', line 196

def artist=(value)
  write_property(:artist, value)
end

#artwork_surfaceObject

The supporting materials for the artwork, e.g. Canvas, Paper, Wood, Board, etc. Supersedes surface.



202
203
204
# File 'lib/schema_org/mixins/visual_artwork.rb', line 202

def artwork_surface
  read_property(:artwork_surface)
end

#artwork_surface=(value) ⇒ Object

The supporting materials for the artwork, e.g. Canvas, Paper, Wood, Board, etc. Supersedes surface.



208
209
210
# File 'lib/schema_org/mixins/visual_artwork.rb', line 208

def artwork_surface=(value)
  write_property(:artwork_surface, value)
end

#coloristObject

The individual who adds color to inked drawings.



213
214
215
# File 'lib/schema_org/mixins/visual_artwork.rb', line 213

def colorist
  read_property(:colorist)
end

#colorist=(value) ⇒ Object

The individual who adds color to inked drawings.



218
219
220
# File 'lib/schema_org/mixins/visual_artwork.rb', line 218

def colorist=(value)
  write_property(:colorist, value)
end

#depthObject

The depth of the item.



223
224
225
# File 'lib/schema_org/mixins/visual_artwork.rb', line 223

def depth
  read_property(:depth)
end

#depth=(value) ⇒ Object

The depth of the item.



228
229
230
# File 'lib/schema_org/mixins/visual_artwork.rb', line 228

def depth=(value)
  write_property(:depth, value)
end

#heightObject

The height of the item.



233
234
235
# File 'lib/schema_org/mixins/visual_artwork.rb', line 233

def height
  read_property(:height)
end

#height=(value) ⇒ Object

The height of the item.



238
239
240
# File 'lib/schema_org/mixins/visual_artwork.rb', line 238

def height=(value)
  write_property(:height, value)
end

#inkerObject

The individual who traces over the pencil drawings in ink after pencils are complete.



243
244
245
# File 'lib/schema_org/mixins/visual_artwork.rb', line 243

def inker
  read_property(:inker)
end

#inker=(value) ⇒ Object

The individual who traces over the pencil drawings in ink after pencils are complete.



248
249
250
# File 'lib/schema_org/mixins/visual_artwork.rb', line 248

def inker=(value)
  write_property(:inker, value)
end

#lettererObject

The individual who adds lettering, including speech balloons and sound effects, to artwork.



253
254
255
# File 'lib/schema_org/mixins/visual_artwork.rb', line 253

def letterer
  read_property(:letterer)
end

#letterer=(value) ⇒ Object

The individual who adds lettering, including speech balloons and sound effects, to artwork.



258
259
260
# File 'lib/schema_org/mixins/visual_artwork.rb', line 258

def letterer=(value)
  write_property(:letterer, value)
end

#pencilerObject

The individual who draws the primary narrative artwork.



263
264
265
# File 'lib/schema_org/mixins/visual_artwork.rb', line 263

def penciler
  read_property(:penciler)
end

#penciler=(value) ⇒ Object

The individual who draws the primary narrative artwork.



268
269
270
# File 'lib/schema_org/mixins/visual_artwork.rb', line 268

def penciler=(value)
  write_property(:penciler, value)
end

#surfaceObject

A material used as a surface in some artwork, e.g. Canvas, Paper, Wood, Board, etc. Superseded by artworkSurface.



274
275
276
# File 'lib/schema_org/mixins/visual_artwork.rb', line 274

def surface
  read_property(:surface)
end

#surface=(value) ⇒ Object

A material used as a surface in some artwork, e.g. Canvas, Paper, Wood, Board, etc. Superseded by artworkSurface.



280
281
282
# File 'lib/schema_org/mixins/visual_artwork.rb', line 280

def surface=(value)
  write_property(:surface, value)
end

#weightObject

The weight of the product or person.



285
286
287
# File 'lib/schema_org/mixins/visual_artwork.rb', line 285

def weight
  read_property(:weight)
end

#weight=(value) ⇒ Object

The weight of the product or person.



290
291
292
# File 'lib/schema_org/mixins/visual_artwork.rb', line 290

def weight=(value)
  write_property(:weight, value)
end

#widthObject

The width of the item.



295
296
297
# File 'lib/schema_org/mixins/visual_artwork.rb', line 295

def width
  read_property(:width)
end

#width=(value) ⇒ Object

The width of the item.



300
301
302
# File 'lib/schema_org/mixins/visual_artwork.rb', line 300

def width=(value)
  write_property(:width, value)
end