Module: SchemaOrg::Mixins::WorkBasedProgram

Includes:
EducationalOccupationalProgram
Included in:
WorkBasedProgram
Defined in:
lib/schema_org/mixins/work_based_program.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from EducationalOccupationalProgram

#application_deadline, #application_deadline=, #application_start_date, #application_start_date=, #day_of_week, #day_of_week=, #educational_credential_awarded, #educational_credential_awarded=, #educational_program_mode, #educational_program_mode=, #end_date, #end_date=, #financial_aid_eligible, #financial_aid_eligible=, #has_course, #has_course=, #maximum_enrollment, #maximum_enrollment=, #number_of_credits, #number_of_credits=, #occupational_credential_awarded, #occupational_credential_awarded=, #offers, #offers=, #program_prerequisites, #program_prerequisites=, #program_type, #program_type=, #provider, #provider=, #salary_upon_completion, #salary_upon_completion=, #start_date, #start_date=, #term_duration, #term_duration=, #terms_per_year, #terms_per_year=, #time_of_day, #time_of_day=, #time_to_complete, #time_to_complete=, #typical_credits_per_term, #typical_credits_per_term=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/schema_org/mixins/work_based_program.rb', line 11

def self.schema_property_definitions
  {
    occupational_category: {
      schema_name: "occupationalCategory",
      schema_url: "https://schema.org/occupationalCategory",
      comment_lines: ["A category describing the job, preferably using a term from a taxonomy such as [BLS O*NET-SOC](http://www.onetcenter.org/taxonomy.html), [ISCO-08](https://www.ilo.org/public/english/bureau/stat/isco/isco08/) or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided.\\n", "Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC."].freeze,
      ranges: ["CategoryCode", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze,
    training_salary: {
      schema_name: "trainingSalary",
      schema_url: "https://schema.org/trainingSalary",
      comment_lines: ["The estimated salary earned while in the program."].freeze,
      ranges: ["MonetaryAmountDistribution"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#occupational_categoryObject

A category describing the job, preferably using a term from a taxonomy such as BLS O*NET-SOC, ISCO-08 or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided.\n Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC.



38
39
40
# File 'lib/schema_org/mixins/work_based_program.rb', line 38

def occupational_category
  read_property(:occupational_category)
end

#occupational_category=(value) ⇒ Object

A category describing the job, preferably using a term from a taxonomy such as BLS O*NET-SOC, ISCO-08 or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided.\n Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC.



44
45
46
# File 'lib/schema_org/mixins/work_based_program.rb', line 44

def occupational_category=(value)
  write_property(:occupational_category, value)
end

#training_salaryObject

The estimated salary earned while in the program.



49
50
51
# File 'lib/schema_org/mixins/work_based_program.rb', line 49

def training_salary
  read_property(:training_salary)
end

#training_salary=(value) ⇒ Object

The estimated salary earned while in the program.



54
55
56
# File 'lib/schema_org/mixins/work_based_program.rb', line 54

def training_salary=(value)
  write_property(:training_salary, value)
end