Module: SchemaOrg::Mixins::WriteAction

Includes:
CreateAction
Included in:
WriteAction
Defined in:
lib/schema_org/mixins/write_action.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Action

#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, #start_time, #start_time=, #target, #target=

Methods included from Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.schema_property_definitionsObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/schema_org/mixins/write_action.rb', line 11

def self.schema_property_definitions
  {
    in_language: {
      schema_name: "inLanguage",
      schema_url: "https://schema.org/inLanguage",
      comment_lines: ["The language of the content or performance or used in an action. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[availableLanguage]]."].freeze,
      ranges: ["Language", "Text"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: nil,
      supersedes: ["language"].freeze
    }.freeze,
    language: {
      schema_name: "language",
      schema_url: "https://schema.org/language",
      comment_lines: ["A sub property of instrument. The language used on this action."].freeze,
      ranges: ["Language"].freeze,
      external_ranges: [].freeze,
      inverse_of: nil,
      superseded_by: "inLanguage",
      supersedes: nil
    }.freeze
  }.freeze
end

Instance Method Details

#in_languageObject

The language of the content or performance or used in an action. Please use one of the language codes from the IETF BCP 47 standard. See also [[availableLanguage]]. Supersedes language.



38
39
40
# File 'lib/schema_org/mixins/write_action.rb', line 38

def in_language
  read_property(:in_language)
end

#in_language=(value) ⇒ Object

The language of the content or performance or used in an action. Please use one of the language codes from the IETF BCP 47 standard. See also [[availableLanguage]]. Supersedes language.



44
45
46
# File 'lib/schema_org/mixins/write_action.rb', line 44

def in_language=(value)
  write_property(:in_language, value)
end

#languageObject

A sub property of instrument. The language used on this action. Superseded by inLanguage.



50
51
52
# File 'lib/schema_org/mixins/write_action.rb', line 50

def language
  read_property(:language)
end

#language=(value) ⇒ Object

A sub property of instrument. The language used on this action. Superseded by inLanguage.



56
57
58
# File 'lib/schema_org/mixins/write_action.rb', line 56

def language=(value)
  write_property(:language, value)
end