Class: SchemaOrg::Observation
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::Observation
- Includes:
- Mixins::Observation, _Observation
- Defined in:
- lib/schema_org/types/observation.rb,
sig/schema_org.rbs
Overview
https://schema.org/Observation
Instances of the class [[Observation]] are used to specify observations about an entity at a particular time. The principal properties of an [[Observation]] are [[observationAbout]], [[measuredProperty]], [[statType]], [[value] and [[observationDate]] and [[measuredProperty]]. Some but not all Observations represent a [[QuantitativeValue]]. Quantitative observations can be about a [[StatisticalVariable]], which is an abstract specification about which we can make observations that are grounded at a particular location and time.
Observations can also encode a subset of simple RDF-like statements (its observationAbout, a StatisticalVariable, defining the measuredPoperty; its observationAbout property indicating the entity the statement is about, and [[value]] )
In the context of a quantitative knowledge graph, typical properties could include [[measuredProperty]], [[observationAbout]], [[observationDate]], [[value]], [[unitCode]], [[unitText]], [[measurementMethod]].
Constant Summary collapse
- SCHEMA_NAME =
"Observation"- SCHEMA_TYPES =
[self, SchemaOrg::Intangible, SchemaOrg::QuantitativeValue, SchemaOrg::Thing, SchemaOrg::StructuredValue].freeze
Class Method Summary collapse
- .new(**properties) ⇒ Observation
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::Observation
#margin_of_error, #margin_of_error=, #measured_property, #measured_property=, #measurement_denominator, #measurement_denominator=, #measurement_method, #measurement_method=, #measurement_qualifier, #measurement_qualifier=, #measurement_technique, #measurement_technique=, #observation_about, #observation_about=, #observation_date, #observation_date=, #observation_period, #observation_period=, schema_property_definitions, #variable_measured, #variable_measured=
Methods included from Mixins::QuantitativeValue
#additional_property, #additional_property=, #max_value, #max_value=, #min_value, #min_value=, schema_property_definitions, #unit_code, #unit_code=, #unit_text, #unit_text=, #value, #value=, #value_reference, #value_reference=
Methods included from Mixins::StructuredValue
Methods included from Mixins::Intangible
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _Observation
#additional_property, #additional_property=, #additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #margin_of_error, #margin_of_error=, #max_value, #max_value=, #measured_property, #measured_property=, #measurement_denominator, #measurement_denominator=, #measurement_method, #measurement_method=, #measurement_qualifier, #measurement_qualifier=, #measurement_technique, #measurement_technique=, #min_value, #min_value=, #name, #name=, #observation_about, #observation_about=, #observation_date, #observation_date=, #observation_period, #observation_period=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #unit_code, #unit_code=, #unit_text, #unit_text=, #url, #url=, #value, #value=, #value_reference, #value_reference=, #variable_measured, #variable_measured=
Class Method Details
.new(**properties) ⇒ Observation
34 35 36 |
# File 'lib/schema_org/types/observation.rb', line 34 def new(**properties) super end |
.schema_name ⇒ String
21 22 23 |
# File 'lib/schema_org/types/observation.rb', line 21 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
29 30 31 32 |
# File 'lib/schema_org/types/observation.rb', line 29 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
25 26 27 |
# File 'lib/schema_org/types/observation.rb', line 25 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
86429 |
# File 'sig/schema_org.rbs', line 86429
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
86428 |
# File 'sig/schema_org.rbs', line 86428
def schema_types: () -> ::Array[::Class]
|