Class: SchemaOrg::OfferShippingDetails

Inherits:
Base
  • Object
show all
Includes:
Mixins::OfferShippingDetails, _OfferShippingDetails
Defined in:
lib/schema_org/types/offer_shipping_details.rb,
sig/schema_org.rbs

Overview

https://schema.org/OfferShippingDetails

OfferShippingDetails represents information about shipping destinations.

Multiple of these entities can be used to represent different shipping rates for different destinations:

One entity for Alaska/Hawaii. A different one for continental US. A different one for all France.

Multiple of these entities can be used to represent different shipping costs and delivery times.

Two entities that are identical but differ in rate and time:

E.g. Cheaper and slower: $5 in 5-7 days or Fast and expensive: $15 in 1-2 days.

Constant Summary collapse

SCHEMA_NAME =
"OfferShippingDetails"
SCHEMA_TYPES =
[self, SchemaOrg::StructuredValue, SchemaOrg::Intangible, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::OfferShippingDetails

#delivery_time, #delivery_time=, #depth, #depth=, #does_not_ship, #does_not_ship=, #has_shipping_service, #has_shipping_service=, #height, #height=, schema_property_definitions, #shipping_destination, #shipping_destination=, #shipping_label, #shipping_label=, #shipping_origin, #shipping_origin=, #shipping_rate, #shipping_rate=, #shipping_settings_link, #shipping_settings_link=, #transit_time_label, #transit_time_label=, #valid_for_member_tier, #valid_for_member_tier=, #weight, #weight=, #width, #width=

Methods included from Mixins::StructuredValue

schema_property_definitions

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _OfferShippingDetails

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #delivery_time, #delivery_time=, #depth, #depth=, #description, #description=, #disambiguating_description, #disambiguating_description=, #does_not_ship, #does_not_ship=, #has_shipping_service, #has_shipping_service=, #height, #height=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #shipping_destination, #shipping_destination=, #shipping_label, #shipping_label=, #shipping_origin, #shipping_origin=, #shipping_rate, #shipping_rate=, #shipping_settings_link, #shipping_settings_link=, #subject_of, #subject_of=, #transit_time_label, #transit_time_label=, #url, #url=, #valid_for_member_tier, #valid_for_member_tier=, #weight, #weight=, #width, #width=

Class Method Details

.new(**properties) ⇒ OfferShippingDetails

Parameters:

Returns:



41
42
43
# File 'lib/schema_org/types/offer_shipping_details.rb', line 41

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


28
29
30
# File 'lib/schema_org/types/offer_shipping_details.rb', line 28

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



36
37
38
39
# File 'lib/schema_org/types/offer_shipping_details.rb', line 36

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


32
33
34
# File 'lib/schema_org/types/offer_shipping_details.rb', line 32

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



87338
# File 'sig/schema_org.rbs', line 87338

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


87337
# File 'sig/schema_org.rbs', line 87337

def schema_types: () -> ::Array[::Class]