Class: SchemaOrg::Order

Inherits:
Base
  • Object
show all
Includes:
Mixins::Order, _Order
Defined in:
lib/schema_org/types/order.rb,
sig/schema_org.rbs

Overview

https://schema.org/Order

An order is a confirmation of a transaction (a receipt), which can contain multiple line items, each represented by an Offer that has been accepted by the customer.

Constant Summary collapse

SCHEMA_NAME =
"Order"
SCHEMA_TYPES =
[self, SchemaOrg::Intangible, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::Order

#accepted_offer, #accepted_offer=, #billing_address, #billing_address=, #broker, #broker=, #confirmation_number, #confirmation_number=, #customer, #customer=, #discount, #discount=, #discount_code, #discount_code=, #discount_currency, #discount_currency=, #is_gift, #is_gift=, #merchant, #merchant=, #order_date, #order_date=, #order_delivery, #order_delivery=, #order_number, #order_number=, #order_status, #order_status=, #ordered_item, #ordered_item=, #part_of_invoice, #part_of_invoice=, #payment_due, #payment_due=, #payment_due_date, #payment_due_date=, #payment_method, #payment_method=, #payment_method_id, #payment_method_id=, #payment_url, #payment_url=, schema_property_definitions, #seller, #seller=

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _Order

#accepted_offer, #accepted_offer=, #additional_type, #additional_type=, #alternate_name, #alternate_name=, #billing_address, #billing_address=, #broker, #broker=, #confirmation_number, #confirmation_number=, #customer, #customer=, #description, #description=, #disambiguating_description, #disambiguating_description=, #discount, #discount=, #discount_code, #discount_code=, #discount_currency, #discount_currency=, #identifier, #identifier=, #image, #image=, #is_gift, #is_gift=, #main_entity_of_page, #main_entity_of_page=, #merchant, #merchant=, #name, #name=, #order_date, #order_date=, #order_delivery, #order_delivery=, #order_number, #order_number=, #order_status, #order_status=, #ordered_item, #ordered_item=, #owner, #owner=, #part_of_invoice, #part_of_invoice=, #payment_due, #payment_due=, #payment_due_date, #payment_due_date=, #payment_method, #payment_method=, #payment_method_id, #payment_method_id=, #payment_url, #payment_url=, #potential_action, #potential_action=, #same_as, #same_as=, #seller, #seller=, #subject_of, #subject_of=, #url, #url=

Class Method Details

.new(**properties) ⇒ Order

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/order.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/order.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/order.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/order.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



89340
# File 'sig/schema_org.rbs', line 89340

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


89339
# File 'sig/schema_org.rbs', line 89339

def schema_types: () -> ::Array[::Class]