Class: SchemaOrg::PathologyTest

Inherits:
Base
  • Object
show all
Includes:
Mixins::PathologyTest, _PathologyTest
Defined in:
lib/schema_org/types/pathology_test.rb,
sig/schema_org.rbs

Overview

https://schema.org/PathologyTest

A medical test performed by a laboratory that typically involves examination of a tissue sample by a pathologist.

Constant Summary collapse

SCHEMA_NAME =
"PathologyTest"
SCHEMA_TYPES =
[self, SchemaOrg::MedicalTest, SchemaOrg::MedicalEntity, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::PathologyTest

schema_property_definitions, #tissue_sample, #tissue_sample=

Methods included from Mixins::MedicalTest

#affected_by, #affected_by=, #normal_range, #normal_range=, schema_property_definitions, #sign_detected, #sign_detected=, #used_to_diagnose, #used_to_diagnose=, #uses_device, #uses_device=

Methods included from Mixins::MedicalEntity

#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, schema_property_definitions, #study, #study=

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _PathologyTest

#additional_type, #additional_type=, #affected_by, #affected_by=, #alternate_name, #alternate_name=, #code, #code=, #description, #description=, #disambiguating_description, #disambiguating_description=, #funding, #funding=, #guideline, #guideline=, #identifier, #identifier=, #image, #image=, #legal_status, #legal_status=, #main_entity_of_page, #main_entity_of_page=, #medicine_system, #medicine_system=, #name, #name=, #normal_range, #normal_range=, #owner, #owner=, #potential_action, #potential_action=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #same_as, #same_as=, #sign_detected, #sign_detected=, #study, #study=, #subject_of, #subject_of=, #tissue_sample, #tissue_sample=, #url, #url=, #used_to_diagnose, #used_to_diagnose=, #uses_device, #uses_device=

Class Method Details

.new(**properties) ⇒ PathologyTest

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/pathology_test.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/pathology_test.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/pathology_test.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/pathology_test.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



91015
# File 'sig/schema_org.rbs', line 91015

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


91014
# File 'sig/schema_org.rbs', line 91014

def schema_types: () -> ::Array[::Class]