Class: SchemaOrg::PaymentMethodType
Overview
https://schema.org/PaymentMethodType
The type of payment method, only for generic payment types, specific forms of payments, like card payment should be expressed using subclasses of PaymentMethod.
Constant Summary
collapse
- SCHEMA_NAME =
"PaymentMethodType"
- SCHEMA_TYPES =
[self, SchemaOrg::Enumeration, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
- BY_BANK_TRANSFER_IN_ADVANCE =
EnumerationValue.new("ByBankTransferInAdvance", [SchemaOrg::PaymentMethodType])
- BY_INVOICE =
EnumerationValue.new("ByInvoice", [SchemaOrg::PaymentMethodType])
- COD =
EnumerationValue.new("COD", [SchemaOrg::PaymentMethodType])
- CASH =
EnumerationValue.new("Cash", [SchemaOrg::PaymentMethodType])
- CHECK_IN_ADVANCE =
EnumerationValue.new("CheckInAdvance", [SchemaOrg::PaymentMethodType])
- DIRECT_DEBIT =
EnumerationValue.new("DirectDebit", [SchemaOrg::PaymentMethodType])
- IN_STORE_PREPAY =
EnumerationValue.new("InStorePrepay", [SchemaOrg::PaymentMethodType])
- PHONE_CARRIER_PAYMENT =
EnumerationValue.new("PhoneCarrierPayment", [SchemaOrg::PaymentMethodType])
- VALUES =
[BY_BANK_TRANSFER_IN_ADVANCE, BY_INVOICE, COD, CASH, CHECK_IN_ADVANCE, DIRECT_DEBIT, IN_STORE_PREPAY, PHONE_CARRIER_PAYMENT].freeze
Class Method Summary
collapse
Instance Method Summary
collapse
schema_property_definitions
schema_property_definitions, #superseded_by, #superseded_by=
schema_property_definitions
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #superseded_by, #superseded_by=, #url, #url=
Class Method Details
30
31
32
|
# File 'lib/schema_org/types/payment_method_type.rb', line 30
def new(**properties)
super
end
|
.schema_name ⇒ String
17
18
19
|
# File 'lib/schema_org/types/payment_method_type.rb', line 17
def schema_name
SCHEMA_NAME
end
|
.schema_type?(other_type) ⇒ Boolean
25
26
27
28
|
# File 'lib/schema_org/types/payment_method_type.rb', line 25
def schema_type?(other_type)
Base.schema_type_argument!(other_type)
SCHEMA_TYPES.include?(other_type)
end
|
.schema_types ⇒ ::Array[::Class]
21
22
23
|
# File 'lib/schema_org/types/payment_method_type.rb', line 21
def schema_types
SCHEMA_TYPES
end
|
44
45
46
|
# File 'lib/schema_org/types/payment_method_type.rb', line 44
def self.values
VALUES
end
|
Instance Method Details
#schema_type? ⇒ Boolean
91810
|
# File 'sig/schema_org.rbs', line 91810
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
91809
|
# File 'sig/schema_org.rbs', line 91809
def schema_types: () -> ::Array[::Class]
|