Class: SchemaOrg::PhysicalActivity
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::PhysicalActivity
- Includes:
- Mixins::PhysicalActivity, _PhysicalActivity
- Defined in:
- lib/schema_org/types/physical_activity.rb,
sig/schema_org.rbs
Overview
https://schema.org/PhysicalActivity
Any bodily activity that enhances or maintains physical fitness and overall health and wellness. Includes activity that is part of daily living and routine, structured exercise, and exercise prescribed as part of a medical treatment or recovery plan.
Constant Summary collapse
- SCHEMA_NAME =
"PhysicalActivity"- SCHEMA_TYPES =
[self, SchemaOrg::LifestyleModification, SchemaOrg::MedicalEntity, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ PhysicalActivity
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::PhysicalActivity
#associated_anatomy, #associated_anatomy=, #category, #category=, #epidemiology, #epidemiology=, #pathophysiology, #pathophysiology=, schema_property_definitions
Methods included from Mixins::LifestyleModification
Methods included from Mixins::MedicalEntity
#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, schema_property_definitions, #study, #study=
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _PhysicalActivity
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #associated_anatomy, #associated_anatomy=, #category, #category=, #code, #code=, #description, #description=, #disambiguating_description, #disambiguating_description=, #epidemiology, #epidemiology=, #funding, #funding=, #guideline, #guideline=, #identifier, #identifier=, #image, #image=, #legal_status, #legal_status=, #main_entity_of_page, #main_entity_of_page=, #medicine_system, #medicine_system=, #name, #name=, #owner, #owner=, #pathophysiology, #pathophysiology=, #potential_action, #potential_action=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #same_as, #same_as=, #study, #study=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.new(**properties) ⇒ PhysicalActivity
30 31 32 |
# File 'lib/schema_org/types/physical_activity.rb', line 30 def new(**properties) super end |
.schema_name ⇒ String
17 18 19 |
# File 'lib/schema_org/types/physical_activity.rb', line 17 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
25 26 27 28 |
# File 'lib/schema_org/types/physical_activity.rb', line 25 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
21 22 23 |
# File 'lib/schema_org/types/physical_activity.rb', line 21 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
94045 |
# File 'sig/schema_org.rbs', line 94045
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
94044 |
# File 'sig/schema_org.rbs', line 94044
def schema_types: () -> ::Array[::Class]
|