Class: SchemaOrg::PriceSpecification

Inherits:
Base
  • Object
show all
Includes:
Mixins::PriceSpecification, _PriceSpecification
Defined in:
lib/schema_org/types/price_specification.rb,
sig/schema_org.rbs

Overview

https://schema.org/PriceSpecification

A structured value representing a price or price range. Typically, only the subclasses of this type are used for markup. It is recommended to use [[MonetaryAmount]] to describe independent amounts of money such as a salary, credit card limits, etc.

Constant Summary collapse

SCHEMA_NAME =
"PriceSpecification"
SCHEMA_TYPES =
[self, SchemaOrg::StructuredValue, SchemaOrg::Intangible, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::PriceSpecification

#eligible_quantity, #eligible_quantity=, #eligible_transaction_volume, #eligible_transaction_volume=, #max_price, #max_price=, #membership_points_earned, #membership_points_earned=, #min_price, #min_price=, #price, #price=, #price_currency, #price_currency=, schema_property_definitions, #valid_for_member_tier, #valid_for_member_tier=, #valid_from, #valid_from=, #valid_through, #valid_through=, #value_added_tax_included, #value_added_tax_included=

Methods included from Mixins::StructuredValue

schema_property_definitions

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _PriceSpecification

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #eligible_quantity, #eligible_quantity=, #eligible_transaction_volume, #eligible_transaction_volume=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #max_price, #max_price=, #membership_points_earned, #membership_points_earned=, #min_price, #min_price=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #price, #price=, #price_currency, #price_currency=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=, #valid_for_member_tier, #valid_for_member_tier=, #valid_from, #valid_from=, #valid_through, #valid_through=, #value_added_tax_included, #value_added_tax_included=

Class Method Details

.new(**properties) ⇒ PriceSpecification

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/price_specification.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/price_specification.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/price_specification.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/price_specification.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



98929
# File 'sig/schema_org.rbs', line 98929

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


98928
# File 'sig/schema_org.rbs', line 98928

def schema_types: () -> ::Array[::Class]