Class: SchemaOrg::PublicToilet

Inherits:
Base
  • Object
show all
Includes:
Mixins::PublicToilet, _PublicToilet
Defined in:
lib/schema_org/types/public_toilet.rb,
sig/schema_org.rbs

Overview

https://schema.org/PublicToilet

A public toilet is a room or small building containing one or more toilets (and possibly also urinals) which is available for use by the general public, or by customers or employees of certain businesses.

Constant Summary collapse

SCHEMA_NAME =
"PublicToilet"
SCHEMA_TYPES =
[self, SchemaOrg::CivicStructure, SchemaOrg::Place, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::PublicToilet

schema_property_definitions

Methods included from Mixins::CivicStructure

#opening_hours, #opening_hours=, schema_property_definitions

Methods included from Mixins::Place

#additional_property, #additional_property=, #address, #address=, #aggregate_rating, #aggregate_rating=, #amenity_feature, #amenity_feature=, #branch_code, #branch_code=, #contained_in, #contained_in=, #contained_in_place, #contained_in_place=, #contains_place, #contains_place=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #geo, #geo=, #geo_contains, #geo_contains=, #geo_covered_by, #geo_covered_by=, #geo_covers, #geo_covers=, #geo_crosses, #geo_crosses=, #geo_disjoint, #geo_disjoint=, #geo_equals, #geo_equals=, #geo_intersects, #geo_intersects=, #geo_overlaps, #geo_overlaps=, #geo_touches, #geo_touches=, #geo_within, #geo_within=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_drive_through_service, #has_drive_through_service=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_map, #has_map=, #is_accessible_for_free, #is_accessible_for_free=, #isic_v4, #isic_v4=, #keywords, #keywords=, #latitude, #latitude=, #logo, #logo=, #longitude, #longitude=, #map, #map=, #maps, #maps=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #opening_hours_specification, #opening_hours_specification=, #photo, #photo=, #photos, #photos=, #public_access, #public_access=, #review, #review=, #reviews, #reviews=, schema_property_definitions, #slogan, #slogan=, #smoking_allowed, #smoking_allowed=, #special_opening_hours_specification, #special_opening_hours_specification=, #telephone, #telephone=, #tour_booking_page, #tour_booking_page=

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _PublicToilet

#additional_property, #additional_property=, #additional_type, #additional_type=, #address, #address=, #aggregate_rating, #aggregate_rating=, #alternate_name, #alternate_name=, #amenity_feature, #amenity_feature=, #branch_code, #branch_code=, #contained_in, #contained_in=, #contained_in_place, #contained_in_place=, #contains_place, #contains_place=, #description, #description=, #disambiguating_description, #disambiguating_description=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #geo, #geo=, #geo_contains, #geo_contains=, #geo_covered_by, #geo_covered_by=, #geo_covers, #geo_covers=, #geo_crosses, #geo_crosses=, #geo_disjoint, #geo_disjoint=, #geo_equals, #geo_equals=, #geo_intersects, #geo_intersects=, #geo_overlaps, #geo_overlaps=, #geo_touches, #geo_touches=, #geo_within, #geo_within=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_drive_through_service, #has_drive_through_service=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_map, #has_map=, #identifier, #identifier=, #image, #image=, #is_accessible_for_free, #is_accessible_for_free=, #isic_v4, #isic_v4=, #keywords, #keywords=, #latitude, #latitude=, #logo, #logo=, #longitude, #longitude=, #main_entity_of_page, #main_entity_of_page=, #map, #map=, #maps, #maps=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #name, #name=, #opening_hours, #opening_hours=, #opening_hours_specification, #opening_hours_specification=, #owner, #owner=, #photo, #photo=, #photos, #photos=, #potential_action, #potential_action=, #public_access, #public_access=, #review, #review=, #reviews, #reviews=, #same_as, #same_as=, #slogan, #slogan=, #smoking_allowed, #smoking_allowed=, #special_opening_hours_specification, #special_opening_hours_specification=, #subject_of, #subject_of=, #telephone, #telephone=, #tour_booking_page, #tour_booking_page=, #url, #url=

Class Method Details

.new(**properties) ⇒ PublicToilet

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/public_toilet.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/public_toilet.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/public_toilet.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/public_toilet.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



101448
# File 'sig/schema_org.rbs', line 101448

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


101447
# File 'sig/schema_org.rbs', line 101447

def schema_types: () -> ::Array[::Class]