Class: SchemaOrg::ReceiveAction
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::ReceiveAction
- Includes:
- Mixins::ReceiveAction, _ReceiveAction
- Defined in:
- lib/schema_org/types/receive_action.rb,
sig/schema_org.rbs
Overview
https://schema.org/ReceiveAction
The act of physically/electronically taking delivery of an object that has been transferred from an origin to a destination. Reciprocal of SendAction.\n\nRelated actions:\n\n* [[SendAction]]: The reciprocal of ReceiveAction.\n* [[TakeAction]]: Unlike TakeAction, ReceiveAction does not imply that the ownership has been transferred (e.g. I can receive a package, but it does not mean the package is now mine).
Constant Summary collapse
- SCHEMA_NAME =
"ReceiveAction"- SCHEMA_TYPES =
[self, SchemaOrg::TransferAction, SchemaOrg::Action, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ ReceiveAction
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::ReceiveAction
#delivery_method, #delivery_method=, schema_property_definitions, #sender, #sender=
Methods included from Mixins::TransferAction
#from_location, #from_location=, schema_property_definitions, #to_location, #to_location=
Methods included from Mixins::Action
#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, schema_property_definitions, #start_time, #start_time=, #target, #target=
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _ReceiveAction
#action_process, #action_process=, #action_status, #action_status=, #additional_type, #additional_type=, #agent, #agent=, #alternate_name, #alternate_name=, #delivery_method, #delivery_method=, #description, #description=, #disambiguating_description, #disambiguating_description=, #end_time, #end_time=, #error, #error=, #from_location, #from_location=, #identifier, #identifier=, #image, #image=, #instrument, #instrument=, #location, #location=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #object, #object=, #owner, #owner=, #participant, #participant=, #potential_action, #potential_action=, #provider, #provider=, #result, #result=, #same_as, #same_as=, #sender, #sender=, #start_time, #start_time=, #subject_of, #subject_of=, #target, #target=, #to_location, #to_location=, #url, #url=
Class Method Details
.new(**properties) ⇒ ReceiveAction
30 31 32 |
# File 'lib/schema_org/types/receive_action.rb', line 30 def new(**properties) super end |
.schema_name ⇒ String
17 18 19 |
# File 'lib/schema_org/types/receive_action.rb', line 17 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
25 26 27 28 |
# File 'lib/schema_org/types/receive_action.rb', line 25 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
21 22 23 |
# File 'lib/schema_org/types/receive_action.rb', line 21 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
106203 |
# File 'sig/schema_org.rbs', line 106203
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
106202 |
# File 'sig/schema_org.rbs', line 106202
def schema_types: () -> ::Array[::Class]
|