Class: SchemaOrg::RecommendedDoseSchedule
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::RecommendedDoseSchedule
- Defined in:
- lib/schema_org/types/recommended_dose_schedule.rb,
sig/schema_org.rbs
Overview
https://schema.org/RecommendedDoseSchedule
A recommended dosing schedule for a drug or supplement as prescribed or recommended by an authority or by the drug/supplement's manufacturer. Capture the recommending authority in the recognizingAuthority property of MedicalEntity.
Constant Summary collapse
- SCHEMA_NAME =
"RecommendedDoseSchedule"- SCHEMA_TYPES =
[self, SchemaOrg::DoseSchedule, SchemaOrg::MedicalIntangible, SchemaOrg::MedicalEntity, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ RecommendedDoseSchedule
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::RecommendedDoseSchedule
Methods included from Mixins::DoseSchedule
#dose_unit, #dose_unit=, #dose_value, #dose_value=, #frequency, #frequency=, schema_property_definitions, #target_population, #target_population=
Methods included from Mixins::MedicalIntangible
Methods included from Mixins::MedicalEntity
#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, schema_property_definitions, #study, #study=
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _RecommendedDoseSchedule
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #code, #code=, #description, #description=, #disambiguating_description, #disambiguating_description=, #dose_unit, #dose_unit=, #dose_value, #dose_value=, #frequency, #frequency=, #funding, #funding=, #guideline, #guideline=, #identifier, #identifier=, #image, #image=, #legal_status, #legal_status=, #main_entity_of_page, #main_entity_of_page=, #medicine_system, #medicine_system=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #same_as, #same_as=, #study, #study=, #subject_of, #subject_of=, #target_population, #target_population=, #url, #url=
Class Method Details
.new(**properties) ⇒ RecommendedDoseSchedule
30 31 32 |
# File 'lib/schema_org/types/recommended_dose_schedule.rb', line 30 def new(**properties) super end |
.schema_name ⇒ String
17 18 19 |
# File 'lib/schema_org/types/recommended_dose_schedule.rb', line 17 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
25 26 27 28 |
# File 'lib/schema_org/types/recommended_dose_schedule.rb', line 25 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
21 22 23 |
# File 'lib/schema_org/types/recommended_dose_schedule.rb', line 21 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
106866 |
# File 'sig/schema_org.rbs', line 106866
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
106865 |
# File 'sig/schema_org.rbs', line 106865
def schema_types: () -> ::Array[::Class]
|