Class: SchemaOrg::Role
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::Role
show all
- Includes:
- Mixins::Role, _Role
- Defined in:
- lib/schema_org/types/role.rb,
sig/schema_org.rbs
Overview
https://schema.org/Role
Represents additional information about a relationship or property. For example a Role can be used to say that a 'member' role linking some SportsTeam to a player occurred during a particular time period. Or that a Person's 'actor' role in a Movie was for some particular characterName. Such properties can be attached to a Role entity, which is then associated with the main entities using ordinary properties like 'member' or 'actor'.\n\nSee also blog post.
Constant Summary
collapse
- SCHEMA_NAME =
"Role"
- SCHEMA_TYPES =
[self, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
Class Method Summary
collapse
Instance Method Summary
collapse
#end_date, #end_date=, #named_position, #named_position=, #role_name, #role_name=, schema_property_definitions, #start_date, #start_date=
schema_property_definitions
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _Role
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #end_date, #end_date=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #named_position, #named_position=, #owner, #owner=, #potential_action, #potential_action=, #role_name, #role_name=, #same_as, #same_as=, #start_date, #start_date=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.new(**properties) ⇒ Role
30
31
32
|
# File 'lib/schema_org/types/role.rb', line 30
def new(**properties)
super
end
|
.schema_name ⇒ String
17
18
19
|
# File 'lib/schema_org/types/role.rb', line 17
def schema_name
SCHEMA_NAME
end
|
.schema_type?(other_type) ⇒ Boolean
25
26
27
28
|
# File 'lib/schema_org/types/role.rb', line 25
def schema_type?(other_type)
Base.schema_type_argument!(other_type)
SCHEMA_TYPES.include?(other_type)
end
|
.schema_types ⇒ ::Array[::Class]
21
22
23
|
# File 'lib/schema_org/types/role.rb', line 21
def schema_types
SCHEMA_TYPES
end
|
Instance Method Details
#schema_type? ⇒ Boolean
111047
|
# File 'sig/schema_org.rbs', line 111047
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
111046
|
# File 'sig/schema_org.rbs', line 111046
def schema_types: () -> ::Array[::Class]
|