Class: SchemaOrg::SellAction

Inherits:
Base
  • Object
show all
Includes:
Mixins::SellAction, _SellAction
Defined in:
lib/schema_org/types/sell_action.rb,
sig/schema_org.rbs

Overview

https://schema.org/SellAction

The act of taking money from a buyer in exchange for goods or services rendered. An agent sells an object, product, or service to a buyer for a price. Reciprocal of BuyAction.

Constant Summary collapse

SCHEMA_NAME =
"SellAction"
SCHEMA_TYPES =
[self, SchemaOrg::TradeAction, SchemaOrg::Action, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::SellAction

#buyer, #buyer=, schema_property_definitions, #warranty_promise, #warranty_promise=

Methods included from Mixins::TradeAction

#price, #price=, #price_currency, #price_currency=, #price_specification, #price_specification=, schema_property_definitions

Methods included from Mixins::Action

#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, schema_property_definitions, #start_time, #start_time=, #target, #target=

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _SellAction

#action_process, #action_process=, #action_status, #action_status=, #additional_type, #additional_type=, #agent, #agent=, #alternate_name, #alternate_name=, #buyer, #buyer=, #description, #description=, #disambiguating_description, #disambiguating_description=, #end_time, #end_time=, #error, #error=, #identifier, #identifier=, #image, #image=, #instrument, #instrument=, #location, #location=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #object, #object=, #owner, #owner=, #participant, #participant=, #potential_action, #potential_action=, #price, #price=, #price_currency, #price_currency=, #price_specification, #price_specification=, #provider, #provider=, #result, #result=, #same_as, #same_as=, #start_time, #start_time=, #subject_of, #subject_of=, #target, #target=, #url, #url=, #warranty_promise, #warranty_promise=

Class Method Details

.new(**properties) ⇒ SellAction

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/sell_action.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/sell_action.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/sell_action.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/sell_action.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



114960
# File 'sig/schema_org.rbs', line 114960

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


114959
# File 'sig/schema_org.rbs', line 114959

def schema_types: () -> ::Array[::Class]