Class: SchemaOrg::ShippingConditions

Inherits:
Base
  • Object
show all
Includes:
Mixins::ShippingConditions, _ShippingConditions
Defined in:
lib/schema_org/types/shipping_conditions.rb,
sig/schema_org.rbs

Overview

https://schema.org/ShippingConditions

NOTE: Supersedes DeliveryTimeSettings.

ShippingConditions represent a set of constraints and information about the conditions of shipping a product. Such conditions may apply to only a subset of the products being shipped, depending on aspects of the product like weight, size, price, destination, and others. All the specified conditions must be met for this ShippingConditions to apply.

Constant Summary collapse

SCHEMA_NAME =
"ShippingConditions"
SCHEMA_TYPES =
[self, SchemaOrg::StructuredValue, SchemaOrg::Intangible, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::ShippingConditions

#depth, #depth=, #does_not_ship, #does_not_ship=, #height, #height=, #num_items, #num_items=, #order_value, #order_value=, schema_property_definitions, #seasonal_override, #seasonal_override=, #shipping_destination, #shipping_destination=, #shipping_origin, #shipping_origin=, #shipping_rate, #shipping_rate=, #transit_time, #transit_time=, #weight, #weight=, #width, #width=

Methods included from Mixins::StructuredValue

schema_property_definitions

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _ShippingConditions

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #depth, #depth=, #description, #description=, #disambiguating_description, #disambiguating_description=, #does_not_ship, #does_not_ship=, #height, #height=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #num_items, #num_items=, #order_value, #order_value=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #seasonal_override, #seasonal_override=, #shipping_destination, #shipping_destination=, #shipping_origin, #shipping_origin=, #shipping_rate, #shipping_rate=, #subject_of, #subject_of=, #transit_time, #transit_time=, #url, #url=, #weight, #weight=, #width, #width=

Class Method Details

.new(**properties) ⇒ ShippingConditions

Parameters:

Returns:



32
33
34
# File 'lib/schema_org/types/shipping_conditions.rb', line 32

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


19
20
21
# File 'lib/schema_org/types/shipping_conditions.rb', line 19

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



27
28
29
30
# File 'lib/schema_org/types/shipping_conditions.rb', line 27

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


23
24
25
# File 'lib/schema_org/types/shipping_conditions.rb', line 23

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



115979
# File 'sig/schema_org.rbs', line 115979

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


115978
# File 'sig/schema_org.rbs', line 115978

def schema_types: () -> ::Array[::Class]