Class: SchemaOrg::ShippingService

Inherits:
Base
  • Object
show all
Includes:
Mixins::ShippingService, _ShippingService
Defined in:
lib/schema_org/types/shipping_service.rb,
sig/schema_org.rbs

Overview

https://schema.org/ShippingService

ShippingService represents the criteria used to determine if and how an offer could be shipped to a customer.

Constant Summary collapse

SCHEMA_NAME =
"ShippingService"
SCHEMA_TYPES =
[self, SchemaOrg::StructuredValue, SchemaOrg::Intangible, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::ShippingService

#fulfillment_type, #fulfillment_type=, #handling_time, #handling_time=, schema_property_definitions, #shipping_conditions, #shipping_conditions=, #valid_for_member_tier, #valid_for_member_tier=

Methods included from Mixins::StructuredValue

schema_property_definitions

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _ShippingService

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #fulfillment_type, #fulfillment_type=, #handling_time, #handling_time=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #shipping_conditions, #shipping_conditions=, #subject_of, #subject_of=, #url, #url=, #valid_for_member_tier, #valid_for_member_tier=

Class Method Details

.new(**properties) ⇒ ShippingService

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/shipping_service.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/shipping_service.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/shipping_service.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/shipping_service.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



116128
# File 'sig/schema_org.rbs', line 116128

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


116127
# File 'sig/schema_org.rbs', line 116127

def schema_types: () -> ::Array[::Class]