Class: SchemaOrg::SolveMathAction
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::SolveMathAction
- Includes:
- Mixins::SolveMathAction, _SolveMathAction
- Defined in:
- lib/schema_org/types/solve_math_action.rb,
sig/schema_org.rbs
Overview
https://schema.org/SolveMathAction
The action that takes in a math expression and directs users to a page potentially capable of solving/simplifying that expression.
Constant Summary collapse
Class Method Summary collapse
- .new(**properties) ⇒ SolveMathAction
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::SolveMathAction
#edu_question_type, #edu_question_type=, schema_property_definitions
Methods included from Mixins::Action
#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, schema_property_definitions, #start_time, #start_time=, #target, #target=
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _SolveMathAction
#action_process, #action_process=, #action_status, #action_status=, #additional_type, #additional_type=, #agent, #agent=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #edu_question_type, #edu_question_type=, #end_time, #end_time=, #error, #error=, #identifier, #identifier=, #image, #image=, #instrument, #instrument=, #location, #location=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #object, #object=, #owner, #owner=, #participant, #participant=, #potential_action, #potential_action=, #provider, #provider=, #result, #result=, #same_as, #same_as=, #start_time, #start_time=, #subject_of, #subject_of=, #target, #target=, #url, #url=
Class Method Details
.new(**properties) ⇒ SolveMathAction
30 31 32 |
# File 'lib/schema_org/types/solve_math_action.rb', line 30 def new(**properties) super end |
.schema_name ⇒ String
17 18 19 |
# File 'lib/schema_org/types/solve_math_action.rb', line 17 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
25 26 27 28 |
# File 'lib/schema_org/types/solve_math_action.rb', line 25 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
21 22 23 |
# File 'lib/schema_org/types/solve_math_action.rb', line 21 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
118897 |
# File 'sig/schema_org.rbs', line 118897
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
118896 |
# File 'sig/schema_org.rbs', line 118896
def schema_types: () -> ::Array[::Class]
|