Class: SchemaOrg::TouristTrip
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::TouristTrip
- Includes:
- Mixins::TouristTrip, _TouristTrip
- Defined in:
- lib/schema_org/types/tourist_trip.rb,
sig/schema_org.rbs
Overview
https://schema.org/TouristTrip
A tourist trip. A created itinerary of visits to one or more places of interest ([[TouristAttraction]]/[[TouristDestination]]) often linked by a similar theme, geographic area, or interest to a particular [[touristType]]. The UNWTO defines tourism trip as the Trip taken by visitors. (See examples below.)
Constant Summary collapse
- SCHEMA_NAME =
"TouristTrip"- SCHEMA_TYPES =
[self, SchemaOrg::Trip, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ TouristTrip
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::TouristTrip
schema_property_definitions, #tourist_type, #tourist_type=
Methods included from Mixins::Trip
#arrival_time, #arrival_time=, #departure_time, #departure_time=, #itinerary, #itinerary=, #offers, #offers=, #part_of_trip, #part_of_trip=, #provider, #provider=, schema_property_definitions, #sub_trip, #sub_trip=, #trip_origin, #trip_origin=
Methods included from Mixins::Intangible
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _TouristTrip
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #arrival_time, #arrival_time=, #departure_time, #departure_time=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #itinerary, #itinerary=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #offers, #offers=, #owner, #owner=, #part_of_trip, #part_of_trip=, #potential_action, #potential_action=, #provider, #provider=, #same_as, #same_as=, #sub_trip, #sub_trip=, #subject_of, #subject_of=, #tourist_type, #tourist_type=, #trip_origin, #trip_origin=, #url, #url=
Class Method Details
.new(**properties) ⇒ TouristTrip
31 32 33 |
# File 'lib/schema_org/types/tourist_trip.rb', line 31 def new(**properties) super end |
.schema_name ⇒ String
18 19 20 |
# File 'lib/schema_org/types/tourist_trip.rb', line 18 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
26 27 28 29 |
# File 'lib/schema_org/types/tourist_trip.rb', line 26 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
22 23 24 |
# File 'lib/schema_org/types/tourist_trip.rb', line 22 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
128835 |
# File 'sig/schema_org.rbs', line 128835
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
128834 |
# File 'sig/schema_org.rbs', line 128834
def schema_types: () -> ::Array[::Class]
|