Class: SchemaOrg::TypeAndQuantityNode

Inherits:
Base
  • Object
show all
Includes:
Mixins::TypeAndQuantityNode, _TypeAndQuantityNode
Defined in:
lib/schema_org/types/type_and_quantity_node.rb,
sig/schema_org.rbs

Overview

https://schema.org/TypeAndQuantityNode

A structured value indicating the quantity, unit of measurement, and business function of goods included in a bundle offer.

Constant Summary collapse

SCHEMA_NAME =
"TypeAndQuantityNode"
SCHEMA_TYPES =
[self, SchemaOrg::StructuredValue, SchemaOrg::Intangible, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::TypeAndQuantityNode

#amount_of_this_good, #amount_of_this_good=, #business_function, #business_function=, schema_property_definitions, #type_of_good, #type_of_good=, #unit_code, #unit_code=, #unit_text, #unit_text=

Methods included from Mixins::StructuredValue

schema_property_definitions

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _TypeAndQuantityNode

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #amount_of_this_good, #amount_of_this_good=, #business_function, #business_function=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #type_of_good, #type_of_good=, #unit_code, #unit_code=, #unit_text, #unit_text=, #url, #url=

Class Method Details

.new(**properties) ⇒ TypeAndQuantityNode

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/type_and_quantity_node.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/type_and_quantity_node.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/type_and_quantity_node.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/type_and_quantity_node.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



130077
# File 'sig/schema_org.rbs', line 130077

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


130076
# File 'sig/schema_org.rbs', line 130076

def schema_types: () -> ::Array[::Class]