Class: SchemaOrg::WorkBasedProgram

Inherits:
Base
  • Object
show all
Includes:
Mixins::WorkBasedProgram, _WorkBasedProgram
Defined in:
lib/schema_org/types/work_based_program.rb,
sig/schema_org.rbs

Overview

https://schema.org/WorkBasedProgram

A program with both an educational and employment component. Typically based at a workplace and structured around work-based learning, with the aim of instilling competencies related to an occupation. WorkBasedProgram is used to distinguish programs such as apprenticeships from school, college or other classroom based educational programs.

Constant Summary collapse

SCHEMA_NAME =
"WorkBasedProgram"
SCHEMA_TYPES =
[self, SchemaOrg::EducationalOccupationalProgram, SchemaOrg::Intangible, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::WorkBasedProgram

#occupational_category, #occupational_category=, schema_property_definitions, #training_salary, #training_salary=

Methods included from Mixins::EducationalOccupationalProgram

#application_deadline, #application_deadline=, #application_start_date, #application_start_date=, #day_of_week, #day_of_week=, #educational_credential_awarded, #educational_credential_awarded=, #educational_program_mode, #educational_program_mode=, #end_date, #end_date=, #financial_aid_eligible, #financial_aid_eligible=, #has_course, #has_course=, #maximum_enrollment, #maximum_enrollment=, #number_of_credits, #number_of_credits=, #occupational_category, #occupational_category=, #occupational_credential_awarded, #occupational_credential_awarded=, #offers, #offers=, #program_prerequisites, #program_prerequisites=, #program_type, #program_type=, #provider, #provider=, #salary_upon_completion, #salary_upon_completion=, schema_property_definitions, #start_date, #start_date=, #term_duration, #term_duration=, #terms_per_year, #terms_per_year=, #time_of_day, #time_of_day=, #time_to_complete, #time_to_complete=, #training_salary, #training_salary=, #typical_credits_per_term, #typical_credits_per_term=

Methods included from Mixins::Intangible

schema_property_definitions

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _WorkBasedProgram

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #application_deadline, #application_deadline=, #application_start_date, #application_start_date=, #day_of_week, #day_of_week=, #description, #description=, #disambiguating_description, #disambiguating_description=, #educational_credential_awarded, #educational_credential_awarded=, #educational_program_mode, #educational_program_mode=, #end_date, #end_date=, #financial_aid_eligible, #financial_aid_eligible=, #has_course, #has_course=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #maximum_enrollment, #maximum_enrollment=, #name, #name=, #number_of_credits, #number_of_credits=, #occupational_category, #occupational_category=, #occupational_credential_awarded, #occupational_credential_awarded=, #offers, #offers=, #owner, #owner=, #potential_action, #potential_action=, #program_prerequisites, #program_prerequisites=, #program_type, #program_type=, #provider, #provider=, #salary_upon_completion, #salary_upon_completion=, #same_as, #same_as=, #start_date, #start_date=, #subject_of, #subject_of=, #term_duration, #term_duration=, #terms_per_year, #terms_per_year=, #time_of_day, #time_of_day=, #time_to_complete, #time_to_complete=, #training_salary, #training_salary=, #typical_credits_per_term, #typical_credits_per_term=, #url, #url=

Class Method Details

.new(**properties) ⇒ WorkBasedProgram

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/work_based_program.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/work_based_program.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/work_based_program.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/work_based_program.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



139566
# File 'sig/schema_org.rbs', line 139566

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


139565
# File 'sig/schema_org.rbs', line 139565

def schema_types: () -> ::Array[::Class]