Class: SchemaOrg::WorkersUnion

Inherits:
Base
  • Object
show all
Includes:
Mixins::WorkersUnion, _WorkersUnion
Defined in:
lib/schema_org/types/workers_union.rb,
sig/schema_org.rbs

Overview

https://schema.org/WorkersUnion

A Workers Union (also known as a Labor Union, Labour Union, or Trade Union) is an organization that promotes the interests of its worker members by collectively bargaining with management, organizing, and political lobbying.

Constant Summary collapse

SCHEMA_NAME =
"WorkersUnion"
SCHEMA_TYPES =
[self, SchemaOrg::Organization, SchemaOrg::Thing].freeze

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Mixins::WorkersUnion

schema_property_definitions

Methods included from Mixins::Organization

#accepted_payment_method, #accepted_payment_method=, #actionable_feedback_policy, #actionable_feedback_policy=, #address, #address=, #agent_interaction_statistic, #agent_interaction_statistic=, #aggregate_rating, #aggregate_rating=, #alumni, #alumni=, #area_served, #area_served=, #award, #award=, #awards, #awards=, #brand, #brand=, #company_registration, #company_registration=, #contact_point, #contact_point=, #contact_points, #contact_points=, #corrections_policy, #corrections_policy=, #department, #department=, #dissolution_date, #dissolution_date=, #diversity_policy, #diversity_policy=, #diversity_staffing_report, #diversity_staffing_report=, #duns, #duns=, #email, #email=, #employee, #employee=, #employees, #employees=, #ethics_policy, #ethics_policy=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #founder, #founder=, #founders, #founders=, #founding_date, #founding_date=, #founding_location, #founding_location=, #funder, #funder=, #funding, #funding=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_credential, #has_credential=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_member_program, #has_member_program=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_offer_catalog, #has_offer_catalog=, #has_pos, #has_pos=, #has_product_return_policy, #has_product_return_policy=, #has_shipping_service, #has_shipping_service=, #interaction_statistic, #interaction_statistic=, #isic_v4, #isic_v4=, #iso6523_code, #iso6523_code=, #keywords, #keywords=, #knows_about, #knows_about=, #knows_language, #knows_language=, #legal_address, #legal_address=, #legal_name, #legal_name=, #legal_representative, #legal_representative=, #lei_code, #lei_code=, #location, #location=, #logo, #logo=, #makes_offer, #makes_offer=, #member, #member=, #member_of, #member_of=, #members, #members=, #naics, #naics=, #nonprofit_status, #nonprofit_status=, #number_of_employees, #number_of_employees=, #ownership_funding_info, #ownership_funding_info=, #owns, #owns=, #parent_organization, #parent_organization=, #publishing_principles, #publishing_principles=, #review, #review=, #reviews, #reviews=, schema_property_definitions, #seeks, #seeks=, #service_area, #service_area=, #skills, #skills=, #slogan, #slogan=, #sponsor, #sponsor=, #sub_organization, #sub_organization=, #tax_id, #tax_id=, #telephone, #telephone=, #unnamed_sources_policy, #unnamed_sources_policy=, #vat_id, #vat_id=

Methods included from Mixins::Thing

#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=

Methods included from _WorkersUnion

#accepted_payment_method, #accepted_payment_method=, #actionable_feedback_policy, #actionable_feedback_policy=, #additional_type, #additional_type=, #address, #address=, #agent_interaction_statistic, #agent_interaction_statistic=, #aggregate_rating, #aggregate_rating=, #alternate_name, #alternate_name=, #alumni, #alumni=, #area_served, #area_served=, #award, #award=, #awards, #awards=, #brand, #brand=, #company_registration, #company_registration=, #contact_point, #contact_point=, #contact_points, #contact_points=, #corrections_policy, #corrections_policy=, #department, #department=, #description, #description=, #disambiguating_description, #disambiguating_description=, #dissolution_date, #dissolution_date=, #diversity_policy, #diversity_policy=, #diversity_staffing_report, #diversity_staffing_report=, #duns, #duns=, #email, #email=, #employee, #employee=, #employees, #employees=, #ethics_policy, #ethics_policy=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #founder, #founder=, #founders, #founders=, #founding_date, #founding_date=, #founding_location, #founding_location=, #funder, #funder=, #funding, #funding=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_credential, #has_credential=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_member_program, #has_member_program=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_offer_catalog, #has_offer_catalog=, #has_pos, #has_pos=, #has_product_return_policy, #has_product_return_policy=, #has_shipping_service, #has_shipping_service=, #identifier, #identifier=, #image, #image=, #interaction_statistic, #interaction_statistic=, #isic_v4, #isic_v4=, #iso6523_code, #iso6523_code=, #keywords, #keywords=, #knows_about, #knows_about=, #knows_language, #knows_language=, #legal_address, #legal_address=, #legal_name, #legal_name=, #legal_representative, #legal_representative=, #lei_code, #lei_code=, #location, #location=, #logo, #logo=, #main_entity_of_page, #main_entity_of_page=, #makes_offer, #makes_offer=, #member, #member=, #member_of, #member_of=, #members, #members=, #naics, #naics=, #name, #name=, #nonprofit_status, #nonprofit_status=, #number_of_employees, #number_of_employees=, #owner, #owner=, #ownership_funding_info, #ownership_funding_info=, #owns, #owns=, #parent_organization, #parent_organization=, #potential_action, #potential_action=, #publishing_principles, #publishing_principles=, #review, #review=, #reviews, #reviews=, #same_as, #same_as=, #seeks, #seeks=, #service_area, #service_area=, #skills, #skills=, #slogan, #slogan=, #sponsor, #sponsor=, #sub_organization, #sub_organization=, #subject_of, #subject_of=, #tax_id, #tax_id=, #telephone, #telephone=, #unnamed_sources_policy, #unnamed_sources_policy=, #url, #url=, #vat_id, #vat_id=

Class Method Details

.new(**properties) ⇒ WorkersUnion

Parameters:

Returns:



30
31
32
# File 'lib/schema_org/types/workers_union.rb', line 30

def new(**properties)
  super
end

.schema_nameString

Returns:

  • (String)


17
18
19
# File 'lib/schema_org/types/workers_union.rb', line 17

def schema_name
  SCHEMA_NAME
end

.schema_type?(other_type) ⇒ Boolean

Parameters:

  • (Object)

Returns:



25
26
27
28
# File 'lib/schema_org/types/workers_union.rb', line 25

def schema_type?(other_type)
  Base.schema_type_argument!(other_type)
  SCHEMA_TYPES.include?(other_type)
end

.schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


21
22
23
# File 'lib/schema_org/types/workers_union.rb', line 21

def schema_types
  SCHEMA_TYPES
end

Instance Method Details

#schema_type?Boolean

Parameters:

  • (Object)

Returns:



139759
# File 'sig/schema_org.rbs', line 139759

def schema_type?: (untyped) -> bool

#schema_types::Array[::Class]

Returns:

  • (::Array[::Class])


139758
# File 'sig/schema_org.rbs', line 139758

def schema_types: () -> ::Array[::Class]