Class: SchemaOrg::AnatomicalSystem
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::AnatomicalSystem
- Includes:
- Mixins::AnatomicalSystem, _AnatomicalSystem
- Defined in:
- lib/schema_org/types/anatomical_system.rb,
sig/schema_org.rbs
Overview
https://schema.org/AnatomicalSystem
An anatomical system is a group of anatomical structures that work together to perform a certain task. Anatomical systems, such as organ systems, are one organizing principle of anatomy, and can include circulatory, digestive, endocrine, integumentary, immune, lymphatic, muscular, nervous, reproductive, respiratory, skeletal, urinary, vestibular, and other systems.
Constant Summary collapse
- SCHEMA_NAME =
"AnatomicalSystem"- SCHEMA_TYPES =
[self, SchemaOrg::MedicalEntity, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ AnatomicalSystem
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::AnatomicalSystem
#associated_pathophysiology, #associated_pathophysiology=, #comprised_of, #comprised_of=, #related_condition, #related_condition=, #related_structure, #related_structure=, #related_therapy, #related_therapy=, schema_property_definitions
Methods included from Mixins::MedicalEntity
#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, schema_property_definitions, #study, #study=
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _AnatomicalSystem
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #associated_pathophysiology, #associated_pathophysiology=, #code, #code=, #comprised_of, #comprised_of=, #description, #description=, #disambiguating_description, #disambiguating_description=, #funding, #funding=, #guideline, #guideline=, #identifier, #identifier=, #image, #image=, #legal_status, #legal_status=, #main_entity_of_page, #main_entity_of_page=, #medicine_system, #medicine_system=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #recognizing_authority, #recognizing_authority=, #related_condition, #related_condition=, #related_structure, #related_structure=, #related_therapy, #related_therapy=, #relevant_specialty, #relevant_specialty=, #same_as, #same_as=, #study, #study=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.new(**properties) ⇒ AnatomicalSystem
30 31 32 |
# File 'lib/schema_org/types/anatomical_system.rb', line 30 def new(**properties) super end |
.schema_name ⇒ String
17 18 19 |
# File 'lib/schema_org/types/anatomical_system.rb', line 17 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
25 26 27 28 |
# File 'lib/schema_org/types/anatomical_system.rb', line 25 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
21 22 23 |
# File 'lib/schema_org/types/anatomical_system.rb', line 21 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
4335 |
# File 'sig/schema_org.rbs', line 4335
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
4334 |
# File 'sig/schema_org.rbs', line 4334
def schema_types: () -> ::Array[::Class]
|