Class: SchemaOrg::Campground
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::Campground
- Includes:
- Mixins::Campground, _Campground
- Defined in:
- lib/schema_org/types/campground.rb,
sig/schema_org.rbs
Overview
A camping site, campsite, or [[Campground]] is a place used for overnight stay in the outdoors, typically containing individual [[CampingPitch]] locations. \n\n In British English a campsite is an area, usually divided into a number of pitches, where people can camp overnight using tents or camper vans or caravans; this British English use of the word is synonymous with the American English expression campground. In American English the term campsite generally means an area where an individual, family, group, or military unit can pitch a tent or park a camper; a campground may contain many campsites (source: Wikipedia, see https://en.wikipedia.org/wiki/Campsite).\n\n
See also the dedicated document on the use of schema.org for marking up hotels and other forms of accommodations.
Constant Summary collapse
- SCHEMA_NAME =
"Campground"- SCHEMA_TYPES =
[self, SchemaOrg::CivicStructure, SchemaOrg::LodgingBusiness, SchemaOrg::Place, SchemaOrg::LocalBusiness, SchemaOrg::Thing, SchemaOrg::Organization].freeze
Class Method Summary collapse
- .new(**properties) ⇒ Campground
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::Campground
Methods included from Mixins::LodgingBusiness
#amenity_feature, #amenity_feature=, #audience, #audience=, #available_language, #available_language=, #checkin_time, #checkin_time=, #checkout_time, #checkout_time=, #number_of_rooms, #number_of_rooms=, #pets_allowed, #pets_allowed=, schema_property_definitions, #star_rating, #star_rating=
Methods included from Mixins::LocalBusiness
#branch_of, #branch_of=, #currencies_accepted, #currencies_accepted=, #floor_level, #floor_level=, #opening_hours, #opening_hours=, #payment_accepted, #payment_accepted=, #price_range, #price_range=, schema_property_definitions
Methods included from Mixins::Place
#additional_property, #additional_property=, #address, #address=, #aggregate_rating, #aggregate_rating=, #amenity_feature, #amenity_feature=, #branch_code, #branch_code=, #contained_in, #contained_in=, #contained_in_place, #contained_in_place=, #contains_place, #contains_place=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #geo, #geo=, #geo_contains, #geo_contains=, #geo_covered_by, #geo_covered_by=, #geo_covers, #geo_covers=, #geo_crosses, #geo_crosses=, #geo_disjoint, #geo_disjoint=, #geo_equals, #geo_equals=, #geo_intersects, #geo_intersects=, #geo_overlaps, #geo_overlaps=, #geo_touches, #geo_touches=, #geo_within, #geo_within=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_drive_through_service, #has_drive_through_service=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_map, #has_map=, #is_accessible_for_free, #is_accessible_for_free=, #isic_v4, #isic_v4=, #keywords, #keywords=, #latitude, #latitude=, #logo, #logo=, #longitude, #longitude=, #map, #map=, #maps, #maps=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #opening_hours_specification, #opening_hours_specification=, #photo, #photo=, #photos, #photos=, #public_access, #public_access=, #review, #review=, #reviews, #reviews=, schema_property_definitions, #slogan, #slogan=, #smoking_allowed, #smoking_allowed=, #special_opening_hours_specification, #special_opening_hours_specification=, #telephone, #telephone=, #tour_booking_page, #tour_booking_page=
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from Mixins::Organization
#accepted_payment_method, #accepted_payment_method=, #actionable_feedback_policy, #actionable_feedback_policy=, #address, #address=, #agent_interaction_statistic, #agent_interaction_statistic=, #aggregate_rating, #aggregate_rating=, #alumni, #alumni=, #area_served, #area_served=, #award, #award=, #awards, #awards=, #brand, #brand=, #company_registration, #company_registration=, #contact_point, #contact_point=, #contact_points, #contact_points=, #corrections_policy, #corrections_policy=, #department, #department=, #dissolution_date, #dissolution_date=, #diversity_policy, #diversity_policy=, #diversity_staffing_report, #diversity_staffing_report=, #duns, #duns=, #email, #email=, #employee, #employee=, #employees, #employees=, #ethics_policy, #ethics_policy=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #founder, #founder=, #founders, #founders=, #founding_date, #founding_date=, #founding_location, #founding_location=, #funder, #funder=, #funding, #funding=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_credential, #has_credential=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_member_program, #has_member_program=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_offer_catalog, #has_offer_catalog=, #has_pos, #has_pos=, #has_product_return_policy, #has_product_return_policy=, #has_shipping_service, #has_shipping_service=, #interaction_statistic, #interaction_statistic=, #isic_v4, #isic_v4=, #iso6523_code, #iso6523_code=, #keywords, #keywords=, #knows_about, #knows_about=, #knows_language, #knows_language=, #legal_address, #legal_address=, #legal_name, #legal_name=, #legal_representative, #legal_representative=, #lei_code, #lei_code=, #location, #location=, #logo, #logo=, #makes_offer, #makes_offer=, #member, #member=, #member_of, #member_of=, #members, #members=, #naics, #naics=, #nonprofit_status, #nonprofit_status=, #number_of_employees, #number_of_employees=, #ownership_funding_info, #ownership_funding_info=, #owns, #owns=, #parent_organization, #parent_organization=, #publishing_principles, #publishing_principles=, #review, #review=, #reviews, #reviews=, schema_property_definitions, #seeks, #seeks=, #service_area, #service_area=, #skills, #skills=, #slogan, #slogan=, #sponsor, #sponsor=, #sub_organization, #sub_organization=, #tax_id, #tax_id=, #telephone, #telephone=, #unnamed_sources_policy, #unnamed_sources_policy=, #vat_id, #vat_id=
Methods included from Mixins::CivicStructure
#opening_hours, #opening_hours=, schema_property_definitions
Methods included from _Campground
#accepted_payment_method, #accepted_payment_method=, #actionable_feedback_policy, #actionable_feedback_policy=, #additional_property, #additional_property=, #additional_type, #additional_type=, #address, #address=, #agent_interaction_statistic, #agent_interaction_statistic=, #aggregate_rating, #aggregate_rating=, #alternate_name, #alternate_name=, #alumni, #alumni=, #amenity_feature, #amenity_feature=, #area_served, #area_served=, #audience, #audience=, #available_language, #available_language=, #award, #award=, #awards, #awards=, #branch_code, #branch_code=, #branch_of, #branch_of=, #brand, #brand=, #checkin_time, #checkin_time=, #checkout_time, #checkout_time=, #company_registration, #company_registration=, #contact_point, #contact_point=, #contact_points, #contact_points=, #contained_in, #contained_in=, #contained_in_place, #contained_in_place=, #contains_place, #contains_place=, #corrections_policy, #corrections_policy=, #currencies_accepted, #currencies_accepted=, #department, #department=, #description, #description=, #disambiguating_description, #disambiguating_description=, #dissolution_date, #dissolution_date=, #diversity_policy, #diversity_policy=, #diversity_staffing_report, #diversity_staffing_report=, #duns, #duns=, #email, #email=, #employee, #employee=, #employees, #employees=, #ethics_policy, #ethics_policy=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #floor_level, #floor_level=, #founder, #founder=, #founders, #founders=, #founding_date, #founding_date=, #founding_location, #founding_location=, #funder, #funder=, #funding, #funding=, #geo, #geo=, #geo_contains, #geo_contains=, #geo_covered_by, #geo_covered_by=, #geo_covers, #geo_covers=, #geo_crosses, #geo_crosses=, #geo_disjoint, #geo_disjoint=, #geo_equals, #geo_equals=, #geo_intersects, #geo_intersects=, #geo_overlaps, #geo_overlaps=, #geo_touches, #geo_touches=, #geo_within, #geo_within=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_credential, #has_credential=, #has_drive_through_service, #has_drive_through_service=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_map, #has_map=, #has_member_program, #has_member_program=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_offer_catalog, #has_offer_catalog=, #has_pos, #has_pos=, #has_product_return_policy, #has_product_return_policy=, #has_shipping_service, #has_shipping_service=, #identifier, #identifier=, #image, #image=, #interaction_statistic, #interaction_statistic=, #is_accessible_for_free, #is_accessible_for_free=, #isic_v4, #isic_v4=, #iso6523_code, #iso6523_code=, #keywords, #keywords=, #knows_about, #knows_about=, #knows_language, #knows_language=, #latitude, #latitude=, #legal_address, #legal_address=, #legal_name, #legal_name=, #legal_representative, #legal_representative=, #lei_code, #lei_code=, #location, #location=, #logo, #logo=, #longitude, #longitude=, #main_entity_of_page, #main_entity_of_page=, #makes_offer, #makes_offer=, #map, #map=, #maps, #maps=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #member, #member=, #member_of, #member_of=, #members, #members=, #naics, #naics=, #name, #name=, #nonprofit_status, #nonprofit_status=, #number_of_employees, #number_of_employees=, #number_of_rooms, #number_of_rooms=, #opening_hours, #opening_hours=, #opening_hours_specification, #opening_hours_specification=, #owner, #owner=, #ownership_funding_info, #ownership_funding_info=, #owns, #owns=, #parent_organization, #parent_organization=, #payment_accepted, #payment_accepted=, #pets_allowed, #pets_allowed=, #photo, #photo=, #photos, #photos=, #potential_action, #potential_action=, #price_range, #price_range=, #public_access, #public_access=, #publishing_principles, #publishing_principles=, #review, #review=, #reviews, #reviews=, #same_as, #same_as=, #seeks, #seeks=, #service_area, #service_area=, #skills, #skills=, #slogan, #slogan=, #smoking_allowed, #smoking_allowed=, #special_opening_hours_specification, #special_opening_hours_specification=, #sponsor, #sponsor=, #star_rating, #star_rating=, #sub_organization, #sub_organization=, #subject_of, #subject_of=, #tax_id, #tax_id=, #telephone, #telephone=, #tour_booking_page, #tour_booking_page=, #unnamed_sources_policy, #unnamed_sources_policy=, #url, #url=, #vat_id, #vat_id=
Class Method Details
.new(**properties) ⇒ Campground
33 34 35 |
# File 'lib/schema_org/types/campground.rb', line 33 def new(**properties) super end |
.schema_name ⇒ String
20 21 22 |
# File 'lib/schema_org/types/campground.rb', line 20 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
28 29 30 31 |
# File 'lib/schema_org/types/campground.rb', line 28 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
24 25 26 |
# File 'lib/schema_org/types/campground.rb', line 24 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
19148 |
# File 'sig/schema_org.rbs', line 19148
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
19147 |
# File 'sig/schema_org.rbs', line 19147
def schema_types: () -> ::Array[::Class]
|