Class: SchemaOrg::DefinedTerm
Overview
https://schema.org/DefinedTerm
A word, name, acronym, phrase, etc. with a formal definition. Often used in the context of category or subject classification, glossaries or dictionaries, product or creative work types, etc. Use the name property for the term being defined, use termCode if the term has an alpha-numeric code allocated, use description to provide the definition of the term. Use the about property to specify what the term is about.
Constant Summary
collapse
- SCHEMA_NAME =
"DefinedTerm"
- SCHEMA_TYPES =
[self, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
Class Method Summary
collapse
Instance Method Summary
collapse
#about, #about=, #in_defined_term_set, #in_defined_term_set=, schema_property_definitions, #term_code, #term_code=
schema_property_definitions
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
#about, #about=, #additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #in_defined_term_set, #in_defined_term_set=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #term_code, #term_code=, #url, #url=
Class Method Details
30
31
32
|
# File 'lib/schema_org/types/defined_term.rb', line 30
def new(**properties)
super
end
|
.schema_name ⇒ String
17
18
19
|
# File 'lib/schema_org/types/defined_term.rb', line 17
def schema_name
SCHEMA_NAME
end
|
.schema_type?(other_type) ⇒ Boolean
25
26
27
28
|
# File 'lib/schema_org/types/defined_term.rb', line 25
def schema_type?(other_type)
Base.schema_type_argument!(other_type)
SCHEMA_TYPES.include?(other_type)
end
|
.schema_types ⇒ ::Array[::Class]
21
22
23
|
# File 'lib/schema_org/types/defined_term.rb', line 21
def schema_types
SCHEMA_TYPES
end
|
Instance Method Details
#schema_type? ⇒ Boolean
35663
|
# File 'sig/schema_org.rbs', line 35663
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
35662
|
# File 'sig/schema_org.rbs', line 35662
def schema_types: () -> ::Array[::Class]
|