Class: SchemaOrg::DrugCost
Overview
https://schema.org/DrugCost
The cost per unit of a medical drug. Note that this type is not meant to represent the price in an offer of a drug for sale; see the Offer type for that. This type will typically be used to tag wholesale or average retail cost of a drug, or maximum reimbursable cost. Costs of medical drugs vary widely depending on how and where they are paid for, so while this type captures some of the variables, costs should be used with caution by consumers of this schema's markup.
Constant Summary
collapse
- SCHEMA_NAME =
"DrugCost"
- SCHEMA_TYPES =
[self, SchemaOrg::MedicalEntity, SchemaOrg::Thing].freeze
Class Method Summary
collapse
Instance Method Summary
collapse
#applicable_location, #applicable_location=, #cost_category, #cost_category=, #cost_currency, #cost_currency=, #cost_origin, #cost_origin=, #cost_per_unit, #cost_per_unit=, #drug_unit, #drug_unit=, schema_property_definitions
#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, schema_property_definitions, #study, #study=
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _DrugCost
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #applicable_location, #applicable_location=, #code, #code=, #cost_category, #cost_category=, #cost_currency, #cost_currency=, #cost_origin, #cost_origin=, #cost_per_unit, #cost_per_unit=, #description, #description=, #disambiguating_description, #disambiguating_description=, #drug_unit, #drug_unit=, #funding, #funding=, #guideline, #guideline=, #identifier, #identifier=, #image, #image=, #legal_status, #legal_status=, #main_entity_of_page, #main_entity_of_page=, #medicine_system, #medicine_system=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #same_as, #same_as=, #study, #study=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.new(**properties) ⇒ DrugCost
30
31
32
|
# File 'lib/schema_org/types/drug_cost.rb', line 30
def new(**properties)
super
end
|
.schema_name ⇒ String
17
18
19
|
# File 'lib/schema_org/types/drug_cost.rb', line 17
def schema_name
SCHEMA_NAME
end
|
.schema_type?(other_type) ⇒ Boolean
25
26
27
28
|
# File 'lib/schema_org/types/drug_cost.rb', line 25
def schema_type?(other_type)
Base.schema_type_argument!(other_type)
SCHEMA_TYPES.include?(other_type)
end
|
.schema_types ⇒ ::Array[::Class]
21
22
23
|
# File 'lib/schema_org/types/drug_cost.rb', line 21
def schema_types
SCHEMA_TYPES
end
|
Instance Method Details
#schema_type? ⇒ Boolean
40089
|
# File 'sig/schema_org.rbs', line 40089
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
40088
|
# File 'sig/schema_org.rbs', line 40088
def schema_types: () -> ::Array[::Class]
|