Class: SchemaOrg::EndorsementRating
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::EndorsementRating
- Includes:
- Mixins::EndorsementRating, _EndorsementRating
- Defined in:
- lib/schema_org/types/endorsement_rating.rb,
sig/schema_org.rbs
Overview
https://schema.org/EndorsementRating
An EndorsementRating is a rating that expresses some level of endorsement, for example inclusion in a "critic's pick" blog, a "Like" or "+1" on a social network. It can be considered the [[result]] of an [[EndorseAction]] in which the [[object]] of the action is rated positively by some [[agent]]. As is common elsewhere in schema.org, it is sometimes more useful to describe the results of such an action without explicitly describing the [[Action]].
An [[EndorsementRating]] may be part of a numeric scale or organized system, but this is not required: having an explicit type for indicating a positive, endorsement rating is particularly useful in the absence of numeric scales as it helps consumers understand that the rating is broadly positive.
Constant Summary collapse
- SCHEMA_NAME =
"EndorsementRating"- SCHEMA_TYPES =
[self, SchemaOrg::Rating, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ EndorsementRating
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::EndorsementRating
Methods included from Mixins::Rating
#author, #author=, #best_rating, #best_rating=, #rating_explanation, #rating_explanation=, #rating_value, #rating_value=, #review_aspect, #review_aspect=, schema_property_definitions, #worst_rating, #worst_rating=
Methods included from Mixins::Intangible
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _EndorsementRating
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #author, #author=, #best_rating, #best_rating=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #rating_explanation, #rating_explanation=, #rating_value, #rating_value=, #review_aspect, #review_aspect=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=, #worst_rating, #worst_rating=
Class Method Details
.new(**properties) ⇒ EndorsementRating
35 36 37 |
# File 'lib/schema_org/types/endorsement_rating.rb', line 35 def new(**properties) super end |
.schema_name ⇒ String
22 23 24 |
# File 'lib/schema_org/types/endorsement_rating.rb', line 22 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
30 31 32 33 |
# File 'lib/schema_org/types/endorsement_rating.rb', line 30 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
26 27 28 |
# File 'lib/schema_org/types/endorsement_rating.rb', line 26 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
43830 |
# File 'sig/schema_org.rbs', line 43830
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
43829 |
# File 'sig/schema_org.rbs', line 43829
def schema_types: () -> ::Array[::Class]
|