Class: SchemaOrg::FollowAction
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::FollowAction
- Includes:
- Mixins::FollowAction, _FollowAction
- Defined in:
- lib/schema_org/types/follow_action.rb,
sig/schema_org.rbs
Overview
https://schema.org/FollowAction
The act of forming a personal connection with someone/something (object) unidirectionally/asymmetrically to get updates polled from.\n\nRelated actions:\n\n* [[BefriendAction]]: Unlike BefriendAction, FollowAction implies that the connection is not necessarily reciprocal.\n* [[SubscribeAction]]: Unlike SubscribeAction, FollowAction implies that the follower acts as an active agent constantly/actively polling for updates.\n* [[RegisterAction]]: Unlike RegisterAction, FollowAction implies that the agent is interested in continuing receiving updates from the object.\n* [[JoinAction]]: Unlike JoinAction, FollowAction implies that the agent is interested in getting updates from the object.\n* [[TrackAction]]: Unlike TrackAction, FollowAction refers to the polling of updates of all aspects of animate objects rather than the location of inanimate objects (e.g. you track a package, but you don't follow it).
Constant Summary collapse
- SCHEMA_NAME =
"FollowAction"- SCHEMA_TYPES =
[self, SchemaOrg::InteractAction, SchemaOrg::Action, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ FollowAction
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::FollowAction
#followee, #followee=, schema_property_definitions
Methods included from Mixins::InteractAction
Methods included from Mixins::Action
#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, schema_property_definitions, #start_time, #start_time=, #target, #target=
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _FollowAction
#action_process, #action_process=, #action_status, #action_status=, #additional_type, #additional_type=, #agent, #agent=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #end_time, #end_time=, #error, #error=, #followee, #followee=, #identifier, #identifier=, #image, #image=, #instrument, #instrument=, #location, #location=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #object, #object=, #owner, #owner=, #participant, #participant=, #potential_action, #potential_action=, #provider, #provider=, #result, #result=, #same_as, #same_as=, #start_time, #start_time=, #subject_of, #subject_of=, #target, #target=, #url, #url=
Class Method Details
.new(**properties) ⇒ FollowAction
30 31 32 |
# File 'lib/schema_org/types/follow_action.rb', line 30 def new(**properties) super end |
.schema_name ⇒ String
17 18 19 |
# File 'lib/schema_org/types/follow_action.rb', line 17 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
25 26 27 28 |
# File 'lib/schema_org/types/follow_action.rb', line 25 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
21 22 23 |
# File 'lib/schema_org/types/follow_action.rb', line 21 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
48257 |
# File 'sig/schema_org.rbs', line 48257
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
48256 |
# File 'sig/schema_org.rbs', line 48256
def schema_types: () -> ::Array[::Class]
|