Class: SchemaOrg::GovernmentBenefitsType
Overview
https://schema.org/GovernmentBenefitsType
GovernmentBenefitsType enumerates several kinds of government benefits to support the COVID-19 situation. Note that this structure may not capture all benefits offered.
Constant Summary
collapse
- SCHEMA_NAME =
"GovernmentBenefitsType"
- SCHEMA_TYPES =
[self, SchemaOrg::Enumeration, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
- BASIC_INCOME =
EnumerationValue.new("BasicIncome", [SchemaOrg::GovernmentBenefitsType])
- BUSINESS_SUPPORT =
EnumerationValue.new("BusinessSupport", [SchemaOrg::GovernmentBenefitsType])
- DISABILITY_SUPPORT =
EnumerationValue.new("DisabilitySupport", [SchemaOrg::GovernmentBenefitsType])
- HEALTH_CARE =
EnumerationValue.new("HealthCare", [SchemaOrg::GovernmentBenefitsType])
- ONE_TIME_PAYMENTS =
EnumerationValue.new("OneTimePayments", [SchemaOrg::GovernmentBenefitsType])
- PAID_LEAVE =
EnumerationValue.new("PaidLeave", [SchemaOrg::GovernmentBenefitsType])
- PARENTAL_SUPPORT =
EnumerationValue.new("ParentalSupport", [SchemaOrg::GovernmentBenefitsType])
- UNEMPLOYMENT_SUPPORT =
EnumerationValue.new("UnemploymentSupport", [SchemaOrg::GovernmentBenefitsType])
- VALUES =
[BASIC_INCOME, BUSINESS_SUPPORT, DISABILITY_SUPPORT, HEALTH_CARE, ONE_TIME_PAYMENTS, PAID_LEAVE, PARENTAL_SUPPORT, UNEMPLOYMENT_SUPPORT].freeze
Class Method Summary
collapse
Instance Method Summary
collapse
schema_property_definitions
schema_property_definitions, #superseded_by, #superseded_by=
schema_property_definitions
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #superseded_by, #superseded_by=, #url, #url=
Class Method Details
30
31
32
|
# File 'lib/schema_org/types/government_benefits_type.rb', line 30
def new(**properties)
super
end
|
.schema_name ⇒ String
17
18
19
|
# File 'lib/schema_org/types/government_benefits_type.rb', line 17
def schema_name
SCHEMA_NAME
end
|
.schema_type?(other_type) ⇒ Boolean
25
26
27
28
|
# File 'lib/schema_org/types/government_benefits_type.rb', line 25
def schema_type?(other_type)
Base.schema_type_argument!(other_type)
SCHEMA_TYPES.include?(other_type)
end
|
.schema_types ⇒ ::Array[::Class]
21
22
23
|
# File 'lib/schema_org/types/government_benefits_type.rb', line 21
def schema_types
SCHEMA_TYPES
end
|
44
45
46
|
# File 'lib/schema_org/types/government_benefits_type.rb', line 44
def self.values
VALUES
end
|
Instance Method Details
#schema_type? ⇒ Boolean
51650
|
# File 'sig/schema_org.rbs', line 51650
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
51649
|
# File 'sig/schema_org.rbs', line 51649
def schema_types: () -> ::Array[::Class]
|