Class: SchemaOrg::Grant
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::Grant
- Includes:
- Mixins::Grant, _Grant
- Defined in:
- lib/schema_org/types/grant.rb,
sig/schema_org.rbs
Overview
A grant, typically financial or otherwise quantifiable, of resources. Typically a [[funder]] sponsors some [[MonetaryAmount]] to an [[Organization]] or [[Person]], sometimes not necessarily via a dedicated or long-lived [[Project]], resulting in one or more outputs, or [[fundedItem]]s. For financial sponsorship, indicate the [[funder]] of a [[MonetaryGrant]]. For non-financial support, indicate [[sponsor]] of [[Grant]]s of resources (e.g. office space).
Grants support activities directed towards some agreed collective goals, often but not always organized as [[Project]]s. Long-lived projects are sometimes sponsored by a variety of grants over time, but it is also common for a project to be associated with a single grant.
The amount of a [[Grant]] is represented using [[amount]] as a [[MonetaryAmount]].
Constant Summary collapse
- SCHEMA_NAME =
"Grant"- SCHEMA_TYPES =
[self, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ Grant
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::Grant
#funded_item, #funded_item=, #funder, #funder=, schema_property_definitions, #sponsor, #sponsor=
Methods included from Mixins::Intangible
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _Grant
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #funded_item, #funded_item=, #funder, #funder=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #sponsor, #sponsor=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.new(**properties) ⇒ Grant
35 36 37 |
# File 'lib/schema_org/types/grant.rb', line 35 def new(**properties) super end |
.schema_name ⇒ String
22 23 24 |
# File 'lib/schema_org/types/grant.rb', line 22 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
30 31 32 33 |
# File 'lib/schema_org/types/grant.rb', line 30 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
26 27 28 |
# File 'lib/schema_org/types/grant.rb', line 26 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
52447 |
# File 'sig/schema_org.rbs', line 52447
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
52446 |
# File 'sig/schema_org.rbs', line 52446
def schema_types: () -> ::Array[::Class]
|