Class: SchemaOrg::InteractionCounter
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::InteractionCounter
- Includes:
- Mixins::InteractionCounter, _InteractionCounter
- Defined in:
- lib/schema_org/types/interaction_counter.rb,
sig/schema_org.rbs
Overview
https://schema.org/InteractionCounter
NOTE: Supersedes UserBlocks.
NOTE: Supersedes UserCheckins.
NOTE: Supersedes UserComments.
NOTE: Supersedes UserDownloads.
NOTE: Supersedes UserInteraction.
NOTE: Supersedes UserLikes.
NOTE: Supersedes UserPageVisits.
NOTE: Supersedes UserPlays.
NOTE: Supersedes UserPlusOnes.
NOTE: Supersedes UserTweets.
A summary of how users have interacted with this CreativeWork. In most cases, authors will use a subtype to specify the specific type of interaction.
Constant Summary collapse
- SCHEMA_NAME =
"InteractionCounter"- SCHEMA_TYPES =
[self, SchemaOrg::StructuredValue, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ InteractionCounter
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::InteractionCounter
#end_time, #end_time=, #interaction_service, #interaction_service=, #interaction_type, #interaction_type=, #location, #location=, schema_property_definitions, #start_time, #start_time=, #user_interaction_count, #user_interaction_count=
Methods included from Mixins::StructuredValue
Methods included from Mixins::Intangible
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _InteractionCounter
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #end_time, #end_time=, #identifier, #identifier=, #image, #image=, #interaction_service, #interaction_service=, #interaction_type, #interaction_type=, #location, #location=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #start_time, #start_time=, #subject_of, #subject_of=, #url, #url=, #user_interaction_count, #user_interaction_count=
Class Method Details
.new(**properties) ⇒ InteractionCounter
41 42 43 |
# File 'lib/schema_org/types/interaction_counter.rb', line 41 def new(**properties) super end |
.schema_name ⇒ String
28 29 30 |
# File 'lib/schema_org/types/interaction_counter.rb', line 28 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
36 37 38 39 |
# File 'lib/schema_org/types/interaction_counter.rb', line 36 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
32 33 34 |
# File 'lib/schema_org/types/interaction_counter.rb', line 32 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
62636 |
# File 'sig/schema_org.rbs', line 62636
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
62635 |
# File 'sig/schema_org.rbs', line 62635
def schema_types: () -> ::Array[::Class]
|