Class: SchemaOrg::MedicalStudy
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::MedicalStudy
- Includes:
- SchemaOrg::Mixins::MedicalStudy, _MedicalStudy
- Defined in:
- lib/schema_org/types/medical_study.rb,
sig/schema_org.rbs
Overview
https://schema.org/MedicalStudy
A medical study is an umbrella type covering all kinds of research studies relating to human medicine or health, including observational studies and interventional trials and registries, randomized, controlled or not. When the specific type of study is known, use one of the extensions of this type, such as MedicalTrial or MedicalObservationalStudy. Also, note that this type should be used to mark up data that describes the study itself; to tag an article that publishes the results of a study, use MedicalScholarlyArticle. Note: use the code property of MedicalEntity to store study IDs, e.g. clinicaltrials.gov ID.
Constant Summary collapse
- SCHEMA_NAME =
"MedicalStudy"- SCHEMA_TYPES =
[self, SchemaOrg::MedicalEntity, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ MedicalStudy
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from SchemaOrg::Mixins::MedicalStudy
#health_condition, #health_condition=, schema_property_definitions, #sponsor, #sponsor=, #status, #status=, #study_location, #study_location=, #study_subject, #study_subject=
Methods included from SchemaOrg::Mixins::MedicalEntity
#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, schema_property_definitions, #study, #study=
Methods included from SchemaOrg::Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _MedicalStudy
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #code, #code=, #description, #description=, #disambiguating_description, #disambiguating_description=, #funding, #funding=, #guideline, #guideline=, #health_condition, #health_condition=, #identifier, #identifier=, #image, #image=, #legal_status, #legal_status=, #main_entity_of_page, #main_entity_of_page=, #medicine_system, #medicine_system=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #same_as, #same_as=, #sponsor, #sponsor=, #status, #status=, #study, #study=, #study_location, #study_location=, #study_subject, #study_subject=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.new(**properties) ⇒ MedicalStudy
30 31 32 |
# File 'lib/schema_org/types/medical_study.rb', line 30 def new(**properties) super end |
.schema_name ⇒ String
17 18 19 |
# File 'lib/schema_org/types/medical_study.rb', line 17 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
25 26 27 28 |
# File 'lib/schema_org/types/medical_study.rb', line 25 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
21 22 23 |
# File 'lib/schema_org/types/medical_study.rb', line 21 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
74248 |
# File 'sig/schema_org.rbs', line 74248
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
74247 |
# File 'sig/schema_org.rbs', line 74247
def schema_types: () -> ::Array[::Class]
|