Class: SchemaOrg::MedicalTherapy
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::MedicalTherapy
- Includes:
- SchemaOrg::Mixins::MedicalTherapy, _MedicalTherapy
- Defined in:
- lib/schema_org/types/medical_therapy.rb,
sig/schema_org.rbs
Overview
https://schema.org/MedicalTherapy
Any medical intervention designed to prevent, treat, and cure human diseases and medical conditions, including both curative and palliative therapies. Medical therapies are typically processes of care relying upon pharmacotherapy, behavioral therapy, supportive therapy (with fluid or nutrition for example), or detoxification (e.g. hemodialysis) aimed at improving or preventing a health condition.
Constant Summary collapse
- SCHEMA_NAME =
"MedicalTherapy"- SCHEMA_TYPES =
[self, SchemaOrg::TherapeuticProcedure, SchemaOrg::MedicalProcedure, SchemaOrg::MedicalEntity, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ MedicalTherapy
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from SchemaOrg::Mixins::MedicalTherapy
#contraindication, #contraindication=, #duplicate_therapy, #duplicate_therapy=, schema_property_definitions, #serious_adverse_outcome, #serious_adverse_outcome=
Methods included from SchemaOrg::Mixins::TherapeuticProcedure
#adverse_outcome, #adverse_outcome=, #dose_schedule, #dose_schedule=, #drug, #drug=, schema_property_definitions
Methods included from SchemaOrg::Mixins::MedicalProcedure
#body_location, #body_location=, #followup, #followup=, #how_performed, #how_performed=, #preparation, #preparation=, #procedure_type, #procedure_type=, schema_property_definitions, #status, #status=
Methods included from SchemaOrg::Mixins::MedicalEntity
#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, schema_property_definitions, #study, #study=
Methods included from SchemaOrg::Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _MedicalTherapy
#additional_type, #additional_type=, #adverse_outcome, #adverse_outcome=, #alternate_name, #alternate_name=, #body_location, #body_location=, #code, #code=, #contraindication, #contraindication=, #description, #description=, #disambiguating_description, #disambiguating_description=, #dose_schedule, #dose_schedule=, #drug, #drug=, #duplicate_therapy, #duplicate_therapy=, #followup, #followup=, #funding, #funding=, #guideline, #guideline=, #how_performed, #how_performed=, #identifier, #identifier=, #image, #image=, #legal_status, #legal_status=, #main_entity_of_page, #main_entity_of_page=, #medicine_system, #medicine_system=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #preparation, #preparation=, #procedure_type, #procedure_type=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #same_as, #same_as=, #serious_adverse_outcome, #serious_adverse_outcome=, #status, #status=, #study, #study=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.new(**properties) ⇒ MedicalTherapy
30 31 32 |
# File 'lib/schema_org/types/medical_therapy.rb', line 30 def new(**properties) super end |
.schema_name ⇒ String
17 18 19 |
# File 'lib/schema_org/types/medical_therapy.rb', line 17 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
25 26 27 28 |
# File 'lib/schema_org/types/medical_therapy.rb', line 25 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
21 22 23 |
# File 'lib/schema_org/types/medical_therapy.rb', line 21 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
74600 |
# File 'sig/schema_org.rbs', line 74600
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
74599 |
# File 'sig/schema_org.rbs', line 74599
def schema_types: () -> ::Array[::Class]
|