Class: SchemaOrg::MedicalTrial
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::MedicalTrial
- Includes:
- SchemaOrg::Mixins::MedicalTrial, _MedicalTrial
- Defined in:
- lib/schema_org/types/medical_trial.rb,
sig/schema_org.rbs
Overview
https://schema.org/MedicalTrial
A medical trial is a type of medical study that uses a scientific process to compare the safety and efficacy of medical therapies or medical procedures. In general, medical trials are controlled and subjects are allocated at random to the different treatment and/or control groups.
Constant Summary collapse
- SCHEMA_NAME =
"MedicalTrial"- SCHEMA_TYPES =
[self, SchemaOrg::MedicalStudy, SchemaOrg::MedicalEntity, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ MedicalTrial
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from SchemaOrg::Mixins::MedicalTrial
schema_property_definitions, #trial_design, #trial_design=
Methods included from SchemaOrg::Mixins::MedicalStudy
#health_condition, #health_condition=, schema_property_definitions, #sponsor, #sponsor=, #status, #status=, #study_location, #study_location=, #study_subject, #study_subject=
Methods included from SchemaOrg::Mixins::MedicalEntity
#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, schema_property_definitions, #study, #study=
Methods included from SchemaOrg::Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _MedicalTrial
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #code, #code=, #description, #description=, #disambiguating_description, #disambiguating_description=, #funding, #funding=, #guideline, #guideline=, #health_condition, #health_condition=, #identifier, #identifier=, #image, #image=, #legal_status, #legal_status=, #main_entity_of_page, #main_entity_of_page=, #medicine_system, #medicine_system=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #same_as, #same_as=, #sponsor, #sponsor=, #status, #status=, #study, #study=, #study_location, #study_location=, #study_subject, #study_subject=, #subject_of, #subject_of=, #trial_design, #trial_design=, #url, #url=
Class Method Details
.new(**properties) ⇒ MedicalTrial
30 31 32 |
# File 'lib/schema_org/types/medical_trial.rb', line 30 def new(**properties) super end |
.schema_name ⇒ String
17 18 19 |
# File 'lib/schema_org/types/medical_trial.rb', line 17 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
25 26 27 28 |
# File 'lib/schema_org/types/medical_trial.rb', line 25 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
21 22 23 |
# File 'lib/schema_org/types/medical_trial.rb', line 21 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
74667 |
# File 'sig/schema_org.rbs', line 74667
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
74666 |
# File 'sig/schema_org.rbs', line 74666
def schema_types: () -> ::Array[::Class]
|