Module: SchemaOrg::Mixins::Action
- Includes:
- Thing
- Included in:
- Action, AchieveAction, AssessAction, ConsumeAction, ControlAction, CreateAction, FindAction, InteractAction, MoveAction, OrganizeAction, PlayAction, SearchAction, SeekToAction, SolveMathAction, TradeAction, TransferAction, UpdateAction
- Defined in:
- lib/schema_org/mixins/action.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#action_process ⇒ Object
Description of the process by which the action was performed.
-
#action_process=(value) ⇒ Object
Description of the process by which the action was performed.
-
#action_status ⇒ Object
Indicates the current disposition of the Action.
-
#action_status=(value) ⇒ Object
Indicates the current disposition of the Action.
-
#agent ⇒ Object
The direct performer or driver of the action (animate or inanimate).
-
#agent=(value) ⇒ Object
The direct performer or driver of the action (animate or inanimate).
-
#end_time ⇒ Object
The endTime of something.
-
#end_time=(value) ⇒ Object
The endTime of something.
-
#error ⇒ Object
For failed actions, more information on the cause of the failure.
-
#error=(value) ⇒ Object
For failed actions, more information on the cause of the failure.
-
#instrument ⇒ Object
The object that helped the agent perform the action.
-
#instrument=(value) ⇒ Object
The object that helped the agent perform the action.
-
#location ⇒ Object
The location of, for example, where an event is happening, where an organization is located, or where an action takes place.
-
#location=(value) ⇒ Object
The location of, for example, where an event is happening, where an organization is located, or where an action takes place.
-
#object ⇒ Object
The object upon which the action is carried out, whose state is kept intact or changed.
-
#object=(value) ⇒ Object
The object upon which the action is carried out, whose state is kept intact or changed.
-
#participant ⇒ Object
Other co-agents that participated in the action indirectly.
-
#participant=(value) ⇒ Object
Other co-agents that participated in the action indirectly.
-
#provider ⇒ Object
The service provider, service operator, or service performer; the goods producer.
-
#provider=(value) ⇒ Object
The service provider, service operator, or service performer; the goods producer.
-
#result ⇒ Object
The result produced in the action.
-
#result=(value) ⇒ Object
The result produced in the action.
-
#start_time ⇒ Object
The startTime of something.
-
#start_time=(value) ⇒ Object
The startTime of something.
-
#target ⇒ Object
Indicates a target EntryPoint, or url, for an Action.
-
#target=(value) ⇒ Object
Indicates a target EntryPoint, or url, for an Action.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/schema_org/mixins/action.rb', line 11 def self.schema_property_definitions { action_process: { schema_name: "actionProcess", schema_url: "https://schema.org/actionProcess", comment_lines: ["Description of the process by which the action was performed."].freeze, ranges: ["HowTo"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, action_status: { schema_name: "actionStatus", schema_url: "https://schema.org/actionStatus", comment_lines: ["Indicates the current disposition of the Action."].freeze, ranges: ["ActionStatusType"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, agent: { schema_name: "agent", schema_url: "https://schema.org/agent", comment_lines: ["The direct performer or driver of the action (animate or inanimate). E.g. *John* wrote a book."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, end_time: { schema_name: "endTime", schema_url: "https://schema.org/endTime", comment_lines: ["The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to *December*. For media, including audio and video, it's the time offset of the end of a clip within a larger file.\\n\\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions."].freeze, ranges: ["DateTime", "Time"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, error: { schema_name: "error", schema_url: "https://schema.org/error", comment_lines: ["For failed actions, more information on the cause of the failure. Consider using the Error type."].freeze, ranges: ["Thing"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, instrument: { schema_name: "instrument", schema_url: "https://schema.org/instrument", comment_lines: ["The object that helped the agent perform the action. E.g. John wrote a book with *a pen*."].freeze, ranges: ["Thing"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, location: { schema_name: "location", schema_url: "https://schema.org/location", comment_lines: ["The location of, for example, where an event is happening, where an organization is located, or where an action takes place."].freeze, ranges: ["Place", "PostalAddress", "Text", "VirtualLocation"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, object: { schema_name: "object", schema_url: "https://schema.org/object", comment_lines: ["The object upon which the action is carried out, whose state is kept intact or changed. Also known as the semantic roles patient, affected or undergoer (which change their state) or theme (which doesn't). E.g. John read *a book*."].freeze, ranges: ["Thing"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, participant: { schema_name: "participant", schema_url: "https://schema.org/participant", comment_lines: ["Other co-agents that participated in the action indirectly. E.g. John wrote a book with *Steve*."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, provider: { schema_name: "provider", schema_url: "https://schema.org/provider", comment_lines: ["The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["carrier"].freeze }.freeze, result: { schema_name: "result", schema_url: "https://schema.org/result", comment_lines: ["The result produced in the action. E.g. John wrote *a book*."].freeze, ranges: ["Thing"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, start_time: { schema_name: "startTime", schema_url: "https://schema.org/startTime", comment_lines: ["The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from *January* to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file.\\n\\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions."].freeze, ranges: ["DateTime", "Time"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, target: { schema_name: "target", schema_url: "https://schema.org/target", comment_lines: ["Indicates a target EntryPoint, or url, for an Action."].freeze, ranges: ["EntryPoint", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#action_process ⇒ Object
Description of the process by which the action was performed.
147 148 149 |
# File 'lib/schema_org/mixins/action.rb', line 147 def action_process read_property(:action_process) end |
#action_process=(value) ⇒ Object
Description of the process by which the action was performed.
152 153 154 |
# File 'lib/schema_org/mixins/action.rb', line 152 def action_process=(value) write_property(:action_process, value) end |
#action_status ⇒ Object
Indicates the current disposition of the Action.
157 158 159 |
# File 'lib/schema_org/mixins/action.rb', line 157 def action_status read_property(:action_status) end |
#action_status=(value) ⇒ Object
Indicates the current disposition of the Action.
162 163 164 |
# File 'lib/schema_org/mixins/action.rb', line 162 def action_status=(value) write_property(:action_status, value) end |
#agent ⇒ Object
The direct performer or driver of the action (animate or inanimate). E.g. John wrote a book.
167 168 169 |
# File 'lib/schema_org/mixins/action.rb', line 167 def agent read_property(:agent) end |
#agent=(value) ⇒ Object
The direct performer or driver of the action (animate or inanimate). E.g. John wrote a book.
172 173 174 |
# File 'lib/schema_org/mixins/action.rb', line 172 def agent=(value) write_property(:agent, value) end |
#end_time ⇒ Object
The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the end of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.
177 178 179 |
# File 'lib/schema_org/mixins/action.rb', line 177 def end_time read_property(:end_time) end |
#end_time=(value) ⇒ Object
The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the end of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.
182 183 184 |
# File 'lib/schema_org/mixins/action.rb', line 182 def end_time=(value) write_property(:end_time, value) end |
#error ⇒ Object
For failed actions, more information on the cause of the failure. Consider using the Error type.
187 188 189 |
# File 'lib/schema_org/mixins/action.rb', line 187 def error read_property(:error) end |
#error=(value) ⇒ Object
For failed actions, more information on the cause of the failure. Consider using the Error type.
192 193 194 |
# File 'lib/schema_org/mixins/action.rb', line 192 def error=(value) write_property(:error, value) end |
#instrument ⇒ Object
The object that helped the agent perform the action. E.g. John wrote a book with a pen.
197 198 199 |
# File 'lib/schema_org/mixins/action.rb', line 197 def instrument read_property(:instrument) end |
#instrument=(value) ⇒ Object
The object that helped the agent perform the action. E.g. John wrote a book with a pen.
202 203 204 |
# File 'lib/schema_org/mixins/action.rb', line 202 def instrument=(value) write_property(:instrument, value) end |
#location ⇒ Object
The location of, for example, where an event is happening, where an organization is located, or where an action takes place.
207 208 209 |
# File 'lib/schema_org/mixins/action.rb', line 207 def location read_property(:location) end |
#location=(value) ⇒ Object
The location of, for example, where an event is happening, where an organization is located, or where an action takes place.
212 213 214 |
# File 'lib/schema_org/mixins/action.rb', line 212 def location=(value) write_property(:location, value) end |
#object ⇒ Object
The object upon which the action is carried out, whose state is kept intact or changed. Also known as the semantic roles patient, affected or undergoer (which change their state) or theme (which doesn't). E.g. John read a book.
217 218 219 |
# File 'lib/schema_org/mixins/action.rb', line 217 def object read_property(:object) end |
#object=(value) ⇒ Object
The object upon which the action is carried out, whose state is kept intact or changed. Also known as the semantic roles patient, affected or undergoer (which change their state) or theme (which doesn't). E.g. John read a book.
222 223 224 |
# File 'lib/schema_org/mixins/action.rb', line 222 def object=(value) write_property(:object, value) end |
#participant ⇒ Object
Other co-agents that participated in the action indirectly. E.g. John wrote a book with Steve.
227 228 229 |
# File 'lib/schema_org/mixins/action.rb', line 227 def participant read_property(:participant) end |
#participant=(value) ⇒ Object
Other co-agents that participated in the action indirectly. E.g. John wrote a book with Steve.
232 233 234 |
# File 'lib/schema_org/mixins/action.rb', line 232 def participant=(value) write_property(:participant, value) end |
#provider ⇒ Object
The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.
Supersedes carrier.
238 239 240 |
# File 'lib/schema_org/mixins/action.rb', line 238 def provider read_property(:provider) end |
#provider=(value) ⇒ Object
The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.
Supersedes carrier.
244 245 246 |
# File 'lib/schema_org/mixins/action.rb', line 244 def provider=(value) write_property(:provider, value) end |
#result ⇒ Object
The result produced in the action. E.g. John wrote a book.
249 250 251 |
# File 'lib/schema_org/mixins/action.rb', line 249 def result read_property(:result) end |
#result=(value) ⇒ Object
The result produced in the action. E.g. John wrote a book.
254 255 256 |
# File 'lib/schema_org/mixins/action.rb', line 254 def result=(value) write_property(:result, value) end |
#start_time ⇒ Object
The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.
259 260 261 |
# File 'lib/schema_org/mixins/action.rb', line 259 def start_time read_property(:start_time) end |
#start_time=(value) ⇒ Object
The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.
264 265 266 |
# File 'lib/schema_org/mixins/action.rb', line 264 def start_time=(value) write_property(:start_time, value) end |
#target ⇒ Object
Indicates a target EntryPoint, or url, for an Action.
269 270 271 |
# File 'lib/schema_org/mixins/action.rb', line 269 def target read_property(:target) end |
#target=(value) ⇒ Object
Indicates a target EntryPoint, or url, for an Action.
274 275 276 |
# File 'lib/schema_org/mixins/action.rb', line 274 def target=(value) write_property(:target, value) end |