Module: SchemaOrg::Mixins::ActionAccessSpecification
- Includes:
- Intangible
- Included in:
- ActionAccessSpecification
- Defined in:
- lib/schema_org/mixins/action_access_specification.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#availability_ends ⇒ Object
The end of the availability of the product or service included in the offer.
-
#availability_ends=(value) ⇒ Object
The end of the availability of the product or service included in the offer.
-
#availability_starts ⇒ Object
The beginning of the availability of the product or service included in the offer.
-
#availability_starts=(value) ⇒ Object
The beginning of the availability of the product or service included in the offer.
-
#category ⇒ Object
A category for the item.
-
#category=(value) ⇒ Object
A category for the item.
-
#eligible_region ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.\n\nSee also [[ineligibleRegion]].
-
#eligible_region=(value) ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.\n\nSee also [[ineligibleRegion]].
-
#expects_acceptance_of ⇒ Object
An Offer which must be accepted before the user can perform the Action.
-
#expects_acceptance_of=(value) ⇒ Object
An Offer which must be accepted before the user can perform the Action.
-
#ineligible_region ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g.
-
#ineligible_region=(value) ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g.
-
#requires_subscription ⇒ Object
Indicates if use of the media require a subscription (either paid or free).
-
#requires_subscription=(value) ⇒ Object
Indicates if use of the media require a subscription (either paid or free).
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/schema_org/mixins/action_access_specification.rb', line 11 def self.schema_property_definitions { availability_ends: { schema_name: "availabilityEnds", schema_url: "https://schema.org/availabilityEnds", comment_lines: ["The end of the availability of the product or service included in the offer."].freeze, ranges: ["Date", "DateTime", "Time"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, availability_starts: { schema_name: "availabilityStarts", schema_url: "https://schema.org/availabilityStarts", comment_lines: ["The beginning of the availability of the product or service included in the offer."].freeze, ranges: ["Date", "DateTime", "Time"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, category: { schema_name: "category", schema_url: "https://schema.org/category", comment_lines: ["A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy."].freeze, ranges: ["CategoryCode", "PhysicalActivityCategory", "Text", "Thing", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, eligible_region: { schema_name: "eligibleRegion", schema_url: "https://schema.org/eligibleRegion", comment_lines: ["The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.\\n\\nSee also [[ineligibleRegion]]."].freeze, ranges: ["GeoShape", "Place", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, expects_acceptance_of: { schema_name: "expectsAcceptanceOf", schema_url: "https://schema.org/expectsAcceptanceOf", comment_lines: ["An Offer which must be accepted before the user can perform the Action. For example, the user may need to buy a movie before being able to watch it."].freeze, ranges: ["Offer"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, ineligible_region: { schema_name: "ineligibleRegion", schema_url: "https://schema.org/ineligibleRegion", comment_lines: ["The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed.\\n\\nSee also [[eligibleRegion]]."].freeze, ranges: ["GeoShape", "Place", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, requires_subscription: { schema_name: "requiresSubscription", schema_url: "https://schema.org/requiresSubscription", comment_lines: ["Indicates if use of the media require a subscription (either paid or free). Allowed values are ```true``` or ```false``` (note that an earlier version had 'yes', 'no')."].freeze, ranges: ["Boolean", "MediaSubscription"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#availability_ends ⇒ Object
The end of the availability of the product or service included in the offer.
87 88 89 |
# File 'lib/schema_org/mixins/action_access_specification.rb', line 87 def availability_ends read_property(:availability_ends) end |
#availability_ends=(value) ⇒ Object
The end of the availability of the product or service included in the offer.
92 93 94 |
# File 'lib/schema_org/mixins/action_access_specification.rb', line 92 def availability_ends=(value) write_property(:availability_ends, value) end |
#availability_starts ⇒ Object
The beginning of the availability of the product or service included in the offer.
97 98 99 |
# File 'lib/schema_org/mixins/action_access_specification.rb', line 97 def availability_starts read_property(:availability_starts) end |
#availability_starts=(value) ⇒ Object
The beginning of the availability of the product or service included in the offer.
102 103 104 |
# File 'lib/schema_org/mixins/action_access_specification.rb', line 102 def availability_starts=(value) write_property(:availability_starts, value) end |
#category ⇒ Object
A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.
107 108 109 |
# File 'lib/schema_org/mixins/action_access_specification.rb', line 107 def category read_property(:category) end |
#category=(value) ⇒ Object
A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.
112 113 114 |
# File 'lib/schema_org/mixins/action_access_specification.rb', line 112 def category=(value) write_property(:category, value) end |
#eligible_region ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.\n\nSee also [[ineligibleRegion]].
117 118 119 |
# File 'lib/schema_org/mixins/action_access_specification.rb', line 117 def eligible_region read_property(:eligible_region) end |
#eligible_region=(value) ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.\n\nSee also [[ineligibleRegion]].
122 123 124 |
# File 'lib/schema_org/mixins/action_access_specification.rb', line 122 def eligible_region=(value) write_property(:eligible_region, value) end |
#expects_acceptance_of ⇒ Object
An Offer which must be accepted before the user can perform the Action. For example, the user may need to buy a movie before being able to watch it.
127 128 129 |
# File 'lib/schema_org/mixins/action_access_specification.rb', line 127 def expects_acceptance_of read_property(:expects_acceptance_of) end |
#expects_acceptance_of=(value) ⇒ Object
An Offer which must be accepted before the user can perform the Action. For example, the user may need to buy a movie before being able to watch it.
132 133 134 |
# File 'lib/schema_org/mixins/action_access_specification.rb', line 132 def expects_acceptance_of=(value) write_property(:expects_acceptance_of, value) end |
#ineligible_region ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed.\n\nSee also [[eligibleRegion]].
137 138 139 |
# File 'lib/schema_org/mixins/action_access_specification.rb', line 137 def ineligible_region read_property(:ineligible_region) end |
#ineligible_region=(value) ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed.\n\nSee also [[eligibleRegion]].
142 143 144 |
# File 'lib/schema_org/mixins/action_access_specification.rb', line 142 def ineligible_region=(value) write_property(:ineligible_region, value) end |
#requires_subscription ⇒ Object
Indicates if use of the media require a subscription (either paid or free). Allowed values are true or false (note that an earlier version had 'yes', 'no').
147 148 149 |
# File 'lib/schema_org/mixins/action_access_specification.rb', line 147 def requires_subscription read_property(:requires_subscription) end |
#requires_subscription=(value) ⇒ Object
Indicates if use of the media require a subscription (either paid or free). Allowed values are true or false (note that an earlier version had 'yes', 'no').
152 153 154 |
# File 'lib/schema_org/mixins/action_access_specification.rb', line 152 def requires_subscription=(value) write_property(:requires_subscription, value) end |