Module: SchemaOrg::Mixins::AggregateOffer
Class Method Summary collapse
Instance Method Summary collapse
-
#high_price ⇒ Object
The highest price of all offers available.\n\nUsage guidelines:\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point.
-
#high_price=(value) ⇒ Object
The highest price of all offers available.\n\nUsage guidelines:\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point.
-
#low_price ⇒ Object
The lowest price of all offers available.\n\nUsage guidelines:\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point.
-
#low_price=(value) ⇒ Object
The lowest price of all offers available.\n\nUsage guidelines:\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point.
-
#offer_count ⇒ Object
The number of offers for the product.
-
#offer_count=(value) ⇒ Object
The number of offers for the product.
-
#offers ⇒ Object
An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event.
-
#offers=(value) ⇒ Object
An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event.
Methods included from Offer
#accepted_payment_method, #accepted_payment_method=, #add_on, #add_on=, #additional_property, #additional_property=, #advance_booking_requirement, #advance_booking_requirement=, #aggregate_rating, #aggregate_rating=, #area_served, #area_served=, #asin, #asin=, #availability, #availability=, #availability_ends, #availability_ends=, #availability_starts, #availability_starts=, #available_at_or_from, #available_at_or_from=, #available_delivery_method, #available_delivery_method=, #business_function, #business_function=, #category, #category=, #checkout_page_url_template, #checkout_page_url_template=, #delivery_lead_time, #delivery_lead_time=, #eligible_customer_type, #eligible_customer_type=, #eligible_duration, #eligible_duration=, #eligible_quantity, #eligible_quantity=, #eligible_region, #eligible_region=, #eligible_transaction_volume, #eligible_transaction_volume=, #gtin, #gtin12, #gtin12=, #gtin13, #gtin13=, #gtin14, #gtin14=, #gtin8, #gtin8=, #gtin=, #has_adult_consideration, #has_adult_consideration=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_measurement, #has_measurement=, #has_merchant_return_policy, #has_merchant_return_policy=, #includes_object, #includes_object=, #ineligible_region, #ineligible_region=, #inventory_level, #inventory_level=, #is_family_friendly, #is_family_friendly=, #item_condition, #item_condition=, #item_offered, #item_offered=, #lease_length, #lease_length=, #mobile_url, #mobile_url=, #mpn, #mpn=, #offered_by, #offered_by=, #price, #price=, #price_currency, #price_currency=, #price_specification, #price_specification=, #price_valid_until, #price_valid_until=, #review, #review=, #reviews, #reviews=, #seller, #seller=, #serial_number, #serial_number=, #shipping_details, #shipping_details=, #sku, #sku=, #valid_for_member_tier, #valid_for_member_tier=, #valid_from, #valid_from=, #valid_through, #valid_through=, #warranty, #warranty=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/schema_org/mixins/aggregate_offer.rb', line 11 def self.schema_property_definitions { high_price: { schema_name: "highPrice", schema_url: "https://schema.org/highPrice", comment_lines: ["The highest price of all offers available.\\n\\nUsage guidelines:\\n\\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator."].freeze, ranges: ["Number", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, low_price: { schema_name: "lowPrice", schema_url: "https://schema.org/lowPrice", comment_lines: ["The lowest price of all offers available.\\n\\nUsage guidelines:\\n\\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator."].freeze, ranges: ["Number", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, offer_count: { schema_name: "offerCount", schema_url: "https://schema.org/offerCount", comment_lines: ["The number of offers for the product."].freeze, ranges: ["Integer"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, offers: { schema_name: "offers", schema_url: "https://schema.org/offers", comment_lines: ["An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer."].freeze, ranges: ["Demand", "Offer"].freeze, external_ranges: [].freeze, inverse_of: "itemOffered", superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#high_price ⇒ Object
The highest price of all offers available.\n\nUsage guidelines:\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.
57 58 59 |
# File 'lib/schema_org/mixins/aggregate_offer.rb', line 57 def high_price read_property(:high_price) end |
#high_price=(value) ⇒ Object
The highest price of all offers available.\n\nUsage guidelines:\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.
62 63 64 |
# File 'lib/schema_org/mixins/aggregate_offer.rb', line 62 def high_price=(value) write_property(:high_price, value) end |
#low_price ⇒ Object
The lowest price of all offers available.\n\nUsage guidelines:\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.
67 68 69 |
# File 'lib/schema_org/mixins/aggregate_offer.rb', line 67 def low_price read_property(:low_price) end |
#low_price=(value) ⇒ Object
The lowest price of all offers available.\n\nUsage guidelines:\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.
72 73 74 |
# File 'lib/schema_org/mixins/aggregate_offer.rb', line 72 def low_price=(value) write_property(:low_price, value) end |
#offer_count ⇒ Object
The number of offers for the product.
77 78 79 |
# File 'lib/schema_org/mixins/aggregate_offer.rb', line 77 def offer_count read_property(:offer_count) end |
#offer_count=(value) ⇒ Object
The number of offers for the product.
82 83 84 |
# File 'lib/schema_org/mixins/aggregate_offer.rb', line 82 def offer_count=(value) write_property(:offer_count, value) end |
#offers ⇒ Object
An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.
Inverse-property: itemOffered.
88 89 90 |
# File 'lib/schema_org/mixins/aggregate_offer.rb', line 88 def offers read_property(:offers) end |
#offers=(value) ⇒ Object
An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.
Inverse-property: itemOffered.
94 95 96 |
# File 'lib/schema_org/mixins/aggregate_offer.rb', line 94 def offers=(value) write_property(:offers, value) end |