Module: SchemaOrg::Mixins::AlignmentObject
- Includes:
- Intangible
- Included in:
- AlignmentObject
- Defined in:
- lib/schema_org/mixins/alignment_object.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#alignment_type ⇒ Object
A category of alignment between the learning resource and the framework node.
-
#alignment_type=(value) ⇒ Object
A category of alignment between the learning resource and the framework node.
-
#educational_framework ⇒ Object
The framework to which the resource being described is aligned.
-
#educational_framework=(value) ⇒ Object
The framework to which the resource being described is aligned.
-
#target_description ⇒ Object
The description of a node in an established educational framework.
-
#target_description=(value) ⇒ Object
The description of a node in an established educational framework.
-
#target_name ⇒ Object
The name of a node in an established educational framework.
-
#target_name=(value) ⇒ Object
The name of a node in an established educational framework.
-
#target_url ⇒ Object
The URL of a node in an established educational framework.
-
#target_url=(value) ⇒ Object
The URL of a node in an established educational framework.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/schema_org/mixins/alignment_object.rb', line 11 def self.schema_property_definitions { alignment_type: { schema_name: "alignmentType", schema_url: "https://schema.org/alignmentType", comment_lines: ["A category of alignment between the learning resource and the framework node. Recommended values include: 'requires', 'textComplexity', 'readingLevel', and 'educationalSubject'."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, educational_framework: { schema_name: "educationalFramework", schema_url: "https://schema.org/educationalFramework", comment_lines: ["The framework to which the resource being described is aligned."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, target_description: { schema_name: "targetDescription", schema_url: "https://schema.org/targetDescription", comment_lines: ["The description of a node in an established educational framework."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, target_name: { schema_name: "targetName", schema_url: "https://schema.org/targetName", comment_lines: ["The name of a node in an established educational framework."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, target_url: { schema_name: "targetUrl", schema_url: "https://schema.org/targetUrl", comment_lines: ["The URL of a node in an established educational framework."].freeze, ranges: ["URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#alignment_type ⇒ Object
A category of alignment between the learning resource and the framework node. Recommended values include: 'requires', 'textComplexity', 'readingLevel', and 'educationalSubject'.
67 68 69 |
# File 'lib/schema_org/mixins/alignment_object.rb', line 67 def alignment_type read_property(:alignment_type) end |
#alignment_type=(value) ⇒ Object
A category of alignment between the learning resource and the framework node. Recommended values include: 'requires', 'textComplexity', 'readingLevel', and 'educationalSubject'.
72 73 74 |
# File 'lib/schema_org/mixins/alignment_object.rb', line 72 def alignment_type=(value) write_property(:alignment_type, value) end |
#educational_framework ⇒ Object
The framework to which the resource being described is aligned.
77 78 79 |
# File 'lib/schema_org/mixins/alignment_object.rb', line 77 def educational_framework read_property(:educational_framework) end |
#educational_framework=(value) ⇒ Object
The framework to which the resource being described is aligned.
82 83 84 |
# File 'lib/schema_org/mixins/alignment_object.rb', line 82 def educational_framework=(value) write_property(:educational_framework, value) end |
#target_description ⇒ Object
The description of a node in an established educational framework.
87 88 89 |
# File 'lib/schema_org/mixins/alignment_object.rb', line 87 def target_description read_property(:target_description) end |
#target_description=(value) ⇒ Object
The description of a node in an established educational framework.
92 93 94 |
# File 'lib/schema_org/mixins/alignment_object.rb', line 92 def target_description=(value) write_property(:target_description, value) end |
#target_name ⇒ Object
The name of a node in an established educational framework.
97 98 99 |
# File 'lib/schema_org/mixins/alignment_object.rb', line 97 def target_name read_property(:target_name) end |
#target_name=(value) ⇒ Object
The name of a node in an established educational framework.
102 103 104 |
# File 'lib/schema_org/mixins/alignment_object.rb', line 102 def target_name=(value) write_property(:target_name, value) end |
#target_url ⇒ Object
The URL of a node in an established educational framework.
107 108 109 |
# File 'lib/schema_org/mixins/alignment_object.rb', line 107 def target_url read_property(:target_url) end |
#target_url=(value) ⇒ Object
The URL of a node in an established educational framework.
112 113 114 |
# File 'lib/schema_org/mixins/alignment_object.rb', line 112 def target_url=(value) write_property(:target_url, value) end |