Module: SchemaOrg::Mixins::AnatomicalStructure
- Includes:
- MedicalEntity
- Included in:
- AnatomicalStructure, Bone, BrainStructure, Joint, Ligament, Muscle, Nerve, Vessel
- Defined in:
- lib/schema_org/mixins/anatomical_structure.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#associated_pathophysiology ⇒ Object
If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system.
-
#associated_pathophysiology=(value) ⇒ Object
If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system.
-
#body_location ⇒ Object
Location in the body of the anatomical structure.
-
#body_location=(value) ⇒ Object
Location in the body of the anatomical structure.
-
#connected_to ⇒ Object
Other anatomical structures to which this structure is connected.
-
#connected_to=(value) ⇒ Object
Other anatomical structures to which this structure is connected.
-
#diagram ⇒ Object
An image containing a diagram that illustrates the structure and/or its component substructures and/or connections with other structures.
-
#diagram=(value) ⇒ Object
An image containing a diagram that illustrates the structure and/or its component substructures and/or connections with other structures.
-
#part_of_system ⇒ Object
The anatomical or organ system that this structure is part of.
-
#part_of_system=(value) ⇒ Object
The anatomical or organ system that this structure is part of.
-
#related_condition ⇒ Object
A medical condition associated with this anatomy.
-
#related_condition=(value) ⇒ Object
A medical condition associated with this anatomy.
-
#related_therapy ⇒ Object
A medical therapy related to this anatomy.
-
#related_therapy=(value) ⇒ Object
A medical therapy related to this anatomy.
-
#sub_structure ⇒ Object
Component (sub-)structure(s) that comprise this anatomical structure.
-
#sub_structure=(value) ⇒ Object
Component (sub-)structure(s) that comprise this anatomical structure.
Methods included from MedicalEntity
#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/schema_org/mixins/anatomical_structure.rb', line 11 def self.schema_property_definitions { associated_pathophysiology: { schema_name: "associatedPathophysiology", schema_url: "https://schema.org/associatedPathophysiology", comment_lines: ["If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, body_location: { schema_name: "bodyLocation", schema_url: "https://schema.org/bodyLocation", comment_lines: ["Location in the body of the anatomical structure."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, connected_to: { schema_name: "connectedTo", schema_url: "https://schema.org/connectedTo", comment_lines: ["Other anatomical structures to which this structure is connected."].freeze, ranges: ["AnatomicalStructure"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, diagram: { schema_name: "diagram", schema_url: "https://schema.org/diagram", comment_lines: ["An image containing a diagram that illustrates the structure and/or its component substructures and/or connections with other structures."].freeze, ranges: ["ImageObject"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, part_of_system: { schema_name: "partOfSystem", schema_url: "https://schema.org/partOfSystem", comment_lines: ["The anatomical or organ system that this structure is part of."].freeze, ranges: ["AnatomicalSystem"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, related_condition: { schema_name: "relatedCondition", schema_url: "https://schema.org/relatedCondition", comment_lines: ["A medical condition associated with this anatomy."].freeze, ranges: ["MedicalCondition"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, related_therapy: { schema_name: "relatedTherapy", schema_url: "https://schema.org/relatedTherapy", comment_lines: ["A medical therapy related to this anatomy."].freeze, ranges: ["MedicalTherapy"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, sub_structure: { schema_name: "subStructure", schema_url: "https://schema.org/subStructure", comment_lines: ["Component (sub-)structure(s) that comprise this anatomical structure."].freeze, ranges: ["AnatomicalStructure"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#associated_pathophysiology ⇒ Object
If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system.
97 98 99 |
# File 'lib/schema_org/mixins/anatomical_structure.rb', line 97 def associated_pathophysiology read_property(:associated_pathophysiology) end |
#associated_pathophysiology=(value) ⇒ Object
If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system.
102 103 104 |
# File 'lib/schema_org/mixins/anatomical_structure.rb', line 102 def associated_pathophysiology=(value) write_property(:associated_pathophysiology, value) end |
#body_location ⇒ Object
Location in the body of the anatomical structure.
107 108 109 |
# File 'lib/schema_org/mixins/anatomical_structure.rb', line 107 def body_location read_property(:body_location) end |
#body_location=(value) ⇒ Object
Location in the body of the anatomical structure.
112 113 114 |
# File 'lib/schema_org/mixins/anatomical_structure.rb', line 112 def body_location=(value) write_property(:body_location, value) end |
#connected_to ⇒ Object
Other anatomical structures to which this structure is connected.
117 118 119 |
# File 'lib/schema_org/mixins/anatomical_structure.rb', line 117 def connected_to read_property(:connected_to) end |
#connected_to=(value) ⇒ Object
Other anatomical structures to which this structure is connected.
122 123 124 |
# File 'lib/schema_org/mixins/anatomical_structure.rb', line 122 def connected_to=(value) write_property(:connected_to, value) end |
#diagram ⇒ Object
An image containing a diagram that illustrates the structure and/or its component substructures and/or connections with other structures.
127 128 129 |
# File 'lib/schema_org/mixins/anatomical_structure.rb', line 127 def diagram read_property(:diagram) end |
#diagram=(value) ⇒ Object
An image containing a diagram that illustrates the structure and/or its component substructures and/or connections with other structures.
132 133 134 |
# File 'lib/schema_org/mixins/anatomical_structure.rb', line 132 def diagram=(value) write_property(:diagram, value) end |
#part_of_system ⇒ Object
The anatomical or organ system that this structure is part of.
137 138 139 |
# File 'lib/schema_org/mixins/anatomical_structure.rb', line 137 def part_of_system read_property(:part_of_system) end |
#part_of_system=(value) ⇒ Object
The anatomical or organ system that this structure is part of.
142 143 144 |
# File 'lib/schema_org/mixins/anatomical_structure.rb', line 142 def part_of_system=(value) write_property(:part_of_system, value) end |
#related_condition ⇒ Object
A medical condition associated with this anatomy.
147 148 149 |
# File 'lib/schema_org/mixins/anatomical_structure.rb', line 147 def read_property(:related_condition) end |
#related_condition=(value) ⇒ Object
A medical condition associated with this anatomy.
152 153 154 |
# File 'lib/schema_org/mixins/anatomical_structure.rb', line 152 def (value) write_property(:related_condition, value) end |
#related_therapy ⇒ Object
A medical therapy related to this anatomy.
157 158 159 |
# File 'lib/schema_org/mixins/anatomical_structure.rb', line 157 def read_property(:related_therapy) end |
#related_therapy=(value) ⇒ Object
A medical therapy related to this anatomy.
162 163 164 |
# File 'lib/schema_org/mixins/anatomical_structure.rb', line 162 def (value) write_property(:related_therapy, value) end |
#sub_structure ⇒ Object
Component (sub-)structure(s) that comprise this anatomical structure.
167 168 169 |
# File 'lib/schema_org/mixins/anatomical_structure.rb', line 167 def sub_structure read_property(:sub_structure) end |
#sub_structure=(value) ⇒ Object
Component (sub-)structure(s) that comprise this anatomical structure.
172 173 174 |
# File 'lib/schema_org/mixins/anatomical_structure.rb', line 172 def sub_structure=(value) write_property(:sub_structure, value) end |