Module: SchemaOrg::Mixins::BankAccount
- Includes:
- FinancialProduct
- Included in:
- BankAccount, DepositAccount
- Defined in:
- lib/schema_org/mixins/bank_account.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#account_minimum_inflow ⇒ Object
A minimum amount that has to be paid in every month.
-
#account_minimum_inflow=(value) ⇒ Object
A minimum amount that has to be paid in every month.
-
#account_overdraft_limit ⇒ Object
An overdraft is an extension of credit from a lending institution when an account reaches zero.
-
#account_overdraft_limit=(value) ⇒ Object
An overdraft is an extension of credit from a lending institution when an account reaches zero.
-
#bank_account_type ⇒ Object
The type of a bank account.
-
#bank_account_type=(value) ⇒ Object
The type of a bank account.
Methods included from FinancialProduct
#annual_percentage_rate, #annual_percentage_rate=, #fees_and_commissions_specification, #fees_and_commissions_specification=, #interest_rate, #interest_rate=
Methods included from Service
#aggregate_rating, #aggregate_rating=, #area_served, #area_served=, #audience, #audience=, #available_channel, #available_channel=, #award, #award=, #brand, #brand=, #broker, #broker=, #category, #category=, #has_certification, #has_certification=, #has_offer_catalog, #has_offer_catalog=, #hours_available, #hours_available=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #logo, #logo=, #offers, #offers=, #produces, #produces=, #provider, #provider=, #provider_mobility, #provider_mobility=, #review, #review=, #service_area, #service_area=, #service_audience, #service_audience=, #service_output, #service_output=, #service_type, #service_type=, #slogan, #slogan=, #terms_of_service, #terms_of_service=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/schema_org/mixins/bank_account.rb', line 11 def self.schema_property_definitions { account_minimum_inflow: { schema_name: "accountMinimumInflow", schema_url: "https://schema.org/accountMinimumInflow", comment_lines: ["A minimum amount that has to be paid in every month."].freeze, ranges: ["MonetaryAmount"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, account_overdraft_limit: { schema_name: "accountOverdraftLimit", schema_url: "https://schema.org/accountOverdraftLimit", comment_lines: ["An overdraft is an extension of credit from a lending institution when an account reaches zero. An overdraft allows the individual to continue withdrawing money even if the account has no funds in it. Basically the bank allows people to borrow a set amount of money."].freeze, ranges: ["MonetaryAmount"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, bank_account_type: { schema_name: "bankAccountType", schema_url: "https://schema.org/bankAccountType", comment_lines: ["The type of a bank account."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#account_minimum_inflow ⇒ Object
A minimum amount that has to be paid in every month.
47 48 49 |
# File 'lib/schema_org/mixins/bank_account.rb', line 47 def account_minimum_inflow read_property(:account_minimum_inflow) end |
#account_minimum_inflow=(value) ⇒ Object
A minimum amount that has to be paid in every month.
52 53 54 |
# File 'lib/schema_org/mixins/bank_account.rb', line 52 def account_minimum_inflow=(value) write_property(:account_minimum_inflow, value) end |
#account_overdraft_limit ⇒ Object
An overdraft is an extension of credit from a lending institution when an account reaches zero. An overdraft allows the individual to continue withdrawing money even if the account has no funds in it. Basically the bank allows people to borrow a set amount of money.
57 58 59 |
# File 'lib/schema_org/mixins/bank_account.rb', line 57 def account_overdraft_limit read_property(:account_overdraft_limit) end |
#account_overdraft_limit=(value) ⇒ Object
An overdraft is an extension of credit from a lending institution when an account reaches zero. An overdraft allows the individual to continue withdrawing money even if the account has no funds in it. Basically the bank allows people to borrow a set amount of money.
62 63 64 |
# File 'lib/schema_org/mixins/bank_account.rb', line 62 def account_overdraft_limit=(value) write_property(:account_overdraft_limit, value) end |
#bank_account_type ⇒ Object
The type of a bank account.
67 68 69 |
# File 'lib/schema_org/mixins/bank_account.rb', line 67 def bank_account_type read_property(:bank_account_type) end |
#bank_account_type=(value) ⇒ Object
The type of a bank account.
72 73 74 |
# File 'lib/schema_org/mixins/bank_account.rb', line 72 def bank_account_type=(value) write_property(:bank_account_type, value) end |