Module: SchemaOrg::Mixins::BioChemEntity
- Includes:
- Thing
- Included in:
- BioChemEntity, ChemicalSubstance, Gene, MolecularEntity, Protein
- Defined in:
- lib/schema_org/mixins/bio_chem_entity.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#associated_disease ⇒ Object
Disease associated to this BioChemEntity.
-
#associated_disease=(value) ⇒ Object
Disease associated to this BioChemEntity.
-
#bio_chem_interaction ⇒ Object
A BioChemEntity that is known to interact with this item.
-
#bio_chem_interaction=(value) ⇒ Object
A BioChemEntity that is known to interact with this item.
-
#bio_chem_similarity ⇒ Object
A similar BioChemEntity, e.g., obtained by fingerprint similarity algorithms.
-
#bio_chem_similarity=(value) ⇒ Object
A similar BioChemEntity, e.g., obtained by fingerprint similarity algorithms.
-
#biological_role ⇒ Object
A role played by the BioChemEntity within a biological context.
-
#biological_role=(value) ⇒ Object
A role played by the BioChemEntity within a biological context.
-
#funding ⇒ Object
A [[Grant]] that directly or indirectly provide funding or sponsorship for this item.
-
#funding=(value) ⇒ Object
A [[Grant]] that directly or indirectly provide funding or sponsorship for this item.
-
#has_bio_chem_entity_part ⇒ Object
Indicates a BioChemEntity that (in some sense) has this BioChemEntity as a part.
-
#has_bio_chem_entity_part=(value) ⇒ Object
Indicates a BioChemEntity that (in some sense) has this BioChemEntity as a part.
-
#has_molecular_function ⇒ Object
Molecular function performed by this BioChemEntity; please use PropertyValue if you want to include any evidence.
-
#has_molecular_function=(value) ⇒ Object
Molecular function performed by this BioChemEntity; please use PropertyValue if you want to include any evidence.
-
#has_representation ⇒ Object
A common representation such as a protein sequence or chemical structure for this entity.
-
#has_representation=(value) ⇒ Object
A common representation such as a protein sequence or chemical structure for this entity.
-
#is_encoded_by_bio_chem_entity ⇒ Object
Another BioChemEntity encoding by this one.
-
#is_encoded_by_bio_chem_entity=(value) ⇒ Object
Another BioChemEntity encoding by this one.
-
#is_involved_in_biological_process ⇒ Object
Biological process this BioChemEntity is involved in; please use PropertyValue if you want to include any evidence.
-
#is_involved_in_biological_process=(value) ⇒ Object
Biological process this BioChemEntity is involved in; please use PropertyValue if you want to include any evidence.
-
#is_located_in_subcellular_location ⇒ Object
Subcellular location where this BioChemEntity is located; please use PropertyValue if you want to include any evidence.
-
#is_located_in_subcellular_location=(value) ⇒ Object
Subcellular location where this BioChemEntity is located; please use PropertyValue if you want to include any evidence.
-
#is_part_of_bio_chem_entity ⇒ Object
Indicates a BioChemEntity that is (in some sense) a part of this BioChemEntity.
-
#is_part_of_bio_chem_entity=(value) ⇒ Object
Indicates a BioChemEntity that is (in some sense) a part of this BioChemEntity.
-
#taxonomic_range ⇒ Object
The taxonomic grouping of the organism that expresses, encodes, or in some way related to the BioChemEntity.
-
#taxonomic_range=(value) ⇒ Object
The taxonomic grouping of the organism that expresses, encodes, or in some way related to the BioChemEntity.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 11 def self.schema_property_definitions { associated_disease: { schema_name: "associatedDisease", schema_url: "https://schema.org/associatedDisease", comment_lines: ["Disease associated to this BioChemEntity. Such disease can be a MedicalCondition or a URL. If you want to add an evidence supporting the association, please use PropertyValue."].freeze, ranges: ["MedicalCondition", "PropertyValue", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, bio_chem_interaction: { schema_name: "bioChemInteraction", schema_url: "https://schema.org/bioChemInteraction", comment_lines: ["A BioChemEntity that is known to interact with this item."].freeze, ranges: ["BioChemEntity"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, bio_chem_similarity: { schema_name: "bioChemSimilarity", schema_url: "https://schema.org/bioChemSimilarity", comment_lines: ["A similar BioChemEntity, e.g., obtained by fingerprint similarity algorithms."].freeze, ranges: ["BioChemEntity"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, biological_role: { schema_name: "biologicalRole", schema_url: "https://schema.org/biologicalRole", comment_lines: ["A role played by the BioChemEntity within a biological context."].freeze, ranges: ["DefinedTerm"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, funding: { schema_name: "funding", schema_url: "https://schema.org/funding", comment_lines: ["A [[Grant]] that directly or indirectly provide funding or sponsorship for this item. See also [[ownershipFundingInfo]]."].freeze, ranges: ["Grant"].freeze, external_ranges: [].freeze, inverse_of: "fundedItem", superseded_by: nil, supersedes: nil }.freeze, has_bio_chem_entity_part: { schema_name: "hasBioChemEntityPart", schema_url: "https://schema.org/hasBioChemEntityPart", comment_lines: ["Indicates a BioChemEntity that (in some sense) has this BioChemEntity as a part."].freeze, ranges: ["BioChemEntity"].freeze, external_ranges: [].freeze, inverse_of: "isPartOfBioChemEntity", superseded_by: nil, supersedes: nil }.freeze, has_molecular_function: { schema_name: "hasMolecularFunction", schema_url: "https://schema.org/hasMolecularFunction", comment_lines: ["Molecular function performed by this BioChemEntity; please use PropertyValue if you want to include any evidence."].freeze, ranges: ["DefinedTerm", "PropertyValue", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, has_representation: { schema_name: "hasRepresentation", schema_url: "https://schema.org/hasRepresentation", comment_lines: ["A common representation such as a protein sequence or chemical structure for this entity. For images use schema.org/image."].freeze, ranges: ["PropertyValue", "Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, is_encoded_by_bio_chem_entity: { schema_name: "isEncodedByBioChemEntity", schema_url: "https://schema.org/isEncodedByBioChemEntity", comment_lines: ["Another BioChemEntity encoding by this one."].freeze, ranges: ["Gene"].freeze, external_ranges: [].freeze, inverse_of: "encodesBioChemEntity", superseded_by: nil, supersedes: nil }.freeze, is_involved_in_biological_process: { schema_name: "isInvolvedInBiologicalProcess", schema_url: "https://schema.org/isInvolvedInBiologicalProcess", comment_lines: ["Biological process this BioChemEntity is involved in; please use PropertyValue if you want to include any evidence."].freeze, ranges: ["DefinedTerm", "PropertyValue", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, is_located_in_subcellular_location: { schema_name: "isLocatedInSubcellularLocation", schema_url: "https://schema.org/isLocatedInSubcellularLocation", comment_lines: ["Subcellular location where this BioChemEntity is located; please use PropertyValue if you want to include any evidence."].freeze, ranges: ["DefinedTerm", "PropertyValue", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, is_part_of_bio_chem_entity: { schema_name: "isPartOfBioChemEntity", schema_url: "https://schema.org/isPartOfBioChemEntity", comment_lines: ["Indicates a BioChemEntity that is (in some sense) a part of this BioChemEntity."].freeze, ranges: ["BioChemEntity"].freeze, external_ranges: [].freeze, inverse_of: "hasBioChemEntityPart", superseded_by: nil, supersedes: nil }.freeze, taxonomic_range: { schema_name: "taxonomicRange", schema_url: "https://schema.org/taxonomicRange", comment_lines: ["The taxonomic grouping of the organism that expresses, encodes, or in some way related to the BioChemEntity."].freeze, ranges: ["DefinedTerm", "Taxon", "Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#associated_disease ⇒ Object
Disease associated to this BioChemEntity. Such disease can be a MedicalCondition or a URL. If you want to add an evidence supporting the association, please use PropertyValue.
147 148 149 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 147 def associated_disease read_property(:associated_disease) end |
#associated_disease=(value) ⇒ Object
Disease associated to this BioChemEntity. Such disease can be a MedicalCondition or a URL. If you want to add an evidence supporting the association, please use PropertyValue.
152 153 154 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 152 def associated_disease=(value) write_property(:associated_disease, value) end |
#bio_chem_interaction ⇒ Object
A BioChemEntity that is known to interact with this item.
157 158 159 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 157 def bio_chem_interaction read_property(:bio_chem_interaction) end |
#bio_chem_interaction=(value) ⇒ Object
A BioChemEntity that is known to interact with this item.
162 163 164 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 162 def bio_chem_interaction=(value) write_property(:bio_chem_interaction, value) end |
#bio_chem_similarity ⇒ Object
A similar BioChemEntity, e.g., obtained by fingerprint similarity algorithms.
167 168 169 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 167 def bio_chem_similarity read_property(:bio_chem_similarity) end |
#bio_chem_similarity=(value) ⇒ Object
A similar BioChemEntity, e.g., obtained by fingerprint similarity algorithms.
172 173 174 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 172 def bio_chem_similarity=(value) write_property(:bio_chem_similarity, value) end |
#biological_role ⇒ Object
A role played by the BioChemEntity within a biological context.
177 178 179 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 177 def biological_role read_property(:biological_role) end |
#biological_role=(value) ⇒ Object
A role played by the BioChemEntity within a biological context.
182 183 184 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 182 def biological_role=(value) write_property(:biological_role, value) end |
#funding ⇒ Object
A [[Grant]] that directly or indirectly provide funding or sponsorship for this item. See also [[ownershipFundingInfo]].
Inverse-property: fundedItem.
188 189 190 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 188 def funding read_property(:funding) end |
#funding=(value) ⇒ Object
A [[Grant]] that directly or indirectly provide funding or sponsorship for this item. See also [[ownershipFundingInfo]].
Inverse-property: fundedItem.
194 195 196 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 194 def funding=(value) write_property(:funding, value) end |
#has_bio_chem_entity_part ⇒ Object
Indicates a BioChemEntity that (in some sense) has this BioChemEntity as a part.
Inverse-property: isPartOfBioChemEntity.
200 201 202 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 200 def has_bio_chem_entity_part read_property(:has_bio_chem_entity_part) end |
#has_bio_chem_entity_part=(value) ⇒ Object
Indicates a BioChemEntity that (in some sense) has this BioChemEntity as a part.
Inverse-property: isPartOfBioChemEntity.
206 207 208 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 206 def has_bio_chem_entity_part=(value) write_property(:has_bio_chem_entity_part, value) end |
#has_molecular_function ⇒ Object
Molecular function performed by this BioChemEntity; please use PropertyValue if you want to include any evidence.
211 212 213 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 211 def has_molecular_function read_property(:has_molecular_function) end |
#has_molecular_function=(value) ⇒ Object
Molecular function performed by this BioChemEntity; please use PropertyValue if you want to include any evidence.
216 217 218 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 216 def has_molecular_function=(value) write_property(:has_molecular_function, value) end |
#has_representation ⇒ Object
A common representation such as a protein sequence or chemical structure for this entity. For images use schema.org/image.
221 222 223 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 221 def has_representation read_property(:has_representation) end |
#has_representation=(value) ⇒ Object
A common representation such as a protein sequence or chemical structure for this entity. For images use schema.org/image.
226 227 228 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 226 def has_representation=(value) write_property(:has_representation, value) end |
#is_encoded_by_bio_chem_entity ⇒ Object
Another BioChemEntity encoding by this one.
Inverse-property: encodesBioChemEntity.
232 233 234 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 232 def is_encoded_by_bio_chem_entity read_property(:is_encoded_by_bio_chem_entity) end |
#is_encoded_by_bio_chem_entity=(value) ⇒ Object
Another BioChemEntity encoding by this one.
Inverse-property: encodesBioChemEntity.
238 239 240 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 238 def is_encoded_by_bio_chem_entity=(value) write_property(:is_encoded_by_bio_chem_entity, value) end |
#is_involved_in_biological_process ⇒ Object
Biological process this BioChemEntity is involved in; please use PropertyValue if you want to include any evidence.
243 244 245 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 243 def is_involved_in_biological_process read_property(:is_involved_in_biological_process) end |
#is_involved_in_biological_process=(value) ⇒ Object
Biological process this BioChemEntity is involved in; please use PropertyValue if you want to include any evidence.
248 249 250 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 248 def is_involved_in_biological_process=(value) write_property(:is_involved_in_biological_process, value) end |
#is_located_in_subcellular_location ⇒ Object
Subcellular location where this BioChemEntity is located; please use PropertyValue if you want to include any evidence.
253 254 255 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 253 def is_located_in_subcellular_location read_property(:is_located_in_subcellular_location) end |
#is_located_in_subcellular_location=(value) ⇒ Object
Subcellular location where this BioChemEntity is located; please use PropertyValue if you want to include any evidence.
258 259 260 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 258 def is_located_in_subcellular_location=(value) write_property(:is_located_in_subcellular_location, value) end |
#is_part_of_bio_chem_entity ⇒ Object
Indicates a BioChemEntity that is (in some sense) a part of this BioChemEntity.
Inverse-property: hasBioChemEntityPart.
264 265 266 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 264 def is_part_of_bio_chem_entity read_property(:is_part_of_bio_chem_entity) end |
#is_part_of_bio_chem_entity=(value) ⇒ Object
Indicates a BioChemEntity that is (in some sense) a part of this BioChemEntity.
Inverse-property: hasBioChemEntityPart.
270 271 272 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 270 def is_part_of_bio_chem_entity=(value) write_property(:is_part_of_bio_chem_entity, value) end |
#taxonomic_range ⇒ Object
The taxonomic grouping of the organism that expresses, encodes, or in some way related to the BioChemEntity.
275 276 277 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 275 def taxonomic_range read_property(:taxonomic_range) end |
#taxonomic_range=(value) ⇒ Object
The taxonomic grouping of the organism that expresses, encodes, or in some way related to the BioChemEntity.
280 281 282 |
# File 'lib/schema_org/mixins/bio_chem_entity.rb', line 280 def taxonomic_range=(value) write_property(:taxonomic_range, value) end |