Module: SchemaOrg::Mixins::Blog
Class Method Summary collapse
Instance Method Summary collapse
-
#blog_post ⇒ Object
A posting that is part of this blog.
-
#blog_post=(value) ⇒ Object
A posting that is part of this blog.
-
#blog_posts ⇒ Object
Indicates a post that is part of a [[Blog]].
-
#blog_posts=(value) ⇒ Object
Indicates a post that is part of a [[Blog]].
-
#issn ⇒ Object
The International Standard Serial Number (ISSN) that identifies this serial publication.
-
#issn=(value) ⇒ Object
The International Standard Serial Number (ISSN) that identifies this serial publication.
Methods included from CreativeWork
#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/schema_org/mixins/blog.rb', line 11 def self.schema_property_definitions { blog_post: { schema_name: "blogPost", schema_url: "https://schema.org/blogPost", comment_lines: ["A posting that is part of this blog."].freeze, ranges: ["BlogPosting"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["blogPosts"].freeze }.freeze, blog_posts: { schema_name: "blogPosts", schema_url: "https://schema.org/blogPosts", comment_lines: ["Indicates a post that is part of a [[Blog]]. Note that historically, what we term a \"Blog\" was once known as a \"weblog\", and that what we term a \"BlogPosting\" is now often colloquially referred to as a \"blog\"."].freeze, ranges: ["BlogPosting"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "blogPost", supersedes: nil }.freeze, issn: { schema_name: "issn", schema_url: "https://schema.org/issn", comment_lines: ["The International Standard Serial Number (ISSN) that identifies this serial publication. You can repeat this property to identify different formats of, or the linking ISSN (ISSN-L) for, this serial publication."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#blog_post ⇒ Object
A posting that is part of this blog.
Supersedes blogPosts.
48 49 50 |
# File 'lib/schema_org/mixins/blog.rb', line 48 def blog_post read_property(:blog_post) end |
#blog_post=(value) ⇒ Object
A posting that is part of this blog.
Supersedes blogPosts.
54 55 56 |
# File 'lib/schema_org/mixins/blog.rb', line 54 def blog_post=(value) write_property(:blog_post, value) end |
#blog_posts ⇒ Object
Indicates a post that is part of a [[Blog]]. Note that historically, what we term a "Blog" was once known as a "weblog", and that what we term a "BlogPosting" is now often colloquially referred to as a "blog".
Superseded by blogPost.
60 61 62 |
# File 'lib/schema_org/mixins/blog.rb', line 60 def blog_posts read_property(:blog_posts) end |
#blog_posts=(value) ⇒ Object
Indicates a post that is part of a [[Blog]]. Note that historically, what we term a "Blog" was once known as a "weblog", and that what we term a "BlogPosting" is now often colloquially referred to as a "blog".
Superseded by blogPost.
66 67 68 |
# File 'lib/schema_org/mixins/blog.rb', line 66 def blog_posts=(value) write_property(:blog_posts, value) end |
#issn ⇒ Object
The International Standard Serial Number (ISSN) that identifies this serial publication. You can repeat this property to identify different formats of, or the linking ISSN (ISSN-L) for, this serial publication.
71 72 73 |
# File 'lib/schema_org/mixins/blog.rb', line 71 def issn read_property(:issn) end |
#issn=(value) ⇒ Object
The International Standard Serial Number (ISSN) that identifies this serial publication. You can repeat this property to identify different formats of, or the linking ISSN (ISSN-L) for, this serial publication.
76 77 78 |
# File 'lib/schema_org/mixins/blog.rb', line 76 def issn=(value) write_property(:issn, value) end |