Module: SchemaOrg::Mixins::BroadcastService
- Includes:
- Service
- Included in:
- BroadcastService, RadioBroadcastService
- Defined in:
- lib/schema_org/mixins/broadcast_service.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#area ⇒ Object
The area within which users can expect to reach the broadcast service.
-
#area=(value) ⇒ Object
The area within which users can expect to reach the broadcast service.
-
#broadcast_affiliate_of ⇒ Object
The media network(s) whose content is broadcast on this station.
-
#broadcast_affiliate_of=(value) ⇒ Object
The media network(s) whose content is broadcast on this station.
-
#broadcast_display_name ⇒ Object
The name displayed in the channel guide.
-
#broadcast_display_name=(value) ⇒ Object
The name displayed in the channel guide.
-
#broadcast_frequency ⇒ Object
The frequency used for over-the-air broadcasts.
-
#broadcast_frequency=(value) ⇒ Object
The frequency used for over-the-air broadcasts.
-
#broadcast_timezone ⇒ Object
The timezone in ISO 8601 format for which the service bases its broadcasts.
-
#broadcast_timezone=(value) ⇒ Object
The timezone in ISO 8601 format for which the service bases its broadcasts.
-
#broadcaster ⇒ Object
The organization owning or operating the broadcast service.
-
#broadcaster=(value) ⇒ Object
The organization owning or operating the broadcast service.
-
#call_sign ⇒ Object
A callsign, as used in broadcasting and radio communications to identify people, radio and TV stations, or vehicles.
-
#call_sign=(value) ⇒ Object
A callsign, as used in broadcasting and radio communications to identify people, radio and TV stations, or vehicles.
-
#has_broadcast_channel ⇒ Object
A broadcast channel of a broadcast service.
-
#has_broadcast_channel=(value) ⇒ Object
A broadcast channel of a broadcast service.
-
#in_language ⇒ Object
The language of the content or performance or used in an action.
-
#in_language=(value) ⇒ Object
The language of the content or performance or used in an action.
-
#parent_service ⇒ Object
A broadcast service to which the broadcast service may belong to such as regional variations of a national channel.
-
#parent_service=(value) ⇒ Object
A broadcast service to which the broadcast service may belong to such as regional variations of a national channel.
-
#video_format ⇒ Object
The type of screening or video broadcast used (e.g. IMAX, 3D, SD, HD, etc.).
-
#video_format=(value) ⇒ Object
The type of screening or video broadcast used (e.g. IMAX, 3D, SD, HD, etc.).
Methods included from Service
#aggregate_rating, #aggregate_rating=, #area_served, #area_served=, #audience, #audience=, #available_channel, #available_channel=, #award, #award=, #brand, #brand=, #broker, #broker=, #category, #category=, #has_certification, #has_certification=, #has_offer_catalog, #has_offer_catalog=, #hours_available, #hours_available=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #logo, #logo=, #offers, #offers=, #produces, #produces=, #provider, #provider=, #provider_mobility, #provider_mobility=, #review, #review=, #service_area, #service_area=, #service_audience, #service_audience=, #service_output, #service_output=, #service_type, #service_type=, #slogan, #slogan=, #terms_of_service, #terms_of_service=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 11 def self.schema_property_definitions { area: { schema_name: "area", schema_url: "https://schema.org/area", comment_lines: ["The area within which users can expect to reach the broadcast service."].freeze, ranges: ["Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "serviceArea", supersedes: nil }.freeze, broadcast_affiliate_of: { schema_name: "broadcastAffiliateOf", schema_url: "https://schema.org/broadcastAffiliateOf", comment_lines: ["The media network(s) whose content is broadcast on this station."].freeze, ranges: ["Organization"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, broadcast_display_name: { schema_name: "broadcastDisplayName", schema_url: "https://schema.org/broadcastDisplayName", comment_lines: ["The name displayed in the channel guide. For many US affiliates, it is the network name."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, broadcast_frequency: { schema_name: "broadcastFrequency", schema_url: "https://schema.org/broadcastFrequency", comment_lines: ["The frequency used for over-the-air broadcasts. Numeric values or simple ranges, e.g. 87-99. In addition a shortcut idiom is supported for frequencies of AM and FM radio channels, e.g. \"87 FM\"."].freeze, ranges: ["BroadcastFrequencySpecification", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, broadcast_timezone: { schema_name: "broadcastTimezone", schema_url: "https://schema.org/broadcastTimezone", comment_lines: ["The timezone in [ISO 8601 format](http://en.wikipedia.org/wiki/ISO_8601) for which the service bases its broadcasts."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, broadcaster: { schema_name: "broadcaster", schema_url: "https://schema.org/broadcaster", comment_lines: ["The organization owning or operating the broadcast service."].freeze, ranges: ["Organization"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, call_sign: { schema_name: "callSign", schema_url: "https://schema.org/callSign", comment_lines: ["A [callsign](https://en.wikipedia.org/wiki/Call_sign), as used in broadcasting and radio communications to identify people, radio and TV stations, or vehicles."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, has_broadcast_channel: { schema_name: "hasBroadcastChannel", schema_url: "https://schema.org/hasBroadcastChannel", comment_lines: ["A broadcast channel of a broadcast service."].freeze, ranges: ["BroadcastChannel"].freeze, external_ranges: [].freeze, inverse_of: "providesBroadcastService", superseded_by: nil, supersedes: nil }.freeze, in_language: { schema_name: "inLanguage", schema_url: "https://schema.org/inLanguage", comment_lines: ["The language of the content or performance or used in an action. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[availableLanguage]]."].freeze, ranges: ["Language", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["language"].freeze }.freeze, parent_service: { schema_name: "parentService", schema_url: "https://schema.org/parentService", comment_lines: ["A broadcast service to which the broadcast service may belong to such as regional variations of a national channel."].freeze, ranges: ["BroadcastService"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, video_format: { schema_name: "videoFormat", schema_url: "https://schema.org/videoFormat", comment_lines: ["The type of screening or video broadcast used (e.g. IMAX, 3D, SD, HD, etc.)."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#area ⇒ Object
The area within which users can expect to reach the broadcast service.
Superseded by serviceArea.
128 129 130 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 128 def area read_property(:area) end |
#area=(value) ⇒ Object
The area within which users can expect to reach the broadcast service.
Superseded by serviceArea.
134 135 136 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 134 def area=(value) write_property(:area, value) end |
#broadcast_affiliate_of ⇒ Object
The media network(s) whose content is broadcast on this station.
139 140 141 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 139 def broadcast_affiliate_of read_property(:broadcast_affiliate_of) end |
#broadcast_affiliate_of=(value) ⇒ Object
The media network(s) whose content is broadcast on this station.
144 145 146 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 144 def broadcast_affiliate_of=(value) write_property(:broadcast_affiliate_of, value) end |
#broadcast_display_name ⇒ Object
The name displayed in the channel guide. For many US affiliates, it is the network name.
149 150 151 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 149 def broadcast_display_name read_property(:broadcast_display_name) end |
#broadcast_display_name=(value) ⇒ Object
The name displayed in the channel guide. For many US affiliates, it is the network name.
154 155 156 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 154 def broadcast_display_name=(value) write_property(:broadcast_display_name, value) end |
#broadcast_frequency ⇒ Object
The frequency used for over-the-air broadcasts. Numeric values or simple ranges, e.g. 87-99. In addition a shortcut idiom is supported for frequencies of AM and FM radio channels, e.g. "87 FM".
159 160 161 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 159 def broadcast_frequency read_property(:broadcast_frequency) end |
#broadcast_frequency=(value) ⇒ Object
The frequency used for over-the-air broadcasts. Numeric values or simple ranges, e.g. 87-99. In addition a shortcut idiom is supported for frequencies of AM and FM radio channels, e.g. "87 FM".
164 165 166 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 164 def broadcast_frequency=(value) write_property(:broadcast_frequency, value) end |
#broadcast_timezone ⇒ Object
The timezone in ISO 8601 format for which the service bases its broadcasts.
169 170 171 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 169 def broadcast_timezone read_property(:broadcast_timezone) end |
#broadcast_timezone=(value) ⇒ Object
The timezone in ISO 8601 format for which the service bases its broadcasts.
174 175 176 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 174 def broadcast_timezone=(value) write_property(:broadcast_timezone, value) end |
#broadcaster ⇒ Object
The organization owning or operating the broadcast service.
179 180 181 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 179 def broadcaster read_property(:broadcaster) end |
#broadcaster=(value) ⇒ Object
The organization owning or operating the broadcast service.
184 185 186 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 184 def broadcaster=(value) write_property(:broadcaster, value) end |
#call_sign ⇒ Object
A callsign, as used in broadcasting and radio communications to identify people, radio and TV stations, or vehicles.
189 190 191 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 189 def call_sign read_property(:call_sign) end |
#call_sign=(value) ⇒ Object
A callsign, as used in broadcasting and radio communications to identify people, radio and TV stations, or vehicles.
194 195 196 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 194 def call_sign=(value) write_property(:call_sign, value) end |
#has_broadcast_channel ⇒ Object
A broadcast channel of a broadcast service.
Inverse-property: providesBroadcastService.
200 201 202 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 200 def has_broadcast_channel read_property(:has_broadcast_channel) end |
#has_broadcast_channel=(value) ⇒ Object
A broadcast channel of a broadcast service.
Inverse-property: providesBroadcastService.
206 207 208 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 206 def has_broadcast_channel=(value) write_property(:has_broadcast_channel, value) end |
#in_language ⇒ Object
The language of the content or performance or used in an action. Please use one of the language codes from the IETF BCP 47 standard. See also [[availableLanguage]].
Supersedes language.
212 213 214 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 212 def in_language read_property(:in_language) end |
#in_language=(value) ⇒ Object
The language of the content or performance or used in an action. Please use one of the language codes from the IETF BCP 47 standard. See also [[availableLanguage]].
Supersedes language.
218 219 220 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 218 def in_language=(value) write_property(:in_language, value) end |
#parent_service ⇒ Object
A broadcast service to which the broadcast service may belong to such as regional variations of a national channel.
223 224 225 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 223 def parent_service read_property(:parent_service) end |
#parent_service=(value) ⇒ Object
A broadcast service to which the broadcast service may belong to such as regional variations of a national channel.
228 229 230 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 228 def parent_service=(value) write_property(:parent_service, value) end |
#video_format ⇒ Object
The type of screening or video broadcast used (e.g. IMAX, 3D, SD, HD, etc.).
233 234 235 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 233 def video_format read_property(:video_format) end |
#video_format=(value) ⇒ Object
The type of screening or video broadcast used (e.g. IMAX, 3D, SD, HD, etc.).
238 239 240 |
# File 'lib/schema_org/mixins/broadcast_service.rb', line 238 def video_format=(value) write_property(:video_format, value) end |