Module: SchemaOrg::Mixins::BusTrip
Class Method Summary collapse
Instance Method Summary collapse
-
#arrival_bus_stop ⇒ Object
The stop or station from which the bus arrives.
-
#arrival_bus_stop=(value) ⇒ Object
The stop or station from which the bus arrives.
-
#bus_name ⇒ Object
The name of the bus (e.g. Bolt Express).
-
#bus_name=(value) ⇒ Object
The name of the bus (e.g. Bolt Express).
-
#bus_number ⇒ Object
The unique identifier for the bus.
-
#bus_number=(value) ⇒ Object
The unique identifier for the bus.
-
#departure_bus_stop ⇒ Object
The stop or station from which the bus departs.
-
#departure_bus_stop=(value) ⇒ Object
The stop or station from which the bus departs.
Methods included from Trip
#arrival_time, #arrival_time=, #departure_time, #departure_time=, #itinerary, #itinerary=, #offers, #offers=, #part_of_trip, #part_of_trip=, #provider, #provider=, #sub_trip, #sub_trip=, #trip_origin, #trip_origin=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/schema_org/mixins/bus_trip.rb', line 11 def self.schema_property_definitions { arrival_bus_stop: { schema_name: "arrivalBusStop", schema_url: "https://schema.org/arrivalBusStop", comment_lines: ["The stop or station from which the bus arrives."].freeze, ranges: ["BusStation", "BusStop"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, bus_name: { schema_name: "busName", schema_url: "https://schema.org/busName", comment_lines: ["The name of the bus (e.g. Bolt Express)."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, bus_number: { schema_name: "busNumber", schema_url: "https://schema.org/busNumber", comment_lines: ["The unique identifier for the bus."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, departure_bus_stop: { schema_name: "departureBusStop", schema_url: "https://schema.org/departureBusStop", comment_lines: ["The stop or station from which the bus departs."].freeze, ranges: ["BusStation", "BusStop"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#arrival_bus_stop ⇒ Object
The stop or station from which the bus arrives.
57 58 59 |
# File 'lib/schema_org/mixins/bus_trip.rb', line 57 def arrival_bus_stop read_property(:arrival_bus_stop) end |
#arrival_bus_stop=(value) ⇒ Object
The stop or station from which the bus arrives.
62 63 64 |
# File 'lib/schema_org/mixins/bus_trip.rb', line 62 def arrival_bus_stop=(value) write_property(:arrival_bus_stop, value) end |
#bus_name ⇒ Object
The name of the bus (e.g. Bolt Express).
67 68 69 |
# File 'lib/schema_org/mixins/bus_trip.rb', line 67 def bus_name read_property(:bus_name) end |
#bus_name=(value) ⇒ Object
The name of the bus (e.g. Bolt Express).
72 73 74 |
# File 'lib/schema_org/mixins/bus_trip.rb', line 72 def bus_name=(value) write_property(:bus_name, value) end |
#bus_number ⇒ Object
The unique identifier for the bus.
77 78 79 |
# File 'lib/schema_org/mixins/bus_trip.rb', line 77 def bus_number read_property(:bus_number) end |
#bus_number=(value) ⇒ Object
The unique identifier for the bus.
82 83 84 |
# File 'lib/schema_org/mixins/bus_trip.rb', line 82 def bus_number=(value) write_property(:bus_number, value) end |
#departure_bus_stop ⇒ Object
The stop or station from which the bus departs.
87 88 89 |
# File 'lib/schema_org/mixins/bus_trip.rb', line 87 def departure_bus_stop read_property(:departure_bus_stop) end |
#departure_bus_stop=(value) ⇒ Object
The stop or station from which the bus departs.
92 93 94 |
# File 'lib/schema_org/mixins/bus_trip.rb', line 92 def departure_bus_stop=(value) write_property(:departure_bus_stop, value) end |