Module: SchemaOrg::Mixins::CDCPMDRecord
- Includes:
- StructuredValue
- Included in:
- CDCPMDRecord
- Defined in:
- lib/schema_org/mixins/cdcpmd_record.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#cvd_collection_date ⇒ Object
collectiondate - Date for which patient counts are reported.
-
#cvd_collection_date=(value) ⇒ Object
collectiondate - Date for which patient counts are reported.
-
#cvd_facility_county ⇒ Object
Name of the County of the NHSN facility that this data record applies to.
-
#cvd_facility_county=(value) ⇒ Object
Name of the County of the NHSN facility that this data record applies to.
-
#cvd_facility_id ⇒ Object
Identifier of the NHSN facility that this data record applies to.
-
#cvd_facility_id=(value) ⇒ Object
Identifier of the NHSN facility that this data record applies to.
-
#cvd_num_beds ⇒ Object
numbeds - HOSPITAL INPATIENT BEDS: Inpatient beds, including all staffed, licensed, and overflow (surge) beds used for inpatients.
-
#cvd_num_beds=(value) ⇒ Object
numbeds - HOSPITAL INPATIENT BEDS: Inpatient beds, including all staffed, licensed, and overflow (surge) beds used for inpatients.
-
#cvd_num_beds_occ ⇒ Object
numbedsocc - HOSPITAL INPATIENT BED OCCUPANCY: Total number of staffed inpatient beds that are occupied.
-
#cvd_num_beds_occ=(value) ⇒ Object
numbedsocc - HOSPITAL INPATIENT BED OCCUPANCY: Total number of staffed inpatient beds that are occupied.
-
#cvd_num_c19_died ⇒ Object
numc19died - DEATHS: Patients with suspected or confirmed COVID-19 who died in the hospital, ED, or any overflow location.
-
#cvd_num_c19_died=(value) ⇒ Object
numc19died - DEATHS: Patients with suspected or confirmed COVID-19 who died in the hospital, ED, or any overflow location.
-
#cvd_num_c19_ho_pats ⇒ Object
numc19hopats - HOSPITAL ONSET: Patients hospitalized in an NHSN inpatient care location with onset of suspected or confirmed COVID-19 14 or more days after hospitalization.
-
#cvd_num_c19_ho_pats=(value) ⇒ Object
numc19hopats - HOSPITAL ONSET: Patients hospitalized in an NHSN inpatient care location with onset of suspected or confirmed COVID-19 14 or more days after hospitalization.
-
#cvd_num_c19_hosp_pats ⇒ Object
numc19hosppats - HOSPITALIZED: Patients currently hospitalized in an inpatient care location who have suspected or confirmed COVID-19.
-
#cvd_num_c19_hosp_pats=(value) ⇒ Object
numc19hosppats - HOSPITALIZED: Patients currently hospitalized in an inpatient care location who have suspected or confirmed COVID-19.
-
#cvd_num_c19_mech_vent_pats ⇒ Object
numc19mechventpats - HOSPITALIZED and VENTILATED: Patients hospitalized in an NHSN inpatient care location who have suspected or confirmed COVID-19 and are on a mechanical ventilator.
-
#cvd_num_c19_mech_vent_pats=(value) ⇒ Object
numc19mechventpats - HOSPITALIZED and VENTILATED: Patients hospitalized in an NHSN inpatient care location who have suspected or confirmed COVID-19 and are on a mechanical ventilator.
-
#cvd_num_c19_of_mech_vent_pats ⇒ Object
numc19ofmechventpats - ED/OVERFLOW and VENTILATED: Patients with suspected or confirmed COVID-19 who are in the ED or any overflow location awaiting an inpatient bed and on a mechanical ventilator.
-
#cvd_num_c19_of_mech_vent_pats=(value) ⇒ Object
numc19ofmechventpats - ED/OVERFLOW and VENTILATED: Patients with suspected or confirmed COVID-19 who are in the ED or any overflow location awaiting an inpatient bed and on a mechanical ventilator.
-
#cvd_num_c19_overflow_pats ⇒ Object
numc19overflowpats - ED/OVERFLOW: Patients with suspected or confirmed COVID-19 who are in the ED or any overflow location awaiting an inpatient bed.
-
#cvd_num_c19_overflow_pats=(value) ⇒ Object
numc19overflowpats - ED/OVERFLOW: Patients with suspected or confirmed COVID-19 who are in the ED or any overflow location awaiting an inpatient bed.
-
#cvd_num_icu_beds ⇒ Object
numicubeds - ICU BEDS: Total number of staffed inpatient intensive care unit (ICU) beds.
-
#cvd_num_icu_beds=(value) ⇒ Object
numicubeds - ICU BEDS: Total number of staffed inpatient intensive care unit (ICU) beds.
-
#cvd_num_icu_beds_occ ⇒ Object
numicubedsocc - ICU BED OCCUPANCY: Total number of staffed inpatient ICU beds that are occupied.
-
#cvd_num_icu_beds_occ=(value) ⇒ Object
numicubedsocc - ICU BED OCCUPANCY: Total number of staffed inpatient ICU beds that are occupied.
-
#cvd_num_tot_beds ⇒ Object
numtotbeds - ALL HOSPITAL BEDS: Total number of all inpatient and outpatient beds, including all staffed, ICU, licensed, and overflow (surge) beds used for inpatients or outpatients.
-
#cvd_num_tot_beds=(value) ⇒ Object
numtotbeds - ALL HOSPITAL BEDS: Total number of all inpatient and outpatient beds, including all staffed, ICU, licensed, and overflow (surge) beds used for inpatients or outpatients.
-
#cvd_num_vent ⇒ Object
numvent - MECHANICAL VENTILATORS: Total number of ventilators available.
-
#cvd_num_vent=(value) ⇒ Object
numvent - MECHANICAL VENTILATORS: Total number of ventilators available.
-
#cvd_num_vent_use ⇒ Object
numventuse - MECHANICAL VENTILATORS IN USE: Total number of ventilators in use.
-
#cvd_num_vent_use=(value) ⇒ Object
numventuse - MECHANICAL VENTILATORS IN USE: Total number of ventilators in use.
-
#date_posted ⇒ Object
Publication date of an online listing.
-
#date_posted=(value) ⇒ Object
Publication date of an online listing.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 11 def self.schema_property_definitions { cvd_collection_date: { schema_name: "cvdCollectionDate", schema_url: "https://schema.org/cvdCollectionDate", comment_lines: ["collectiondate - Date for which patient counts are reported."].freeze, ranges: ["DateTime", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, cvd_facility_county: { schema_name: "cvdFacilityCounty", schema_url: "https://schema.org/cvdFacilityCounty", comment_lines: ["Name of the County of the NHSN facility that this data record applies to. Use [[cvdFacilityId]] to identify the facility. To provide other details, [[healthcareReportingData]] can be used on a [[Hospital]] entry."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, cvd_facility_id: { schema_name: "cvdFacilityId", schema_url: "https://schema.org/cvdFacilityId", comment_lines: ["Identifier of the NHSN facility that this data record applies to. Use [[cvdFacilityCounty]] to indicate the county. To provide other details, [[healthcareReportingData]] can be used on a [[Hospital]] entry."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, cvd_num_beds: { schema_name: "cvdNumBeds", schema_url: "https://schema.org/cvdNumBeds", comment_lines: ["numbeds - HOSPITAL INPATIENT BEDS: Inpatient beds, including all staffed, licensed, and overflow (surge) beds used for inpatients."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, cvd_num_beds_occ: { schema_name: "cvdNumBedsOcc", schema_url: "https://schema.org/cvdNumBedsOcc", comment_lines: ["numbedsocc - HOSPITAL INPATIENT BED OCCUPANCY: Total number of staffed inpatient beds that are occupied."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, cvd_num_c19_died: { schema_name: "cvdNumC19Died", schema_url: "https://schema.org/cvdNumC19Died", comment_lines: ["numc19died - DEATHS: Patients with suspected or confirmed COVID-19 who died in the hospital, ED, or any overflow location."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, cvd_num_c19_ho_pats: { schema_name: "cvdNumC19HOPats", schema_url: "https://schema.org/cvdNumC19HOPats", comment_lines: ["numc19hopats - HOSPITAL ONSET: Patients hospitalized in an NHSN inpatient care location with onset of suspected or confirmed COVID-19 14 or more days after hospitalization."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, cvd_num_c19_hosp_pats: { schema_name: "cvdNumC19HospPats", schema_url: "https://schema.org/cvdNumC19HospPats", comment_lines: ["numc19hosppats - HOSPITALIZED: Patients currently hospitalized in an inpatient care location who have suspected or confirmed COVID-19."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, cvd_num_c19_mech_vent_pats: { schema_name: "cvdNumC19MechVentPats", schema_url: "https://schema.org/cvdNumC19MechVentPats", comment_lines: ["numc19mechventpats - HOSPITALIZED and VENTILATED: Patients hospitalized in an NHSN inpatient care location who have suspected or confirmed COVID-19 and are on a mechanical ventilator."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, cvd_num_c19_of_mech_vent_pats: { schema_name: "cvdNumC19OFMechVentPats", schema_url: "https://schema.org/cvdNumC19OFMechVentPats", comment_lines: ["numc19ofmechventpats - ED/OVERFLOW and VENTILATED: Patients with suspected or confirmed COVID-19 who are in the ED or any overflow location awaiting an inpatient bed and on a mechanical ventilator."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, cvd_num_c19_overflow_pats: { schema_name: "cvdNumC19OverflowPats", schema_url: "https://schema.org/cvdNumC19OverflowPats", comment_lines: ["numc19overflowpats - ED/OVERFLOW: Patients with suspected or confirmed COVID-19 who are in the ED or any overflow location awaiting an inpatient bed."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, cvd_num_icu_beds: { schema_name: "cvdNumICUBeds", schema_url: "https://schema.org/cvdNumICUBeds", comment_lines: ["numicubeds - ICU BEDS: Total number of staffed inpatient intensive care unit (ICU) beds."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, cvd_num_icu_beds_occ: { schema_name: "cvdNumICUBedsOcc", schema_url: "https://schema.org/cvdNumICUBedsOcc", comment_lines: ["numicubedsocc - ICU BED OCCUPANCY: Total number of staffed inpatient ICU beds that are occupied."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, cvd_num_tot_beds: { schema_name: "cvdNumTotBeds", schema_url: "https://schema.org/cvdNumTotBeds", comment_lines: ["numtotbeds - ALL HOSPITAL BEDS: Total number of all inpatient and outpatient beds, including all staffed, ICU, licensed, and overflow (surge) beds used for inpatients or outpatients."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, cvd_num_vent: { schema_name: "cvdNumVent", schema_url: "https://schema.org/cvdNumVent", comment_lines: ["numvent - MECHANICAL VENTILATORS: Total number of ventilators available."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, cvd_num_vent_use: { schema_name: "cvdNumVentUse", schema_url: "https://schema.org/cvdNumVentUse", comment_lines: ["numventuse - MECHANICAL VENTILATORS IN USE: Total number of ventilators in use."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, date_posted: { schema_name: "datePosted", schema_url: "https://schema.org/datePosted", comment_lines: ["Publication date of an online listing."].freeze, ranges: ["Date", "DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#cvd_collection_date ⇒ Object
collectiondate - Date for which patient counts are reported.
187 188 189 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 187 def cvd_collection_date read_property(:cvd_collection_date) end |
#cvd_collection_date=(value) ⇒ Object
collectiondate - Date for which patient counts are reported.
192 193 194 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 192 def cvd_collection_date=(value) write_property(:cvd_collection_date, value) end |
#cvd_facility_county ⇒ Object
Name of the County of the NHSN facility that this data record applies to. Use [[cvdFacilityId]] to identify the facility. To provide other details, [[healthcareReportingData]] can be used on a [[Hospital]] entry.
197 198 199 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 197 def cvd_facility_county read_property(:cvd_facility_county) end |
#cvd_facility_county=(value) ⇒ Object
Name of the County of the NHSN facility that this data record applies to. Use [[cvdFacilityId]] to identify the facility. To provide other details, [[healthcareReportingData]] can be used on a [[Hospital]] entry.
202 203 204 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 202 def cvd_facility_county=(value) write_property(:cvd_facility_county, value) end |
#cvd_facility_id ⇒ Object
Identifier of the NHSN facility that this data record applies to. Use [[cvdFacilityCounty]] to indicate the county. To provide other details, [[healthcareReportingData]] can be used on a [[Hospital]] entry.
207 208 209 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 207 def cvd_facility_id read_property(:cvd_facility_id) end |
#cvd_facility_id=(value) ⇒ Object
Identifier of the NHSN facility that this data record applies to. Use [[cvdFacilityCounty]] to indicate the county. To provide other details, [[healthcareReportingData]] can be used on a [[Hospital]] entry.
212 213 214 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 212 def cvd_facility_id=(value) write_property(:cvd_facility_id, value) end |
#cvd_num_beds ⇒ Object
numbeds - HOSPITAL INPATIENT BEDS: Inpatient beds, including all staffed, licensed, and overflow (surge) beds used for inpatients.
217 218 219 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 217 def cvd_num_beds read_property(:cvd_num_beds) end |
#cvd_num_beds=(value) ⇒ Object
numbeds - HOSPITAL INPATIENT BEDS: Inpatient beds, including all staffed, licensed, and overflow (surge) beds used for inpatients.
222 223 224 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 222 def cvd_num_beds=(value) write_property(:cvd_num_beds, value) end |
#cvd_num_beds_occ ⇒ Object
numbedsocc - HOSPITAL INPATIENT BED OCCUPANCY: Total number of staffed inpatient beds that are occupied.
227 228 229 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 227 def cvd_num_beds_occ read_property(:cvd_num_beds_occ) end |
#cvd_num_beds_occ=(value) ⇒ Object
numbedsocc - HOSPITAL INPATIENT BED OCCUPANCY: Total number of staffed inpatient beds that are occupied.
232 233 234 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 232 def cvd_num_beds_occ=(value) write_property(:cvd_num_beds_occ, value) end |
#cvd_num_c19_died ⇒ Object
numc19died - DEATHS: Patients with suspected or confirmed COVID-19 who died in the hospital, ED, or any overflow location.
237 238 239 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 237 def cvd_num_c19_died read_property(:cvd_num_c19_died) end |
#cvd_num_c19_died=(value) ⇒ Object
numc19died - DEATHS: Patients with suspected or confirmed COVID-19 who died in the hospital, ED, or any overflow location.
242 243 244 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 242 def cvd_num_c19_died=(value) write_property(:cvd_num_c19_died, value) end |
#cvd_num_c19_ho_pats ⇒ Object
numc19hopats - HOSPITAL ONSET: Patients hospitalized in an NHSN inpatient care location with onset of suspected or confirmed COVID-19 14 or more days after hospitalization.
247 248 249 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 247 def cvd_num_c19_ho_pats read_property(:cvd_num_c19_ho_pats) end |
#cvd_num_c19_ho_pats=(value) ⇒ Object
numc19hopats - HOSPITAL ONSET: Patients hospitalized in an NHSN inpatient care location with onset of suspected or confirmed COVID-19 14 or more days after hospitalization.
252 253 254 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 252 def cvd_num_c19_ho_pats=(value) write_property(:cvd_num_c19_ho_pats, value) end |
#cvd_num_c19_hosp_pats ⇒ Object
numc19hosppats - HOSPITALIZED: Patients currently hospitalized in an inpatient care location who have suspected or confirmed COVID-19.
257 258 259 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 257 def cvd_num_c19_hosp_pats read_property(:cvd_num_c19_hosp_pats) end |
#cvd_num_c19_hosp_pats=(value) ⇒ Object
numc19hosppats - HOSPITALIZED: Patients currently hospitalized in an inpatient care location who have suspected or confirmed COVID-19.
262 263 264 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 262 def cvd_num_c19_hosp_pats=(value) write_property(:cvd_num_c19_hosp_pats, value) end |
#cvd_num_c19_mech_vent_pats ⇒ Object
numc19mechventpats - HOSPITALIZED and VENTILATED: Patients hospitalized in an NHSN inpatient care location who have suspected or confirmed COVID-19 and are on a mechanical ventilator.
267 268 269 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 267 def cvd_num_c19_mech_vent_pats read_property(:cvd_num_c19_mech_vent_pats) end |
#cvd_num_c19_mech_vent_pats=(value) ⇒ Object
numc19mechventpats - HOSPITALIZED and VENTILATED: Patients hospitalized in an NHSN inpatient care location who have suspected or confirmed COVID-19 and are on a mechanical ventilator.
272 273 274 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 272 def cvd_num_c19_mech_vent_pats=(value) write_property(:cvd_num_c19_mech_vent_pats, value) end |
#cvd_num_c19_of_mech_vent_pats ⇒ Object
numc19ofmechventpats - ED/OVERFLOW and VENTILATED: Patients with suspected or confirmed COVID-19 who are in the ED or any overflow location awaiting an inpatient bed and on a mechanical ventilator.
277 278 279 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 277 def cvd_num_c19_of_mech_vent_pats read_property(:cvd_num_c19_of_mech_vent_pats) end |
#cvd_num_c19_of_mech_vent_pats=(value) ⇒ Object
numc19ofmechventpats - ED/OVERFLOW and VENTILATED: Patients with suspected or confirmed COVID-19 who are in the ED or any overflow location awaiting an inpatient bed and on a mechanical ventilator.
282 283 284 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 282 def cvd_num_c19_of_mech_vent_pats=(value) write_property(:cvd_num_c19_of_mech_vent_pats, value) end |
#cvd_num_c19_overflow_pats ⇒ Object
numc19overflowpats - ED/OVERFLOW: Patients with suspected or confirmed COVID-19 who are in the ED or any overflow location awaiting an inpatient bed.
287 288 289 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 287 def cvd_num_c19_overflow_pats read_property(:cvd_num_c19_overflow_pats) end |
#cvd_num_c19_overflow_pats=(value) ⇒ Object
numc19overflowpats - ED/OVERFLOW: Patients with suspected or confirmed COVID-19 who are in the ED or any overflow location awaiting an inpatient bed.
292 293 294 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 292 def cvd_num_c19_overflow_pats=(value) write_property(:cvd_num_c19_overflow_pats, value) end |
#cvd_num_icu_beds ⇒ Object
numicubeds - ICU BEDS: Total number of staffed inpatient intensive care unit (ICU) beds.
297 298 299 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 297 def cvd_num_icu_beds read_property(:cvd_num_icu_beds) end |
#cvd_num_icu_beds=(value) ⇒ Object
numicubeds - ICU BEDS: Total number of staffed inpatient intensive care unit (ICU) beds.
302 303 304 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 302 def cvd_num_icu_beds=(value) write_property(:cvd_num_icu_beds, value) end |
#cvd_num_icu_beds_occ ⇒ Object
numicubedsocc - ICU BED OCCUPANCY: Total number of staffed inpatient ICU beds that are occupied.
307 308 309 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 307 def cvd_num_icu_beds_occ read_property(:cvd_num_icu_beds_occ) end |
#cvd_num_icu_beds_occ=(value) ⇒ Object
numicubedsocc - ICU BED OCCUPANCY: Total number of staffed inpatient ICU beds that are occupied.
312 313 314 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 312 def cvd_num_icu_beds_occ=(value) write_property(:cvd_num_icu_beds_occ, value) end |
#cvd_num_tot_beds ⇒ Object
numtotbeds - ALL HOSPITAL BEDS: Total number of all inpatient and outpatient beds, including all staffed, ICU, licensed, and overflow (surge) beds used for inpatients or outpatients.
317 318 319 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 317 def cvd_num_tot_beds read_property(:cvd_num_tot_beds) end |
#cvd_num_tot_beds=(value) ⇒ Object
numtotbeds - ALL HOSPITAL BEDS: Total number of all inpatient and outpatient beds, including all staffed, ICU, licensed, and overflow (surge) beds used for inpatients or outpatients.
322 323 324 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 322 def cvd_num_tot_beds=(value) write_property(:cvd_num_tot_beds, value) end |
#cvd_num_vent ⇒ Object
numvent - MECHANICAL VENTILATORS: Total number of ventilators available.
327 328 329 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 327 def cvd_num_vent read_property(:cvd_num_vent) end |
#cvd_num_vent=(value) ⇒ Object
numvent - MECHANICAL VENTILATORS: Total number of ventilators available.
332 333 334 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 332 def cvd_num_vent=(value) write_property(:cvd_num_vent, value) end |
#cvd_num_vent_use ⇒ Object
numventuse - MECHANICAL VENTILATORS IN USE: Total number of ventilators in use.
337 338 339 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 337 def cvd_num_vent_use read_property(:cvd_num_vent_use) end |
#cvd_num_vent_use=(value) ⇒ Object
numventuse - MECHANICAL VENTILATORS IN USE: Total number of ventilators in use.
342 343 344 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 342 def cvd_num_vent_use=(value) write_property(:cvd_num_vent_use, value) end |
#date_posted ⇒ Object
Publication date of an online listing.
347 348 349 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 347 def date_posted read_property(:date_posted) end |
#date_posted=(value) ⇒ Object
Publication date of an online listing.
352 353 354 |
# File 'lib/schema_org/mixins/cdcpmd_record.rb', line 352 def date_posted=(value) write_property(:date_posted, value) end |