Module: SchemaOrg::Mixins::CategoryCode
- Includes:
- DefinedTerm
- Included in:
- CategoryCode, MedicalCode
- Defined in:
- lib/schema_org/mixins/category_code.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#code_value ⇒ Object
A short textual code that uniquely identifies the value.
-
#code_value=(value) ⇒ Object
A short textual code that uniquely identifies the value.
-
#in_code_set ⇒ Object
A [[CategoryCodeSet]] that contains this category code.
-
#in_code_set=(value) ⇒ Object
A [[CategoryCodeSet]] that contains this category code.
Methods included from DefinedTerm
#about, #about=, #in_defined_term_set, #in_defined_term_set=, #term_code, #term_code=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/schema_org/mixins/category_code.rb', line 11 def self.schema_property_definitions { code_value: { schema_name: "codeValue", schema_url: "https://schema.org/codeValue", comment_lines: ["A short textual code that uniquely identifies the value."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, in_code_set: { schema_name: "inCodeSet", schema_url: "https://schema.org/inCodeSet", comment_lines: ["A [[CategoryCodeSet]] that contains this category code."].freeze, ranges: ["CategoryCodeSet", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#code_value ⇒ Object
A short textual code that uniquely identifies the value.
37 38 39 |
# File 'lib/schema_org/mixins/category_code.rb', line 37 def code_value read_property(:code_value) end |
#code_value=(value) ⇒ Object
A short textual code that uniquely identifies the value.
42 43 44 |
# File 'lib/schema_org/mixins/category_code.rb', line 42 def code_value=(value) write_property(:code_value, value) end |
#in_code_set ⇒ Object
A [[CategoryCodeSet]] that contains this category code.
47 48 49 |
# File 'lib/schema_org/mixins/category_code.rb', line 47 def in_code_set read_property(:in_code_set) end |
#in_code_set=(value) ⇒ Object
A [[CategoryCodeSet]] that contains this category code.
52 53 54 |
# File 'lib/schema_org/mixins/category_code.rb', line 52 def in_code_set=(value) write_property(:in_code_set, value) end |