Module: SchemaOrg::Mixins::ChemicalSubstance
- Includes:
- BioChemEntity
- Included in:
- ChemicalSubstance
- Defined in:
- lib/schema_org/mixins/chemical_substance.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#chemical_composition ⇒ Object
The chemical composition describes the identity and relative ratio of the chemical elements that make up the substance.
-
#chemical_composition=(value) ⇒ Object
The chemical composition describes the identity and relative ratio of the chemical elements that make up the substance.
-
#chemical_role ⇒ Object
A role played by the BioChemEntity within a chemical context.
-
#chemical_role=(value) ⇒ Object
A role played by the BioChemEntity within a chemical context.
-
#potential_use ⇒ Object
Intended use of the BioChemEntity by humans.
-
#potential_use=(value) ⇒ Object
Intended use of the BioChemEntity by humans.
Methods included from BioChemEntity
#associated_disease, #associated_disease=, #bio_chem_interaction, #bio_chem_interaction=, #bio_chem_similarity, #bio_chem_similarity=, #biological_role, #biological_role=, #funding, #funding=, #has_bio_chem_entity_part, #has_bio_chem_entity_part=, #has_molecular_function, #has_molecular_function=, #has_representation, #has_representation=, #is_encoded_by_bio_chem_entity, #is_encoded_by_bio_chem_entity=, #is_involved_in_biological_process, #is_involved_in_biological_process=, #is_located_in_subcellular_location, #is_located_in_subcellular_location=, #is_part_of_bio_chem_entity, #is_part_of_bio_chem_entity=, #taxonomic_range, #taxonomic_range=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/schema_org/mixins/chemical_substance.rb', line 11 def self.schema_property_definitions { chemical_composition: { schema_name: "chemicalComposition", schema_url: "https://schema.org/chemicalComposition", comment_lines: ["The chemical composition describes the identity and relative ratio of the chemical elements that make up the substance."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, chemical_role: { schema_name: "chemicalRole", schema_url: "https://schema.org/chemicalRole", comment_lines: ["A role played by the BioChemEntity within a chemical context."].freeze, ranges: ["DefinedTerm"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, potential_use: { schema_name: "potentialUse", schema_url: "https://schema.org/potentialUse", comment_lines: ["Intended use of the BioChemEntity by humans."].freeze, ranges: ["DefinedTerm"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#chemical_composition ⇒ Object
The chemical composition describes the identity and relative ratio of the chemical elements that make up the substance.
47 48 49 |
# File 'lib/schema_org/mixins/chemical_substance.rb', line 47 def chemical_composition read_property(:chemical_composition) end |
#chemical_composition=(value) ⇒ Object
The chemical composition describes the identity and relative ratio of the chemical elements that make up the substance.
52 53 54 |
# File 'lib/schema_org/mixins/chemical_substance.rb', line 52 def chemical_composition=(value) write_property(:chemical_composition, value) end |
#chemical_role ⇒ Object
A role played by the BioChemEntity within a chemical context.
57 58 59 |
# File 'lib/schema_org/mixins/chemical_substance.rb', line 57 def chemical_role read_property(:chemical_role) end |
#chemical_role=(value) ⇒ Object
A role played by the BioChemEntity within a chemical context.
62 63 64 |
# File 'lib/schema_org/mixins/chemical_substance.rb', line 62 def chemical_role=(value) write_property(:chemical_role, value) end |
#potential_use ⇒ Object
Intended use of the BioChemEntity by humans.
67 68 69 |
# File 'lib/schema_org/mixins/chemical_substance.rb', line 67 def potential_use read_property(:potential_use) end |
#potential_use=(value) ⇒ Object
Intended use of the BioChemEntity by humans.
72 73 74 |
# File 'lib/schema_org/mixins/chemical_substance.rb', line 72 def potential_use=(value) write_property(:potential_use, value) end |