Module: SchemaOrg::Mixins::ComicIssue
Class Method Summary collapse
Instance Method Summary collapse
-
#artist ⇒ Object
The primary artist for a work in a medium other than pencils or digital line art--for example, if the primary artwork is done in watercolors or digital paints.
-
#artist=(value) ⇒ Object
The primary artist for a work in a medium other than pencils or digital line art--for example, if the primary artwork is done in watercolors or digital paints.
-
#colorist ⇒ Object
The individual who adds color to inked drawings.
-
#colorist=(value) ⇒ Object
The individual who adds color to inked drawings.
-
#inker ⇒ Object
The individual who traces over the pencil drawings in ink after pencils are complete.
-
#inker=(value) ⇒ Object
The individual who traces over the pencil drawings in ink after pencils are complete.
-
#letterer ⇒ Object
The individual who adds lettering, including speech balloons and sound effects, to artwork.
-
#letterer=(value) ⇒ Object
The individual who adds lettering, including speech balloons and sound effects, to artwork.
-
#penciler ⇒ Object
The individual who draws the primary narrative artwork.
-
#penciler=(value) ⇒ Object
The individual who draws the primary narrative artwork.
-
#variant_cover ⇒ Object
A description of the variant cover for the issue, if the issue is a variant printing.
-
#variant_cover=(value) ⇒ Object
A description of the variant cover for the issue, if the issue is a variant printing.
Methods included from PublicationIssue
#issue_number, #issue_number=, #page_end, #page_end=, #page_start, #page_start=, #pagination, #pagination=
Methods included from CreativeWork
#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/schema_org/mixins/comic_issue.rb', line 11 def self.schema_property_definitions { artist: { schema_name: "artist", schema_url: "https://schema.org/artist", comment_lines: ["The primary artist for a work", " \tin a medium other than pencils or digital line art--for example, if the", " \tprimary artwork is done in watercolors or digital paints."].freeze, ranges: ["Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, colorist: { schema_name: "colorist", schema_url: "https://schema.org/colorist", comment_lines: ["The individual who adds color to inked drawings."].freeze, ranges: ["Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, inker: { schema_name: "inker", schema_url: "https://schema.org/inker", comment_lines: ["The individual who traces over the pencil drawings in ink after pencils are complete."].freeze, ranges: ["Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, letterer: { schema_name: "letterer", schema_url: "https://schema.org/letterer", comment_lines: ["The individual who adds lettering, including speech balloons and sound effects, to artwork."].freeze, ranges: ["Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, penciler: { schema_name: "penciler", schema_url: "https://schema.org/penciler", comment_lines: ["The individual who draws the primary narrative artwork."].freeze, ranges: ["Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, variant_cover: { schema_name: "variantCover", schema_url: "https://schema.org/variantCover", comment_lines: ["A description of the variant cover", " \tfor the issue, if the issue is a variant printing. For example, \"Bryan Hitch", " \tVariant Cover\" or \"2nd Printing Variant\"."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#artist ⇒ Object
The primary artist for a work in a medium other than pencils or digital line art--for example, if the primary artwork is done in watercolors or digital paints.
79 80 81 |
# File 'lib/schema_org/mixins/comic_issue.rb', line 79 def artist read_property(:artist) end |
#artist=(value) ⇒ Object
The primary artist for a work in a medium other than pencils or digital line art--for example, if the primary artwork is done in watercolors or digital paints.
86 87 88 |
# File 'lib/schema_org/mixins/comic_issue.rb', line 86 def artist=(value) write_property(:artist, value) end |
#colorist ⇒ Object
The individual who adds color to inked drawings.
91 92 93 |
# File 'lib/schema_org/mixins/comic_issue.rb', line 91 def colorist read_property(:colorist) end |
#colorist=(value) ⇒ Object
The individual who adds color to inked drawings.
96 97 98 |
# File 'lib/schema_org/mixins/comic_issue.rb', line 96 def colorist=(value) write_property(:colorist, value) end |
#inker ⇒ Object
The individual who traces over the pencil drawings in ink after pencils are complete.
101 102 103 |
# File 'lib/schema_org/mixins/comic_issue.rb', line 101 def inker read_property(:inker) end |
#inker=(value) ⇒ Object
The individual who traces over the pencil drawings in ink after pencils are complete.
106 107 108 |
# File 'lib/schema_org/mixins/comic_issue.rb', line 106 def inker=(value) write_property(:inker, value) end |
#letterer ⇒ Object
The individual who adds lettering, including speech balloons and sound effects, to artwork.
111 112 113 |
# File 'lib/schema_org/mixins/comic_issue.rb', line 111 def letterer read_property(:letterer) end |
#letterer=(value) ⇒ Object
The individual who adds lettering, including speech balloons and sound effects, to artwork.
116 117 118 |
# File 'lib/schema_org/mixins/comic_issue.rb', line 116 def letterer=(value) write_property(:letterer, value) end |
#penciler ⇒ Object
The individual who draws the primary narrative artwork.
121 122 123 |
# File 'lib/schema_org/mixins/comic_issue.rb', line 121 def penciler read_property(:penciler) end |
#penciler=(value) ⇒ Object
The individual who draws the primary narrative artwork.
126 127 128 |
# File 'lib/schema_org/mixins/comic_issue.rb', line 126 def penciler=(value) write_property(:penciler, value) end |
#variant_cover ⇒ Object
A description of the variant cover for the issue, if the issue is a variant printing. For example, "Bryan Hitch Variant Cover" or "2nd Printing Variant".
133 134 135 |
# File 'lib/schema_org/mixins/comic_issue.rb', line 133 def variant_cover read_property(:variant_cover) end |
#variant_cover=(value) ⇒ Object
A description of the variant cover for the issue, if the issue is a variant printing. For example, "Bryan Hitch Variant Cover" or "2nd Printing Variant".
140 141 142 |
# File 'lib/schema_org/mixins/comic_issue.rb', line 140 def variant_cover=(value) write_property(:variant_cover, value) end |