Module: SchemaOrg::Mixins::ConsumeAction
- Includes:
- Action
- Included in:
- ConsumeAction, DrinkAction, EatAction, InstallAction, ListenAction, PlayGameAction, ReadAction, UseAction, ViewAction, WatchAction
- Defined in:
- lib/schema_org/mixins/consume_action.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#action_accessibility_requirement ⇒ Object
A set of requirements that must be fulfilled in order to perform an Action.
-
#action_accessibility_requirement=(value) ⇒ Object
A set of requirements that must be fulfilled in order to perform an Action.
-
#expects_acceptance_of ⇒ Object
An Offer which must be accepted before the user can perform the Action.
-
#expects_acceptance_of=(value) ⇒ Object
An Offer which must be accepted before the user can perform the Action.
Methods included from Action
#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, #start_time, #start_time=, #target, #target=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/schema_org/mixins/consume_action.rb', line 11 def self.schema_property_definitions { action_accessibility_requirement: { schema_name: "actionAccessibilityRequirement", schema_url: "https://schema.org/actionAccessibilityRequirement", comment_lines: ["A set of requirements that must be fulfilled in order to perform an Action. If more than one value is specified, fulfilling one set of requirements will allow the Action to be performed."].freeze, ranges: ["ActionAccessSpecification"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, expects_acceptance_of: { schema_name: "expectsAcceptanceOf", schema_url: "https://schema.org/expectsAcceptanceOf", comment_lines: ["An Offer which must be accepted before the user can perform the Action. For example, the user may need to buy a movie before being able to watch it."].freeze, ranges: ["Offer"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#action_accessibility_requirement ⇒ Object
A set of requirements that must be fulfilled in order to perform an Action. If more than one value is specified, fulfilling one set of requirements will allow the Action to be performed.
37 38 39 |
# File 'lib/schema_org/mixins/consume_action.rb', line 37 def action_accessibility_requirement read_property(:action_accessibility_requirement) end |
#action_accessibility_requirement=(value) ⇒ Object
A set of requirements that must be fulfilled in order to perform an Action. If more than one value is specified, fulfilling one set of requirements will allow the Action to be performed.
42 43 44 |
# File 'lib/schema_org/mixins/consume_action.rb', line 42 def action_accessibility_requirement=(value) write_property(:action_accessibility_requirement, value) end |
#expects_acceptance_of ⇒ Object
An Offer which must be accepted before the user can perform the Action. For example, the user may need to buy a movie before being able to watch it.
47 48 49 |
# File 'lib/schema_org/mixins/consume_action.rb', line 47 def expects_acceptance_of read_property(:expects_acceptance_of) end |
#expects_acceptance_of=(value) ⇒ Object
An Offer which must be accepted before the user can perform the Action. For example, the user may need to buy a movie before being able to watch it.
52 53 54 |
# File 'lib/schema_org/mixins/consume_action.rb', line 52 def expects_acceptance_of=(value) write_property(:expects_acceptance_of, value) end |