Module: SchemaOrg::Mixins::CourseInstance
Class Method Summary collapse
Instance Method Summary collapse
-
#course_mode ⇒ Object
The medium or means of delivery of the course instance or the mode of study, either as a text label (e.g. "online", "onsite" or "blended"; "synchronous" or "asynchronous"; "full-time" or "part-time") or as a URL reference to a term from a controlled vocabulary (e.g. https://ceds.ed.gov/element/001311#Asynchronous).
-
#course_mode=(value) ⇒ Object
The medium or means of delivery of the course instance or the mode of study, either as a text label (e.g. "online", "onsite" or "blended"; "synchronous" or "asynchronous"; "full-time" or "part-time") or as a URL reference to a term from a controlled vocabulary (e.g. https://ceds.ed.gov/element/001311#Asynchronous).
-
#course_schedule ⇒ Object
Represents the length and pace of a course, expressed as a [[Schedule]].
-
#course_schedule=(value) ⇒ Object
Represents the length and pace of a course, expressed as a [[Schedule]].
-
#course_workload ⇒ Object
The amount of work expected of students taking the course, often provided as a figure per week or per month, and may be broken down by type.
-
#course_workload=(value) ⇒ Object
The amount of work expected of students taking the course, often provided as a figure per week or per month, and may be broken down by type.
-
#instructor ⇒ Object
A person assigned to instruct or provide instructional assistance for the [[CourseInstance]].
-
#instructor=(value) ⇒ Object
A person assigned to instruct or provide instructional assistance for the [[CourseInstance]].
Methods included from Event
#about, #about=, #actor, #actor=, #aggregate_rating, #aggregate_rating=, #attendee, #attendee=, #attendees, #attendees=, #audience, #audience=, #composer, #composer=, #contributor, #contributor=, #director, #director=, #door_time, #door_time=, #duration, #duration=, #end_date, #end_date=, #event_attendance_mode, #event_attendance_mode=, #event_schedule, #event_schedule=, #event_status, #event_status=, #funder, #funder=, #funding, #funding=, #has_participation_offer, #has_participation_offer=, #has_sponsorship_offer, #has_sponsorship_offer=, #in_language, #in_language=, #is_accessible_for_free, #is_accessible_for_free=, #keywords, #keywords=, #location, #location=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #maximum_physical_attendee_capacity, #maximum_physical_attendee_capacity=, #maximum_virtual_attendee_capacity, #maximum_virtual_attendee_capacity=, #offers, #offers=, #organizer, #organizer=, #performer, #performer=, #performers, #performers=, #previous_start_date, #previous_start_date=, #recorded_in, #recorded_in=, #remaining_attendee_capacity, #remaining_attendee_capacity=, #review, #review=, #sponsor, #sponsor=, #start_date, #start_date=, #sub_event, #sub_event=, #sub_events, #sub_events=, #super_event, #super_event=, #translator, #translator=, #typical_age_range, #typical_age_range=, #work_featured, #work_featured=, #work_performed, #work_performed=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/schema_org/mixins/course_instance.rb', line 11 def self.schema_property_definitions { course_mode: { schema_name: "courseMode", schema_url: "https://schema.org/courseMode", comment_lines: ["The medium or means of delivery of the course instance or the mode of study, either as a text label (e.g. \"online\", \"onsite\" or \"blended\"; \"synchronous\" or \"asynchronous\"; \"full-time\" or \"part-time\") or as a URL reference to a term from a controlled vocabulary (e.g. https://ceds.ed.gov/element/001311#Asynchronous)."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, course_schedule: { schema_name: "courseSchedule", schema_url: "https://schema.org/courseSchedule", comment_lines: ["Represents the length and pace of a course, expressed as a [[Schedule]]."].freeze, ranges: ["Schedule"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, course_workload: { schema_name: "courseWorkload", schema_url: "https://schema.org/courseWorkload", comment_lines: ["The amount of work expected of students taking the course, often provided as a figure per week or per month, and may be broken down by type. For example, \"2 hours of lectures, 1 hour of lab work and 3 hours of independent study per week\"."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, instructor: { schema_name: "instructor", schema_url: "https://schema.org/instructor", comment_lines: ["A person assigned to instruct or provide instructional assistance for the [[CourseInstance]]."].freeze, ranges: ["Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#course_mode ⇒ Object
The medium or means of delivery of the course instance or the mode of study, either as a text label (e.g. "online", "onsite" or "blended"; "synchronous" or "asynchronous"; "full-time" or "part-time") or as a URL reference to a term from a controlled vocabulary (e.g. https://ceds.ed.gov/element/001311#Asynchronous).
57 58 59 |
# File 'lib/schema_org/mixins/course_instance.rb', line 57 def course_mode read_property(:course_mode) end |
#course_mode=(value) ⇒ Object
The medium or means of delivery of the course instance or the mode of study, either as a text label (e.g. "online", "onsite" or "blended"; "synchronous" or "asynchronous"; "full-time" or "part-time") or as a URL reference to a term from a controlled vocabulary (e.g. https://ceds.ed.gov/element/001311#Asynchronous).
62 63 64 |
# File 'lib/schema_org/mixins/course_instance.rb', line 62 def course_mode=(value) write_property(:course_mode, value) end |
#course_schedule ⇒ Object
Represents the length and pace of a course, expressed as a [[Schedule]].
67 68 69 |
# File 'lib/schema_org/mixins/course_instance.rb', line 67 def course_schedule read_property(:course_schedule) end |
#course_schedule=(value) ⇒ Object
Represents the length and pace of a course, expressed as a [[Schedule]].
72 73 74 |
# File 'lib/schema_org/mixins/course_instance.rb', line 72 def course_schedule=(value) write_property(:course_schedule, value) end |
#course_workload ⇒ Object
The amount of work expected of students taking the course, often provided as a figure per week or per month, and may be broken down by type. For example, "2 hours of lectures, 1 hour of lab work and 3 hours of independent study per week".
77 78 79 |
# File 'lib/schema_org/mixins/course_instance.rb', line 77 def course_workload read_property(:course_workload) end |
#course_workload=(value) ⇒ Object
The amount of work expected of students taking the course, often provided as a figure per week or per month, and may be broken down by type. For example, "2 hours of lectures, 1 hour of lab work and 3 hours of independent study per week".
82 83 84 |
# File 'lib/schema_org/mixins/course_instance.rb', line 82 def course_workload=(value) write_property(:course_workload, value) end |
#instructor ⇒ Object
A person assigned to instruct or provide instructional assistance for the [[CourseInstance]].
87 88 89 |
# File 'lib/schema_org/mixins/course_instance.rb', line 87 def instructor read_property(:instructor) end |
#instructor=(value) ⇒ Object
A person assigned to instruct or provide instructional assistance for the [[CourseInstance]].
92 93 94 |
# File 'lib/schema_org/mixins/course_instance.rb', line 92 def instructor=(value) write_property(:instructor, value) end |