Module: SchemaOrg::Mixins::DDxElement
- Includes:
- MedicalIntangible
- Included in:
- DDxElement
- Defined in:
- lib/schema_org/mixins/d_dx_element.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#diagnosis ⇒ Object
One or more alternative conditions considered in the differential diagnosis process as output of a diagnosis process.
-
#diagnosis=(value) ⇒ Object
One or more alternative conditions considered in the differential diagnosis process as output of a diagnosis process.
-
#distinguishing_sign ⇒ Object
One of a set of signs and symptoms that can be used to distinguish this diagnosis from others in the differential diagnosis.
-
#distinguishing_sign=(value) ⇒ Object
One of a set of signs and symptoms that can be used to distinguish this diagnosis from others in the differential diagnosis.
Methods included from MedicalEntity
#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/schema_org/mixins/d_dx_element.rb', line 11 def self.schema_property_definitions { diagnosis: { schema_name: "diagnosis", schema_url: "https://schema.org/diagnosis", comment_lines: ["One or more alternative conditions considered in the differential diagnosis process as output of a diagnosis process."].freeze, ranges: ["MedicalCondition"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, distinguishing_sign: { schema_name: "distinguishingSign", schema_url: "https://schema.org/distinguishingSign", comment_lines: ["One of a set of signs and symptoms that can be used to distinguish this diagnosis from others in the differential diagnosis."].freeze, ranges: ["MedicalSignOrSymptom"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#diagnosis ⇒ Object
One or more alternative conditions considered in the differential diagnosis process as output of a diagnosis process.
37 38 39 |
# File 'lib/schema_org/mixins/d_dx_element.rb', line 37 def diagnosis read_property(:diagnosis) end |
#diagnosis=(value) ⇒ Object
One or more alternative conditions considered in the differential diagnosis process as output of a diagnosis process.
42 43 44 |
# File 'lib/schema_org/mixins/d_dx_element.rb', line 42 def diagnosis=(value) write_property(:diagnosis, value) end |
#distinguishing_sign ⇒ Object
One of a set of signs and symptoms that can be used to distinguish this diagnosis from others in the differential diagnosis.
47 48 49 |
# File 'lib/schema_org/mixins/d_dx_element.rb', line 47 def distinguishing_sign read_property(:distinguishing_sign) end |
#distinguishing_sign=(value) ⇒ Object
One of a set of signs and symptoms that can be used to distinguish this diagnosis from others in the differential diagnosis.
52 53 54 |
# File 'lib/schema_org/mixins/d_dx_element.rb', line 52 def distinguishing_sign=(value) write_property(:distinguishing_sign, value) end |