Module: SchemaOrg::Mixins::DataFeedItem
Class Method Summary collapse
Instance Method Summary collapse
-
#date_created ⇒ Object
The date on which the CreativeWork was created or the item was added to a DataFeed.
-
#date_created=(value) ⇒ Object
The date on which the CreativeWork was created or the item was added to a DataFeed.
-
#date_deleted ⇒ Object
The datetime the item was removed from the DataFeed.
-
#date_deleted=(value) ⇒ Object
The datetime the item was removed from the DataFeed.
-
#date_modified ⇒ Object
The date on which the CreativeWork was most recently modified or when the item's entry was modified within a DataFeed.
-
#date_modified=(value) ⇒ Object
The date on which the CreativeWork was most recently modified or when the item's entry was modified within a DataFeed.
-
#item ⇒ Object
An entity represented by an entry in a list or data feed (e.g. an 'artist' in a list of 'artists').
-
#item=(value) ⇒ Object
An entity represented by an entry in a list or data feed (e.g. an 'artist' in a list of 'artists').
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/schema_org/mixins/data_feed_item.rb', line 11 def self.schema_property_definitions { date_created: { schema_name: "dateCreated", schema_url: "https://schema.org/dateCreated", comment_lines: ["The date on which the CreativeWork was created or the item was added to a DataFeed."].freeze, ranges: ["Date", "DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, date_deleted: { schema_name: "dateDeleted", schema_url: "https://schema.org/dateDeleted", comment_lines: ["The datetime the item was removed from the DataFeed."].freeze, ranges: ["Date", "DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, date_modified: { schema_name: "dateModified", schema_url: "https://schema.org/dateModified", comment_lines: ["The date on which the CreativeWork was most recently modified or when the item's entry was modified within a DataFeed."].freeze, ranges: ["Date", "DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, item: { schema_name: "item", schema_url: "https://schema.org/item", comment_lines: ["An entity represented by an entry in a list or data feed (e.g. an 'artist' in a list of 'artists')."].freeze, ranges: ["Thing"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#date_created ⇒ Object
The date on which the CreativeWork was created or the item was added to a DataFeed.
57 58 59 |
# File 'lib/schema_org/mixins/data_feed_item.rb', line 57 def date_created read_property(:date_created) end |
#date_created=(value) ⇒ Object
The date on which the CreativeWork was created or the item was added to a DataFeed.
62 63 64 |
# File 'lib/schema_org/mixins/data_feed_item.rb', line 62 def date_created=(value) write_property(:date_created, value) end |
#date_deleted ⇒ Object
The datetime the item was removed from the DataFeed.
67 68 69 |
# File 'lib/schema_org/mixins/data_feed_item.rb', line 67 def date_deleted read_property(:date_deleted) end |
#date_deleted=(value) ⇒ Object
The datetime the item was removed from the DataFeed.
72 73 74 |
# File 'lib/schema_org/mixins/data_feed_item.rb', line 72 def date_deleted=(value) write_property(:date_deleted, value) end |
#date_modified ⇒ Object
The date on which the CreativeWork was most recently modified or when the item's entry was modified within a DataFeed.
77 78 79 |
# File 'lib/schema_org/mixins/data_feed_item.rb', line 77 def date_modified read_property(:date_modified) end |
#date_modified=(value) ⇒ Object
The date on which the CreativeWork was most recently modified or when the item's entry was modified within a DataFeed.
82 83 84 |
# File 'lib/schema_org/mixins/data_feed_item.rb', line 82 def date_modified=(value) write_property(:date_modified, value) end |
#item ⇒ Object
An entity represented by an entry in a list or data feed (e.g. an 'artist' in a list of 'artists').
87 88 89 |
# File 'lib/schema_org/mixins/data_feed_item.rb', line 87 def item read_property(:item) end |
#item=(value) ⇒ Object
An entity represented by an entry in a list or data feed (e.g. an 'artist' in a list of 'artists').
92 93 94 |
# File 'lib/schema_org/mixins/data_feed_item.rb', line 92 def item=(value) write_property(:item, value) end |