Module: SchemaOrg::Mixins::Dataset
Class Method Summary collapse
Instance Method Summary collapse
-
#catalog ⇒ Object
A data catalog which contains this dataset.
-
#catalog=(value) ⇒ Object
A data catalog which contains this dataset.
-
#dataset_time_interval ⇒ Object
The range of temporal applicability of a dataset, e.g.
-
#dataset_time_interval=(value) ⇒ Object
The range of temporal applicability of a dataset, e.g.
-
#distribution ⇒ Object
A downloadable form of this dataset, at a specific location, in a specific format.
-
#distribution=(value) ⇒ Object
A downloadable form of this dataset, at a specific location, in a specific format.
-
#included_data_catalog ⇒ Object
A data catalog which contains this dataset (this property was previously 'catalog', preferred name is now 'includedInDataCatalog').
-
#included_data_catalog=(value) ⇒ Object
A data catalog which contains this dataset (this property was previously 'catalog', preferred name is now 'includedInDataCatalog').
-
#included_in_data_catalog ⇒ Object
A data catalog which contains this dataset.
-
#included_in_data_catalog=(value) ⇒ Object
A data catalog which contains this dataset.
-
#issn ⇒ Object
The International Standard Serial Number (ISSN) that identifies this serial publication.
-
#issn=(value) ⇒ Object
The International Standard Serial Number (ISSN) that identifies this serial publication.
-
#measurement_method ⇒ Object
A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].
-
#measurement_method=(value) ⇒ Object
A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].
-
#measurement_technique ⇒ Object
A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]).
-
#measurement_technique=(value) ⇒ Object
A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]).
-
#variable_measured ⇒ Object
The variableMeasured property can indicate (repeated as necessary) the variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue, or more explicitly as a [[StatisticalVariable]].
-
#variable_measured=(value) ⇒ Object
The variableMeasured property can indicate (repeated as necessary) the variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue, or more explicitly as a [[StatisticalVariable]].
-
#variables_measured ⇒ Object
Originally named [[variablesMeasured]], the [[variableMeasured]] property can indicate (repeated as necessary) the variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue.
-
#variables_measured=(value) ⇒ Object
Originally named [[variablesMeasured]], the [[variableMeasured]] property can indicate (repeated as necessary) the variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue.
Methods included from CreativeWork
#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/schema_org/mixins/dataset.rb', line 11 def self.schema_property_definitions { catalog: { schema_name: "catalog", schema_url: "https://schema.org/catalog", comment_lines: ["A data catalog which contains this dataset."].freeze, ranges: ["DataCatalog"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "includedInDataCatalog", supersedes: nil }.freeze, dataset_time_interval: { schema_name: "datasetTimeInterval", schema_url: "https://schema.org/datasetTimeInterval", comment_lines: ["The range of temporal applicability of a dataset, e.g. for a 2011 census dataset, the year 2011 (in ISO 8601 time interval format)."].freeze, ranges: ["DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "temporalCoverage", supersedes: nil }.freeze, distribution: { schema_name: "distribution", schema_url: "https://schema.org/distribution", comment_lines: ["A downloadable form of this dataset, at a specific location, in a specific format. This property can be repeated if different variations are available. There is no expectation that different downloadable distributions must contain exactly equivalent information (see also [DCAT](https://www.w3.org/TR/vocab-dcat-3/#Class:Distribution) on this point). Different distributions might include or exclude different subsets of the entire dataset, for example."].freeze, ranges: ["DataDownload"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, included_data_catalog: { schema_name: "includedDataCatalog", schema_url: "https://schema.org/includedDataCatalog", comment_lines: ["A data catalog which contains this dataset (this property was previously 'catalog', preferred name is now 'includedInDataCatalog')."].freeze, ranges: ["DataCatalog"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "includedInDataCatalog", supersedes: nil }.freeze, included_in_data_catalog: { schema_name: "includedInDataCatalog", schema_url: "https://schema.org/includedInDataCatalog", comment_lines: ["A data catalog which contains this dataset."].freeze, ranges: ["DataCatalog"].freeze, external_ranges: [].freeze, inverse_of: "dataset", superseded_by: nil, supersedes: ["catalog", "includedDataCatalog"].freeze }.freeze, issn: { schema_name: "issn", schema_url: "https://schema.org/issn", comment_lines: ["The International Standard Serial Number (ISSN) that identifies this serial publication. You can repeat this property to identify different formats of, or the linking ISSN (ISSN-L) for, this serial publication."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, measurement_method: { schema_name: "measurementMethod", schema_url: "https://schema.org/measurementMethod", comment_lines: ["A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]]."].freeze, ranges: ["DefinedTerm", "MeasurementMethodEnum", "Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, measurement_technique: { schema_name: "measurementTechnique", schema_url: "https://schema.org/measurementTechnique", comment_lines: ["A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]). Often but not necessarily each [[variableMeasured]] will have an explicit representation as (or mapping to) an property such as those defined in Schema.org, or other RDF vocabularies and \"knowledge graphs\". In that case the subproperty of [[variableMeasured]] called [[measuredProperty]] is applicable.", "", "The [[measurementTechnique]] property helps when extra clarification is needed about how a [[measuredProperty]] was measured. This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but can often serve as a high level summary for dataset discovery.", "", "For example, if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]] could be: \"mass spectrometry\" or \"nmr spectroscopy\" or \"colorimetry\" or \"immunofluorescence\". If the [[variableMeasured]] is \"depression rating\", the [[measurementTechnique]] could be \"Zung Scale\" or \"HAM-D\" or \"Beck Depression Inventory\".", "", "If there are several [[variableMeasured]] properties recorded for some given data object, use a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]]. The value can also be from an enumeration, organized as a [[MeasurementMethodEnum]]."].freeze, ranges: ["DefinedTerm", "MeasurementMethodEnum", "Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, variable_measured: { schema_name: "variableMeasured", schema_url: "https://schema.org/variableMeasured", comment_lines: ["The variableMeasured property can indicate (repeated as necessary) the variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue, or more explicitly as a [[StatisticalVariable]]."].freeze, ranges: ["PropertyValue", "StatisticalVariable", "Text"].freeze, external_ranges: ["Property"].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, variables_measured: { schema_name: "variablesMeasured", schema_url: "https://schema.org/variablesMeasured", comment_lines: ["Originally named [[variablesMeasured]], the [[variableMeasured]] property can indicate (repeated as necessary) the variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue."].freeze, ranges: ["PropertyValue", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#catalog ⇒ Object
A data catalog which contains this dataset.
Superseded by includedInDataCatalog.
118 119 120 |
# File 'lib/schema_org/mixins/dataset.rb', line 118 def catalog read_property(:catalog) end |
#catalog=(value) ⇒ Object
A data catalog which contains this dataset.
Superseded by includedInDataCatalog.
124 125 126 |
# File 'lib/schema_org/mixins/dataset.rb', line 124 def catalog=(value) write_property(:catalog, value) end |
#dataset_time_interval ⇒ Object
The range of temporal applicability of a dataset, e.g. for a 2011 census dataset, the year 2011 (in ISO 8601 time interval format).
Superseded by temporalCoverage.
130 131 132 |
# File 'lib/schema_org/mixins/dataset.rb', line 130 def dataset_time_interval read_property(:dataset_time_interval) end |
#dataset_time_interval=(value) ⇒ Object
The range of temporal applicability of a dataset, e.g. for a 2011 census dataset, the year 2011 (in ISO 8601 time interval format).
Superseded by temporalCoverage.
136 137 138 |
# File 'lib/schema_org/mixins/dataset.rb', line 136 def dataset_time_interval=(value) write_property(:dataset_time_interval, value) end |
#distribution ⇒ Object
A downloadable form of this dataset, at a specific location, in a specific format. This property can be repeated if different variations are available. There is no expectation that different downloadable distributions must contain exactly equivalent information (see also DCAT on this point). Different distributions might include or exclude different subsets of the entire dataset, for example.
141 142 143 |
# File 'lib/schema_org/mixins/dataset.rb', line 141 def distribution read_property(:distribution) end |
#distribution=(value) ⇒ Object
A downloadable form of this dataset, at a specific location, in a specific format. This property can be repeated if different variations are available. There is no expectation that different downloadable distributions must contain exactly equivalent information (see also DCAT on this point). Different distributions might include or exclude different subsets of the entire dataset, for example.
146 147 148 |
# File 'lib/schema_org/mixins/dataset.rb', line 146 def distribution=(value) write_property(:distribution, value) end |
#included_data_catalog ⇒ Object
A data catalog which contains this dataset (this property was previously 'catalog', preferred name is now 'includedInDataCatalog').
Superseded by includedInDataCatalog.
152 153 154 |
# File 'lib/schema_org/mixins/dataset.rb', line 152 def included_data_catalog read_property(:included_data_catalog) end |
#included_data_catalog=(value) ⇒ Object
A data catalog which contains this dataset (this property was previously 'catalog', preferred name is now 'includedInDataCatalog').
Superseded by includedInDataCatalog.
158 159 160 |
# File 'lib/schema_org/mixins/dataset.rb', line 158 def included_data_catalog=(value) write_property(:included_data_catalog, value) end |
#included_in_data_catalog ⇒ Object
A data catalog which contains this dataset.
Supersedes catalog.
Supersedes includedDataCatalog.
Inverse-property: dataset.
166 167 168 |
# File 'lib/schema_org/mixins/dataset.rb', line 166 def included_in_data_catalog read_property(:included_in_data_catalog) end |
#included_in_data_catalog=(value) ⇒ Object
A data catalog which contains this dataset.
Supersedes catalog.
Supersedes includedDataCatalog.
Inverse-property: dataset.
174 175 176 |
# File 'lib/schema_org/mixins/dataset.rb', line 174 def included_in_data_catalog=(value) write_property(:included_in_data_catalog, value) end |
#issn ⇒ Object
The International Standard Serial Number (ISSN) that identifies this serial publication. You can repeat this property to identify different formats of, or the linking ISSN (ISSN-L) for, this serial publication.
179 180 181 |
# File 'lib/schema_org/mixins/dataset.rb', line 179 def issn read_property(:issn) end |
#issn=(value) ⇒ Object
The International Standard Serial Number (ISSN) that identifies this serial publication. You can repeat this property to identify different formats of, or the linking ISSN (ISSN-L) for, this serial publication.
184 185 186 |
# File 'lib/schema_org/mixins/dataset.rb', line 184 def issn=(value) write_property(:issn, value) end |
#measurement_method ⇒ Object
A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].
189 190 191 |
# File 'lib/schema_org/mixins/dataset.rb', line 189 def measurement_method read_property(:measurement_method) end |
#measurement_method=(value) ⇒ Object
A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].
194 195 196 |
# File 'lib/schema_org/mixins/dataset.rb', line 194 def measurement_method=(value) write_property(:measurement_method, value) end |
#measurement_technique ⇒ Object
A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]). Often but not necessarily each [[variableMeasured]] will have an explicit representation as (or mapping to) an property such as those defined in Schema.org, or other RDF vocabularies and "knowledge graphs". In that case the subproperty of [[variableMeasured]] called [[measuredProperty]] is applicable.
The [[measurementTechnique]] property helps when extra clarification is needed about how a [[measuredProperty]] was measured. This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but can often serve as a high level summary for dataset discovery.
For example, if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]] could be: "mass spectrometry" or "nmr spectroscopy" or "colorimetry" or "immunofluorescence". If the [[variableMeasured]] is "depression rating", the [[measurementTechnique]] could be "Zung Scale" or "HAM-D" or "Beck Depression Inventory".
If there are several [[variableMeasured]] properties recorded for some given data object, use a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]]. The value can also be from an enumeration, organized as a [[MeasurementMethodEnum]].
205 206 207 |
# File 'lib/schema_org/mixins/dataset.rb', line 205 def measurement_technique read_property(:measurement_technique) end |
#measurement_technique=(value) ⇒ Object
A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]). Often but not necessarily each [[variableMeasured]] will have an explicit representation as (or mapping to) an property such as those defined in Schema.org, or other RDF vocabularies and "knowledge graphs". In that case the subproperty of [[variableMeasured]] called [[measuredProperty]] is applicable.
The [[measurementTechnique]] property helps when extra clarification is needed about how a [[measuredProperty]] was measured. This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but can often serve as a high level summary for dataset discovery.
For example, if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]] could be: "mass spectrometry" or "nmr spectroscopy" or "colorimetry" or "immunofluorescence". If the [[variableMeasured]] is "depression rating", the [[measurementTechnique]] could be "Zung Scale" or "HAM-D" or "Beck Depression Inventory".
If there are several [[variableMeasured]] properties recorded for some given data object, use a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]]. The value can also be from an enumeration, organized as a [[MeasurementMethodEnum]].
216 217 218 |
# File 'lib/schema_org/mixins/dataset.rb', line 216 def measurement_technique=(value) write_property(:measurement_technique, value) end |
#variable_measured ⇒ Object
The variableMeasured property can indicate (repeated as necessary) the variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue, or more explicitly as a [[StatisticalVariable]].
221 222 223 |
# File 'lib/schema_org/mixins/dataset.rb', line 221 def variable_measured read_property(:variable_measured) end |
#variable_measured=(value) ⇒ Object
The variableMeasured property can indicate (repeated as necessary) the variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue, or more explicitly as a [[StatisticalVariable]].
226 227 228 |
# File 'lib/schema_org/mixins/dataset.rb', line 226 def variable_measured=(value) write_property(:variable_measured, value) end |
#variables_measured ⇒ Object
Originally named [[variablesMeasured]], the [[variableMeasured]] property can indicate (repeated as necessary) the variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue.
231 232 233 |
# File 'lib/schema_org/mixins/dataset.rb', line 231 def variables_measured read_property(:variables_measured) end |
#variables_measured=(value) ⇒ Object
Originally named [[variablesMeasured]], the [[variableMeasured]] property can indicate (repeated as necessary) the variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue.
236 237 238 |
# File 'lib/schema_org/mixins/dataset.rb', line 236 def variables_measured=(value) write_property(:variables_measured, value) end |