Module: SchemaOrg::Mixins::DeliveryChargeSpecification
- Includes:
- PriceSpecification
- Included in:
- DeliveryChargeSpecification
- Defined in:
- lib/schema_org/mixins/delivery_charge_specification.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#applies_to_delivery_method ⇒ Object
The delivery method(s) to which the delivery charge or payment charge specification applies.
-
#applies_to_delivery_method=(value) ⇒ Object
The delivery method(s) to which the delivery charge or payment charge specification applies.
-
#area_served ⇒ Object
The geographic area where a service or offered item is provided.
-
#area_served=(value) ⇒ Object
The geographic area where a service or offered item is provided.
-
#eligible_region ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.\n\nSee also [[ineligibleRegion]].
-
#eligible_region=(value) ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.\n\nSee also [[ineligibleRegion]].
-
#ineligible_region ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g.
-
#ineligible_region=(value) ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g.
Methods included from PriceSpecification
#eligible_quantity, #eligible_quantity=, #eligible_transaction_volume, #eligible_transaction_volume=, #max_price, #max_price=, #membership_points_earned, #membership_points_earned=, #min_price, #min_price=, #price, #price=, #price_currency, #price_currency=, #valid_for_member_tier, #valid_for_member_tier=, #valid_from, #valid_from=, #valid_through, #valid_through=, #value_added_tax_included, #value_added_tax_included=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/schema_org/mixins/delivery_charge_specification.rb', line 11 def self.schema_property_definitions { applies_to_delivery_method: { schema_name: "appliesToDeliveryMethod", schema_url: "https://schema.org/appliesToDeliveryMethod", comment_lines: ["The delivery method(s) to which the delivery charge or payment charge specification applies."].freeze, ranges: ["DeliveryMethod"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, area_served: { schema_name: "areaServed", schema_url: "https://schema.org/areaServed", comment_lines: ["The geographic area where a service or offered item is provided."].freeze, ranges: ["AdministrativeArea", "GeoShape", "Place", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["serviceArea"].freeze }.freeze, eligible_region: { schema_name: "eligibleRegion", schema_url: "https://schema.org/eligibleRegion", comment_lines: ["The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.\\n\\nSee also [[ineligibleRegion]]."].freeze, ranges: ["GeoShape", "Place", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, ineligible_region: { schema_name: "ineligibleRegion", schema_url: "https://schema.org/ineligibleRegion", comment_lines: ["The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed.\\n\\nSee also [[eligibleRegion]]."].freeze, ranges: ["GeoShape", "Place", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#applies_to_delivery_method ⇒ Object
The delivery method(s) to which the delivery charge or payment charge specification applies.
57 58 59 |
# File 'lib/schema_org/mixins/delivery_charge_specification.rb', line 57 def applies_to_delivery_method read_property(:applies_to_delivery_method) end |
#applies_to_delivery_method=(value) ⇒ Object
The delivery method(s) to which the delivery charge or payment charge specification applies.
62 63 64 |
# File 'lib/schema_org/mixins/delivery_charge_specification.rb', line 62 def applies_to_delivery_method=(value) write_property(:applies_to_delivery_method, value) end |
#area_served ⇒ Object
The geographic area where a service or offered item is provided.
Supersedes serviceArea.
68 69 70 |
# File 'lib/schema_org/mixins/delivery_charge_specification.rb', line 68 def area_served read_property(:area_served) end |
#area_served=(value) ⇒ Object
The geographic area where a service or offered item is provided.
Supersedes serviceArea.
74 75 76 |
# File 'lib/schema_org/mixins/delivery_charge_specification.rb', line 74 def area_served=(value) write_property(:area_served, value) end |
#eligible_region ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.\n\nSee also [[ineligibleRegion]].
79 80 81 |
# File 'lib/schema_org/mixins/delivery_charge_specification.rb', line 79 def eligible_region read_property(:eligible_region) end |
#eligible_region=(value) ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.\n\nSee also [[ineligibleRegion]].
84 85 86 |
# File 'lib/schema_org/mixins/delivery_charge_specification.rb', line 84 def eligible_region=(value) write_property(:eligible_region, value) end |
#ineligible_region ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed.\n\nSee also [[eligibleRegion]].
89 90 91 |
# File 'lib/schema_org/mixins/delivery_charge_specification.rb', line 89 def ineligible_region read_property(:ineligible_region) end |
#ineligible_region=(value) ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed.\n\nSee also [[eligibleRegion]].
94 95 96 |
# File 'lib/schema_org/mixins/delivery_charge_specification.rb', line 94 def ineligible_region=(value) write_property(:ineligible_region, value) end |