Module: SchemaOrg::Mixins::Demand
Class Method Summary collapse
Instance Method Summary collapse
-
#accepted_payment_method ⇒ Object
The payment method(s) that are accepted in general by an organization, or for some specific demand or offer.
-
#accepted_payment_method=(value) ⇒ Object
The payment method(s) that are accepted in general by an organization, or for some specific demand or offer.
-
#advance_booking_requirement ⇒ Object
The amount of time that is required between accepting the offer and the actual usage of the resource or service.
-
#advance_booking_requirement=(value) ⇒ Object
The amount of time that is required between accepting the offer and the actual usage of the resource or service.
-
#area_served ⇒ Object
The geographic area where a service or offered item is provided.
-
#area_served=(value) ⇒ Object
The geographic area where a service or offered item is provided.
-
#asin ⇒ Object
An Amazon Standard Identification Number (ASIN) is a 10-character alphanumeric unique identifier assigned by Amazon.com and its partners for product identification within the Amazon organization (summary from Wikipedia's article).
-
#asin=(value) ⇒ Object
An Amazon Standard Identification Number (ASIN) is a 10-character alphanumeric unique identifier assigned by Amazon.com and its partners for product identification within the Amazon organization (summary from Wikipedia's article).
-
#availability ⇒ Object
The availability of this item—for example In stock, Out of stock, Pre-order, etc.
-
#availability=(value) ⇒ Object
The availability of this item—for example In stock, Out of stock, Pre-order, etc.
-
#availability_ends ⇒ Object
The end of the availability of the product or service included in the offer.
-
#availability_ends=(value) ⇒ Object
The end of the availability of the product or service included in the offer.
-
#availability_starts ⇒ Object
The beginning of the availability of the product or service included in the offer.
-
#availability_starts=(value) ⇒ Object
The beginning of the availability of the product or service included in the offer.
-
#available_at_or_from ⇒ Object
The place(s) from which the offer can be obtained (e.g. store locations).
-
#available_at_or_from=(value) ⇒ Object
The place(s) from which the offer can be obtained (e.g. store locations).
-
#available_delivery_method ⇒ Object
The delivery method(s) available for this offer.
-
#available_delivery_method=(value) ⇒ Object
The delivery method(s) available for this offer.
-
#business_function ⇒ Object
The business function (e.g. sell, lease, repair, dispose) of the offer or component of a bundle (TypeAndQuantityNode).
-
#business_function=(value) ⇒ Object
The business function (e.g. sell, lease, repair, dispose) of the offer or component of a bundle (TypeAndQuantityNode).
-
#delivery_lead_time ⇒ Object
The typical delay between the receipt of the order and the goods either leaving the warehouse or being prepared for pickup, in case the delivery method is on site pickup.
-
#delivery_lead_time=(value) ⇒ Object
The typical delay between the receipt of the order and the goods either leaving the warehouse or being prepared for pickup, in case the delivery method is on site pickup.
-
#eligible_customer_type ⇒ Object
The type(s) of customers for which the given offer is valid.
-
#eligible_customer_type=(value) ⇒ Object
The type(s) of customers for which the given offer is valid.
-
#eligible_duration ⇒ Object
The duration for which the given offer is valid.
-
#eligible_duration=(value) ⇒ Object
The duration for which the given offer is valid.
-
#eligible_quantity ⇒ Object
The interval and unit of measurement of ordering quantities for which the offer or price specification is valid.
-
#eligible_quantity=(value) ⇒ Object
The interval and unit of measurement of ordering quantities for which the offer or price specification is valid.
-
#eligible_region ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.\n\nSee also [[ineligibleRegion]].
-
#eligible_region=(value) ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.\n\nSee also [[ineligibleRegion]].
-
#eligible_transaction_volume ⇒ Object
The transaction volume, in a monetary unit, for which the offer or price specification is valid, e.g.
-
#eligible_transaction_volume=(value) ⇒ Object
The transaction volume, in a monetary unit, for which the offer or price specification is valid, e.g.
-
#gtin ⇒ Object
A Global Trade Item Number (GTIN).
-
#gtin12 ⇒ Object
The GTIN-12 code of the product, or the product to which the offer refers.
-
#gtin12=(value) ⇒ Object
The GTIN-12 code of the product, or the product to which the offer refers.
-
#gtin13 ⇒ Object
The GTIN-13 code of the product, or the product to which the offer refers.
-
#gtin13=(value) ⇒ Object
The GTIN-13 code of the product, or the product to which the offer refers.
-
#gtin14 ⇒ Object
The GTIN-14 code of the product, or the product to which the offer refers.
-
#gtin14=(value) ⇒ Object
The GTIN-14 code of the product, or the product to which the offer refers.
-
#gtin8 ⇒ Object
The GTIN-8 code of the product, or the product to which the offer refers.
-
#gtin8=(value) ⇒ Object
The GTIN-8 code of the product, or the product to which the offer refers.
-
#gtin=(value) ⇒ Object
A Global Trade Item Number (GTIN).
-
#includes_object ⇒ Object
This links to a node or nodes indicating the exact quantity of the products included in an [[Offer]] or [[ProductCollection]].
-
#includes_object=(value) ⇒ Object
This links to a node or nodes indicating the exact quantity of the products included in an [[Offer]] or [[ProductCollection]].
-
#ineligible_region ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g.
-
#ineligible_region=(value) ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g.
-
#inventory_level ⇒ Object
The current approximate inventory level for the item or items.
-
#inventory_level=(value) ⇒ Object
The current approximate inventory level for the item or items.
-
#item_condition ⇒ Object
A predefined value from OfferItemCondition specifying the condition of the product or service, or the products or services included in the offer.
-
#item_condition=(value) ⇒ Object
A predefined value from OfferItemCondition specifying the condition of the product or service, or the products or services included in the offer.
-
#item_offered ⇒ Object
An item being offered (or demanded).
-
#item_offered=(value) ⇒ Object
An item being offered (or demanded).
-
#mpn ⇒ Object
The Manufacturer Part Number (MPN) of the product, or the product to which the offer refers.
-
#mpn=(value) ⇒ Object
The Manufacturer Part Number (MPN) of the product, or the product to which the offer refers.
-
#price_specification ⇒ Object
One or more detailed price specifications, indicating the unit price and delivery or payment charges.
-
#price_specification=(value) ⇒ Object
One or more detailed price specifications, indicating the unit price and delivery or payment charges.
-
#seller ⇒ Object
An entity which offers (sells / leases / lends / loans) the services / goods.
-
#seller=(value) ⇒ Object
An entity which offers (sells / leases / lends / loans) the services / goods.
-
#serial_number ⇒ Object
The serial number or any alphanumeric identifier of a particular product.
-
#serial_number=(value) ⇒ Object
The serial number or any alphanumeric identifier of a particular product.
-
#sku ⇒ Object
The Stock Keeping Unit (SKU), i.e.
-
#sku=(value) ⇒ Object
The Stock Keeping Unit (SKU), i.e.
-
#valid_from ⇒ Object
The date when the item becomes valid.
-
#valid_from=(value) ⇒ Object
The date when the item becomes valid.
-
#valid_through ⇒ Object
The date after when the item is not valid.
-
#valid_through=(value) ⇒ Object
The date after when the item is not valid.
-
#warranty ⇒ Object
The warranty promise(s) included in the offer.
-
#warranty=(value) ⇒ Object
The warranty promise(s) included in the offer.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/schema_org/mixins/demand.rb', line 11 def self.schema_property_definitions { accepted_payment_method: { schema_name: "acceptedPaymentMethod", schema_url: "https://schema.org/acceptedPaymentMethod", comment_lines: ["The payment method(s) that are accepted in general by an organization, or for some specific demand or offer."].freeze, ranges: ["LoanOrCredit", "PaymentMethod", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, advance_booking_requirement: { schema_name: "advanceBookingRequirement", schema_url: "https://schema.org/advanceBookingRequirement", comment_lines: ["The amount of time that is required between accepting the offer and the actual usage of the resource or service."].freeze, ranges: ["QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, area_served: { schema_name: "areaServed", schema_url: "https://schema.org/areaServed", comment_lines: ["The geographic area where a service or offered item is provided."].freeze, ranges: ["AdministrativeArea", "GeoShape", "Place", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["serviceArea"].freeze }.freeze, asin: { schema_name: "asin", schema_url: "https://schema.org/asin", comment_lines: ["An Amazon Standard Identification Number (ASIN) is a 10-character alphanumeric unique identifier assigned by Amazon.com and its partners for product identification within the Amazon organization (summary from [Wikipedia](https://en.wikipedia.org/wiki/Amazon_Standard_Identification_Number)'s article).", "", "Note also that this is a definition for how to include ASINs in Schema.org data, and not a definition of ASINs in general - see documentation from Amazon for authoritative details.", "ASINs are most commonly encoded as text strings, but the [asin] property supports URL/URI as potential values too."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, availability: { schema_name: "availability", schema_url: "https://schema.org/availability", comment_lines: ["The availability of this item—for example In stock, Out of stock, Pre-order, etc."].freeze, ranges: ["ItemAvailability"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, availability_ends: { schema_name: "availabilityEnds", schema_url: "https://schema.org/availabilityEnds", comment_lines: ["The end of the availability of the product or service included in the offer."].freeze, ranges: ["Date", "DateTime", "Time"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, availability_starts: { schema_name: "availabilityStarts", schema_url: "https://schema.org/availabilityStarts", comment_lines: ["The beginning of the availability of the product or service included in the offer."].freeze, ranges: ["Date", "DateTime", "Time"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, available_at_or_from: { schema_name: "availableAtOrFrom", schema_url: "https://schema.org/availableAtOrFrom", comment_lines: ["The place(s) from which the offer can be obtained (e.g. store locations)."].freeze, ranges: ["Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, available_delivery_method: { schema_name: "availableDeliveryMethod", schema_url: "https://schema.org/availableDeliveryMethod", comment_lines: ["The delivery method(s) available for this offer."].freeze, ranges: ["DeliveryMethod"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, business_function: { schema_name: "businessFunction", schema_url: "https://schema.org/businessFunction", comment_lines: ["The business function (e.g. sell, lease, repair, dispose) of the offer or component of a bundle (TypeAndQuantityNode). The default is http://purl.org/goodrelations/v1#Sell."].freeze, ranges: ["BusinessFunction"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, delivery_lead_time: { schema_name: "deliveryLeadTime", schema_url: "https://schema.org/deliveryLeadTime", comment_lines: ["The typical delay between the receipt of the order and the goods either leaving the warehouse or being prepared for pickup, in case the delivery method is on site pickup."].freeze, ranges: ["QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, eligible_customer_type: { schema_name: "eligibleCustomerType", schema_url: "https://schema.org/eligibleCustomerType", comment_lines: ["The type(s) of customers for which the given offer is valid."].freeze, ranges: ["BusinessEntityType"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, eligible_duration: { schema_name: "eligibleDuration", schema_url: "https://schema.org/eligibleDuration", comment_lines: ["The duration for which the given offer is valid."].freeze, ranges: ["QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, eligible_quantity: { schema_name: "eligibleQuantity", schema_url: "https://schema.org/eligibleQuantity", comment_lines: ["The interval and unit of measurement of ordering quantities for which the offer or price specification is valid. This allows e.g. specifying that a certain freight charge is valid only for a certain quantity."].freeze, ranges: ["QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, eligible_region: { schema_name: "eligibleRegion", schema_url: "https://schema.org/eligibleRegion", comment_lines: ["The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.\\n\\nSee also [[ineligibleRegion]]."].freeze, ranges: ["GeoShape", "Place", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, eligible_transaction_volume: { schema_name: "eligibleTransactionVolume", schema_url: "https://schema.org/eligibleTransactionVolume", comment_lines: ["The transaction volume, in a monetary unit, for which the offer or price specification is valid, e.g. for indicating a minimal purchasing volume, to express free shipping above a certain order volume, or to limit the acceptance of credit cards to purchases to a certain minimal amount."].freeze, ranges: ["PriceSpecification"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, gtin: { schema_name: "gtin", schema_url: "https://schema.org/gtin", comment_lines: ["A Global Trade Item Number ([GTIN](https://www.gs1.org/standards/id-keys/gtin)). GTINs identify trade items, including products and services, using numeric identification codes.", "", "A correct [[gtin]] value should be a valid GTIN, which means that it should be an all-numeric string of either 8, 12, 13 or 14 digits, or a \"GS1 Digital Link\" URL based on such a string. The numeric component should also have a [valid GS1 check digit](https://www.gs1.org/services/check-digit-calculator) and meet the other rules for valid GTINs. See also [GS1's GTIN Summary](http://www.gs1.org/barcodes/technical/idkeys/gtin) and [Wikipedia](https://en.wikipedia.org/wiki/Global_Trade_Item_Number) for more details. Left-padding of the gtin values is not required or encouraged. The [[gtin]] property generalizes the earlier [[gtin8]], [[gtin12]], [[gtin13]], and [[gtin14]] properties.", "", "The GS1 [digital link specifications](https://www.gs1.org/standards/Digital-Link/) expresses GTINs as URLs (URIs, IRIs, etc.).", "Digital Links should be populated into the [[hasGS1DigitalLink]] attribute.", "", "Note also that this is a definition for how to include GTINs in Schema.org data, and not a definition of GTINs in general - see the GS1 documentation for authoritative details."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, gtin12: { schema_name: "gtin12", schema_url: "https://schema.org/gtin12", comment_lines: ["The GTIN-12 code of the product, or the product to which the offer refers. The GTIN-12 is the 12-digit GS1 Identification Key composed of a U.P.C. Company Prefix, Item Reference, and Check Digit used to identify trade items. See [GS1 GTIN Summary](http://www.gs1.org/barcodes/technical/idkeys/gtin) for more details."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, gtin13: { schema_name: "gtin13", schema_url: "https://schema.org/gtin13", comment_lines: ["The GTIN-13 code of the product, or the product to which the offer refers. This is equivalent to 13-digit ISBN codes and EAN UCC-13. Former 12-digit UPC codes can be converted into a GTIN-13 code by simply adding a preceding zero. See [GS1 GTIN Summary](http://www.gs1.org/barcodes/technical/idkeys/gtin) for more details."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, gtin14: { schema_name: "gtin14", schema_url: "https://schema.org/gtin14", comment_lines: ["The GTIN-14 code of the product, or the product to which the offer refers. See [GS1 GTIN Summary](http://www.gs1.org/barcodes/technical/idkeys/gtin) for more details."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, gtin8: { schema_name: "gtin8", schema_url: "https://schema.org/gtin8", comment_lines: ["The GTIN-8 code of the product, or the product to which the offer refers. This code is also known as EAN/UCC-8 or 8-digit EAN. See [GS1 GTIN Summary](http://www.gs1.org/barcodes/technical/idkeys/gtin) for more details."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, includes_object: { schema_name: "includesObject", schema_url: "https://schema.org/includesObject", comment_lines: ["This links to a node or nodes indicating the exact quantity of the products included in an [[Offer]] or [[ProductCollection]]."].freeze, ranges: ["TypeAndQuantityNode"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, ineligible_region: { schema_name: "ineligibleRegion", schema_url: "https://schema.org/ineligibleRegion", comment_lines: ["The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed.\\n\\nSee also [[eligibleRegion]]."].freeze, ranges: ["GeoShape", "Place", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, inventory_level: { schema_name: "inventoryLevel", schema_url: "https://schema.org/inventoryLevel", comment_lines: ["The current approximate inventory level for the item or items."].freeze, ranges: ["QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, item_condition: { schema_name: "itemCondition", schema_url: "https://schema.org/itemCondition", comment_lines: ["A predefined value from OfferItemCondition specifying the condition of the product or service, or the products or services included in the offer. Also used for product return policies to specify the condition of products accepted for returns."].freeze, ranges: ["OfferItemCondition"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, item_offered: { schema_name: "itemOffered", schema_url: "https://schema.org/itemOffered", comment_lines: ["An item being offered (or demanded). The transactional nature of the offer or demand is documented using [[businessFunction]], e.g. sell, lease etc. While several common expected types are listed explicitly in this definition, others can be used. Using a second type, such as Product or a subtype of Product, can clarify the nature of the offer."].freeze, ranges: ["AggregateOffer", "CreativeWork", "Event", "MenuItem", "Product", "Service", "Trip"].freeze, external_ranges: [].freeze, inverse_of: "offers", superseded_by: nil, supersedes: nil }.freeze, mpn: { schema_name: "mpn", schema_url: "https://schema.org/mpn", comment_lines: ["The Manufacturer Part Number (MPN) of the product, or the product to which the offer refers."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, price_specification: { schema_name: "priceSpecification", schema_url: "https://schema.org/priceSpecification", comment_lines: ["One or more detailed price specifications, indicating the unit price and delivery or payment charges."].freeze, ranges: ["PriceSpecification"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, seller: { schema_name: "seller", schema_url: "https://schema.org/seller", comment_lines: ["An entity which offers (sells / leases / lends / loans) the services / goods. A seller may also be a provider."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["merchant", "vendor"].freeze }.freeze, serial_number: { schema_name: "serialNumber", schema_url: "https://schema.org/serialNumber", comment_lines: ["The serial number or any alphanumeric identifier of a particular product. When attached to an offer, it is a shortcut for the serial number of the product included in the offer."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, sku: { schema_name: "sku", schema_url: "https://schema.org/sku", comment_lines: ["The Stock Keeping Unit (SKU), i.e. a merchant-specific identifier for a product or service, or the product to which the offer refers."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, valid_from: { schema_name: "validFrom", schema_url: "https://schema.org/validFrom", comment_lines: ["The date when the item becomes valid."].freeze, ranges: ["Date", "DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, valid_through: { schema_name: "validThrough", schema_url: "https://schema.org/validThrough", comment_lines: ["The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours."].freeze, ranges: ["Date", "DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, warranty: { schema_name: "warranty", schema_url: "https://schema.org/warranty", comment_lines: ["The warranty promise(s) included in the offer."].freeze, ranges: ["WarrantyPromise"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["warrantyPromise"].freeze }.freeze }.freeze end |
Instance Method Details
#accepted_payment_method ⇒ Object
The payment method(s) that are accepted in general by an organization, or for some specific demand or offer.
357 358 359 |
# File 'lib/schema_org/mixins/demand.rb', line 357 def accepted_payment_method read_property(:accepted_payment_method) end |
#accepted_payment_method=(value) ⇒ Object
The payment method(s) that are accepted in general by an organization, or for some specific demand or offer.
362 363 364 |
# File 'lib/schema_org/mixins/demand.rb', line 362 def accepted_payment_method=(value) write_property(:accepted_payment_method, value) end |
#advance_booking_requirement ⇒ Object
The amount of time that is required between accepting the offer and the actual usage of the resource or service.
367 368 369 |
# File 'lib/schema_org/mixins/demand.rb', line 367 def advance_booking_requirement read_property(:advance_booking_requirement) end |
#advance_booking_requirement=(value) ⇒ Object
The amount of time that is required between accepting the offer and the actual usage of the resource or service.
372 373 374 |
# File 'lib/schema_org/mixins/demand.rb', line 372 def advance_booking_requirement=(value) write_property(:advance_booking_requirement, value) end |
#area_served ⇒ Object
The geographic area where a service or offered item is provided.
Supersedes serviceArea.
378 379 380 |
# File 'lib/schema_org/mixins/demand.rb', line 378 def area_served read_property(:area_served) end |
#area_served=(value) ⇒ Object
The geographic area where a service or offered item is provided.
Supersedes serviceArea.
384 385 386 |
# File 'lib/schema_org/mixins/demand.rb', line 384 def area_served=(value) write_property(:area_served, value) end |
#asin ⇒ Object
An Amazon Standard Identification Number (ASIN) is a 10-character alphanumeric unique identifier assigned by Amazon.com and its partners for product identification within the Amazon organization (summary from Wikipedia's article).
Note also that this is a definition for how to include ASINs in Schema.org data, and not a definition of ASINs in general - see documentation from Amazon for authoritative details. ASINs are most commonly encoded as text strings, but the [asin] property supports URL/URI as potential values too.
392 393 394 |
# File 'lib/schema_org/mixins/demand.rb', line 392 def asin read_property(:asin) end |
#asin=(value) ⇒ Object
An Amazon Standard Identification Number (ASIN) is a 10-character alphanumeric unique identifier assigned by Amazon.com and its partners for product identification within the Amazon organization (summary from Wikipedia's article).
Note also that this is a definition for how to include ASINs in Schema.org data, and not a definition of ASINs in general - see documentation from Amazon for authoritative details. ASINs are most commonly encoded as text strings, but the [asin] property supports URL/URI as potential values too.
400 401 402 |
# File 'lib/schema_org/mixins/demand.rb', line 400 def asin=(value) write_property(:asin, value) end |
#availability ⇒ Object
The availability of this item—for example In stock, Out of stock, Pre-order, etc.
405 406 407 |
# File 'lib/schema_org/mixins/demand.rb', line 405 def availability read_property(:availability) end |
#availability=(value) ⇒ Object
The availability of this item—for example In stock, Out of stock, Pre-order, etc.
410 411 412 |
# File 'lib/schema_org/mixins/demand.rb', line 410 def availability=(value) write_property(:availability, value) end |
#availability_ends ⇒ Object
The end of the availability of the product or service included in the offer.
415 416 417 |
# File 'lib/schema_org/mixins/demand.rb', line 415 def availability_ends read_property(:availability_ends) end |
#availability_ends=(value) ⇒ Object
The end of the availability of the product or service included in the offer.
420 421 422 |
# File 'lib/schema_org/mixins/demand.rb', line 420 def availability_ends=(value) write_property(:availability_ends, value) end |
#availability_starts ⇒ Object
The beginning of the availability of the product or service included in the offer.
425 426 427 |
# File 'lib/schema_org/mixins/demand.rb', line 425 def availability_starts read_property(:availability_starts) end |
#availability_starts=(value) ⇒ Object
The beginning of the availability of the product or service included in the offer.
430 431 432 |
# File 'lib/schema_org/mixins/demand.rb', line 430 def availability_starts=(value) write_property(:availability_starts, value) end |
#available_at_or_from ⇒ Object
The place(s) from which the offer can be obtained (e.g. store locations).
435 436 437 |
# File 'lib/schema_org/mixins/demand.rb', line 435 def available_at_or_from read_property(:available_at_or_from) end |
#available_at_or_from=(value) ⇒ Object
The place(s) from which the offer can be obtained (e.g. store locations).
440 441 442 |
# File 'lib/schema_org/mixins/demand.rb', line 440 def available_at_or_from=(value) write_property(:available_at_or_from, value) end |
#available_delivery_method ⇒ Object
The delivery method(s) available for this offer.
445 446 447 |
# File 'lib/schema_org/mixins/demand.rb', line 445 def available_delivery_method read_property(:available_delivery_method) end |
#available_delivery_method=(value) ⇒ Object
The delivery method(s) available for this offer.
450 451 452 |
# File 'lib/schema_org/mixins/demand.rb', line 450 def available_delivery_method=(value) write_property(:available_delivery_method, value) end |
#business_function ⇒ Object
The business function (e.g. sell, lease, repair, dispose) of the offer or component of a bundle (TypeAndQuantityNode). The default is http://purl.org/goodrelations/v1#Sell.
455 456 457 |
# File 'lib/schema_org/mixins/demand.rb', line 455 def business_function read_property(:business_function) end |
#business_function=(value) ⇒ Object
The business function (e.g. sell, lease, repair, dispose) of the offer or component of a bundle (TypeAndQuantityNode). The default is http://purl.org/goodrelations/v1#Sell.
460 461 462 |
# File 'lib/schema_org/mixins/demand.rb', line 460 def business_function=(value) write_property(:business_function, value) end |
#delivery_lead_time ⇒ Object
The typical delay between the receipt of the order and the goods either leaving the warehouse or being prepared for pickup, in case the delivery method is on site pickup.
465 466 467 |
# File 'lib/schema_org/mixins/demand.rb', line 465 def delivery_lead_time read_property(:delivery_lead_time) end |
#delivery_lead_time=(value) ⇒ Object
The typical delay between the receipt of the order and the goods either leaving the warehouse or being prepared for pickup, in case the delivery method is on site pickup.
470 471 472 |
# File 'lib/schema_org/mixins/demand.rb', line 470 def delivery_lead_time=(value) write_property(:delivery_lead_time, value) end |
#eligible_customer_type ⇒ Object
The type(s) of customers for which the given offer is valid.
475 476 477 |
# File 'lib/schema_org/mixins/demand.rb', line 475 def eligible_customer_type read_property(:eligible_customer_type) end |
#eligible_customer_type=(value) ⇒ Object
The type(s) of customers for which the given offer is valid.
480 481 482 |
# File 'lib/schema_org/mixins/demand.rb', line 480 def eligible_customer_type=(value) write_property(:eligible_customer_type, value) end |
#eligible_duration ⇒ Object
The duration for which the given offer is valid.
485 486 487 |
# File 'lib/schema_org/mixins/demand.rb', line 485 def eligible_duration read_property(:eligible_duration) end |
#eligible_duration=(value) ⇒ Object
The duration for which the given offer is valid.
490 491 492 |
# File 'lib/schema_org/mixins/demand.rb', line 490 def eligible_duration=(value) write_property(:eligible_duration, value) end |
#eligible_quantity ⇒ Object
The interval and unit of measurement of ordering quantities for which the offer or price specification is valid. This allows e.g. specifying that a certain freight charge is valid only for a certain quantity.
495 496 497 |
# File 'lib/schema_org/mixins/demand.rb', line 495 def eligible_quantity read_property(:eligible_quantity) end |
#eligible_quantity=(value) ⇒ Object
The interval and unit of measurement of ordering quantities for which the offer or price specification is valid. This allows e.g. specifying that a certain freight charge is valid only for a certain quantity.
500 501 502 |
# File 'lib/schema_org/mixins/demand.rb', line 500 def eligible_quantity=(value) write_property(:eligible_quantity, value) end |
#eligible_region ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.\n\nSee also [[ineligibleRegion]].
505 506 507 |
# File 'lib/schema_org/mixins/demand.rb', line 505 def eligible_region read_property(:eligible_region) end |
#eligible_region=(value) ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.\n\nSee also [[ineligibleRegion]].
510 511 512 |
# File 'lib/schema_org/mixins/demand.rb', line 510 def eligible_region=(value) write_property(:eligible_region, value) end |
#eligible_transaction_volume ⇒ Object
The transaction volume, in a monetary unit, for which the offer or price specification is valid, e.g. for indicating a minimal purchasing volume, to express free shipping above a certain order volume, or to limit the acceptance of credit cards to purchases to a certain minimal amount.
515 516 517 |
# File 'lib/schema_org/mixins/demand.rb', line 515 def eligible_transaction_volume read_property(:eligible_transaction_volume) end |
#eligible_transaction_volume=(value) ⇒ Object
The transaction volume, in a monetary unit, for which the offer or price specification is valid, e.g. for indicating a minimal purchasing volume, to express free shipping above a certain order volume, or to limit the acceptance of credit cards to purchases to a certain minimal amount.
520 521 522 |
# File 'lib/schema_org/mixins/demand.rb', line 520 def eligible_transaction_volume=(value) write_property(:eligible_transaction_volume, value) end |
#gtin ⇒ Object
A Global Trade Item Number (GTIN). GTINs identify trade items, including products and services, using numeric identification codes.
A correct [[gtin]] value should be a valid GTIN, which means that it should be an all-numeric string of either 8, 12, 13 or 14 digits, or a "GS1 Digital Link" URL based on such a string. The numeric component should also have a valid GS1 check digit and meet the other rules for valid GTINs. See also GS1's GTIN Summary and Wikipedia for more details. Left-padding of the gtin values is not required or encouraged. The [[gtin]] property generalizes the earlier [[gtin8]], [[gtin12]], [[gtin13]], and [[gtin14]] properties.
The GS1 digital link specifications expresses GTINs as URLs (URIs, IRIs, etc.). Digital Links should be populated into the [[hasGS1DigitalLink]] attribute.
Note also that this is a definition for how to include GTINs in Schema.org data, and not a definition of GTINs in general - see the GS1 documentation for authoritative details.
532 533 534 |
# File 'lib/schema_org/mixins/demand.rb', line 532 def gtin read_property(:gtin) end |
#gtin12 ⇒ Object
The GTIN-12 code of the product, or the product to which the offer refers. The GTIN-12 is the 12-digit GS1 Identification Key composed of a U.P.C. Company Prefix, Item Reference, and Check Digit used to identify trade items. See GS1 GTIN Summary for more details.
549 550 551 |
# File 'lib/schema_org/mixins/demand.rb', line 549 def gtin12 read_property(:gtin12) end |
#gtin12=(value) ⇒ Object
The GTIN-12 code of the product, or the product to which the offer refers. The GTIN-12 is the 12-digit GS1 Identification Key composed of a U.P.C. Company Prefix, Item Reference, and Check Digit used to identify trade items. See GS1 GTIN Summary for more details.
554 555 556 |
# File 'lib/schema_org/mixins/demand.rb', line 554 def gtin12=(value) write_property(:gtin12, value) end |
#gtin13 ⇒ Object
The GTIN-13 code of the product, or the product to which the offer refers. This is equivalent to 13-digit ISBN codes and EAN UCC-13. Former 12-digit UPC codes can be converted into a GTIN-13 code by simply adding a preceding zero. See GS1 GTIN Summary for more details.
559 560 561 |
# File 'lib/schema_org/mixins/demand.rb', line 559 def gtin13 read_property(:gtin13) end |
#gtin13=(value) ⇒ Object
The GTIN-13 code of the product, or the product to which the offer refers. This is equivalent to 13-digit ISBN codes and EAN UCC-13. Former 12-digit UPC codes can be converted into a GTIN-13 code by simply adding a preceding zero. See GS1 GTIN Summary for more details.
564 565 566 |
# File 'lib/schema_org/mixins/demand.rb', line 564 def gtin13=(value) write_property(:gtin13, value) end |
#gtin14 ⇒ Object
The GTIN-14 code of the product, or the product to which the offer refers. See GS1 GTIN Summary for more details.
569 570 571 |
# File 'lib/schema_org/mixins/demand.rb', line 569 def gtin14 read_property(:gtin14) end |
#gtin14=(value) ⇒ Object
The GTIN-14 code of the product, or the product to which the offer refers. See GS1 GTIN Summary for more details.
574 575 576 |
# File 'lib/schema_org/mixins/demand.rb', line 574 def gtin14=(value) write_property(:gtin14, value) end |
#gtin8 ⇒ Object
The GTIN-8 code of the product, or the product to which the offer refers. This code is also known as EAN/UCC-8 or 8-digit EAN. See GS1 GTIN Summary for more details.
579 580 581 |
# File 'lib/schema_org/mixins/demand.rb', line 579 def gtin8 read_property(:gtin8) end |
#gtin8=(value) ⇒ Object
The GTIN-8 code of the product, or the product to which the offer refers. This code is also known as EAN/UCC-8 or 8-digit EAN. See GS1 GTIN Summary for more details.
584 585 586 |
# File 'lib/schema_org/mixins/demand.rb', line 584 def gtin8=(value) write_property(:gtin8, value) end |
#gtin=(value) ⇒ Object
A Global Trade Item Number (GTIN). GTINs identify trade items, including products and services, using numeric identification codes.
A correct [[gtin]] value should be a valid GTIN, which means that it should be an all-numeric string of either 8, 12, 13 or 14 digits, or a "GS1 Digital Link" URL based on such a string. The numeric component should also have a valid GS1 check digit and meet the other rules for valid GTINs. See also GS1's GTIN Summary and Wikipedia for more details. Left-padding of the gtin values is not required or encouraged. The [[gtin]] property generalizes the earlier [[gtin8]], [[gtin12]], [[gtin13]], and [[gtin14]] properties.
The GS1 digital link specifications expresses GTINs as URLs (URIs, IRIs, etc.). Digital Links should be populated into the [[hasGS1DigitalLink]] attribute.
Note also that this is a definition for how to include GTINs in Schema.org data, and not a definition of GTINs in general - see the GS1 documentation for authoritative details.
544 545 546 |
# File 'lib/schema_org/mixins/demand.rb', line 544 def gtin=(value) write_property(:gtin, value) end |
#includes_object ⇒ Object
This links to a node or nodes indicating the exact quantity of the products included in an [[Offer]] or [[ProductCollection]].
589 590 591 |
# File 'lib/schema_org/mixins/demand.rb', line 589 def includes_object read_property(:includes_object) end |
#includes_object=(value) ⇒ Object
This links to a node or nodes indicating the exact quantity of the products included in an [[Offer]] or [[ProductCollection]].
594 595 596 |
# File 'lib/schema_org/mixins/demand.rb', line 594 def includes_object=(value) write_property(:includes_object, value) end |
#ineligible_region ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed.\n\nSee also [[eligibleRegion]].
599 600 601 |
# File 'lib/schema_org/mixins/demand.rb', line 599 def ineligible_region read_property(:ineligible_region) end |
#ineligible_region=(value) ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed.\n\nSee also [[eligibleRegion]].
604 605 606 |
# File 'lib/schema_org/mixins/demand.rb', line 604 def ineligible_region=(value) write_property(:ineligible_region, value) end |
#inventory_level ⇒ Object
The current approximate inventory level for the item or items.
609 610 611 |
# File 'lib/schema_org/mixins/demand.rb', line 609 def inventory_level read_property(:inventory_level) end |
#inventory_level=(value) ⇒ Object
The current approximate inventory level for the item or items.
614 615 616 |
# File 'lib/schema_org/mixins/demand.rb', line 614 def inventory_level=(value) write_property(:inventory_level, value) end |
#item_condition ⇒ Object
A predefined value from OfferItemCondition specifying the condition of the product or service, or the products or services included in the offer. Also used for product return policies to specify the condition of products accepted for returns.
619 620 621 |
# File 'lib/schema_org/mixins/demand.rb', line 619 def item_condition read_property(:item_condition) end |
#item_condition=(value) ⇒ Object
A predefined value from OfferItemCondition specifying the condition of the product or service, or the products or services included in the offer. Also used for product return policies to specify the condition of products accepted for returns.
624 625 626 |
# File 'lib/schema_org/mixins/demand.rb', line 624 def item_condition=(value) write_property(:item_condition, value) end |
#item_offered ⇒ Object
An item being offered (or demanded). The transactional nature of the offer or demand is documented using [[businessFunction]], e.g. sell, lease etc. While several common expected types are listed explicitly in this definition, others can be used. Using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.
Inverse-property: offers.
630 631 632 |
# File 'lib/schema_org/mixins/demand.rb', line 630 def item_offered read_property(:item_offered) end |
#item_offered=(value) ⇒ Object
An item being offered (or demanded). The transactional nature of the offer or demand is documented using [[businessFunction]], e.g. sell, lease etc. While several common expected types are listed explicitly in this definition, others can be used. Using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.
Inverse-property: offers.
636 637 638 |
# File 'lib/schema_org/mixins/demand.rb', line 636 def item_offered=(value) write_property(:item_offered, value) end |
#mpn ⇒ Object
The Manufacturer Part Number (MPN) of the product, or the product to which the offer refers.
641 642 643 |
# File 'lib/schema_org/mixins/demand.rb', line 641 def mpn read_property(:mpn) end |
#mpn=(value) ⇒ Object
The Manufacturer Part Number (MPN) of the product, or the product to which the offer refers.
646 647 648 |
# File 'lib/schema_org/mixins/demand.rb', line 646 def mpn=(value) write_property(:mpn, value) end |
#price_specification ⇒ Object
One or more detailed price specifications, indicating the unit price and delivery or payment charges.
651 652 653 |
# File 'lib/schema_org/mixins/demand.rb', line 651 def price_specification read_property(:price_specification) end |
#price_specification=(value) ⇒ Object
One or more detailed price specifications, indicating the unit price and delivery or payment charges.
656 657 658 |
# File 'lib/schema_org/mixins/demand.rb', line 656 def price_specification=(value) write_property(:price_specification, value) end |
#seller ⇒ Object
An entity which offers (sells / leases / lends / loans) the services / goods. A seller may also be a provider.
Supersedes merchant.
Supersedes vendor.
663 664 665 |
# File 'lib/schema_org/mixins/demand.rb', line 663 def seller read_property(:seller) end |
#seller=(value) ⇒ Object
An entity which offers (sells / leases / lends / loans) the services / goods. A seller may also be a provider.
Supersedes merchant.
Supersedes vendor.
670 671 672 |
# File 'lib/schema_org/mixins/demand.rb', line 670 def seller=(value) write_property(:seller, value) end |
#serial_number ⇒ Object
The serial number or any alphanumeric identifier of a particular product. When attached to an offer, it is a shortcut for the serial number of the product included in the offer.
675 676 677 |
# File 'lib/schema_org/mixins/demand.rb', line 675 def serial_number read_property(:serial_number) end |
#serial_number=(value) ⇒ Object
The serial number or any alphanumeric identifier of a particular product. When attached to an offer, it is a shortcut for the serial number of the product included in the offer.
680 681 682 |
# File 'lib/schema_org/mixins/demand.rb', line 680 def serial_number=(value) write_property(:serial_number, value) end |
#sku ⇒ Object
The Stock Keeping Unit (SKU), i.e. a merchant-specific identifier for a product or service, or the product to which the offer refers.
685 686 687 |
# File 'lib/schema_org/mixins/demand.rb', line 685 def sku read_property(:sku) end |
#sku=(value) ⇒ Object
The Stock Keeping Unit (SKU), i.e. a merchant-specific identifier for a product or service, or the product to which the offer refers.
690 691 692 |
# File 'lib/schema_org/mixins/demand.rb', line 690 def sku=(value) write_property(:sku, value) end |
#valid_from ⇒ Object
The date when the item becomes valid.
695 696 697 |
# File 'lib/schema_org/mixins/demand.rb', line 695 def valid_from read_property(:valid_from) end |
#valid_from=(value) ⇒ Object
The date when the item becomes valid.
700 701 702 |
# File 'lib/schema_org/mixins/demand.rb', line 700 def valid_from=(value) write_property(:valid_from, value) end |
#valid_through ⇒ Object
The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.
705 706 707 |
# File 'lib/schema_org/mixins/demand.rb', line 705 def valid_through read_property(:valid_through) end |
#valid_through=(value) ⇒ Object
The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.
710 711 712 |
# File 'lib/schema_org/mixins/demand.rb', line 710 def valid_through=(value) write_property(:valid_through, value) end |
#warranty ⇒ Object
The warranty promise(s) included in the offer.
Supersedes warrantyPromise.
716 717 718 |
# File 'lib/schema_org/mixins/demand.rb', line 716 def warranty read_property(:warranty) end |
#warranty=(value) ⇒ Object
The warranty promise(s) included in the offer.
Supersedes warrantyPromise.
722 723 724 |
# File 'lib/schema_org/mixins/demand.rb', line 722 def warranty=(value) write_property(:warranty, value) end |