Module: SchemaOrg::Mixins::DietarySupplement
- Included in:
- DietarySupplement
- Defined in:
- lib/schema_org/mixins/dietary_supplement.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#active_ingredient ⇒ Object
An active ingredient, typically chemical compounds and/or biologic substances.
-
#active_ingredient=(value) ⇒ Object
An active ingredient, typically chemical compounds and/or biologic substances.
-
#is_proprietary ⇒ Object
True if this item's name is a proprietary/brand name (vs. generic name).
-
#is_proprietary=(value) ⇒ Object
True if this item's name is a proprietary/brand name (vs. generic name).
-
#legal_status ⇒ Object
The drug or supplement's legal status, including any controlled substance schedules that apply.
-
#legal_status=(value) ⇒ Object
The drug or supplement's legal status, including any controlled substance schedules that apply.
-
#maximum_intake ⇒ Object
Recommended intake of this supplement for a given population as defined by a specific recommending authority.
-
#maximum_intake=(value) ⇒ Object
Recommended intake of this supplement for a given population as defined by a specific recommending authority.
-
#mechanism_of_action ⇒ Object
The specific biochemical interaction through which this drug or supplement produces its pharmacological effect.
-
#mechanism_of_action=(value) ⇒ Object
The specific biochemical interaction through which this drug or supplement produces its pharmacological effect.
-
#non_proprietary_name ⇒ Object
The generic name of this drug or supplement.
-
#non_proprietary_name=(value) ⇒ Object
The generic name of this drug or supplement.
-
#proprietary_name ⇒ Object
Proprietary name given to the diet plan, typically by its originator or creator.
-
#proprietary_name=(value) ⇒ Object
Proprietary name given to the diet plan, typically by its originator or creator.
-
#recommended_intake ⇒ Object
Recommended intake of this supplement for a given population as defined by a specific recommending authority.
-
#recommended_intake=(value) ⇒ Object
Recommended intake of this supplement for a given population as defined by a specific recommending authority.
-
#safety_consideration ⇒ Object
Any potential safety concern associated with the supplement.
-
#safety_consideration=(value) ⇒ Object
Any potential safety concern associated with the supplement.
-
#target_population ⇒ Object
Characteristics of the population for which this is intended, or which typically uses it, e.g.
-
#target_population=(value) ⇒ Object
Characteristics of the population for which this is intended, or which typically uses it, e.g.
Methods included from MedicalEntity
#code, #code=, #funding, #funding=, #guideline, #guideline=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Methods included from Product
#additional_property, #additional_property=, #aggregate_rating, #aggregate_rating=, #asin, #asin=, #audience, #audience=, #award, #award=, #awards, #awards=, #brand, #brand=, #category, #category=, #color, #color=, #color_swatch, #color_swatch=, #country_of_assembly, #country_of_assembly=, #country_of_last_processing, #country_of_last_processing=, #country_of_origin, #country_of_origin=, #depth, #depth=, #display_location, #display_location=, #funding, #funding=, #gtin, #gtin12, #gtin12=, #gtin13, #gtin13=, #gtin14, #gtin14=, #gtin8, #gtin8=, #gtin=, #has_adult_consideration, #has_adult_consideration=, #has_certification, #has_certification=, #has_energy_consumption_details, #has_energy_consumption_details=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_measurement, #has_measurement=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_product_return_policy, #has_product_return_policy=, #height, #height=, #in_product_group_with_id, #in_product_group_with_id=, #is_accessory_or_spare_part_for, #is_accessory_or_spare_part_for=, #is_consumable_for, #is_consumable_for=, #is_family_friendly, #is_family_friendly=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #is_variant_of, #is_variant_of=, #item_condition, #item_condition=, #keywords, #keywords=, #logo, #logo=, #manufacturer, #manufacturer=, #material, #material=, #mobile_url, #mobile_url=, #model, #model=, #mpn, #mpn=, #negative_notes, #negative_notes=, #nsn, #nsn=, #offers, #offers=, #pattern, #pattern=, #positive_notes, #positive_notes=, #product_id, #product_id=, #production_date, #production_date=, #purchase_date, #purchase_date=, #release_date, #release_date=, #review, #review=, #reviews, #reviews=, #size, #size=, #sku, #sku=, #slogan, #slogan=, #weight, #weight=, #width, #width=
Class Method Details
.schema_property_definitions ⇒ Object
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 12 def self.schema_property_definitions { active_ingredient: { schema_name: "activeIngredient", schema_url: "https://schema.org/activeIngredient", comment_lines: ["An active ingredient, typically chemical compounds and/or biologic substances."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, is_proprietary: { schema_name: "isProprietary", schema_url: "https://schema.org/isProprietary", comment_lines: ["True if this item's name is a proprietary/brand name (vs. generic name)."].freeze, ranges: ["Boolean"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legal_status: { schema_name: "legalStatus", schema_url: "https://schema.org/legalStatus", comment_lines: ["The drug or supplement's legal status, including any controlled substance schedules that apply."].freeze, ranges: ["DrugLegalStatus", "MedicalEnumeration", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, maximum_intake: { schema_name: "maximumIntake", schema_url: "https://schema.org/maximumIntake", comment_lines: ["Recommended intake of this supplement for a given population as defined by a specific recommending authority."].freeze, ranges: ["MaximumDoseSchedule"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, mechanism_of_action: { schema_name: "mechanismOfAction", schema_url: "https://schema.org/mechanismOfAction", comment_lines: ["The specific biochemical interaction through which this drug or supplement produces its pharmacological effect."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, non_proprietary_name: { schema_name: "nonProprietaryName", schema_url: "https://schema.org/nonProprietaryName", comment_lines: ["The generic name of this drug or supplement."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, proprietary_name: { schema_name: "proprietaryName", schema_url: "https://schema.org/proprietaryName", comment_lines: ["Proprietary name given to the diet plan, typically by its originator or creator."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, recommended_intake: { schema_name: "recommendedIntake", schema_url: "https://schema.org/recommendedIntake", comment_lines: ["Recommended intake of this supplement for a given population as defined by a specific recommending authority."].freeze, ranges: ["RecommendedDoseSchedule"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, safety_consideration: { schema_name: "safetyConsideration", schema_url: "https://schema.org/safetyConsideration", comment_lines: ["Any potential safety concern associated with the supplement. May include interactions with other drugs and foods, pregnancy, breastfeeding, known adverse reactions, and documented efficacy of the supplement."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, target_population: { schema_name: "targetPopulation", schema_url: "https://schema.org/targetPopulation", comment_lines: ["Characteristics of the population for which this is intended, or which typically uses it, e.g. 'adults'."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#active_ingredient ⇒ Object
An active ingredient, typically chemical compounds and/or biologic substances.
118 119 120 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 118 def active_ingredient read_property(:active_ingredient) end |
#active_ingredient=(value) ⇒ Object
An active ingredient, typically chemical compounds and/or biologic substances.
123 124 125 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 123 def active_ingredient=(value) write_property(:active_ingredient, value) end |
#is_proprietary ⇒ Object
True if this item's name is a proprietary/brand name (vs. generic name).
128 129 130 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 128 def is_proprietary read_property(:is_proprietary) end |
#is_proprietary=(value) ⇒ Object
True if this item's name is a proprietary/brand name (vs. generic name).
133 134 135 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 133 def is_proprietary=(value) write_property(:is_proprietary, value) end |
#legal_status ⇒ Object
The drug or supplement's legal status, including any controlled substance schedules that apply.
138 139 140 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 138 def legal_status read_property(:legal_status) end |
#legal_status=(value) ⇒ Object
The drug or supplement's legal status, including any controlled substance schedules that apply.
143 144 145 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 143 def legal_status=(value) write_property(:legal_status, value) end |
#maximum_intake ⇒ Object
Recommended intake of this supplement for a given population as defined by a specific recommending authority.
148 149 150 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 148 def maximum_intake read_property(:maximum_intake) end |
#maximum_intake=(value) ⇒ Object
Recommended intake of this supplement for a given population as defined by a specific recommending authority.
153 154 155 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 153 def maximum_intake=(value) write_property(:maximum_intake, value) end |
#mechanism_of_action ⇒ Object
The specific biochemical interaction through which this drug or supplement produces its pharmacological effect.
158 159 160 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 158 def mechanism_of_action read_property(:mechanism_of_action) end |
#mechanism_of_action=(value) ⇒ Object
The specific biochemical interaction through which this drug or supplement produces its pharmacological effect.
163 164 165 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 163 def mechanism_of_action=(value) write_property(:mechanism_of_action, value) end |
#non_proprietary_name ⇒ Object
The generic name of this drug or supplement.
168 169 170 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 168 def non_proprietary_name read_property(:non_proprietary_name) end |
#non_proprietary_name=(value) ⇒ Object
The generic name of this drug or supplement.
173 174 175 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 173 def non_proprietary_name=(value) write_property(:non_proprietary_name, value) end |
#proprietary_name ⇒ Object
Proprietary name given to the diet plan, typically by its originator or creator.
178 179 180 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 178 def proprietary_name read_property(:proprietary_name) end |
#proprietary_name=(value) ⇒ Object
Proprietary name given to the diet plan, typically by its originator or creator.
183 184 185 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 183 def proprietary_name=(value) write_property(:proprietary_name, value) end |
#recommended_intake ⇒ Object
Recommended intake of this supplement for a given population as defined by a specific recommending authority.
188 189 190 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 188 def recommended_intake read_property(:recommended_intake) end |
#recommended_intake=(value) ⇒ Object
Recommended intake of this supplement for a given population as defined by a specific recommending authority.
193 194 195 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 193 def recommended_intake=(value) write_property(:recommended_intake, value) end |
#safety_consideration ⇒ Object
Any potential safety concern associated with the supplement. May include interactions with other drugs and foods, pregnancy, breastfeeding, known adverse reactions, and documented efficacy of the supplement.
198 199 200 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 198 def safety_consideration read_property(:safety_consideration) end |
#safety_consideration=(value) ⇒ Object
Any potential safety concern associated with the supplement. May include interactions with other drugs and foods, pregnancy, breastfeeding, known adverse reactions, and documented efficacy of the supplement.
203 204 205 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 203 def safety_consideration=(value) write_property(:safety_consideration, value) end |
#target_population ⇒ Object
Characteristics of the population for which this is intended, or which typically uses it, e.g. 'adults'.
208 209 210 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 208 def target_population read_property(:target_population) end |
#target_population=(value) ⇒ Object
Characteristics of the population for which this is intended, or which typically uses it, e.g. 'adults'.
213 214 215 |
# File 'lib/schema_org/mixins/dietary_supplement.rb', line 213 def target_population=(value) write_property(:target_population, value) end |