Module: SchemaOrg::Mixins::DoseSchedule
- Includes:
- MedicalIntangible
- Included in:
- DoseSchedule, MaximumDoseSchedule, RecommendedDoseSchedule, ReportedDoseSchedule
- Defined in:
- lib/schema_org/mixins/dose_schedule.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#dose_unit ⇒ Object
The unit of the dose, e.g.
-
#dose_unit=(value) ⇒ Object
The unit of the dose, e.g.
-
#dose_value ⇒ Object
The value of the dose, e.g.
-
#dose_value=(value) ⇒ Object
The value of the dose, e.g.
-
#frequency ⇒ Object
How often the dose is taken, e.g.
-
#frequency=(value) ⇒ Object
How often the dose is taken, e.g.
-
#target_population ⇒ Object
Characteristics of the population for which this is intended, or which typically uses it, e.g.
-
#target_population=(value) ⇒ Object
Characteristics of the population for which this is intended, or which typically uses it, e.g.
Methods included from MedicalEntity
#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/schema_org/mixins/dose_schedule.rb', line 11 def self.schema_property_definitions { dose_unit: { schema_name: "doseUnit", schema_url: "https://schema.org/doseUnit", comment_lines: ["The unit of the dose, e.g. 'mg'."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, dose_value: { schema_name: "doseValue", schema_url: "https://schema.org/doseValue", comment_lines: ["The value of the dose, e.g. 500."].freeze, ranges: ["Number", "QualitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, frequency: { schema_name: "frequency", schema_url: "https://schema.org/frequency", comment_lines: ["How often the dose is taken, e.g. 'daily'."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, target_population: { schema_name: "targetPopulation", schema_url: "https://schema.org/targetPopulation", comment_lines: ["Characteristics of the population for which this is intended, or which typically uses it, e.g. 'adults'."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#dose_unit ⇒ Object
The unit of the dose, e.g. 'mg'.
57 58 59 |
# File 'lib/schema_org/mixins/dose_schedule.rb', line 57 def dose_unit read_property(:dose_unit) end |
#dose_unit=(value) ⇒ Object
The unit of the dose, e.g. 'mg'.
62 63 64 |
# File 'lib/schema_org/mixins/dose_schedule.rb', line 62 def dose_unit=(value) write_property(:dose_unit, value) end |
#dose_value ⇒ Object
The value of the dose, e.g. 500.
67 68 69 |
# File 'lib/schema_org/mixins/dose_schedule.rb', line 67 def dose_value read_property(:dose_value) end |
#dose_value=(value) ⇒ Object
The value of the dose, e.g. 500.
72 73 74 |
# File 'lib/schema_org/mixins/dose_schedule.rb', line 72 def dose_value=(value) write_property(:dose_value, value) end |
#frequency ⇒ Object
How often the dose is taken, e.g. 'daily'.
77 78 79 |
# File 'lib/schema_org/mixins/dose_schedule.rb', line 77 def frequency read_property(:frequency) end |
#frequency=(value) ⇒ Object
How often the dose is taken, e.g. 'daily'.
82 83 84 |
# File 'lib/schema_org/mixins/dose_schedule.rb', line 82 def frequency=(value) write_property(:frequency, value) end |
#target_population ⇒ Object
Characteristics of the population for which this is intended, or which typically uses it, e.g. 'adults'.
87 88 89 |
# File 'lib/schema_org/mixins/dose_schedule.rb', line 87 def target_population read_property(:target_population) end |
#target_population=(value) ⇒ Object
Characteristics of the population for which this is intended, or which typically uses it, e.g. 'adults'.
92 93 94 |
# File 'lib/schema_org/mixins/dose_schedule.rb', line 92 def target_population=(value) write_property(:target_population, value) end |