Module: SchemaOrg::Mixins::Drug
Class Method Summary collapse
Instance Method Summary collapse
-
#active_ingredient ⇒ Object
An active ingredient, typically chemical compounds and/or biologic substances.
-
#active_ingredient=(value) ⇒ Object
An active ingredient, typically chemical compounds and/or biologic substances.
-
#administration_route ⇒ Object
A route by which this drug may be administered, e.g.
-
#administration_route=(value) ⇒ Object
A route by which this drug may be administered, e.g.
-
#alcohol_warning ⇒ Object
Any precaution, guidance, contraindication, etc.
-
#alcohol_warning=(value) ⇒ Object
Any precaution, guidance, contraindication, etc.
-
#available_strength ⇒ Object
An available dosage strength for the drug.
-
#available_strength=(value) ⇒ Object
An available dosage strength for the drug.
-
#breastfeeding_warning ⇒ Object
Any precaution, guidance, contraindication, etc.
-
#breastfeeding_warning=(value) ⇒ Object
Any precaution, guidance, contraindication, etc.
-
#clincal_pharmacology ⇒ Object
Description of the absorption and elimination of drugs, including their concentration (pharmacokinetics, pK) and biological effects (pharmacodynamics, pD).
-
#clincal_pharmacology=(value) ⇒ Object
Description of the absorption and elimination of drugs, including their concentration (pharmacokinetics, pK) and biological effects (pharmacodynamics, pD).
-
#clinical_pharmacology ⇒ Object
Description of the absorption and elimination of drugs, including their concentration (pharmacokinetics, pK) and biological effects (pharmacodynamics, pD).
-
#clinical_pharmacology=(value) ⇒ Object
Description of the absorption and elimination of drugs, including their concentration (pharmacokinetics, pK) and biological effects (pharmacodynamics, pD).
-
#dosage_form ⇒ Object
A dosage form in which this drug/supplement is available, e.g.
-
#dosage_form=(value) ⇒ Object
A dosage form in which this drug/supplement is available, e.g.
-
#dose_schedule ⇒ Object
A dosing schedule for the drug for a given population, either observed, recommended, or maximum dose based on the type used.
-
#dose_schedule=(value) ⇒ Object
A dosing schedule for the drug for a given population, either observed, recommended, or maximum dose based on the type used.
-
#drug_class ⇒ Object
The class of drug this belongs to (e.g., statins).
-
#drug_class=(value) ⇒ Object
The class of drug this belongs to (e.g., statins).
-
#drug_unit ⇒ Object
The unit in which the drug is measured, e.g.
-
#drug_unit=(value) ⇒ Object
The unit in which the drug is measured, e.g.
-
#food_warning ⇒ Object
Any precaution, guidance, contraindication, etc.
-
#food_warning=(value) ⇒ Object
Any precaution, guidance, contraindication, etc.
-
#included_in_health_insurance_plan ⇒ Object
The insurance plans that cover this drug.
-
#included_in_health_insurance_plan=(value) ⇒ Object
The insurance plans that cover this drug.
-
#interacting_drug ⇒ Object
Another drug that is known to interact with this drug in a way that impacts the effect of this drug or causes a risk to the patient.
-
#interacting_drug=(value) ⇒ Object
Another drug that is known to interact with this drug in a way that impacts the effect of this drug or causes a risk to the patient.
-
#is_available_generically ⇒ Object
True if the drug is available in a generic form (regardless of name).
-
#is_available_generically=(value) ⇒ Object
True if the drug is available in a generic form (regardless of name).
-
#is_proprietary ⇒ Object
True if this item's name is a proprietary/brand name (vs. generic name).
-
#is_proprietary=(value) ⇒ Object
True if this item's name is a proprietary/brand name (vs. generic name).
-
#label_details ⇒ Object
Link to the drug's label details.
-
#label_details=(value) ⇒ Object
Link to the drug's label details.
-
#legal_status ⇒ Object
The drug or supplement's legal status, including any controlled substance schedules that apply.
-
#legal_status=(value) ⇒ Object
The drug or supplement's legal status, including any controlled substance schedules that apply.
-
#maximum_intake ⇒ Object
Recommended intake of this supplement for a given population as defined by a specific recommending authority.
-
#maximum_intake=(value) ⇒ Object
Recommended intake of this supplement for a given population as defined by a specific recommending authority.
-
#mechanism_of_action ⇒ Object
The specific biochemical interaction through which this drug or supplement produces its pharmacological effect.
-
#mechanism_of_action=(value) ⇒ Object
The specific biochemical interaction through which this drug or supplement produces its pharmacological effect.
-
#non_proprietary_name ⇒ Object
The generic name of this drug or supplement.
-
#non_proprietary_name=(value) ⇒ Object
The generic name of this drug or supplement.
-
#overdosage ⇒ Object
Any information related to overdose on a drug, including signs or symptoms, treatments, contact information for emergency response.
-
#overdosage=(value) ⇒ Object
Any information related to overdose on a drug, including signs or symptoms, treatments, contact information for emergency response.
-
#pregnancy_category ⇒ Object
Pregnancy category of this drug.
-
#pregnancy_category=(value) ⇒ Object
Pregnancy category of this drug.
-
#pregnancy_warning ⇒ Object
Any precaution, guidance, contraindication, etc.
-
#pregnancy_warning=(value) ⇒ Object
Any precaution, guidance, contraindication, etc.
-
#prescribing_info ⇒ Object
Link to prescribing information for the drug.
-
#prescribing_info=(value) ⇒ Object
Link to prescribing information for the drug.
-
#prescription_status ⇒ Object
Indicates the status of drug prescription, e.g.
-
#prescription_status=(value) ⇒ Object
Indicates the status of drug prescription, e.g.
-
#proprietary_name ⇒ Object
Proprietary name given to the diet plan, typically by its originator or creator.
-
#proprietary_name=(value) ⇒ Object
Proprietary name given to the diet plan, typically by its originator or creator.
-
#related_drug ⇒ Object
Any other drug related to this one, for example commonly-prescribed alternatives.
-
#related_drug=(value) ⇒ Object
Any other drug related to this one, for example commonly-prescribed alternatives.
-
#rxcui ⇒ Object
The RxCUI drug identifier from RXNORM.
-
#rxcui=(value) ⇒ Object
The RxCUI drug identifier from RXNORM.
-
#warning ⇒ Object
Any FDA or other warnings about the drug (text or URL).
-
#warning=(value) ⇒ Object
Any FDA or other warnings about the drug (text or URL).
Methods included from MedicalEntity
#code, #code=, #funding, #funding=, #guideline, #guideline=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Methods included from Product
#additional_property, #additional_property=, #aggregate_rating, #aggregate_rating=, #asin, #asin=, #audience, #audience=, #award, #award=, #awards, #awards=, #brand, #brand=, #category, #category=, #color, #color=, #color_swatch, #color_swatch=, #country_of_assembly, #country_of_assembly=, #country_of_last_processing, #country_of_last_processing=, #country_of_origin, #country_of_origin=, #depth, #depth=, #display_location, #display_location=, #funding, #funding=, #gtin, #gtin12, #gtin12=, #gtin13, #gtin13=, #gtin14, #gtin14=, #gtin8, #gtin8=, #gtin=, #has_adult_consideration, #has_adult_consideration=, #has_certification, #has_certification=, #has_energy_consumption_details, #has_energy_consumption_details=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_measurement, #has_measurement=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_product_return_policy, #has_product_return_policy=, #height, #height=, #in_product_group_with_id, #in_product_group_with_id=, #is_accessory_or_spare_part_for, #is_accessory_or_spare_part_for=, #is_consumable_for, #is_consumable_for=, #is_family_friendly, #is_family_friendly=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #is_variant_of, #is_variant_of=, #item_condition, #item_condition=, #keywords, #keywords=, #logo, #logo=, #manufacturer, #manufacturer=, #material, #material=, #mobile_url, #mobile_url=, #model, #model=, #mpn, #mpn=, #negative_notes, #negative_notes=, #nsn, #nsn=, #offers, #offers=, #pattern, #pattern=, #positive_notes, #positive_notes=, #product_id, #product_id=, #production_date, #production_date=, #purchase_date, #purchase_date=, #release_date, #release_date=, #review, #review=, #reviews, #reviews=, #size, #size=, #sku, #sku=, #slogan, #slogan=, #weight, #weight=, #width, #width=
Class Method Details
.schema_property_definitions ⇒ Object
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/schema_org/mixins/drug.rb', line 12 def self.schema_property_definitions { active_ingredient: { schema_name: "activeIngredient", schema_url: "https://schema.org/activeIngredient", comment_lines: ["An active ingredient, typically chemical compounds and/or biologic substances."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, administration_route: { schema_name: "administrationRoute", schema_url: "https://schema.org/administrationRoute", comment_lines: ["A route by which this drug may be administered, e.g. 'oral'."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, alcohol_warning: { schema_name: "alcoholWarning", schema_url: "https://schema.org/alcoholWarning", comment_lines: ["Any precaution, guidance, contraindication, etc. related to consumption of alcohol while taking this drug."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, available_strength: { schema_name: "availableStrength", schema_url: "https://schema.org/availableStrength", comment_lines: ["An available dosage strength for the drug."].freeze, ranges: ["DrugStrength"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, breastfeeding_warning: { schema_name: "breastfeedingWarning", schema_url: "https://schema.org/breastfeedingWarning", comment_lines: ["Any precaution, guidance, contraindication, etc. related to this drug's use by breastfeeding mothers."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, clincal_pharmacology: { schema_name: "clincalPharmacology", schema_url: "https://schema.org/clincalPharmacology", comment_lines: ["Description of the absorption and elimination of drugs, including their concentration (pharmacokinetics, pK) and biological effects (pharmacodynamics, pD)."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "clinicalPharmacology", supersedes: nil }.freeze, clinical_pharmacology: { schema_name: "clinicalPharmacology", schema_url: "https://schema.org/clinicalPharmacology", comment_lines: ["Description of the absorption and elimination of drugs, including their concentration (pharmacokinetics, pK) and biological effects (pharmacodynamics, pD)."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["clincalPharmacology"].freeze }.freeze, dosage_form: { schema_name: "dosageForm", schema_url: "https://schema.org/dosageForm", comment_lines: ["A dosage form in which this drug/supplement is available, e.g. 'tablet', 'suspension', 'injection'."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, dose_schedule: { schema_name: "doseSchedule", schema_url: "https://schema.org/doseSchedule", comment_lines: ["A dosing schedule for the drug for a given population, either observed, recommended, or maximum dose based on the type used."].freeze, ranges: ["DoseSchedule"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, drug_class: { schema_name: "drugClass", schema_url: "https://schema.org/drugClass", comment_lines: ["The class of drug this belongs to (e.g., statins)."].freeze, ranges: ["DrugClass"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, drug_unit: { schema_name: "drugUnit", schema_url: "https://schema.org/drugUnit", comment_lines: ["The unit in which the drug is measured, e.g. '5 mg tablet'."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, food_warning: { schema_name: "foodWarning", schema_url: "https://schema.org/foodWarning", comment_lines: ["Any precaution, guidance, contraindication, etc. related to consumption of specific foods while taking this drug."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, included_in_health_insurance_plan: { schema_name: "includedInHealthInsurancePlan", schema_url: "https://schema.org/includedInHealthInsurancePlan", comment_lines: ["The insurance plans that cover this drug."].freeze, ranges: ["HealthInsurancePlan"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, interacting_drug: { schema_name: "interactingDrug", schema_url: "https://schema.org/interactingDrug", comment_lines: ["Another drug that is known to interact with this drug in a way that impacts the effect of this drug or causes a risk to the patient. Note: disease interactions are typically captured as contraindications."].freeze, ranges: ["Drug"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, is_available_generically: { schema_name: "isAvailableGenerically", schema_url: "https://schema.org/isAvailableGenerically", comment_lines: ["True if the drug is available in a generic form (regardless of name)."].freeze, ranges: ["Boolean"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, is_proprietary: { schema_name: "isProprietary", schema_url: "https://schema.org/isProprietary", comment_lines: ["True if this item's name is a proprietary/brand name (vs. generic name)."].freeze, ranges: ["Boolean"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, label_details: { schema_name: "labelDetails", schema_url: "https://schema.org/labelDetails", comment_lines: ["Link to the drug's label details."].freeze, ranges: ["URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legal_status: { schema_name: "legalStatus", schema_url: "https://schema.org/legalStatus", comment_lines: ["The drug or supplement's legal status, including any controlled substance schedules that apply."].freeze, ranges: ["DrugLegalStatus", "MedicalEnumeration", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, maximum_intake: { schema_name: "maximumIntake", schema_url: "https://schema.org/maximumIntake", comment_lines: ["Recommended intake of this supplement for a given population as defined by a specific recommending authority."].freeze, ranges: ["MaximumDoseSchedule"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, mechanism_of_action: { schema_name: "mechanismOfAction", schema_url: "https://schema.org/mechanismOfAction", comment_lines: ["The specific biochemical interaction through which this drug or supplement produces its pharmacological effect."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, non_proprietary_name: { schema_name: "nonProprietaryName", schema_url: "https://schema.org/nonProprietaryName", comment_lines: ["The generic name of this drug or supplement."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, overdosage: { schema_name: "overdosage", schema_url: "https://schema.org/overdosage", comment_lines: ["Any information related to overdose on a drug, including signs or symptoms, treatments, contact information for emergency response."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, pregnancy_category: { schema_name: "pregnancyCategory", schema_url: "https://schema.org/pregnancyCategory", comment_lines: ["Pregnancy category of this drug."].freeze, ranges: ["DrugPregnancyCategory"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, pregnancy_warning: { schema_name: "pregnancyWarning", schema_url: "https://schema.org/pregnancyWarning", comment_lines: ["Any precaution, guidance, contraindication, etc. related to this drug's use during pregnancy."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, prescribing_info: { schema_name: "prescribingInfo", schema_url: "https://schema.org/prescribingInfo", comment_lines: ["Link to prescribing information for the drug."].freeze, ranges: ["URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, prescription_status: { schema_name: "prescriptionStatus", schema_url: "https://schema.org/prescriptionStatus", comment_lines: ["Indicates the status of drug prescription, e.g. local catalogs classifications or whether the drug is available by prescription or over-the-counter, etc."].freeze, ranges: ["DrugPrescriptionStatus", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, proprietary_name: { schema_name: "proprietaryName", schema_url: "https://schema.org/proprietaryName", comment_lines: ["Proprietary name given to the diet plan, typically by its originator or creator."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, related_drug: { schema_name: "relatedDrug", schema_url: "https://schema.org/relatedDrug", comment_lines: ["Any other drug related to this one, for example commonly-prescribed alternatives."].freeze, ranges: ["Drug"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, rxcui: { schema_name: "rxcui", schema_url: "https://schema.org/rxcui", comment_lines: ["The RxCUI drug identifier from RXNORM."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, warning: { schema_name: "warning", schema_url: "https://schema.org/warning", comment_lines: ["Any FDA or other warnings about the drug (text or URL)."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#active_ingredient ⇒ Object
An active ingredient, typically chemical compounds and/or biologic substances.
318 319 320 |
# File 'lib/schema_org/mixins/drug.rb', line 318 def active_ingredient read_property(:active_ingredient) end |
#active_ingredient=(value) ⇒ Object
An active ingredient, typically chemical compounds and/or biologic substances.
323 324 325 |
# File 'lib/schema_org/mixins/drug.rb', line 323 def active_ingredient=(value) write_property(:active_ingredient, value) end |
#administration_route ⇒ Object
A route by which this drug may be administered, e.g. 'oral'.
328 329 330 |
# File 'lib/schema_org/mixins/drug.rb', line 328 def administration_route read_property(:administration_route) end |
#administration_route=(value) ⇒ Object
A route by which this drug may be administered, e.g. 'oral'.
333 334 335 |
# File 'lib/schema_org/mixins/drug.rb', line 333 def administration_route=(value) write_property(:administration_route, value) end |
#alcohol_warning ⇒ Object
Any precaution, guidance, contraindication, etc. related to consumption of alcohol while taking this drug.
338 339 340 |
# File 'lib/schema_org/mixins/drug.rb', line 338 def alcohol_warning read_property(:alcohol_warning) end |
#alcohol_warning=(value) ⇒ Object
Any precaution, guidance, contraindication, etc. related to consumption of alcohol while taking this drug.
343 344 345 |
# File 'lib/schema_org/mixins/drug.rb', line 343 def alcohol_warning=(value) write_property(:alcohol_warning, value) end |
#available_strength ⇒ Object
An available dosage strength for the drug.
348 349 350 |
# File 'lib/schema_org/mixins/drug.rb', line 348 def available_strength read_property(:available_strength) end |
#available_strength=(value) ⇒ Object
An available dosage strength for the drug.
353 354 355 |
# File 'lib/schema_org/mixins/drug.rb', line 353 def available_strength=(value) write_property(:available_strength, value) end |
#breastfeeding_warning ⇒ Object
Any precaution, guidance, contraindication, etc. related to this drug's use by breastfeeding mothers.
358 359 360 |
# File 'lib/schema_org/mixins/drug.rb', line 358 def breastfeeding_warning read_property(:breastfeeding_warning) end |
#breastfeeding_warning=(value) ⇒ Object
Any precaution, guidance, contraindication, etc. related to this drug's use by breastfeeding mothers.
363 364 365 |
# File 'lib/schema_org/mixins/drug.rb', line 363 def breastfeeding_warning=(value) write_property(:breastfeeding_warning, value) end |
#clincal_pharmacology ⇒ Object
Description of the absorption and elimination of drugs, including their concentration (pharmacokinetics, pK) and biological effects (pharmacodynamics, pD).
Superseded by clinicalPharmacology.
369 370 371 |
# File 'lib/schema_org/mixins/drug.rb', line 369 def clincal_pharmacology read_property(:clincal_pharmacology) end |
#clincal_pharmacology=(value) ⇒ Object
Description of the absorption and elimination of drugs, including their concentration (pharmacokinetics, pK) and biological effects (pharmacodynamics, pD).
Superseded by clinicalPharmacology.
375 376 377 |
# File 'lib/schema_org/mixins/drug.rb', line 375 def clincal_pharmacology=(value) write_property(:clincal_pharmacology, value) end |
#clinical_pharmacology ⇒ Object
Description of the absorption and elimination of drugs, including their concentration (pharmacokinetics, pK) and biological effects (pharmacodynamics, pD).
Supersedes clincalPharmacology.
381 382 383 |
# File 'lib/schema_org/mixins/drug.rb', line 381 def clinical_pharmacology read_property(:clinical_pharmacology) end |
#clinical_pharmacology=(value) ⇒ Object
Description of the absorption and elimination of drugs, including their concentration (pharmacokinetics, pK) and biological effects (pharmacodynamics, pD).
Supersedes clincalPharmacology.
387 388 389 |
# File 'lib/schema_org/mixins/drug.rb', line 387 def clinical_pharmacology=(value) write_property(:clinical_pharmacology, value) end |
#dosage_form ⇒ Object
A dosage form in which this drug/supplement is available, e.g. 'tablet', 'suspension', 'injection'.
392 393 394 |
# File 'lib/schema_org/mixins/drug.rb', line 392 def dosage_form read_property(:dosage_form) end |
#dosage_form=(value) ⇒ Object
A dosage form in which this drug/supplement is available, e.g. 'tablet', 'suspension', 'injection'.
397 398 399 |
# File 'lib/schema_org/mixins/drug.rb', line 397 def dosage_form=(value) write_property(:dosage_form, value) end |
#dose_schedule ⇒ Object
A dosing schedule for the drug for a given population, either observed, recommended, or maximum dose based on the type used.
402 403 404 |
# File 'lib/schema_org/mixins/drug.rb', line 402 def dose_schedule read_property(:dose_schedule) end |
#dose_schedule=(value) ⇒ Object
A dosing schedule for the drug for a given population, either observed, recommended, or maximum dose based on the type used.
407 408 409 |
# File 'lib/schema_org/mixins/drug.rb', line 407 def dose_schedule=(value) write_property(:dose_schedule, value) end |
#drug_class ⇒ Object
The class of drug this belongs to (e.g., statins).
412 413 414 |
# File 'lib/schema_org/mixins/drug.rb', line 412 def drug_class read_property(:drug_class) end |
#drug_class=(value) ⇒ Object
The class of drug this belongs to (e.g., statins).
417 418 419 |
# File 'lib/schema_org/mixins/drug.rb', line 417 def drug_class=(value) write_property(:drug_class, value) end |
#drug_unit ⇒ Object
The unit in which the drug is measured, e.g. '5 mg tablet'.
422 423 424 |
# File 'lib/schema_org/mixins/drug.rb', line 422 def drug_unit read_property(:drug_unit) end |
#drug_unit=(value) ⇒ Object
The unit in which the drug is measured, e.g. '5 mg tablet'.
427 428 429 |
# File 'lib/schema_org/mixins/drug.rb', line 427 def drug_unit=(value) write_property(:drug_unit, value) end |
#food_warning ⇒ Object
Any precaution, guidance, contraindication, etc. related to consumption of specific foods while taking this drug.
432 433 434 |
# File 'lib/schema_org/mixins/drug.rb', line 432 def food_warning read_property(:food_warning) end |
#food_warning=(value) ⇒ Object
Any precaution, guidance, contraindication, etc. related to consumption of specific foods while taking this drug.
437 438 439 |
# File 'lib/schema_org/mixins/drug.rb', line 437 def food_warning=(value) write_property(:food_warning, value) end |
#included_in_health_insurance_plan ⇒ Object
The insurance plans that cover this drug.
442 443 444 |
# File 'lib/schema_org/mixins/drug.rb', line 442 def included_in_health_insurance_plan read_property(:included_in_health_insurance_plan) end |
#included_in_health_insurance_plan=(value) ⇒ Object
The insurance plans that cover this drug.
447 448 449 |
# File 'lib/schema_org/mixins/drug.rb', line 447 def included_in_health_insurance_plan=(value) write_property(:included_in_health_insurance_plan, value) end |
#interacting_drug ⇒ Object
Another drug that is known to interact with this drug in a way that impacts the effect of this drug or causes a risk to the patient. Note: disease interactions are typically captured as contraindications.
452 453 454 |
# File 'lib/schema_org/mixins/drug.rb', line 452 def interacting_drug read_property(:interacting_drug) end |
#interacting_drug=(value) ⇒ Object
Another drug that is known to interact with this drug in a way that impacts the effect of this drug or causes a risk to the patient. Note: disease interactions are typically captured as contraindications.
457 458 459 |
# File 'lib/schema_org/mixins/drug.rb', line 457 def interacting_drug=(value) write_property(:interacting_drug, value) end |
#is_available_generically ⇒ Object
True if the drug is available in a generic form (regardless of name).
462 463 464 |
# File 'lib/schema_org/mixins/drug.rb', line 462 def is_available_generically read_property(:is_available_generically) end |
#is_available_generically=(value) ⇒ Object
True if the drug is available in a generic form (regardless of name).
467 468 469 |
# File 'lib/schema_org/mixins/drug.rb', line 467 def is_available_generically=(value) write_property(:is_available_generically, value) end |
#is_proprietary ⇒ Object
True if this item's name is a proprietary/brand name (vs. generic name).
472 473 474 |
# File 'lib/schema_org/mixins/drug.rb', line 472 def is_proprietary read_property(:is_proprietary) end |
#is_proprietary=(value) ⇒ Object
True if this item's name is a proprietary/brand name (vs. generic name).
477 478 479 |
# File 'lib/schema_org/mixins/drug.rb', line 477 def is_proprietary=(value) write_property(:is_proprietary, value) end |
#label_details ⇒ Object
Link to the drug's label details.
482 483 484 |
# File 'lib/schema_org/mixins/drug.rb', line 482 def label_details read_property(:label_details) end |
#label_details=(value) ⇒ Object
Link to the drug's label details.
487 488 489 |
# File 'lib/schema_org/mixins/drug.rb', line 487 def label_details=(value) write_property(:label_details, value) end |
#legal_status ⇒ Object
The drug or supplement's legal status, including any controlled substance schedules that apply.
492 493 494 |
# File 'lib/schema_org/mixins/drug.rb', line 492 def legal_status read_property(:legal_status) end |
#legal_status=(value) ⇒ Object
The drug or supplement's legal status, including any controlled substance schedules that apply.
497 498 499 |
# File 'lib/schema_org/mixins/drug.rb', line 497 def legal_status=(value) write_property(:legal_status, value) end |
#maximum_intake ⇒ Object
Recommended intake of this supplement for a given population as defined by a specific recommending authority.
502 503 504 |
# File 'lib/schema_org/mixins/drug.rb', line 502 def maximum_intake read_property(:maximum_intake) end |
#maximum_intake=(value) ⇒ Object
Recommended intake of this supplement for a given population as defined by a specific recommending authority.
507 508 509 |
# File 'lib/schema_org/mixins/drug.rb', line 507 def maximum_intake=(value) write_property(:maximum_intake, value) end |
#mechanism_of_action ⇒ Object
The specific biochemical interaction through which this drug or supplement produces its pharmacological effect.
512 513 514 |
# File 'lib/schema_org/mixins/drug.rb', line 512 def mechanism_of_action read_property(:mechanism_of_action) end |
#mechanism_of_action=(value) ⇒ Object
The specific biochemical interaction through which this drug or supplement produces its pharmacological effect.
517 518 519 |
# File 'lib/schema_org/mixins/drug.rb', line 517 def mechanism_of_action=(value) write_property(:mechanism_of_action, value) end |
#non_proprietary_name ⇒ Object
The generic name of this drug or supplement.
522 523 524 |
# File 'lib/schema_org/mixins/drug.rb', line 522 def non_proprietary_name read_property(:non_proprietary_name) end |
#non_proprietary_name=(value) ⇒ Object
The generic name of this drug or supplement.
527 528 529 |
# File 'lib/schema_org/mixins/drug.rb', line 527 def non_proprietary_name=(value) write_property(:non_proprietary_name, value) end |
#overdosage ⇒ Object
Any information related to overdose on a drug, including signs or symptoms, treatments, contact information for emergency response.
532 533 534 |
# File 'lib/schema_org/mixins/drug.rb', line 532 def overdosage read_property(:overdosage) end |
#overdosage=(value) ⇒ Object
Any information related to overdose on a drug, including signs or symptoms, treatments, contact information for emergency response.
537 538 539 |
# File 'lib/schema_org/mixins/drug.rb', line 537 def overdosage=(value) write_property(:overdosage, value) end |
#pregnancy_category ⇒ Object
Pregnancy category of this drug.
542 543 544 |
# File 'lib/schema_org/mixins/drug.rb', line 542 def pregnancy_category read_property(:pregnancy_category) end |
#pregnancy_category=(value) ⇒ Object
Pregnancy category of this drug.
547 548 549 |
# File 'lib/schema_org/mixins/drug.rb', line 547 def pregnancy_category=(value) write_property(:pregnancy_category, value) end |
#pregnancy_warning ⇒ Object
Any precaution, guidance, contraindication, etc. related to this drug's use during pregnancy.
552 553 554 |
# File 'lib/schema_org/mixins/drug.rb', line 552 def pregnancy_warning read_property(:pregnancy_warning) end |
#pregnancy_warning=(value) ⇒ Object
Any precaution, guidance, contraindication, etc. related to this drug's use during pregnancy.
557 558 559 |
# File 'lib/schema_org/mixins/drug.rb', line 557 def pregnancy_warning=(value) write_property(:pregnancy_warning, value) end |
#prescribing_info ⇒ Object
Link to prescribing information for the drug.
562 563 564 |
# File 'lib/schema_org/mixins/drug.rb', line 562 def prescribing_info read_property(:prescribing_info) end |
#prescribing_info=(value) ⇒ Object
Link to prescribing information for the drug.
567 568 569 |
# File 'lib/schema_org/mixins/drug.rb', line 567 def prescribing_info=(value) write_property(:prescribing_info, value) end |
#prescription_status ⇒ Object
Indicates the status of drug prescription, e.g. local catalogs classifications or whether the drug is available by prescription or over-the-counter, etc.
572 573 574 |
# File 'lib/schema_org/mixins/drug.rb', line 572 def prescription_status read_property(:prescription_status) end |
#prescription_status=(value) ⇒ Object
Indicates the status of drug prescription, e.g. local catalogs classifications or whether the drug is available by prescription or over-the-counter, etc.
577 578 579 |
# File 'lib/schema_org/mixins/drug.rb', line 577 def prescription_status=(value) write_property(:prescription_status, value) end |
#proprietary_name ⇒ Object
Proprietary name given to the diet plan, typically by its originator or creator.
582 583 584 |
# File 'lib/schema_org/mixins/drug.rb', line 582 def proprietary_name read_property(:proprietary_name) end |
#proprietary_name=(value) ⇒ Object
Proprietary name given to the diet plan, typically by its originator or creator.
587 588 589 |
# File 'lib/schema_org/mixins/drug.rb', line 587 def proprietary_name=(value) write_property(:proprietary_name, value) end |
#related_drug ⇒ Object
Any other drug related to this one, for example commonly-prescribed alternatives.
592 593 594 |
# File 'lib/schema_org/mixins/drug.rb', line 592 def read_property(:related_drug) end |
#related_drug=(value) ⇒ Object
Any other drug related to this one, for example commonly-prescribed alternatives.
597 598 599 |
# File 'lib/schema_org/mixins/drug.rb', line 597 def (value) write_property(:related_drug, value) end |
#rxcui ⇒ Object
The RxCUI drug identifier from RXNORM.
602 603 604 |
# File 'lib/schema_org/mixins/drug.rb', line 602 def rxcui read_property(:rxcui) end |
#rxcui=(value) ⇒ Object
The RxCUI drug identifier from RXNORM.
607 608 609 |
# File 'lib/schema_org/mixins/drug.rb', line 607 def rxcui=(value) write_property(:rxcui, value) end |
#warning ⇒ Object
Any FDA or other warnings about the drug (text or URL).
612 613 614 |
# File 'lib/schema_org/mixins/drug.rb', line 612 def warning read_property(:warning) end |
#warning=(value) ⇒ Object
Any FDA or other warnings about the drug (text or URL).
617 618 619 |
# File 'lib/schema_org/mixins/drug.rb', line 617 def warning=(value) write_property(:warning, value) end |