Module: SchemaOrg::Mixins::EducationalOccupationalProgram
- Includes:
- Intangible
- Included in:
- EducationalOccupationalProgram, WorkBasedProgram
- Defined in:
- lib/schema_org/mixins/educational_occupational_program.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#application_deadline ⇒ Object
The date on which the program stops collecting applications for the next enrollment cycle.
-
#application_deadline=(value) ⇒ Object
The date on which the program stops collecting applications for the next enrollment cycle.
-
#application_start_date ⇒ Object
The date at which the program begins collecting applications for the next enrollment cycle.
-
#application_start_date=(value) ⇒ Object
The date at which the program begins collecting applications for the next enrollment cycle.
-
#day_of_week ⇒ Object
The day of the week for which these opening hours are valid.
-
#day_of_week=(value) ⇒ Object
The day of the week for which these opening hours are valid.
-
#educational_credential_awarded ⇒ Object
A description of the qualification, award, certificate, diploma or other educational credential awarded as a consequence of successful completion of this course or program.
-
#educational_credential_awarded=(value) ⇒ Object
A description of the qualification, award, certificate, diploma or other educational credential awarded as a consequence of successful completion of this course or program.
-
#educational_program_mode ⇒ Object
Similar to courseMode, the medium or means of delivery of the program as a whole.
-
#educational_program_mode=(value) ⇒ Object
Similar to courseMode, the medium or means of delivery of the program as a whole.
-
#end_date ⇒ Object
The end date and time of the item (in ISO 8601 date format).
-
#end_date=(value) ⇒ Object
The end date and time of the item (in ISO 8601 date format).
-
#financial_aid_eligible ⇒ Object
A financial aid type or program which students may use to pay for tuition or fees associated with the program.
-
#financial_aid_eligible=(value) ⇒ Object
A financial aid type or program which students may use to pay for tuition or fees associated with the program.
-
#has_course ⇒ Object
A course or class that is one of the learning opportunities that constitute an educational / occupational program.
-
#has_course=(value) ⇒ Object
A course or class that is one of the learning opportunities that constitute an educational / occupational program.
-
#maximum_enrollment ⇒ Object
The maximum number of students who may be enrolled in the program.
-
#maximum_enrollment=(value) ⇒ Object
The maximum number of students who may be enrolled in the program.
-
#number_of_credits ⇒ Object
The number of credits or units awarded by a Course or required to complete an EducationalOccupationalProgram.
-
#number_of_credits=(value) ⇒ Object
The number of credits or units awarded by a Course or required to complete an EducationalOccupationalProgram.
-
#occupational_category ⇒ Object
A category describing the job, preferably using a term from a taxonomy such as BLS O*NET-SOC, ISCO-08 or similar, with the property repeated for each applicable value.
-
#occupational_category=(value) ⇒ Object
A category describing the job, preferably using a term from a taxonomy such as BLS O*NET-SOC, ISCO-08 or similar, with the property repeated for each applicable value.
-
#occupational_credential_awarded ⇒ Object
A description of the qualification, award, certificate, diploma or other occupational credential awarded as a consequence of successful completion of this course or program.
-
#occupational_credential_awarded=(value) ⇒ Object
A description of the qualification, award, certificate, diploma or other occupational credential awarded as a consequence of successful completion of this course or program.
-
#offers ⇒ Object
An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event.
-
#offers=(value) ⇒ Object
An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event.
-
#program_prerequisites ⇒ Object
Prerequisites for enrolling in the program.
-
#program_prerequisites=(value) ⇒ Object
Prerequisites for enrolling in the program.
-
#program_type ⇒ Object
The type of educational or occupational program.
-
#program_type=(value) ⇒ Object
The type of educational or occupational program.
-
#provider ⇒ Object
The service provider, service operator, or service performer; the goods producer.
-
#provider=(value) ⇒ Object
The service provider, service operator, or service performer; the goods producer.
-
#salary_upon_completion ⇒ Object
The expected salary upon completing the training.
-
#salary_upon_completion=(value) ⇒ Object
The expected salary upon completing the training.
-
#start_date ⇒ Object
The start date and time of the item (in ISO 8601 date format).
-
#start_date=(value) ⇒ Object
The start date and time of the item (in ISO 8601 date format).
-
#term_duration ⇒ Object
The amount of time in a term as defined by the institution.
-
#term_duration=(value) ⇒ Object
The amount of time in a term as defined by the institution.
-
#terms_per_year ⇒ Object
The number of times terms of study are offered per year.
-
#terms_per_year=(value) ⇒ Object
The number of times terms of study are offered per year.
-
#time_of_day ⇒ Object
The time of day the program normally runs.
-
#time_of_day=(value) ⇒ Object
The time of day the program normally runs.
-
#time_to_complete ⇒ Object
The expected length of time to complete the program if attending full-time.
-
#time_to_complete=(value) ⇒ Object
The expected length of time to complete the program if attending full-time.
-
#training_salary ⇒ Object
The estimated salary earned while in the program.
-
#training_salary=(value) ⇒ Object
The estimated salary earned while in the program.
-
#typical_credits_per_term ⇒ Object
The number of credits or units a full-time student would be expected to take in 1 term however 'term' is defined by the institution.
-
#typical_credits_per_term=(value) ⇒ Object
The number of credits or units a full-time student would be expected to take in 1 term however 'term' is defined by the institution.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 11 def self.schema_property_definitions { application_deadline: { schema_name: "applicationDeadline", schema_url: "https://schema.org/applicationDeadline", comment_lines: ["The date on which the program stops collecting applications for the next enrollment cycle. Flexible application deadlines (for example, a program with rolling admissions) can be described in a textual string, rather than as a DateTime."].freeze, ranges: ["Date", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, application_start_date: { schema_name: "applicationStartDate", schema_url: "https://schema.org/applicationStartDate", comment_lines: ["The date at which the program begins collecting applications for the next enrollment cycle."].freeze, ranges: ["Date"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, day_of_week: { schema_name: "dayOfWeek", schema_url: "https://schema.org/dayOfWeek", comment_lines: ["The day of the week for which these opening hours are valid."].freeze, ranges: ["DayOfWeek"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, educational_credential_awarded: { schema_name: "educationalCredentialAwarded", schema_url: "https://schema.org/educationalCredentialAwarded", comment_lines: ["A description of the qualification, award, certificate, diploma or other educational credential awarded as a consequence of successful completion of this course or program."].freeze, ranges: ["EducationalOccupationalCredential", "Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, educational_program_mode: { schema_name: "educationalProgramMode", schema_url: "https://schema.org/educationalProgramMode", comment_lines: ["Similar to courseMode, the medium or means of delivery of the program as a whole. The value may either be a text label (e.g. \"online\", \"onsite\" or \"blended\"; \"synchronous\" or \"asynchronous\"; \"full-time\" or \"part-time\") or a URL reference to a term from a controlled vocabulary (e.g. https://ceds.ed.gov/element/001311#Asynchronous )."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, end_date: { schema_name: "endDate", schema_url: "https://schema.org/endDate", comment_lines: ["The end date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601))."].freeze, ranges: ["Date", "DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, financial_aid_eligible: { schema_name: "financialAidEligible", schema_url: "https://schema.org/financialAidEligible", comment_lines: ["A financial aid type or program which students may use to pay for tuition or fees associated with the program."].freeze, ranges: ["DefinedTerm", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, has_course: { schema_name: "hasCourse", schema_url: "https://schema.org/hasCourse", comment_lines: ["A course or class that is one of the learning opportunities that constitute an educational / occupational program. No information is implied about whether the course is mandatory or optional; no guarantee is implied about whether the course will be available to everyone on the program."].freeze, ranges: ["Course"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, maximum_enrollment: { schema_name: "maximumEnrollment", schema_url: "https://schema.org/maximumEnrollment", comment_lines: ["The maximum number of students who may be enrolled in the program."].freeze, ranges: ["Integer"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, number_of_credits: { schema_name: "numberOfCredits", schema_url: "https://schema.org/numberOfCredits", comment_lines: ["The number of credits or units awarded by a Course or required to complete an EducationalOccupationalProgram."].freeze, ranges: ["Integer", "StructuredValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, occupational_category: { schema_name: "occupationalCategory", schema_url: "https://schema.org/occupationalCategory", comment_lines: ["A category describing the job, preferably using a term from a taxonomy such as [BLS O*NET-SOC](http://www.onetcenter.org/taxonomy.html), [ISCO-08](https://www.ilo.org/public/english/bureau/stat/isco/isco08/) or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided.\\n", "Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC."].freeze, ranges: ["CategoryCode", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, occupational_credential_awarded: { schema_name: "occupationalCredentialAwarded", schema_url: "https://schema.org/occupationalCredentialAwarded", comment_lines: ["A description of the qualification, award, certificate, diploma or other occupational credential awarded as a consequence of successful completion of this course or program."].freeze, ranges: ["EducationalOccupationalCredential", "Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, offers: { schema_name: "offers", schema_url: "https://schema.org/offers", comment_lines: ["An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer."].freeze, ranges: ["Demand", "Offer"].freeze, external_ranges: [].freeze, inverse_of: "itemOffered", superseded_by: nil, supersedes: nil }.freeze, program_prerequisites: { schema_name: "programPrerequisites", schema_url: "https://schema.org/programPrerequisites", comment_lines: ["Prerequisites for enrolling in the program."].freeze, ranges: ["AlignmentObject", "Course", "EducationalOccupationalCredential", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, program_type: { schema_name: "programType", schema_url: "https://schema.org/programType", comment_lines: ["The type of educational or occupational program. For example, classroom, internship, alternance, etc."].freeze, ranges: ["DefinedTerm", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, provider: { schema_name: "provider", schema_url: "https://schema.org/provider", comment_lines: ["The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["carrier"].freeze }.freeze, salary_upon_completion: { schema_name: "salaryUponCompletion", schema_url: "https://schema.org/salaryUponCompletion", comment_lines: ["The expected salary upon completing the training."].freeze, ranges: ["MonetaryAmountDistribution"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, start_date: { schema_name: "startDate", schema_url: "https://schema.org/startDate", comment_lines: ["The start date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601))."].freeze, ranges: ["Date", "DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, term_duration: { schema_name: "termDuration", schema_url: "https://schema.org/termDuration", comment_lines: ["The amount of time in a term as defined by the institution. A term is a length of time where students take one or more classes. Semesters and quarters are common units for term."].freeze, ranges: ["Duration"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, terms_per_year: { schema_name: "termsPerYear", schema_url: "https://schema.org/termsPerYear", comment_lines: ["The number of times terms of study are offered per year. Semesters and quarters are common units for term. For example, if the student can only take 2 semesters for the program in one year, then termsPerYear should be 2."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, time_of_day: { schema_name: "timeOfDay", schema_url: "https://schema.org/timeOfDay", comment_lines: ["The time of day the program normally runs. For example, \"evenings\"."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, time_to_complete: { schema_name: "timeToComplete", schema_url: "https://schema.org/timeToComplete", comment_lines: ["The expected length of time to complete the program if attending full-time."].freeze, ranges: ["Duration"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, training_salary: { schema_name: "trainingSalary", schema_url: "https://schema.org/trainingSalary", comment_lines: ["The estimated salary earned while in the program."].freeze, ranges: ["MonetaryAmountDistribution"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, typical_credits_per_term: { schema_name: "typicalCreditsPerTerm", schema_url: "https://schema.org/typicalCreditsPerTerm", comment_lines: ["The number of credits or units a full-time student would be expected to take in 1 term however 'term' is defined by the institution."].freeze, ranges: ["Integer", "StructuredValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#application_deadline ⇒ Object
The date on which the program stops collecting applications for the next enrollment cycle. Flexible application deadlines (for example, a program with rolling admissions) can be described in a textual string, rather than as a DateTime.
257 258 259 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 257 def application_deadline read_property(:application_deadline) end |
#application_deadline=(value) ⇒ Object
The date on which the program stops collecting applications for the next enrollment cycle. Flexible application deadlines (for example, a program with rolling admissions) can be described in a textual string, rather than as a DateTime.
262 263 264 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 262 def application_deadline=(value) write_property(:application_deadline, value) end |
#application_start_date ⇒ Object
The date at which the program begins collecting applications for the next enrollment cycle.
267 268 269 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 267 def application_start_date read_property(:application_start_date) end |
#application_start_date=(value) ⇒ Object
The date at which the program begins collecting applications for the next enrollment cycle.
272 273 274 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 272 def application_start_date=(value) write_property(:application_start_date, value) end |
#day_of_week ⇒ Object
The day of the week for which these opening hours are valid.
277 278 279 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 277 def day_of_week read_property(:day_of_week) end |
#day_of_week=(value) ⇒ Object
The day of the week for which these opening hours are valid.
282 283 284 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 282 def day_of_week=(value) write_property(:day_of_week, value) end |
#educational_credential_awarded ⇒ Object
A description of the qualification, award, certificate, diploma or other educational credential awarded as a consequence of successful completion of this course or program.
287 288 289 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 287 def educational_credential_awarded read_property(:educational_credential_awarded) end |
#educational_credential_awarded=(value) ⇒ Object
A description of the qualification, award, certificate, diploma or other educational credential awarded as a consequence of successful completion of this course or program.
292 293 294 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 292 def educational_credential_awarded=(value) write_property(:educational_credential_awarded, value) end |
#educational_program_mode ⇒ Object
Similar to courseMode, the medium or means of delivery of the program as a whole. The value may either be a text label (e.g. "online", "onsite" or "blended"; "synchronous" or "asynchronous"; "full-time" or "part-time") or a URL reference to a term from a controlled vocabulary (e.g. https://ceds.ed.gov/element/001311#Asynchronous ).
297 298 299 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 297 def educational_program_mode read_property(:educational_program_mode) end |
#educational_program_mode=(value) ⇒ Object
Similar to courseMode, the medium or means of delivery of the program as a whole. The value may either be a text label (e.g. "online", "onsite" or "blended"; "synchronous" or "asynchronous"; "full-time" or "part-time") or a URL reference to a term from a controlled vocabulary (e.g. https://ceds.ed.gov/element/001311#Asynchronous ).
302 303 304 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 302 def educational_program_mode=(value) write_property(:educational_program_mode, value) end |
#end_date ⇒ Object
The end date and time of the item (in ISO 8601 date format).
307 308 309 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 307 def end_date read_property(:end_date) end |
#end_date=(value) ⇒ Object
The end date and time of the item (in ISO 8601 date format).
312 313 314 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 312 def end_date=(value) write_property(:end_date, value) end |
#financial_aid_eligible ⇒ Object
A financial aid type or program which students may use to pay for tuition or fees associated with the program.
317 318 319 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 317 def financial_aid_eligible read_property(:financial_aid_eligible) end |
#financial_aid_eligible=(value) ⇒ Object
A financial aid type or program which students may use to pay for tuition or fees associated with the program.
322 323 324 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 322 def financial_aid_eligible=(value) write_property(:financial_aid_eligible, value) end |
#has_course ⇒ Object
A course or class that is one of the learning opportunities that constitute an educational / occupational program. No information is implied about whether the course is mandatory or optional; no guarantee is implied about whether the course will be available to everyone on the program.
327 328 329 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 327 def has_course read_property(:has_course) end |
#has_course=(value) ⇒ Object
A course or class that is one of the learning opportunities that constitute an educational / occupational program. No information is implied about whether the course is mandatory or optional; no guarantee is implied about whether the course will be available to everyone on the program.
332 333 334 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 332 def has_course=(value) write_property(:has_course, value) end |
#maximum_enrollment ⇒ Object
The maximum number of students who may be enrolled in the program.
337 338 339 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 337 def maximum_enrollment read_property(:maximum_enrollment) end |
#maximum_enrollment=(value) ⇒ Object
The maximum number of students who may be enrolled in the program.
342 343 344 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 342 def maximum_enrollment=(value) write_property(:maximum_enrollment, value) end |
#number_of_credits ⇒ Object
The number of credits or units awarded by a Course or required to complete an EducationalOccupationalProgram.
347 348 349 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 347 def number_of_credits read_property(:number_of_credits) end |
#number_of_credits=(value) ⇒ Object
The number of credits or units awarded by a Course or required to complete an EducationalOccupationalProgram.
352 353 354 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 352 def number_of_credits=(value) write_property(:number_of_credits, value) end |
#occupational_category ⇒ Object
A category describing the job, preferably using a term from a taxonomy such as BLS O*NET-SOC, ISCO-08 or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided.\n Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC.
358 359 360 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 358 def occupational_category read_property(:occupational_category) end |
#occupational_category=(value) ⇒ Object
A category describing the job, preferably using a term from a taxonomy such as BLS O*NET-SOC, ISCO-08 or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided.\n Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC.
364 365 366 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 364 def occupational_category=(value) write_property(:occupational_category, value) end |
#occupational_credential_awarded ⇒ Object
A description of the qualification, award, certificate, diploma or other occupational credential awarded as a consequence of successful completion of this course or program.
369 370 371 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 369 def occupational_credential_awarded read_property(:occupational_credential_awarded) end |
#occupational_credential_awarded=(value) ⇒ Object
A description of the qualification, award, certificate, diploma or other occupational credential awarded as a consequence of successful completion of this course or program.
374 375 376 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 374 def occupational_credential_awarded=(value) write_property(:occupational_credential_awarded, value) end |
#offers ⇒ Object
An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.
Inverse-property: itemOffered.
380 381 382 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 380 def offers read_property(:offers) end |
#offers=(value) ⇒ Object
An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.
Inverse-property: itemOffered.
386 387 388 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 386 def offers=(value) write_property(:offers, value) end |
#program_prerequisites ⇒ Object
Prerequisites for enrolling in the program.
391 392 393 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 391 def program_prerequisites read_property(:program_prerequisites) end |
#program_prerequisites=(value) ⇒ Object
Prerequisites for enrolling in the program.
396 397 398 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 396 def program_prerequisites=(value) write_property(:program_prerequisites, value) end |
#program_type ⇒ Object
The type of educational or occupational program. For example, classroom, internship, alternance, etc.
401 402 403 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 401 def program_type read_property(:program_type) end |
#program_type=(value) ⇒ Object
The type of educational or occupational program. For example, classroom, internship, alternance, etc.
406 407 408 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 406 def program_type=(value) write_property(:program_type, value) end |
#provider ⇒ Object
The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.
Supersedes carrier.
412 413 414 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 412 def provider read_property(:provider) end |
#provider=(value) ⇒ Object
The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.
Supersedes carrier.
418 419 420 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 418 def provider=(value) write_property(:provider, value) end |
#salary_upon_completion ⇒ Object
The expected salary upon completing the training.
423 424 425 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 423 def salary_upon_completion read_property(:salary_upon_completion) end |
#salary_upon_completion=(value) ⇒ Object
The expected salary upon completing the training.
428 429 430 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 428 def salary_upon_completion=(value) write_property(:salary_upon_completion, value) end |
#start_date ⇒ Object
The start date and time of the item (in ISO 8601 date format).
433 434 435 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 433 def start_date read_property(:start_date) end |
#start_date=(value) ⇒ Object
The start date and time of the item (in ISO 8601 date format).
438 439 440 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 438 def start_date=(value) write_property(:start_date, value) end |
#term_duration ⇒ Object
The amount of time in a term as defined by the institution. A term is a length of time where students take one or more classes. Semesters and quarters are common units for term.
443 444 445 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 443 def term_duration read_property(:term_duration) end |
#term_duration=(value) ⇒ Object
The amount of time in a term as defined by the institution. A term is a length of time where students take one or more classes. Semesters and quarters are common units for term.
448 449 450 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 448 def term_duration=(value) write_property(:term_duration, value) end |
#terms_per_year ⇒ Object
The number of times terms of study are offered per year. Semesters and quarters are common units for term. For example, if the student can only take 2 semesters for the program in one year, then termsPerYear should be 2.
453 454 455 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 453 def terms_per_year read_property(:terms_per_year) end |
#terms_per_year=(value) ⇒ Object
The number of times terms of study are offered per year. Semesters and quarters are common units for term. For example, if the student can only take 2 semesters for the program in one year, then termsPerYear should be 2.
458 459 460 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 458 def terms_per_year=(value) write_property(:terms_per_year, value) end |
#time_of_day ⇒ Object
The time of day the program normally runs. For example, "evenings".
463 464 465 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 463 def time_of_day read_property(:time_of_day) end |
#time_of_day=(value) ⇒ Object
The time of day the program normally runs. For example, "evenings".
468 469 470 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 468 def time_of_day=(value) write_property(:time_of_day, value) end |
#time_to_complete ⇒ Object
The expected length of time to complete the program if attending full-time.
473 474 475 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 473 def time_to_complete read_property(:time_to_complete) end |
#time_to_complete=(value) ⇒ Object
The expected length of time to complete the program if attending full-time.
478 479 480 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 478 def time_to_complete=(value) write_property(:time_to_complete, value) end |
#training_salary ⇒ Object
The estimated salary earned while in the program.
483 484 485 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 483 def training_salary read_property(:training_salary) end |
#training_salary=(value) ⇒ Object
The estimated salary earned while in the program.
488 489 490 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 488 def training_salary=(value) write_property(:training_salary, value) end |
#typical_credits_per_term ⇒ Object
The number of credits or units a full-time student would be expected to take in 1 term however 'term' is defined by the institution.
493 494 495 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 493 def typical_credits_per_term read_property(:typical_credits_per_term) end |
#typical_credits_per_term=(value) ⇒ Object
The number of credits or units a full-time student would be expected to take in 1 term however 'term' is defined by the institution.
498 499 500 |
# File 'lib/schema_org/mixins/educational_occupational_program.rb', line 498 def typical_credits_per_term=(value) write_property(:typical_credits_per_term, value) end |