Module: SchemaOrg::Mixins::EnergyConsumptionDetails
- Includes:
- Intangible
- Included in:
- EnergyConsumptionDetails
- Defined in:
- lib/schema_org/mixins/energy_consumption_details.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#energy_efficiency_scale_max ⇒ Object
Specifies the most energy efficient class on the regulated EU energy consumption scale for the product category a product belongs to.
-
#energy_efficiency_scale_max=(value) ⇒ Object
Specifies the most energy efficient class on the regulated EU energy consumption scale for the product category a product belongs to.
-
#energy_efficiency_scale_min ⇒ Object
Specifies the least energy efficient class on the regulated EU energy consumption scale for the product category a product belongs to.
-
#energy_efficiency_scale_min=(value) ⇒ Object
Specifies the least energy efficient class on the regulated EU energy consumption scale for the product category a product belongs to.
-
#has_energy_efficiency_category ⇒ Object
Defines the energy efficiency Category (which could be either a rating out of range of values or a yes/no certification) for a product according to an international energy efficiency standard.
-
#has_energy_efficiency_category=(value) ⇒ Object
Defines the energy efficiency Category (which could be either a rating out of range of values or a yes/no certification) for a product according to an international energy efficiency standard.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/schema_org/mixins/energy_consumption_details.rb', line 11 def self.schema_property_definitions { energy_efficiency_scale_max: { schema_name: "energyEfficiencyScaleMax", schema_url: "https://schema.org/energyEfficiencyScaleMax", comment_lines: ["Specifies the most energy efficient class on the regulated EU energy consumption scale for the product category a product belongs to. For example, energy consumption for televisions placed on the market after January 1, 2020 is scaled from D to A+++."].freeze, ranges: ["EUEnergyEfficiencyEnumeration"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, energy_efficiency_scale_min: { schema_name: "energyEfficiencyScaleMin", schema_url: "https://schema.org/energyEfficiencyScaleMin", comment_lines: ["Specifies the least energy efficient class on the regulated EU energy consumption scale for the product category a product belongs to. For example, energy consumption for televisions placed on the market after January 1, 2020 is scaled from D to A+++."].freeze, ranges: ["EUEnergyEfficiencyEnumeration"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, has_energy_efficiency_category: { schema_name: "hasEnergyEfficiencyCategory", schema_url: "https://schema.org/hasEnergyEfficiencyCategory", comment_lines: ["Defines the energy efficiency Category (which could be either a rating out of range of values or a yes/no certification) for a product according to an international energy efficiency standard."].freeze, ranges: ["EnergyEfficiencyEnumeration"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#energy_efficiency_scale_max ⇒ Object
Specifies the most energy efficient class on the regulated EU energy consumption scale for the product category a product belongs to. For example, energy consumption for televisions placed on the market after January 1, 2020 is scaled from D to A+++.
47 48 49 |
# File 'lib/schema_org/mixins/energy_consumption_details.rb', line 47 def energy_efficiency_scale_max read_property(:energy_efficiency_scale_max) end |
#energy_efficiency_scale_max=(value) ⇒ Object
Specifies the most energy efficient class on the regulated EU energy consumption scale for the product category a product belongs to. For example, energy consumption for televisions placed on the market after January 1, 2020 is scaled from D to A+++.
52 53 54 |
# File 'lib/schema_org/mixins/energy_consumption_details.rb', line 52 def energy_efficiency_scale_max=(value) write_property(:energy_efficiency_scale_max, value) end |
#energy_efficiency_scale_min ⇒ Object
Specifies the least energy efficient class on the regulated EU energy consumption scale for the product category a product belongs to. For example, energy consumption for televisions placed on the market after January 1, 2020 is scaled from D to A+++.
57 58 59 |
# File 'lib/schema_org/mixins/energy_consumption_details.rb', line 57 def energy_efficiency_scale_min read_property(:energy_efficiency_scale_min) end |
#energy_efficiency_scale_min=(value) ⇒ Object
Specifies the least energy efficient class on the regulated EU energy consumption scale for the product category a product belongs to. For example, energy consumption for televisions placed on the market after January 1, 2020 is scaled from D to A+++.
62 63 64 |
# File 'lib/schema_org/mixins/energy_consumption_details.rb', line 62 def energy_efficiency_scale_min=(value) write_property(:energy_efficiency_scale_min, value) end |
#has_energy_efficiency_category ⇒ Object
Defines the energy efficiency Category (which could be either a rating out of range of values or a yes/no certification) for a product according to an international energy efficiency standard.
67 68 69 |
# File 'lib/schema_org/mixins/energy_consumption_details.rb', line 67 def has_energy_efficiency_category read_property(:has_energy_efficiency_category) end |
#has_energy_efficiency_category=(value) ⇒ Object
Defines the energy efficiency Category (which could be either a rating out of range of values or a yes/no certification) for a product according to an international energy efficiency standard.
72 73 74 |
# File 'lib/schema_org/mixins/energy_consumption_details.rb', line 72 def has_energy_efficiency_category=(value) write_property(:has_energy_efficiency_category, value) end |