Module: SchemaOrg::Mixins::EntryPoint
Class Method Summary collapse
Instance Method Summary collapse
-
#action_application ⇒ Object
An application that can complete the request.
-
#action_application=(value) ⇒ Object
An application that can complete the request.
-
#action_platform ⇒ Object
The high level platform(s) where the Action can be performed for the given URL.
-
#action_platform=(value) ⇒ Object
The high level platform(s) where the Action can be performed for the given URL.
-
#application ⇒ Object
An application that can complete the request.
-
#application=(value) ⇒ Object
An application that can complete the request.
-
#content_type ⇒ Object
The supported content type(s) for an EntryPoint response.
-
#content_type=(value) ⇒ Object
The supported content type(s) for an EntryPoint response.
-
#encoding_type ⇒ Object
The supported encoding type(s) for an EntryPoint request.
-
#encoding_type=(value) ⇒ Object
The supported encoding type(s) for an EntryPoint request.
-
#http_method ⇒ Object
An HTTP method that specifies the appropriate HTTP method for a request to an HTTP EntryPoint.
-
#http_method=(value) ⇒ Object
An HTTP method that specifies the appropriate HTTP method for a request to an HTTP EntryPoint.
-
#url_template ⇒ Object
An url template (RFC6570) that will be used to construct the target of the execution of the action.
-
#url_template=(value) ⇒ Object
An url template (RFC6570) that will be used to construct the target of the execution of the action.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/schema_org/mixins/entry_point.rb', line 11 def self.schema_property_definitions { action_application: { schema_name: "actionApplication", schema_url: "https://schema.org/actionApplication", comment_lines: ["An application that can complete the request."].freeze, ranges: ["SoftwareApplication"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["application"].freeze }.freeze, action_platform: { schema_name: "actionPlatform", schema_url: "https://schema.org/actionPlatform", comment_lines: ["The high level platform(s) where the Action can be performed for the given URL. To specify a specific application or operating system instance, use actionApplication."].freeze, ranges: ["DigitalPlatformEnumeration", "Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, application: { schema_name: "application", schema_url: "https://schema.org/application", comment_lines: ["An application that can complete the request."].freeze, ranges: ["SoftwareApplication"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "actionApplication", supersedes: nil }.freeze, content_type: { schema_name: "contentType", schema_url: "https://schema.org/contentType", comment_lines: ["The supported content type(s) for an EntryPoint response."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, encoding_type: { schema_name: "encodingType", schema_url: "https://schema.org/encodingType", comment_lines: ["The supported encoding type(s) for an EntryPoint request."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, http_method: { schema_name: "httpMethod", schema_url: "https://schema.org/httpMethod", comment_lines: ["An HTTP method that specifies the appropriate HTTP method for a request to an HTTP EntryPoint. Values are capitalized strings as used in HTTP."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, url_template: { schema_name: "urlTemplate", schema_url: "https://schema.org/urlTemplate", comment_lines: ["An url template (RFC6570) that will be used to construct the target of the execution of the action."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#action_application ⇒ Object
An application that can complete the request.
Supersedes application.
88 89 90 |
# File 'lib/schema_org/mixins/entry_point.rb', line 88 def action_application read_property(:action_application) end |
#action_application=(value) ⇒ Object
An application that can complete the request.
Supersedes application.
94 95 96 |
# File 'lib/schema_org/mixins/entry_point.rb', line 94 def action_application=(value) write_property(:action_application, value) end |
#action_platform ⇒ Object
The high level platform(s) where the Action can be performed for the given URL. To specify a specific application or operating system instance, use actionApplication.
99 100 101 |
# File 'lib/schema_org/mixins/entry_point.rb', line 99 def action_platform read_property(:action_platform) end |
#action_platform=(value) ⇒ Object
The high level platform(s) where the Action can be performed for the given URL. To specify a specific application or operating system instance, use actionApplication.
104 105 106 |
# File 'lib/schema_org/mixins/entry_point.rb', line 104 def action_platform=(value) write_property(:action_platform, value) end |
#application ⇒ Object
An application that can complete the request.
Superseded by actionApplication.
110 111 112 |
# File 'lib/schema_org/mixins/entry_point.rb', line 110 def application read_property(:application) end |
#application=(value) ⇒ Object
An application that can complete the request.
Superseded by actionApplication.
116 117 118 |
# File 'lib/schema_org/mixins/entry_point.rb', line 116 def application=(value) write_property(:application, value) end |
#content_type ⇒ Object
The supported content type(s) for an EntryPoint response.
121 122 123 |
# File 'lib/schema_org/mixins/entry_point.rb', line 121 def content_type read_property(:content_type) end |
#content_type=(value) ⇒ Object
The supported content type(s) for an EntryPoint response.
126 127 128 |
# File 'lib/schema_org/mixins/entry_point.rb', line 126 def content_type=(value) write_property(:content_type, value) end |
#encoding_type ⇒ Object
The supported encoding type(s) for an EntryPoint request.
131 132 133 |
# File 'lib/schema_org/mixins/entry_point.rb', line 131 def encoding_type read_property(:encoding_type) end |
#encoding_type=(value) ⇒ Object
The supported encoding type(s) for an EntryPoint request.
136 137 138 |
# File 'lib/schema_org/mixins/entry_point.rb', line 136 def encoding_type=(value) write_property(:encoding_type, value) end |
#http_method ⇒ Object
An HTTP method that specifies the appropriate HTTP method for a request to an HTTP EntryPoint. Values are capitalized strings as used in HTTP.
141 142 143 |
# File 'lib/schema_org/mixins/entry_point.rb', line 141 def http_method read_property(:http_method) end |
#http_method=(value) ⇒ Object
An HTTP method that specifies the appropriate HTTP method for a request to an HTTP EntryPoint. Values are capitalized strings as used in HTTP.
146 147 148 |
# File 'lib/schema_org/mixins/entry_point.rb', line 146 def http_method=(value) write_property(:http_method, value) end |
#url_template ⇒ Object
An url template (RFC6570) that will be used to construct the target of the execution of the action.
151 152 153 |
# File 'lib/schema_org/mixins/entry_point.rb', line 151 def url_template read_property(:url_template) end |
#url_template=(value) ⇒ Object
An url template (RFC6570) that will be used to construct the target of the execution of the action.
156 157 158 |
# File 'lib/schema_org/mixins/entry_point.rb', line 156 def url_template=(value) write_property(:url_template, value) end |