Module: SchemaOrg::Mixins::FinancialProduct
- Includes:
- Service
- Included in:
- FinancialProduct, BankAccount, CurrencyConversionService, InvestmentOrDeposit, LoanOrCredit, PaymentCard, PaymentService
- Defined in:
- lib/schema_org/mixins/financial_product.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#annual_percentage_rate ⇒ Object
The annual rate that is charged for borrowing (or made by investing), expressed as a single percentage number that represents the actual yearly cost of funds over the term of a loan.
-
#annual_percentage_rate=(value) ⇒ Object
The annual rate that is charged for borrowing (or made by investing), expressed as a single percentage number that represents the actual yearly cost of funds over the term of a loan.
-
#fees_and_commissions_specification ⇒ Object
Description of fees, commissions, and other terms applied either to a class of financial product, or by a financial service organization.
-
#fees_and_commissions_specification=(value) ⇒ Object
Description of fees, commissions, and other terms applied either to a class of financial product, or by a financial service organization.
-
#interest_rate ⇒ Object
The interest rate, charged or paid, applicable to the financial product.
-
#interest_rate=(value) ⇒ Object
The interest rate, charged or paid, applicable to the financial product.
Methods included from Service
#aggregate_rating, #aggregate_rating=, #area_served, #area_served=, #audience, #audience=, #available_channel, #available_channel=, #award, #award=, #brand, #brand=, #broker, #broker=, #category, #category=, #has_certification, #has_certification=, #has_offer_catalog, #has_offer_catalog=, #hours_available, #hours_available=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #logo, #logo=, #offers, #offers=, #produces, #produces=, #provider, #provider=, #provider_mobility, #provider_mobility=, #review, #review=, #service_area, #service_area=, #service_audience, #service_audience=, #service_output, #service_output=, #service_type, #service_type=, #slogan, #slogan=, #terms_of_service, #terms_of_service=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/schema_org/mixins/financial_product.rb', line 11 def self.schema_property_definitions { annual_percentage_rate: { schema_name: "annualPercentageRate", schema_url: "https://schema.org/annualPercentageRate", comment_lines: ["The annual rate that is charged for borrowing (or made by investing), expressed as a single percentage number that represents the actual yearly cost of funds over the term of a loan. This includes any fees or additional costs associated with the transaction."].freeze, ranges: ["Number", "QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, fees_and_commissions_specification: { schema_name: "feesAndCommissionsSpecification", schema_url: "https://schema.org/feesAndCommissionsSpecification", comment_lines: ["Description of fees, commissions, and other terms applied either to a class of financial product, or by a financial service organization."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, interest_rate: { schema_name: "interestRate", schema_url: "https://schema.org/interestRate", comment_lines: ["The interest rate, charged or paid, applicable to the financial product. Note: This is different from the calculated annualPercentageRate."].freeze, ranges: ["Number", "QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#annual_percentage_rate ⇒ Object
The annual rate that is charged for borrowing (or made by investing), expressed as a single percentage number that represents the actual yearly cost of funds over the term of a loan. This includes any fees or additional costs associated with the transaction.
47 48 49 |
# File 'lib/schema_org/mixins/financial_product.rb', line 47 def annual_percentage_rate read_property(:annual_percentage_rate) end |
#annual_percentage_rate=(value) ⇒ Object
The annual rate that is charged for borrowing (or made by investing), expressed as a single percentage number that represents the actual yearly cost of funds over the term of a loan. This includes any fees or additional costs associated with the transaction.
52 53 54 |
# File 'lib/schema_org/mixins/financial_product.rb', line 52 def annual_percentage_rate=(value) write_property(:annual_percentage_rate, value) end |
#fees_and_commissions_specification ⇒ Object
Description of fees, commissions, and other terms applied either to a class of financial product, or by a financial service organization.
57 58 59 |
# File 'lib/schema_org/mixins/financial_product.rb', line 57 def fees_and_commissions_specification read_property(:fees_and_commissions_specification) end |
#fees_and_commissions_specification=(value) ⇒ Object
Description of fees, commissions, and other terms applied either to a class of financial product, or by a financial service organization.
62 63 64 |
# File 'lib/schema_org/mixins/financial_product.rb', line 62 def fees_and_commissions_specification=(value) write_property(:fees_and_commissions_specification, value) end |
#interest_rate ⇒ Object
The interest rate, charged or paid, applicable to the financial product. Note: This is different from the calculated annualPercentageRate.
67 68 69 |
# File 'lib/schema_org/mixins/financial_product.rb', line 67 def interest_rate read_property(:interest_rate) end |
#interest_rate=(value) ⇒ Object
The interest rate, charged or paid, applicable to the financial product. Note: This is different from the calculated annualPercentageRate.
72 73 74 |
# File 'lib/schema_org/mixins/financial_product.rb', line 72 def interest_rate=(value) write_property(:interest_rate, value) end |