Module: SchemaOrg::Mixins::Flight
Class Method Summary collapse
Instance Method Summary collapse
-
#aircraft ⇒ Object
The kind of aircraft (e.g., "Boeing 747").
-
#aircraft=(value) ⇒ Object
The kind of aircraft (e.g., "Boeing 747").
-
#arrival_airport ⇒ Object
The airport where the flight terminates.
-
#arrival_airport=(value) ⇒ Object
The airport where the flight terminates.
-
#arrival_gate ⇒ Object
Identifier of the flight's arrival gate.
-
#arrival_gate=(value) ⇒ Object
Identifier of the flight's arrival gate.
-
#arrival_terminal ⇒ Object
Identifier of the flight's arrival terminal.
-
#arrival_terminal=(value) ⇒ Object
Identifier of the flight's arrival terminal.
-
#boarding_policy ⇒ Object
The type of boarding policy used by the airline (e.g. zone-based or group-based).
-
#boarding_policy=(value) ⇒ Object
The type of boarding policy used by the airline (e.g. zone-based or group-based).
-
#carrier ⇒ Object
'carrier' is an out-dated term indicating the 'provider' for parcel delivery and flights.
-
#carrier=(value) ⇒ Object
'carrier' is an out-dated term indicating the 'provider' for parcel delivery and flights.
-
#departure_airport ⇒ Object
The airport where the flight originates.
-
#departure_airport=(value) ⇒ Object
The airport where the flight originates.
-
#departure_gate ⇒ Object
Identifier of the flight's departure gate.
-
#departure_gate=(value) ⇒ Object
Identifier of the flight's departure gate.
-
#departure_terminal ⇒ Object
Identifier of the flight's departure terminal.
-
#departure_terminal=(value) ⇒ Object
Identifier of the flight's departure terminal.
-
#estimated_flight_duration ⇒ Object
The estimated time the flight will take.
-
#estimated_flight_duration=(value) ⇒ Object
The estimated time the flight will take.
-
#flight_distance ⇒ Object
The distance of the flight.
-
#flight_distance=(value) ⇒ Object
The distance of the flight.
-
#flight_number ⇒ Object
The unique identifier for a flight including the airline IATA code.
-
#flight_number=(value) ⇒ Object
The unique identifier for a flight including the airline IATA code.
-
#meal_service ⇒ Object
Description of the meals that will be provided or available for purchase.
-
#meal_service=(value) ⇒ Object
Description of the meals that will be provided or available for purchase.
-
#seller ⇒ Object
An entity which offers (sells / leases / lends / loans) the services / goods.
-
#seller=(value) ⇒ Object
An entity which offers (sells / leases / lends / loans) the services / goods.
-
#web_checkin_time ⇒ Object
The time when a passenger can check into the flight online.
-
#web_checkin_time=(value) ⇒ Object
The time when a passenger can check into the flight online.
Methods included from Trip
#arrival_time, #arrival_time=, #departure_time, #departure_time=, #itinerary, #itinerary=, #offers, #offers=, #part_of_trip, #part_of_trip=, #provider, #provider=, #sub_trip, #sub_trip=, #trip_origin, #trip_origin=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/schema_org/mixins/flight.rb', line 11 def self.schema_property_definitions { aircraft: { schema_name: "aircraft", schema_url: "https://schema.org/aircraft", comment_lines: ["The kind of aircraft (e.g., \"Boeing 747\")."].freeze, ranges: ["Text", "Vehicle"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, arrival_airport: { schema_name: "arrivalAirport", schema_url: "https://schema.org/arrivalAirport", comment_lines: ["The airport where the flight terminates."].freeze, ranges: ["Airport"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, arrival_gate: { schema_name: "arrivalGate", schema_url: "https://schema.org/arrivalGate", comment_lines: ["Identifier of the flight's arrival gate."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, arrival_terminal: { schema_name: "arrivalTerminal", schema_url: "https://schema.org/arrivalTerminal", comment_lines: ["Identifier of the flight's arrival terminal."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, boarding_policy: { schema_name: "boardingPolicy", schema_url: "https://schema.org/boardingPolicy", comment_lines: ["The type of boarding policy used by the airline (e.g. zone-based or group-based)."].freeze, ranges: ["BoardingPolicyType"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, carrier: { schema_name: "carrier", schema_url: "https://schema.org/carrier", comment_lines: ["'carrier' is an out-dated term indicating the 'provider' for parcel delivery and flights."].freeze, ranges: ["Organization"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "provider", supersedes: nil }.freeze, departure_airport: { schema_name: "departureAirport", schema_url: "https://schema.org/departureAirport", comment_lines: ["The airport where the flight originates."].freeze, ranges: ["Airport"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, departure_gate: { schema_name: "departureGate", schema_url: "https://schema.org/departureGate", comment_lines: ["Identifier of the flight's departure gate."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, departure_terminal: { schema_name: "departureTerminal", schema_url: "https://schema.org/departureTerminal", comment_lines: ["Identifier of the flight's departure terminal."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, estimated_flight_duration: { schema_name: "estimatedFlightDuration", schema_url: "https://schema.org/estimatedFlightDuration", comment_lines: ["The estimated time the flight will take."].freeze, ranges: ["Duration", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, flight_distance: { schema_name: "flightDistance", schema_url: "https://schema.org/flightDistance", comment_lines: ["The distance of the flight."].freeze, ranges: ["Distance", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, flight_number: { schema_name: "flightNumber", schema_url: "https://schema.org/flightNumber", comment_lines: ["The unique identifier for a flight including the airline IATA code. For example, if describing United flight 110, where the IATA code for United is 'UA', the flightNumber is 'UA110'."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, meal_service: { schema_name: "mealService", schema_url: "https://schema.org/mealService", comment_lines: ["Description of the meals that will be provided or available for purchase."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, seller: { schema_name: "seller", schema_url: "https://schema.org/seller", comment_lines: ["An entity which offers (sells / leases / lends / loans) the services / goods. A seller may also be a provider."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["merchant", "vendor"].freeze }.freeze, web_checkin_time: { schema_name: "webCheckinTime", schema_url: "https://schema.org/webCheckinTime", comment_lines: ["The time when a passenger can check into the flight online."].freeze, ranges: ["DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#aircraft ⇒ Object
The kind of aircraft (e.g., "Boeing 747").
167 168 169 |
# File 'lib/schema_org/mixins/flight.rb', line 167 def aircraft read_property(:aircraft) end |
#aircraft=(value) ⇒ Object
The kind of aircraft (e.g., "Boeing 747").
172 173 174 |
# File 'lib/schema_org/mixins/flight.rb', line 172 def aircraft=(value) write_property(:aircraft, value) end |
#arrival_airport ⇒ Object
The airport where the flight terminates.
177 178 179 |
# File 'lib/schema_org/mixins/flight.rb', line 177 def arrival_airport read_property(:arrival_airport) end |
#arrival_airport=(value) ⇒ Object
The airport where the flight terminates.
182 183 184 |
# File 'lib/schema_org/mixins/flight.rb', line 182 def arrival_airport=(value) write_property(:arrival_airport, value) end |
#arrival_gate ⇒ Object
Identifier of the flight's arrival gate.
187 188 189 |
# File 'lib/schema_org/mixins/flight.rb', line 187 def arrival_gate read_property(:arrival_gate) end |
#arrival_gate=(value) ⇒ Object
Identifier of the flight's arrival gate.
192 193 194 |
# File 'lib/schema_org/mixins/flight.rb', line 192 def arrival_gate=(value) write_property(:arrival_gate, value) end |
#arrival_terminal ⇒ Object
Identifier of the flight's arrival terminal.
197 198 199 |
# File 'lib/schema_org/mixins/flight.rb', line 197 def arrival_terminal read_property(:arrival_terminal) end |
#arrival_terminal=(value) ⇒ Object
Identifier of the flight's arrival terminal.
202 203 204 |
# File 'lib/schema_org/mixins/flight.rb', line 202 def arrival_terminal=(value) write_property(:arrival_terminal, value) end |
#boarding_policy ⇒ Object
The type of boarding policy used by the airline (e.g. zone-based or group-based).
207 208 209 |
# File 'lib/schema_org/mixins/flight.rb', line 207 def boarding_policy read_property(:boarding_policy) end |
#boarding_policy=(value) ⇒ Object
The type of boarding policy used by the airline (e.g. zone-based or group-based).
212 213 214 |
# File 'lib/schema_org/mixins/flight.rb', line 212 def boarding_policy=(value) write_property(:boarding_policy, value) end |
#carrier ⇒ Object
'carrier' is an out-dated term indicating the 'provider' for parcel delivery and flights.
Superseded by provider.
218 219 220 |
# File 'lib/schema_org/mixins/flight.rb', line 218 def carrier read_property(:carrier) end |
#carrier=(value) ⇒ Object
'carrier' is an out-dated term indicating the 'provider' for parcel delivery and flights.
Superseded by provider.
224 225 226 |
# File 'lib/schema_org/mixins/flight.rb', line 224 def carrier=(value) write_property(:carrier, value) end |
#departure_airport ⇒ Object
The airport where the flight originates.
229 230 231 |
# File 'lib/schema_org/mixins/flight.rb', line 229 def departure_airport read_property(:departure_airport) end |
#departure_airport=(value) ⇒ Object
The airport where the flight originates.
234 235 236 |
# File 'lib/schema_org/mixins/flight.rb', line 234 def departure_airport=(value) write_property(:departure_airport, value) end |
#departure_gate ⇒ Object
Identifier of the flight's departure gate.
239 240 241 |
# File 'lib/schema_org/mixins/flight.rb', line 239 def departure_gate read_property(:departure_gate) end |
#departure_gate=(value) ⇒ Object
Identifier of the flight's departure gate.
244 245 246 |
# File 'lib/schema_org/mixins/flight.rb', line 244 def departure_gate=(value) write_property(:departure_gate, value) end |
#departure_terminal ⇒ Object
Identifier of the flight's departure terminal.
249 250 251 |
# File 'lib/schema_org/mixins/flight.rb', line 249 def departure_terminal read_property(:departure_terminal) end |
#departure_terminal=(value) ⇒ Object
Identifier of the flight's departure terminal.
254 255 256 |
# File 'lib/schema_org/mixins/flight.rb', line 254 def departure_terminal=(value) write_property(:departure_terminal, value) end |
#estimated_flight_duration ⇒ Object
The estimated time the flight will take.
259 260 261 |
# File 'lib/schema_org/mixins/flight.rb', line 259 def estimated_flight_duration read_property(:estimated_flight_duration) end |
#estimated_flight_duration=(value) ⇒ Object
The estimated time the flight will take.
264 265 266 |
# File 'lib/schema_org/mixins/flight.rb', line 264 def estimated_flight_duration=(value) write_property(:estimated_flight_duration, value) end |
#flight_distance ⇒ Object
The distance of the flight.
269 270 271 |
# File 'lib/schema_org/mixins/flight.rb', line 269 def flight_distance read_property(:flight_distance) end |
#flight_distance=(value) ⇒ Object
The distance of the flight.
274 275 276 |
# File 'lib/schema_org/mixins/flight.rb', line 274 def flight_distance=(value) write_property(:flight_distance, value) end |
#flight_number ⇒ Object
The unique identifier for a flight including the airline IATA code. For example, if describing United flight 110, where the IATA code for United is 'UA', the flightNumber is 'UA110'.
279 280 281 |
# File 'lib/schema_org/mixins/flight.rb', line 279 def flight_number read_property(:flight_number) end |
#flight_number=(value) ⇒ Object
The unique identifier for a flight including the airline IATA code. For example, if describing United flight 110, where the IATA code for United is 'UA', the flightNumber is 'UA110'.
284 285 286 |
# File 'lib/schema_org/mixins/flight.rb', line 284 def flight_number=(value) write_property(:flight_number, value) end |
#meal_service ⇒ Object
Description of the meals that will be provided or available for purchase.
289 290 291 |
# File 'lib/schema_org/mixins/flight.rb', line 289 def meal_service read_property(:meal_service) end |
#meal_service=(value) ⇒ Object
Description of the meals that will be provided or available for purchase.
294 295 296 |
# File 'lib/schema_org/mixins/flight.rb', line 294 def meal_service=(value) write_property(:meal_service, value) end |
#seller ⇒ Object
An entity which offers (sells / leases / lends / loans) the services / goods. A seller may also be a provider.
Supersedes merchant.
Supersedes vendor.
301 302 303 |
# File 'lib/schema_org/mixins/flight.rb', line 301 def seller read_property(:seller) end |
#seller=(value) ⇒ Object
An entity which offers (sells / leases / lends / loans) the services / goods. A seller may also be a provider.
Supersedes merchant.
Supersedes vendor.
308 309 310 |
# File 'lib/schema_org/mixins/flight.rb', line 308 def seller=(value) write_property(:seller, value) end |
#web_checkin_time ⇒ Object
The time when a passenger can check into the flight online.
313 314 315 |
# File 'lib/schema_org/mixins/flight.rb', line 313 def web_checkin_time read_property(:web_checkin_time) end |
#web_checkin_time=(value) ⇒ Object
The time when a passenger can check into the flight online.
318 319 320 |
# File 'lib/schema_org/mixins/flight.rb', line 318 def web_checkin_time=(value) write_property(:web_checkin_time, value) end |