Module: SchemaOrg::Mixins::FloorPlan
Class Method Summary collapse
Instance Method Summary collapse
-
#amenity_feature ⇒ Object
An amenity feature (e.g. a characteristic or service) of the Accommodation.
-
#amenity_feature=(value) ⇒ Object
An amenity feature (e.g. a characteristic or service) of the Accommodation.
-
#floor_size ⇒ Object
The size of the accommodation, e.g.
-
#floor_size=(value) ⇒ Object
The size of the accommodation, e.g.
-
#is_plan_for_apartment ⇒ Object
Indicates some accommodation that this floor plan describes.
-
#is_plan_for_apartment=(value) ⇒ Object
Indicates some accommodation that this floor plan describes.
-
#layout_image ⇒ Object
A schematic image showing the floorplan layout.
-
#layout_image=(value) ⇒ Object
A schematic image showing the floorplan layout.
-
#number_of_accommodation_units ⇒ Object
Indicates the total (available plus unavailable) number of accommodation units in an [[ApartmentComplex]], or the number of accommodation units for a specific [[FloorPlan]] (within its specific [[ApartmentComplex]]).
-
#number_of_accommodation_units=(value) ⇒ Object
Indicates the total (available plus unavailable) number of accommodation units in an [[ApartmentComplex]], or the number of accommodation units for a specific [[FloorPlan]] (within its specific [[ApartmentComplex]]).
-
#number_of_available_accommodation_units ⇒ Object
Indicates the number of available accommodation units in an [[ApartmentComplex]], or the number of accommodation units for a specific [[FloorPlan]] (within its specific [[ApartmentComplex]]).
-
#number_of_available_accommodation_units=(value) ⇒ Object
Indicates the number of available accommodation units in an [[ApartmentComplex]], or the number of accommodation units for a specific [[FloorPlan]] (within its specific [[ApartmentComplex]]).
-
#number_of_bathrooms_total ⇒ Object
The total integer number of bathrooms in some [[Accommodation]], following real estate conventions as documented in RESO: "The simple sum of the number of bathrooms.
-
#number_of_bathrooms_total=(value) ⇒ Object
The total integer number of bathrooms in some [[Accommodation]], following real estate conventions as documented in RESO: "The simple sum of the number of bathrooms.
-
#number_of_bedrooms ⇒ Object
The total integer number of bedrooms in a some [[Accommodation]], [[ApartmentComplex]] or [[FloorPlan]].
-
#number_of_bedrooms=(value) ⇒ Object
The total integer number of bedrooms in a some [[Accommodation]], [[ApartmentComplex]] or [[FloorPlan]].
-
#number_of_full_bathrooms ⇒ Object
Number of full bathrooms - The total number of full and ¾ bathrooms in an [[Accommodation]].
-
#number_of_full_bathrooms=(value) ⇒ Object
Number of full bathrooms - The total number of full and ¾ bathrooms in an [[Accommodation]].
-
#number_of_partial_bathrooms ⇒ Object
Number of partial bathrooms - The total number of half and ¼ bathrooms in an [[Accommodation]].
-
#number_of_partial_bathrooms=(value) ⇒ Object
Number of partial bathrooms - The total number of half and ¼ bathrooms in an [[Accommodation]].
-
#number_of_rooms ⇒ Object
The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business.
-
#number_of_rooms=(value) ⇒ Object
The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business.
-
#pets_allowed ⇒ Object
Indicates whether pets are allowed to enter the accommodation or lodging business.
-
#pets_allowed=(value) ⇒ Object
Indicates whether pets are allowed to enter the accommodation or lodging business.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 11 def self.schema_property_definitions { amenity_feature: { schema_name: "amenityFeature", schema_url: "https://schema.org/amenityFeature", comment_lines: ["An amenity feature (e.g. a characteristic or service) of the Accommodation. This generic property does not make a statement about whether the feature is included in an offer for the main accommodation or available at extra costs."].freeze, ranges: ["LocationFeatureSpecification"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, floor_size: { schema_name: "floorSize", schema_url: "https://schema.org/floorSize", comment_lines: ["The size of the accommodation, e.g. in square meter or squarefoot.", "Typical unit code(s): MTK for square meter, FTK for square foot, or YDK for square yard."].freeze, ranges: ["QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, is_plan_for_apartment: { schema_name: "isPlanForApartment", schema_url: "https://schema.org/isPlanForApartment", comment_lines: ["Indicates some accommodation that this floor plan describes."].freeze, ranges: ["Accommodation"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, layout_image: { schema_name: "layoutImage", schema_url: "https://schema.org/layoutImage", comment_lines: ["A schematic image showing the floorplan layout."].freeze, ranges: ["ImageObject", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, number_of_accommodation_units: { schema_name: "numberOfAccommodationUnits", schema_url: "https://schema.org/numberOfAccommodationUnits", comment_lines: ["Indicates the total (available plus unavailable) number of accommodation units in an [[ApartmentComplex]], or the number of accommodation units for a specific [[FloorPlan]] (within its specific [[ApartmentComplex]]). See also [[numberOfAvailableAccommodationUnits]]."].freeze, ranges: ["QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, number_of_available_accommodation_units: { schema_name: "numberOfAvailableAccommodationUnits", schema_url: "https://schema.org/numberOfAvailableAccommodationUnits", comment_lines: ["Indicates the number of available accommodation units in an [[ApartmentComplex]], or the number of accommodation units for a specific [[FloorPlan]] (within its specific [[ApartmentComplex]]). See also [[numberOfAccommodationUnits]]."].freeze, ranges: ["QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, number_of_bathrooms_total: { schema_name: "numberOfBathroomsTotal", schema_url: "https://schema.org/numberOfBathroomsTotal", comment_lines: ["The total integer number of bathrooms in some [[Accommodation]], following real estate conventions as [documented in RESO](https://ddwiki.reso.org/display/DDW17/BathroomsTotalInteger+Field): \"The simple sum of the number of bathrooms. For example for a property with two Full Bathrooms and one Half Bathroom, the Bathrooms Total Integer will be 3.\". See also [[numberOfRooms]]."].freeze, ranges: ["Integer"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, number_of_bedrooms: { schema_name: "numberOfBedrooms", schema_url: "https://schema.org/numberOfBedrooms", comment_lines: ["The total integer number of bedrooms in a some [[Accommodation]], [[ApartmentComplex]] or [[FloorPlan]]."].freeze, ranges: ["Number", "QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, number_of_full_bathrooms: { schema_name: "numberOfFullBathrooms", schema_url: "https://schema.org/numberOfFullBathrooms", comment_lines: ["Number of full bathrooms - The total number of full and ¾ bathrooms in an [[Accommodation]]. This corresponds to the [BathroomsFull field in RESO](https://ddwiki.reso.org/display/DDW17/BathroomsFull+Field)."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, number_of_partial_bathrooms: { schema_name: "numberOfPartialBathrooms", schema_url: "https://schema.org/numberOfPartialBathrooms", comment_lines: ["Number of partial bathrooms - The total number of half and ¼ bathrooms in an [[Accommodation]]. This corresponds to the [BathroomsPartial field in RESO](https://ddwiki.reso.org/display/DDW17/BathroomsPartial+Field)."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, number_of_rooms: { schema_name: "numberOfRooms", schema_url: "https://schema.org/numberOfRooms", comment_lines: ["The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business.", "Typical unit code(s): ROM for room or C62 for no unit. The type of room can be put in the unitText property of the QuantitativeValue."].freeze, ranges: ["Number", "QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, pets_allowed: { schema_name: "petsAllowed", schema_url: "https://schema.org/petsAllowed", comment_lines: ["Indicates whether pets are allowed to enter the accommodation or lodging business. More detailed information can be put in a text value."].freeze, ranges: ["Boolean", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#amenity_feature ⇒ Object
An amenity feature (e.g. a characteristic or service) of the Accommodation. This generic property does not make a statement about whether the feature is included in an offer for the main accommodation or available at extra costs.
137 138 139 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 137 def amenity_feature read_property(:amenity_feature) end |
#amenity_feature=(value) ⇒ Object
An amenity feature (e.g. a characteristic or service) of the Accommodation. This generic property does not make a statement about whether the feature is included in an offer for the main accommodation or available at extra costs.
142 143 144 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 142 def amenity_feature=(value) write_property(:amenity_feature, value) end |
#floor_size ⇒ Object
The size of the accommodation, e.g. in square meter or squarefoot. Typical unit code(s): MTK for square meter, FTK for square foot, or YDK for square yard.
148 149 150 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 148 def floor_size read_property(:floor_size) end |
#floor_size=(value) ⇒ Object
The size of the accommodation, e.g. in square meter or squarefoot. Typical unit code(s): MTK for square meter, FTK for square foot, or YDK for square yard.
154 155 156 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 154 def floor_size=(value) write_property(:floor_size, value) end |
#is_plan_for_apartment ⇒ Object
Indicates some accommodation that this floor plan describes.
159 160 161 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 159 def is_plan_for_apartment read_property(:is_plan_for_apartment) end |
#is_plan_for_apartment=(value) ⇒ Object
Indicates some accommodation that this floor plan describes.
164 165 166 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 164 def is_plan_for_apartment=(value) write_property(:is_plan_for_apartment, value) end |
#layout_image ⇒ Object
A schematic image showing the floorplan layout.
169 170 171 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 169 def layout_image read_property(:layout_image) end |
#layout_image=(value) ⇒ Object
A schematic image showing the floorplan layout.
174 175 176 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 174 def layout_image=(value) write_property(:layout_image, value) end |
#number_of_accommodation_units ⇒ Object
Indicates the total (available plus unavailable) number of accommodation units in an [[ApartmentComplex]], or the number of accommodation units for a specific [[FloorPlan]] (within its specific [[ApartmentComplex]]). See also [[numberOfAvailableAccommodationUnits]].
179 180 181 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 179 def number_of_accommodation_units read_property(:number_of_accommodation_units) end |
#number_of_accommodation_units=(value) ⇒ Object
Indicates the total (available plus unavailable) number of accommodation units in an [[ApartmentComplex]], or the number of accommodation units for a specific [[FloorPlan]] (within its specific [[ApartmentComplex]]). See also [[numberOfAvailableAccommodationUnits]].
184 185 186 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 184 def number_of_accommodation_units=(value) write_property(:number_of_accommodation_units, value) end |
#number_of_available_accommodation_units ⇒ Object
Indicates the number of available accommodation units in an [[ApartmentComplex]], or the number of accommodation units for a specific [[FloorPlan]] (within its specific [[ApartmentComplex]]). See also [[numberOfAccommodationUnits]].
189 190 191 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 189 def number_of_available_accommodation_units read_property(:number_of_available_accommodation_units) end |
#number_of_available_accommodation_units=(value) ⇒ Object
Indicates the number of available accommodation units in an [[ApartmentComplex]], or the number of accommodation units for a specific [[FloorPlan]] (within its specific [[ApartmentComplex]]). See also [[numberOfAccommodationUnits]].
194 195 196 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 194 def number_of_available_accommodation_units=(value) write_property(:number_of_available_accommodation_units, value) end |
#number_of_bathrooms_total ⇒ Object
The total integer number of bathrooms in some [[Accommodation]], following real estate conventions as documented in RESO: "The simple sum of the number of bathrooms. For example for a property with two Full Bathrooms and one Half Bathroom, the Bathrooms Total Integer will be 3.". See also [[numberOfRooms]].
199 200 201 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 199 def number_of_bathrooms_total read_property(:number_of_bathrooms_total) end |
#number_of_bathrooms_total=(value) ⇒ Object
The total integer number of bathrooms in some [[Accommodation]], following real estate conventions as documented in RESO: "The simple sum of the number of bathrooms. For example for a property with two Full Bathrooms and one Half Bathroom, the Bathrooms Total Integer will be 3.". See also [[numberOfRooms]].
204 205 206 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 204 def number_of_bathrooms_total=(value) write_property(:number_of_bathrooms_total, value) end |
#number_of_bedrooms ⇒ Object
The total integer number of bedrooms in a some [[Accommodation]], [[ApartmentComplex]] or [[FloorPlan]].
209 210 211 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 209 def number_of_bedrooms read_property(:number_of_bedrooms) end |
#number_of_bedrooms=(value) ⇒ Object
The total integer number of bedrooms in a some [[Accommodation]], [[ApartmentComplex]] or [[FloorPlan]].
214 215 216 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 214 def number_of_bedrooms=(value) write_property(:number_of_bedrooms, value) end |
#number_of_full_bathrooms ⇒ Object
Number of full bathrooms - The total number of full and ¾ bathrooms in an [[Accommodation]]. This corresponds to the BathroomsFull field in RESO.
219 220 221 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 219 def number_of_full_bathrooms read_property(:number_of_full_bathrooms) end |
#number_of_full_bathrooms=(value) ⇒ Object
Number of full bathrooms - The total number of full and ¾ bathrooms in an [[Accommodation]]. This corresponds to the BathroomsFull field in RESO.
224 225 226 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 224 def number_of_full_bathrooms=(value) write_property(:number_of_full_bathrooms, value) end |
#number_of_partial_bathrooms ⇒ Object
Number of partial bathrooms - The total number of half and ¼ bathrooms in an [[Accommodation]]. This corresponds to the BathroomsPartial field in RESO.
229 230 231 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 229 def number_of_partial_bathrooms read_property(:number_of_partial_bathrooms) end |
#number_of_partial_bathrooms=(value) ⇒ Object
Number of partial bathrooms - The total number of half and ¼ bathrooms in an [[Accommodation]]. This corresponds to the BathroomsPartial field in RESO.
234 235 236 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 234 def number_of_partial_bathrooms=(value) write_property(:number_of_partial_bathrooms, value) end |
#number_of_rooms ⇒ Object
The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business. Typical unit code(s): ROM for room or C62 for no unit. The type of room can be put in the unitText property of the QuantitativeValue.
240 241 242 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 240 def number_of_rooms read_property(:number_of_rooms) end |
#number_of_rooms=(value) ⇒ Object
The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business. Typical unit code(s): ROM for room or C62 for no unit. The type of room can be put in the unitText property of the QuantitativeValue.
246 247 248 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 246 def number_of_rooms=(value) write_property(:number_of_rooms, value) end |
#pets_allowed ⇒ Object
Indicates whether pets are allowed to enter the accommodation or lodging business. More detailed information can be put in a text value.
251 252 253 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 251 def pets_allowed read_property(:pets_allowed) end |
#pets_allowed=(value) ⇒ Object
Indicates whether pets are allowed to enter the accommodation or lodging business. More detailed information can be put in a text value.
256 257 258 |
# File 'lib/schema_org/mixins/floor_plan.rb', line 256 def pets_allowed=(value) write_property(:pets_allowed, value) end |