Module: SchemaOrg::Mixins::FoodEstablishmentReservation
- Includes:
- Reservation
- Included in:
- FoodEstablishmentReservation
- Defined in:
- lib/schema_org/mixins/food_establishment_reservation.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#end_time ⇒ Object
The endTime of something.
-
#end_time=(value) ⇒ Object
The endTime of something.
-
#party_size ⇒ Object
Number of people the reservation should accommodate.
-
#party_size=(value) ⇒ Object
Number of people the reservation should accommodate.
-
#start_time ⇒ Object
The startTime of something.
-
#start_time=(value) ⇒ Object
The startTime of something.
Methods included from Reservation
#booking_agent, #booking_agent=, #booking_time, #booking_time=, #broker, #broker=, #modified_time, #modified_time=, #price_currency, #price_currency=, #program_membership_used, #program_membership_used=, #provider, #provider=, #reservation_for, #reservation_for=, #reservation_id, #reservation_id=, #reservation_status, #reservation_status=, #reserved_ticket, #reserved_ticket=, #total_price, #total_price=, #under_name, #under_name=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/schema_org/mixins/food_establishment_reservation.rb', line 11 def self.schema_property_definitions { end_time: { schema_name: "endTime", schema_url: "https://schema.org/endTime", comment_lines: ["The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to *December*. For media, including audio and video, it's the time offset of the end of a clip within a larger file.\\n\\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions."].freeze, ranges: ["DateTime", "Time"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, party_size: { schema_name: "partySize", schema_url: "https://schema.org/partySize", comment_lines: ["Number of people the reservation should accommodate."].freeze, ranges: ["Integer", "QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, start_time: { schema_name: "startTime", schema_url: "https://schema.org/startTime", comment_lines: ["The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from *January* to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file.\\n\\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions."].freeze, ranges: ["DateTime", "Time"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#end_time ⇒ Object
The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the end of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.
47 48 49 |
# File 'lib/schema_org/mixins/food_establishment_reservation.rb', line 47 def end_time read_property(:end_time) end |
#end_time=(value) ⇒ Object
The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the end of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.
52 53 54 |
# File 'lib/schema_org/mixins/food_establishment_reservation.rb', line 52 def end_time=(value) write_property(:end_time, value) end |
#party_size ⇒ Object
Number of people the reservation should accommodate.
57 58 59 |
# File 'lib/schema_org/mixins/food_establishment_reservation.rb', line 57 def party_size read_property(:party_size) end |
#party_size=(value) ⇒ Object
Number of people the reservation should accommodate.
62 63 64 |
# File 'lib/schema_org/mixins/food_establishment_reservation.rb', line 62 def party_size=(value) write_property(:party_size, value) end |
#start_time ⇒ Object
The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.
67 68 69 |
# File 'lib/schema_org/mixins/food_establishment_reservation.rb', line 67 def start_time read_property(:start_time) end |
#start_time=(value) ⇒ Object
The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.
72 73 74 |
# File 'lib/schema_org/mixins/food_establishment_reservation.rb', line 72 def start_time=(value) write_property(:start_time, value) end |