Module: SchemaOrg::Mixins::Game
Class Method Summary collapse
Instance Method Summary collapse
-
#character_attribute ⇒ Object
A piece of data that represents a particular aspect of a fictional character (skill, power, character points, advantage, disadvantage).
-
#character_attribute=(value) ⇒ Object
A piece of data that represents a particular aspect of a fictional character (skill, power, character points, advantage, disadvantage).
-
#game_item ⇒ Object
An item is an object within the game world that can be collected by a player or, occasionally, a non-player character.
-
#game_item=(value) ⇒ Object
An item is an object within the game world that can be collected by a player or, occasionally, a non-player character.
-
#game_location ⇒ Object
Real or fictional location of the game (or part of game).
-
#game_location=(value) ⇒ Object
Real or fictional location of the game (or part of game).
-
#number_of_players ⇒ Object
Indicate how many people can play this game (minimum, maximum, or range).
-
#number_of_players=(value) ⇒ Object
Indicate how many people can play this game (minimum, maximum, or range).
-
#quest ⇒ Object
The task that a player-controlled character, or group of characters may complete in order to gain a reward.
-
#quest=(value) ⇒ Object
The task that a player-controlled character, or group of characters may complete in order to gain a reward.
Methods included from CreativeWork
#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/schema_org/mixins/game.rb', line 11 def self.schema_property_definitions { character_attribute: { schema_name: "characterAttribute", schema_url: "https://schema.org/characterAttribute", comment_lines: ["A piece of data that represents a particular aspect of a fictional character (skill, power, character points, advantage, disadvantage)."].freeze, ranges: ["Thing"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, game_item: { schema_name: "gameItem", schema_url: "https://schema.org/gameItem", comment_lines: ["An item is an object within the game world that can be collected by a player or, occasionally, a non-player character."].freeze, ranges: ["Thing"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, game_location: { schema_name: "gameLocation", schema_url: "https://schema.org/gameLocation", comment_lines: ["Real or fictional location of the game (or part of game)."].freeze, ranges: ["Place", "PostalAddress", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, number_of_players: { schema_name: "numberOfPlayers", schema_url: "https://schema.org/numberOfPlayers", comment_lines: ["Indicate how many people can play this game (minimum, maximum, or range)."].freeze, ranges: ["QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, quest: { schema_name: "quest", schema_url: "https://schema.org/quest", comment_lines: ["The task that a player-controlled character, or group of characters may complete in order to gain a reward."].freeze, ranges: ["Thing"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#character_attribute ⇒ Object
A piece of data that represents a particular aspect of a fictional character (skill, power, character points, advantage, disadvantage).
67 68 69 |
# File 'lib/schema_org/mixins/game.rb', line 67 def character_attribute read_property(:character_attribute) end |
#character_attribute=(value) ⇒ Object
A piece of data that represents a particular aspect of a fictional character (skill, power, character points, advantage, disadvantage).
72 73 74 |
# File 'lib/schema_org/mixins/game.rb', line 72 def character_attribute=(value) write_property(:character_attribute, value) end |
#game_item ⇒ Object
An item is an object within the game world that can be collected by a player or, occasionally, a non-player character.
77 78 79 |
# File 'lib/schema_org/mixins/game.rb', line 77 def game_item read_property(:game_item) end |
#game_item=(value) ⇒ Object
An item is an object within the game world that can be collected by a player or, occasionally, a non-player character.
82 83 84 |
# File 'lib/schema_org/mixins/game.rb', line 82 def game_item=(value) write_property(:game_item, value) end |
#game_location ⇒ Object
Real or fictional location of the game (or part of game).
87 88 89 |
# File 'lib/schema_org/mixins/game.rb', line 87 def game_location read_property(:game_location) end |
#game_location=(value) ⇒ Object
Real or fictional location of the game (or part of game).
92 93 94 |
# File 'lib/schema_org/mixins/game.rb', line 92 def game_location=(value) write_property(:game_location, value) end |
#number_of_players ⇒ Object
Indicate how many people can play this game (minimum, maximum, or range).
97 98 99 |
# File 'lib/schema_org/mixins/game.rb', line 97 def number_of_players read_property(:number_of_players) end |
#number_of_players=(value) ⇒ Object
Indicate how many people can play this game (minimum, maximum, or range).
102 103 104 |
# File 'lib/schema_org/mixins/game.rb', line 102 def number_of_players=(value) write_property(:number_of_players, value) end |
#quest ⇒ Object
The task that a player-controlled character, or group of characters may complete in order to gain a reward.
107 108 109 |
# File 'lib/schema_org/mixins/game.rb', line 107 def quest read_property(:quest) end |
#quest=(value) ⇒ Object
The task that a player-controlled character, or group of characters may complete in order to gain a reward.
112 113 114 |
# File 'lib/schema_org/mixins/game.rb', line 112 def quest=(value) write_property(:quest, value) end |