Module: SchemaOrg::Mixins::GeospatialGeometry
- Includes:
- Intangible
- Included in:
- GeospatialGeometry
- Defined in:
- lib/schema_org/mixins/geospatial_geometry.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#geo_contains ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a containing geometry to a contained geometry.
-
#geo_contains=(value) ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a containing geometry to a contained geometry.
-
#geo_covered_by ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a geometry to another that covers it.
-
#geo_covered_by=(value) ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a geometry to another that covers it.
-
#geo_covers ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a covering geometry to a covered geometry.
-
#geo_covers=(value) ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a covering geometry to a covered geometry.
-
#geo_crosses ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a geometry to another that crosses it: "a crosses b: they have some but not all interior points in common, and the dimension of the intersection is less than that of at least one of them".
-
#geo_crosses=(value) ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a geometry to another that crosses it: "a crosses b: they have some but not all interior points in common, and the dimension of the intersection is less than that of at least one of them".
-
#geo_disjoint ⇒ Object
Represents spatial relations in which two geometries (or the places they represent) are topologically disjoint: "they have no point in common.
-
#geo_disjoint=(value) ⇒ Object
Represents spatial relations in which two geometries (or the places they represent) are topologically disjoint: "they have no point in common.
-
#geo_equals ⇒ Object
Represents spatial relations in which two geometries (or the places they represent) are topologically equal, as defined in DE-9IM.
-
#geo_equals=(value) ⇒ Object
Represents spatial relations in which two geometries (or the places they represent) are topologically equal, as defined in DE-9IM.
-
#geo_intersects ⇒ Object
Represents spatial relations in which two geometries (or the places they represent) have at least one point in common.
-
#geo_intersects=(value) ⇒ Object
Represents spatial relations in which two geometries (or the places they represent) have at least one point in common.
-
#geo_overlaps ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a geometry to another that geospatially overlaps it, i.e.
-
#geo_overlaps=(value) ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a geometry to another that geospatially overlaps it, i.e.
-
#geo_touches ⇒ Object
Represents spatial relations in which two geometries (or the places they represent) touch: "they have at least one boundary point in common, but no interior points." (A symmetric relationship, as defined in DE-9IM.).
-
#geo_touches=(value) ⇒ Object
Represents spatial relations in which two geometries (or the places they represent) touch: "they have at least one boundary point in common, but no interior points." (A symmetric relationship, as defined in DE-9IM.).
-
#geo_within ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a geometry to one that contains it, i.e.
-
#geo_within=(value) ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a geometry to one that contains it, i.e.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 11 def self.schema_property_definitions { geo_contains: { schema_name: "geoContains", schema_url: "https://schema.org/geoContains", comment_lines: ["Represents a relationship between two geometries (or the places they represent), relating a containing geometry to a contained geometry. \"a contains b iff no points of b lie in the exterior of a, and at least one point of the interior of b lies in the interior of a\". As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM)."].freeze, ranges: ["GeospatialGeometry", "Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, geo_covered_by: { schema_name: "geoCoveredBy", schema_url: "https://schema.org/geoCoveredBy", comment_lines: ["Represents a relationship between two geometries (or the places they represent), relating a geometry to another that covers it. As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM)."].freeze, ranges: ["GeospatialGeometry", "Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, geo_covers: { schema_name: "geoCovers", schema_url: "https://schema.org/geoCovers", comment_lines: ["Represents a relationship between two geometries (or the places they represent), relating a covering geometry to a covered geometry. \"Every point of b is a point of (the interior or boundary of) a\". As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM)."].freeze, ranges: ["GeospatialGeometry", "Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, geo_crosses: { schema_name: "geoCrosses", schema_url: "https://schema.org/geoCrosses", comment_lines: ["Represents a relationship between two geometries (or the places they represent), relating a geometry to another that crosses it: \"a crosses b: they have some but not all interior points in common, and the dimension of the intersection is less than that of at least one of them\". As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM)."].freeze, ranges: ["GeospatialGeometry", "Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, geo_disjoint: { schema_name: "geoDisjoint", schema_url: "https://schema.org/geoDisjoint", comment_lines: ["Represents spatial relations in which two geometries (or the places they represent) are topologically disjoint: \"they have no point in common. They form a set of disconnected geometries.\" (A symmetric relationship, as defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).)"].freeze, ranges: ["GeospatialGeometry", "Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, geo_equals: { schema_name: "geoEquals", schema_url: "https://schema.org/geoEquals", comment_lines: ["Represents spatial relations in which two geometries (or the places they represent) are topologically equal, as defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM). \"Two geometries are topologically equal if their interiors intersect and no part of the interior or boundary of one geometry intersects the exterior of the other\" (a symmetric relationship)."].freeze, ranges: ["GeospatialGeometry", "Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, geo_intersects: { schema_name: "geoIntersects", schema_url: "https://schema.org/geoIntersects", comment_lines: ["Represents spatial relations in which two geometries (or the places they represent) have at least one point in common. As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM)."].freeze, ranges: ["GeospatialGeometry", "Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, geo_overlaps: { schema_name: "geoOverlaps", schema_url: "https://schema.org/geoOverlaps", comment_lines: ["Represents a relationship between two geometries (or the places they represent), relating a geometry to another that geospatially overlaps it, i.e. they have some but not all points in common. As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM)."].freeze, ranges: ["GeospatialGeometry", "Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, geo_touches: { schema_name: "geoTouches", schema_url: "https://schema.org/geoTouches", comment_lines: ["Represents spatial relations in which two geometries (or the places they represent) touch: \"they have at least one boundary point in common, but no interior points.\" (A symmetric relationship, as defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).)"].freeze, ranges: ["GeospatialGeometry", "Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, geo_within: { schema_name: "geoWithin", schema_url: "https://schema.org/geoWithin", comment_lines: ["Represents a relationship between two geometries (or the places they represent), relating a geometry to one that contains it, i.e. it is inside (i.e. within) its interior. As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM)."].freeze, ranges: ["GeospatialGeometry", "Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#geo_contains ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a containing geometry to a contained geometry. "a contains b iff no points of b lie in the exterior of a, and at least one point of the interior of b lies in the interior of a". As defined in DE-9IM.
117 118 119 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 117 def geo_contains read_property(:geo_contains) end |
#geo_contains=(value) ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a containing geometry to a contained geometry. "a contains b iff no points of b lie in the exterior of a, and at least one point of the interior of b lies in the interior of a". As defined in DE-9IM.
122 123 124 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 122 def geo_contains=(value) write_property(:geo_contains, value) end |
#geo_covered_by ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a geometry to another that covers it. As defined in DE-9IM.
127 128 129 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 127 def geo_covered_by read_property(:geo_covered_by) end |
#geo_covered_by=(value) ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a geometry to another that covers it. As defined in DE-9IM.
132 133 134 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 132 def geo_covered_by=(value) write_property(:geo_covered_by, value) end |
#geo_covers ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a covering geometry to a covered geometry. "Every point of b is a point of (the interior or boundary of) a". As defined in DE-9IM.
137 138 139 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 137 def geo_covers read_property(:geo_covers) end |
#geo_covers=(value) ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a covering geometry to a covered geometry. "Every point of b is a point of (the interior or boundary of) a". As defined in DE-9IM.
142 143 144 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 142 def geo_covers=(value) write_property(:geo_covers, value) end |
#geo_crosses ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a geometry to another that crosses it: "a crosses b: they have some but not all interior points in common, and the dimension of the intersection is less than that of at least one of them". As defined in DE-9IM.
147 148 149 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 147 def geo_crosses read_property(:geo_crosses) end |
#geo_crosses=(value) ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a geometry to another that crosses it: "a crosses b: they have some but not all interior points in common, and the dimension of the intersection is less than that of at least one of them". As defined in DE-9IM.
152 153 154 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 152 def geo_crosses=(value) write_property(:geo_crosses, value) end |
#geo_disjoint ⇒ Object
Represents spatial relations in which two geometries (or the places they represent) are topologically disjoint: "they have no point in common. They form a set of disconnected geometries." (A symmetric relationship, as defined in DE-9IM.)
157 158 159 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 157 def geo_disjoint read_property(:geo_disjoint) end |
#geo_disjoint=(value) ⇒ Object
Represents spatial relations in which two geometries (or the places they represent) are topologically disjoint: "they have no point in common. They form a set of disconnected geometries." (A symmetric relationship, as defined in DE-9IM.)
162 163 164 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 162 def geo_disjoint=(value) write_property(:geo_disjoint, value) end |
#geo_equals ⇒ Object
Represents spatial relations in which two geometries (or the places they represent) are topologically equal, as defined in DE-9IM. "Two geometries are topologically equal if their interiors intersect and no part of the interior or boundary of one geometry intersects the exterior of the other" (a symmetric relationship).
167 168 169 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 167 def geo_equals read_property(:geo_equals) end |
#geo_equals=(value) ⇒ Object
Represents spatial relations in which two geometries (or the places they represent) are topologically equal, as defined in DE-9IM. "Two geometries are topologically equal if their interiors intersect and no part of the interior or boundary of one geometry intersects the exterior of the other" (a symmetric relationship).
172 173 174 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 172 def geo_equals=(value) write_property(:geo_equals, value) end |
#geo_intersects ⇒ Object
Represents spatial relations in which two geometries (or the places they represent) have at least one point in common. As defined in DE-9IM.
177 178 179 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 177 def geo_intersects read_property(:geo_intersects) end |
#geo_intersects=(value) ⇒ Object
Represents spatial relations in which two geometries (or the places they represent) have at least one point in common. As defined in DE-9IM.
182 183 184 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 182 def geo_intersects=(value) write_property(:geo_intersects, value) end |
#geo_overlaps ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a geometry to another that geospatially overlaps it, i.e. they have some but not all points in common. As defined in DE-9IM.
187 188 189 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 187 def geo_overlaps read_property(:geo_overlaps) end |
#geo_overlaps=(value) ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a geometry to another that geospatially overlaps it, i.e. they have some but not all points in common. As defined in DE-9IM.
192 193 194 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 192 def geo_overlaps=(value) write_property(:geo_overlaps, value) end |
#geo_touches ⇒ Object
Represents spatial relations in which two geometries (or the places they represent) touch: "they have at least one boundary point in common, but no interior points." (A symmetric relationship, as defined in DE-9IM.)
197 198 199 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 197 def geo_touches read_property(:geo_touches) end |
#geo_touches=(value) ⇒ Object
Represents spatial relations in which two geometries (or the places they represent) touch: "they have at least one boundary point in common, but no interior points." (A symmetric relationship, as defined in DE-9IM.)
202 203 204 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 202 def geo_touches=(value) write_property(:geo_touches, value) end |
#geo_within ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a geometry to one that contains it, i.e. it is inside (i.e. within) its interior. As defined in DE-9IM.
207 208 209 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 207 def geo_within read_property(:geo_within) end |
#geo_within=(value) ⇒ Object
Represents a relationship between two geometries (or the places they represent), relating a geometry to one that contains it, i.e. it is inside (i.e. within) its interior. As defined in DE-9IM.
212 213 214 |
# File 'lib/schema_org/mixins/geospatial_geometry.rb', line 212 def geo_within=(value) write_property(:geo_within, value) end |