Module: SchemaOrg::Mixins::GovernmentService
- Includes:
- Service
- Included in:
- GovernmentService
- Defined in:
- lib/schema_org/mixins/government_service.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#jurisdiction ⇒ Object
Indicates a legal jurisdiction, e.g.
-
#jurisdiction=(value) ⇒ Object
Indicates a legal jurisdiction, e.g.
-
#service_operator ⇒ Object
The operating organization, if different from the provider.
-
#service_operator=(value) ⇒ Object
The operating organization, if different from the provider.
Methods included from Service
#aggregate_rating, #aggregate_rating=, #area_served, #area_served=, #audience, #audience=, #available_channel, #available_channel=, #award, #award=, #brand, #brand=, #broker, #broker=, #category, #category=, #has_certification, #has_certification=, #has_offer_catalog, #has_offer_catalog=, #hours_available, #hours_available=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #logo, #logo=, #offers, #offers=, #produces, #produces=, #provider, #provider=, #provider_mobility, #provider_mobility=, #review, #review=, #service_area, #service_area=, #service_audience, #service_audience=, #service_output, #service_output=, #service_type, #service_type=, #slogan, #slogan=, #terms_of_service, #terms_of_service=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/schema_org/mixins/government_service.rb', line 11 def self.schema_property_definitions { jurisdiction: { schema_name: "jurisdiction", schema_url: "https://schema.org/jurisdiction", comment_lines: ["Indicates a legal jurisdiction, e.g. of some legislation, or where some government service is based."].freeze, ranges: ["AdministrativeArea", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, service_operator: { schema_name: "serviceOperator", schema_url: "https://schema.org/serviceOperator", comment_lines: ["The operating organization, if different from the provider. This enables the representation of services that are provided by an organization, but operated by another organization like a subcontractor."].freeze, ranges: ["Organization"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#jurisdiction ⇒ Object
Indicates a legal jurisdiction, e.g. of some legislation, or where some government service is based.
37 38 39 |
# File 'lib/schema_org/mixins/government_service.rb', line 37 def jurisdiction read_property(:jurisdiction) end |
#jurisdiction=(value) ⇒ Object
Indicates a legal jurisdiction, e.g. of some legislation, or where some government service is based.
42 43 44 |
# File 'lib/schema_org/mixins/government_service.rb', line 42 def jurisdiction=(value) write_property(:jurisdiction, value) end |
#service_operator ⇒ Object
The operating organization, if different from the provider. This enables the representation of services that are provided by an organization, but operated by another organization like a subcontractor.
47 48 49 |
# File 'lib/schema_org/mixins/government_service.rb', line 47 def service_operator read_property(:service_operator) end |
#service_operator=(value) ⇒ Object
The operating organization, if different from the provider. This enables the representation of services that are provided by an organization, but operated by another organization like a subcontractor.
52 53 54 |
# File 'lib/schema_org/mixins/government_service.rb', line 52 def service_operator=(value) write_property(:service_operator, value) end |