Module: SchemaOrg::Mixins::HealthPlanNetwork
- Includes:
- Intangible
- Included in:
- HealthPlanNetwork
- Defined in:
- lib/schema_org/mixins/health_plan_network.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#health_plan_cost_sharing ⇒ Object
The costs to the patient for services under this network or formulary.
-
#health_plan_cost_sharing=(value) ⇒ Object
The costs to the patient for services under this network or formulary.
-
#health_plan_network_id ⇒ Object
Name or unique ID of network.
-
#health_plan_network_id=(value) ⇒ Object
Name or unique ID of network.
-
#health_plan_network_tier ⇒ Object
The tier(s) for this network.
-
#health_plan_network_tier=(value) ⇒ Object
The tier(s) for this network.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/schema_org/mixins/health_plan_network.rb', line 11 def self.schema_property_definitions { health_plan_cost_sharing: { schema_name: "healthPlanCostSharing", schema_url: "https://schema.org/healthPlanCostSharing", comment_lines: ["The costs to the patient for services under this network or formulary."].freeze, ranges: ["Boolean", "HealthPlanCostSharingSpecification"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, health_plan_network_id: { schema_name: "healthPlanNetworkId", schema_url: "https://schema.org/healthPlanNetworkId", comment_lines: ["Name or unique ID of network. (Networks are often reused across different insurance plans.)"].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, health_plan_network_tier: { schema_name: "healthPlanNetworkTier", schema_url: "https://schema.org/healthPlanNetworkTier", comment_lines: ["The tier(s) for this network."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#health_plan_cost_sharing ⇒ Object
The costs to the patient for services under this network or formulary.
47 48 49 |
# File 'lib/schema_org/mixins/health_plan_network.rb', line 47 def health_plan_cost_sharing read_property(:health_plan_cost_sharing) end |
#health_plan_cost_sharing=(value) ⇒ Object
The costs to the patient for services under this network or formulary.
52 53 54 |
# File 'lib/schema_org/mixins/health_plan_network.rb', line 52 def health_plan_cost_sharing=(value) write_property(:health_plan_cost_sharing, value) end |
#health_plan_network_id ⇒ Object
Name or unique ID of network. (Networks are often reused across different insurance plans.)
57 58 59 |
# File 'lib/schema_org/mixins/health_plan_network.rb', line 57 def health_plan_network_id read_property(:health_plan_network_id) end |
#health_plan_network_id=(value) ⇒ Object
Name or unique ID of network. (Networks are often reused across different insurance plans.)
62 63 64 |
# File 'lib/schema_org/mixins/health_plan_network.rb', line 62 def health_plan_network_id=(value) write_property(:health_plan_network_id, value) end |
#health_plan_network_tier ⇒ Object
The tier(s) for this network.
67 68 69 |
# File 'lib/schema_org/mixins/health_plan_network.rb', line 67 def health_plan_network_tier read_property(:health_plan_network_tier) end |
#health_plan_network_tier=(value) ⇒ Object
The tier(s) for this network.
72 73 74 |
# File 'lib/schema_org/mixins/health_plan_network.rb', line 72 def health_plan_network_tier=(value) write_property(:health_plan_network_tier, value) end |