Module: SchemaOrg::Mixins::HowToSupply
Class Method Summary collapse
Instance Method Summary collapse
-
#estimated_cost ⇒ Object
The estimated cost of the supply or supplies consumed when performing instructions.
-
#estimated_cost=(value) ⇒ Object
The estimated cost of the supply or supplies consumed when performing instructions.
Methods included from HowToItem
#required_quantity, #required_quantity=
Methods included from ListItem
#item, #item=, #next_item, #next_item=, #position, #position=, #previous_item, #previous_item=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 |
# File 'lib/schema_org/mixins/how_to_supply.rb', line 11 def self.schema_property_definitions { estimated_cost: { schema_name: "estimatedCost", schema_url: "https://schema.org/estimatedCost", comment_lines: ["The estimated cost of the supply or supplies consumed when performing instructions."].freeze, ranges: ["MonetaryAmount", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#estimated_cost ⇒ Object
The estimated cost of the supply or supplies consumed when performing instructions.
27 28 29 |
# File 'lib/schema_org/mixins/how_to_supply.rb', line 27 def estimated_cost read_property(:estimated_cost) end |
#estimated_cost=(value) ⇒ Object
The estimated cost of the supply or supplies consumed when performing instructions.
32 33 34 |
# File 'lib/schema_org/mixins/how_to_supply.rb', line 32 def estimated_cost=(value) write_property(:estimated_cost, value) end |