Module: SchemaOrg::Mixins::InstantaneousEvent
- Includes:
- StructuredValue
- Included in:
- InstantaneousEvent, Error
- Defined in:
- lib/schema_org/mixins/instantaneous_event.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#data ⇒ Object
Data associated with the event, like for instance a log message.
-
#data=(value) ⇒ Object
Data associated with the event, like for instance a log message.
-
#source ⇒ Object
The source or cause of the event.
-
#source=(value) ⇒ Object
The source or cause of the event.
-
#timestamp ⇒ Object
The instant the event occured.
-
#timestamp=(value) ⇒ Object
The instant the event occured.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/schema_org/mixins/instantaneous_event.rb', line 11 def self.schema_property_definitions { data: { schema_name: "data", schema_url: "https://schema.org/data", comment_lines: ["Data associated with the event, like for instance a log message."].freeze, ranges: ["Thing"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, source: { schema_name: "source", schema_url: "https://schema.org/source", comment_lines: ["The source or cause of the event."].freeze, ranges: ["Thing"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, timestamp: { schema_name: "timestamp", schema_url: "https://schema.org/timestamp", comment_lines: ["The instant the event occured."].freeze, ranges: ["DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#data ⇒ Object
Data associated with the event, like for instance a log message.
47 48 49 |
# File 'lib/schema_org/mixins/instantaneous_event.rb', line 47 def data read_property(:data) end |
#data=(value) ⇒ Object
Data associated with the event, like for instance a log message.
52 53 54 |
# File 'lib/schema_org/mixins/instantaneous_event.rb', line 52 def data=(value) write_property(:data, value) end |
#source ⇒ Object
The source or cause of the event.
57 58 59 |
# File 'lib/schema_org/mixins/instantaneous_event.rb', line 57 def source read_property(:source) end |
#source=(value) ⇒ Object
The source or cause of the event.
62 63 64 |
# File 'lib/schema_org/mixins/instantaneous_event.rb', line 62 def source=(value) write_property(:source, value) end |
#timestamp ⇒ Object
The instant the event occured.
67 68 69 |
# File 'lib/schema_org/mixins/instantaneous_event.rb', line 67 def read_property(:timestamp) end |
#timestamp=(value) ⇒ Object
The instant the event occured.
72 73 74 |
# File 'lib/schema_org/mixins/instantaneous_event.rb', line 72 def (value) write_property(:timestamp, value) end |