Module: SchemaOrg::Mixins::Legislation
- Includes:
- CreativeWork
- Included in:
- Legislation, LegislationObject
- Defined in:
- lib/schema_org/mixins/legislation.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#jurisdiction ⇒ Object
Indicates a legal jurisdiction, e.g.
-
#jurisdiction=(value) ⇒ Object
Indicates a legal jurisdiction, e.g.
-
#legislation_amends ⇒ Object
Another legislation that this legislation amends, introducing legal changes.
-
#legislation_amends=(value) ⇒ Object
Another legislation that this legislation amends, introducing legal changes.
-
#legislation_applies ⇒ Object
Indicates that this legislation (or part of a legislation) somehow transfers another legislation in a different legislative context.
-
#legislation_applies=(value) ⇒ Object
Indicates that this legislation (or part of a legislation) somehow transfers another legislation in a different legislative context.
-
#legislation_changes ⇒ Object
Another legislation that this legislation changes.
-
#legislation_changes=(value) ⇒ Object
Another legislation that this legislation changes.
-
#legislation_commences ⇒ Object
Another legislation that this one sets into force.
-
#legislation_commences=(value) ⇒ Object
Another legislation that this one sets into force.
-
#legislation_consolidates ⇒ Object
Indicates another legislation taken into account in this consolidated legislation (which is usually the product of an editorial process that revises the legislation).
-
#legislation_consolidates=(value) ⇒ Object
Indicates another legislation taken into account in this consolidated legislation (which is usually the product of an editorial process that revises the legislation).
-
#legislation_corrects ⇒ Object
Another legislation in which this one introduces textual changes, like correction of spelling mistakes, with no legal impact (for modifications that have legal impact, use legislationAmends).
-
#legislation_corrects=(value) ⇒ Object
Another legislation in which this one introduces textual changes, like correction of spelling mistakes, with no legal impact (for modifications that have legal impact, use legislationAmends).
-
#legislation_countersigned_by ⇒ Object
The person or organization that countersigned the legislation.
-
#legislation_countersigned_by=(value) ⇒ Object
The person or organization that countersigned the legislation.
-
#legislation_date ⇒ Object
The date of adoption or signature of the legislation.
-
#legislation_date=(value) ⇒ Object
The date of adoption or signature of the legislation.
-
#legislation_date_of_applicability ⇒ Object
The date at which the Legislation becomes applicable.
-
#legislation_date_of_applicability=(value) ⇒ Object
The date at which the Legislation becomes applicable.
-
#legislation_date_version ⇒ Object
The point-in-time at which the provided description of the legislation is valid (e.g.: when looking at the law on the 2016-04-07 (= dateVersion), I get the consolidation of 2015-04-12 of the "National Insurance Contributions Act 2015").
-
#legislation_date_version=(value) ⇒ Object
The point-in-time at which the provided description of the legislation is valid (e.g.: when looking at the law on the 2016-04-07 (= dateVersion), I get the consolidation of 2015-04-12 of the "National Insurance Contributions Act 2015").
-
#legislation_ensures_implementation_of ⇒ Object
Indicates that this Legislation ensures the implementation of another Legislation, for example by modifying national legislations so that they do not contradict to an EU regulation or decision.
-
#legislation_ensures_implementation_of=(value) ⇒ Object
Indicates that this Legislation ensures the implementation of another Legislation, for example by modifying national legislations so that they do not contradict to an EU regulation or decision.
-
#legislation_identifier ⇒ Object
An identifier for the legislation.
-
#legislation_identifier=(value) ⇒ Object
An identifier for the legislation.
-
#legislation_jurisdiction ⇒ Object
The jurisdiction from which the legislation originates.
-
#legislation_jurisdiction=(value) ⇒ Object
The jurisdiction from which the legislation originates.
-
#legislation_legal_force ⇒ Object
Whether the legislation is currently in force, not in force, or partially in force.
-
#legislation_legal_force=(value) ⇒ Object
Whether the legislation is currently in force, not in force, or partially in force.
-
#legislation_passed_by ⇒ Object
The person or organization that originally passed or made the law: typically parliament (for primary legislation) or government (for secondary legislation).
-
#legislation_passed_by=(value) ⇒ Object
The person or organization that originally passed or made the law: typically parliament (for primary legislation) or government (for secondary legislation).
-
#legislation_repeals ⇒ Object
Another legislation that this legislation repeals (cancels, abrogates).
-
#legislation_repeals=(value) ⇒ Object
Another legislation that this legislation repeals (cancels, abrogates).
-
#legislation_responsible ⇒ Object
An individual or organization that has some kind of responsibility for the legislation.
-
#legislation_responsible=(value) ⇒ Object
An individual or organization that has some kind of responsibility for the legislation.
-
#legislation_transposes ⇒ Object
Indicates that this legislation (or part of legislation) fulfills the objectives set by another legislation, by passing appropriate implementation measures.
-
#legislation_transposes=(value) ⇒ Object
Indicates that this legislation (or part of legislation) fulfills the objectives set by another legislation, by passing appropriate implementation measures.
-
#legislation_type ⇒ Object
The type of the legislation.
-
#legislation_type=(value) ⇒ Object
The type of the legislation.
Methods included from CreativeWork
#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/schema_org/mixins/legislation.rb', line 11 def self.schema_property_definitions { jurisdiction: { schema_name: "jurisdiction", schema_url: "https://schema.org/jurisdiction", comment_lines: ["Indicates a legal jurisdiction, e.g. of some legislation, or where some government service is based."].freeze, ranges: ["AdministrativeArea", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_amends: { schema_name: "legislationAmends", schema_url: "https://schema.org/legislationAmends", comment_lines: ["Another legislation that this legislation amends, introducing legal changes."].freeze, ranges: ["Legislation"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_applies: { schema_name: "legislationApplies", schema_url: "https://schema.org/legislationApplies", comment_lines: ["Indicates that this legislation (or part of a legislation) somehow transfers another legislation in a different legislative context. This is an informative link, and it has no legal value. For legally-binding links of transposition, use the <a href=\"/legislationTransposes\">legislationTransposes</a> property. For example an informative consolidated law of a European Union's member state \"applies\" the consolidated version of the European Directive implemented in it."].freeze, ranges: ["Legislation"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_changes: { schema_name: "legislationChanges", schema_url: "https://schema.org/legislationChanges", comment_lines: ["Another legislation that this legislation changes. This encompasses the notions of amendment, replacement, correction, repeal, or other types of change. This may be a direct change (textual or non-textual amendment) or a consequential or indirect change. The property is to be used to express the existence of a change relationship between two acts rather than the existence of a consolidated version of the text that shows the result of the change. For consolidation relationships, use the <a href=\"/legislationConsolidates\">legislationConsolidates</a> property."].freeze, ranges: ["Legislation"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_commences: { schema_name: "legislationCommences", schema_url: "https://schema.org/legislationCommences", comment_lines: ["Another legislation that this one sets into force."].freeze, ranges: ["Legislation"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_consolidates: { schema_name: "legislationConsolidates", schema_url: "https://schema.org/legislationConsolidates", comment_lines: ["Indicates another legislation taken into account in this consolidated legislation (which is usually the product of an editorial process that revises the legislation). This property should be used multiple times to refer to both the original version or the previous consolidated version, and to the legislations making the change."].freeze, ranges: ["Legislation"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_corrects: { schema_name: "legislationCorrects", schema_url: "https://schema.org/legislationCorrects", comment_lines: ["Another legislation in which this one introduces textual changes, like correction of spelling mistakes, with no legal impact (for modifications that have legal impact, use <a href=\"/legislationAmends\">legislationAmends</a>)."].freeze, ranges: ["Legislation"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_countersigned_by: { schema_name: "legislationCountersignedBy", schema_url: "https://schema.org/legislationCountersignedBy", comment_lines: ["The person or organization that countersigned the legislation. Depending on the legal context, a countersignature can indicate that the signed authority undertakes to assume responsibility for texts emanating from a person who is inviolable and irresponsible, (for example a King, Grand Duc or President), or that the authority is in charge of the implementation of the text."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_date: { schema_name: "legislationDate", schema_url: "https://schema.org/legislationDate", comment_lines: ["The date of adoption or signature of the legislation. This is the date at which the text is officially aknowledged to be a legislation, even though it might not even be published or in force."].freeze, ranges: ["Date"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_date_of_applicability: { schema_name: "legislationDateOfApplicability", schema_url: "https://schema.org/legislationDateOfApplicability", comment_lines: ["The date at which the Legislation becomes applicable. This can sometimes be distinct from the date of entry into force : a text may come in force today, and state it will become applicable in 3 months."].freeze, ranges: ["Date"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_date_version: { schema_name: "legislationDateVersion", schema_url: "https://schema.org/legislationDateVersion", comment_lines: ["The point-in-time at which the provided description of the legislation is valid (e.g.: when looking at the law on the 2016-04-07 (= dateVersion), I get the consolidation of 2015-04-12 of the \"National Insurance Contributions Act 2015\")"].freeze, ranges: ["Date"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_ensures_implementation_of: { schema_name: "legislationEnsuresImplementationOf", schema_url: "https://schema.org/legislationEnsuresImplementationOf", comment_lines: ["Indicates that this Legislation ensures the implementation of another Legislation, for example by modifying national legislations so that they do not contradict to an EU regulation or decision. This implies a legal meaning. Transpositions of EU Directive should be captured with <a href=\"/legislationTransposes\">legislationTransposes</a>."].freeze, ranges: ["Legislation"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_identifier: { schema_name: "legislationIdentifier", schema_url: "https://schema.org/legislationIdentifier", comment_lines: ["An identifier for the legislation. This can be either a string-based identifier, like the CELEX at EU level or the NOR in France, or a web-based, URL/URI identifier, like an ELI (European Legislation Identifier) or an URN-Lex."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_jurisdiction: { schema_name: "legislationJurisdiction", schema_url: "https://schema.org/legislationJurisdiction", comment_lines: ["The jurisdiction from which the legislation originates."].freeze, ranges: ["AdministrativeArea", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_legal_force: { schema_name: "legislationLegalForce", schema_url: "https://schema.org/legislationLegalForce", comment_lines: ["Whether the legislation is currently in force, not in force, or partially in force."].freeze, ranges: ["LegalForceStatus"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_passed_by: { schema_name: "legislationPassedBy", schema_url: "https://schema.org/legislationPassedBy", comment_lines: ["The person or organization that originally passed or made the law: typically parliament (for primary legislation) or government (for secondary legislation). This indicates the \"legal author\" of the law, as opposed to its physical author."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_repeals: { schema_name: "legislationRepeals", schema_url: "https://schema.org/legislationRepeals", comment_lines: ["Another legislation that this legislation repeals (cancels, abrogates)."].freeze, ranges: ["Legislation"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_responsible: { schema_name: "legislationResponsible", schema_url: "https://schema.org/legislationResponsible", comment_lines: ["An individual or organization that has some kind of responsibility for the legislation. Typically the ministry who is/was in charge of elaborating the legislation, or the adressee for potential questions about the legislation once it is published."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_transposes: { schema_name: "legislationTransposes", schema_url: "https://schema.org/legislationTransposes", comment_lines: ["Indicates that this legislation (or part of legislation) fulfills the objectives set by another legislation, by passing appropriate implementation measures. Typically, some legislations of European Union's member states or regions transpose European Directives. This indicates a legally binding link between the 2 legislations."].freeze, ranges: ["Legislation"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legislation_type: { schema_name: "legislationType", schema_url: "https://schema.org/legislationType", comment_lines: ["The type of the legislation. Examples of values are \"law\", \"act\", \"directive\", \"decree\", \"regulation\", \"statutory instrument\", \"loi organique\", \"règlement grand-ducal\", etc., depending on the country."].freeze, ranges: ["CategoryCode", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#jurisdiction ⇒ Object
Indicates a legal jurisdiction, e.g. of some legislation, or where some government service is based.
217 218 219 |
# File 'lib/schema_org/mixins/legislation.rb', line 217 def jurisdiction read_property(:jurisdiction) end |
#jurisdiction=(value) ⇒ Object
Indicates a legal jurisdiction, e.g. of some legislation, or where some government service is based.
222 223 224 |
# File 'lib/schema_org/mixins/legislation.rb', line 222 def jurisdiction=(value) write_property(:jurisdiction, value) end |
#legislation_amends ⇒ Object
Another legislation that this legislation amends, introducing legal changes.
227 228 229 |
# File 'lib/schema_org/mixins/legislation.rb', line 227 def legislation_amends read_property(:legislation_amends) end |
#legislation_amends=(value) ⇒ Object
Another legislation that this legislation amends, introducing legal changes.
232 233 234 |
# File 'lib/schema_org/mixins/legislation.rb', line 232 def legislation_amends=(value) write_property(:legislation_amends, value) end |
#legislation_applies ⇒ Object
Indicates that this legislation (or part of a legislation) somehow transfers another legislation in a different legislative context. This is an informative link, and it has no legal value. For legally-binding links of transposition, use the legislationTransposes property. For example an informative consolidated law of a European Union's member state "applies" the consolidated version of the European Directive implemented in it.
237 238 239 |
# File 'lib/schema_org/mixins/legislation.rb', line 237 def legislation_applies read_property(:legislation_applies) end |
#legislation_applies=(value) ⇒ Object
Indicates that this legislation (or part of a legislation) somehow transfers another legislation in a different legislative context. This is an informative link, and it has no legal value. For legally-binding links of transposition, use the legislationTransposes property. For example an informative consolidated law of a European Union's member state "applies" the consolidated version of the European Directive implemented in it.
242 243 244 |
# File 'lib/schema_org/mixins/legislation.rb', line 242 def legislation_applies=(value) write_property(:legislation_applies, value) end |
#legislation_changes ⇒ Object
Another legislation that this legislation changes. This encompasses the notions of amendment, replacement, correction, repeal, or other types of change. This may be a direct change (textual or non-textual amendment) or a consequential or indirect change. The property is to be used to express the existence of a change relationship between two acts rather than the existence of a consolidated version of the text that shows the result of the change. For consolidation relationships, use the legislationConsolidates property.
247 248 249 |
# File 'lib/schema_org/mixins/legislation.rb', line 247 def legislation_changes read_property(:legislation_changes) end |
#legislation_changes=(value) ⇒ Object
Another legislation that this legislation changes. This encompasses the notions of amendment, replacement, correction, repeal, or other types of change. This may be a direct change (textual or non-textual amendment) or a consequential or indirect change. The property is to be used to express the existence of a change relationship between two acts rather than the existence of a consolidated version of the text that shows the result of the change. For consolidation relationships, use the legislationConsolidates property.
252 253 254 |
# File 'lib/schema_org/mixins/legislation.rb', line 252 def legislation_changes=(value) write_property(:legislation_changes, value) end |
#legislation_commences ⇒ Object
Another legislation that this one sets into force.
257 258 259 |
# File 'lib/schema_org/mixins/legislation.rb', line 257 def legislation_commences read_property(:legislation_commences) end |
#legislation_commences=(value) ⇒ Object
Another legislation that this one sets into force.
262 263 264 |
# File 'lib/schema_org/mixins/legislation.rb', line 262 def legislation_commences=(value) write_property(:legislation_commences, value) end |
#legislation_consolidates ⇒ Object
Indicates another legislation taken into account in this consolidated legislation (which is usually the product of an editorial process that revises the legislation). This property should be used multiple times to refer to both the original version or the previous consolidated version, and to the legislations making the change.
267 268 269 |
# File 'lib/schema_org/mixins/legislation.rb', line 267 def legislation_consolidates read_property(:legislation_consolidates) end |
#legislation_consolidates=(value) ⇒ Object
Indicates another legislation taken into account in this consolidated legislation (which is usually the product of an editorial process that revises the legislation). This property should be used multiple times to refer to both the original version or the previous consolidated version, and to the legislations making the change.
272 273 274 |
# File 'lib/schema_org/mixins/legislation.rb', line 272 def legislation_consolidates=(value) write_property(:legislation_consolidates, value) end |
#legislation_corrects ⇒ Object
Another legislation in which this one introduces textual changes, like correction of spelling mistakes, with no legal impact (for modifications that have legal impact, use legislationAmends).
277 278 279 |
# File 'lib/schema_org/mixins/legislation.rb', line 277 def legislation_corrects read_property(:legislation_corrects) end |
#legislation_corrects=(value) ⇒ Object
Another legislation in which this one introduces textual changes, like correction of spelling mistakes, with no legal impact (for modifications that have legal impact, use legislationAmends).
282 283 284 |
# File 'lib/schema_org/mixins/legislation.rb', line 282 def legislation_corrects=(value) write_property(:legislation_corrects, value) end |
#legislation_countersigned_by ⇒ Object
The person or organization that countersigned the legislation. Depending on the legal context, a countersignature can indicate that the signed authority undertakes to assume responsibility for texts emanating from a person who is inviolable and irresponsible, (for example a King, Grand Duc or President), or that the authority is in charge of the implementation of the text.
287 288 289 |
# File 'lib/schema_org/mixins/legislation.rb', line 287 def legislation_countersigned_by read_property(:legislation_countersigned_by) end |
#legislation_countersigned_by=(value) ⇒ Object
The person or organization that countersigned the legislation. Depending on the legal context, a countersignature can indicate that the signed authority undertakes to assume responsibility for texts emanating from a person who is inviolable and irresponsible, (for example a King, Grand Duc or President), or that the authority is in charge of the implementation of the text.
292 293 294 |
# File 'lib/schema_org/mixins/legislation.rb', line 292 def legislation_countersigned_by=(value) write_property(:legislation_countersigned_by, value) end |
#legislation_date ⇒ Object
The date of adoption or signature of the legislation. This is the date at which the text is officially aknowledged to be a legislation, even though it might not even be published or in force.
297 298 299 |
# File 'lib/schema_org/mixins/legislation.rb', line 297 def legislation_date read_property(:legislation_date) end |
#legislation_date=(value) ⇒ Object
The date of adoption or signature of the legislation. This is the date at which the text is officially aknowledged to be a legislation, even though it might not even be published or in force.
302 303 304 |
# File 'lib/schema_org/mixins/legislation.rb', line 302 def legislation_date=(value) write_property(:legislation_date, value) end |
#legislation_date_of_applicability ⇒ Object
The date at which the Legislation becomes applicable. This can sometimes be distinct from the date of entry into force : a text may come in force today, and state it will become applicable in 3 months.
307 308 309 |
# File 'lib/schema_org/mixins/legislation.rb', line 307 def legislation_date_of_applicability read_property(:legislation_date_of_applicability) end |
#legislation_date_of_applicability=(value) ⇒ Object
The date at which the Legislation becomes applicable. This can sometimes be distinct from the date of entry into force : a text may come in force today, and state it will become applicable in 3 months.
312 313 314 |
# File 'lib/schema_org/mixins/legislation.rb', line 312 def legislation_date_of_applicability=(value) write_property(:legislation_date_of_applicability, value) end |
#legislation_date_version ⇒ Object
The point-in-time at which the provided description of the legislation is valid (e.g.: when looking at the law on the 2016-04-07 (= dateVersion), I get the consolidation of 2015-04-12 of the "National Insurance Contributions Act 2015")
317 318 319 |
# File 'lib/schema_org/mixins/legislation.rb', line 317 def legislation_date_version read_property(:legislation_date_version) end |
#legislation_date_version=(value) ⇒ Object
The point-in-time at which the provided description of the legislation is valid (e.g.: when looking at the law on the 2016-04-07 (= dateVersion), I get the consolidation of 2015-04-12 of the "National Insurance Contributions Act 2015")
322 323 324 |
# File 'lib/schema_org/mixins/legislation.rb', line 322 def legislation_date_version=(value) write_property(:legislation_date_version, value) end |
#legislation_ensures_implementation_of ⇒ Object
Indicates that this Legislation ensures the implementation of another Legislation, for example by modifying national legislations so that they do not contradict to an EU regulation or decision. This implies a legal meaning. Transpositions of EU Directive should be captured with legislationTransposes.
327 328 329 |
# File 'lib/schema_org/mixins/legislation.rb', line 327 def legislation_ensures_implementation_of read_property(:legislation_ensures_implementation_of) end |
#legislation_ensures_implementation_of=(value) ⇒ Object
Indicates that this Legislation ensures the implementation of another Legislation, for example by modifying national legislations so that they do not contradict to an EU regulation or decision. This implies a legal meaning. Transpositions of EU Directive should be captured with legislationTransposes.
332 333 334 |
# File 'lib/schema_org/mixins/legislation.rb', line 332 def legislation_ensures_implementation_of=(value) write_property(:legislation_ensures_implementation_of, value) end |
#legislation_identifier ⇒ Object
An identifier for the legislation. This can be either a string-based identifier, like the CELEX at EU level or the NOR in France, or a web-based, URL/URI identifier, like an ELI (European Legislation Identifier) or an URN-Lex.
337 338 339 |
# File 'lib/schema_org/mixins/legislation.rb', line 337 def legislation_identifier read_property(:legislation_identifier) end |
#legislation_identifier=(value) ⇒ Object
An identifier for the legislation. This can be either a string-based identifier, like the CELEX at EU level or the NOR in France, or a web-based, URL/URI identifier, like an ELI (European Legislation Identifier) or an URN-Lex.
342 343 344 |
# File 'lib/schema_org/mixins/legislation.rb', line 342 def legislation_identifier=(value) write_property(:legislation_identifier, value) end |
#legislation_jurisdiction ⇒ Object
The jurisdiction from which the legislation originates.
347 348 349 |
# File 'lib/schema_org/mixins/legislation.rb', line 347 def legislation_jurisdiction read_property(:legislation_jurisdiction) end |
#legislation_jurisdiction=(value) ⇒ Object
The jurisdiction from which the legislation originates.
352 353 354 |
# File 'lib/schema_org/mixins/legislation.rb', line 352 def legislation_jurisdiction=(value) write_property(:legislation_jurisdiction, value) end |
#legislation_legal_force ⇒ Object
Whether the legislation is currently in force, not in force, or partially in force.
357 358 359 |
# File 'lib/schema_org/mixins/legislation.rb', line 357 def legislation_legal_force read_property(:legislation_legal_force) end |
#legislation_legal_force=(value) ⇒ Object
Whether the legislation is currently in force, not in force, or partially in force.
362 363 364 |
# File 'lib/schema_org/mixins/legislation.rb', line 362 def legislation_legal_force=(value) write_property(:legislation_legal_force, value) end |
#legislation_passed_by ⇒ Object
The person or organization that originally passed or made the law: typically parliament (for primary legislation) or government (for secondary legislation). This indicates the "legal author" of the law, as opposed to its physical author.
367 368 369 |
# File 'lib/schema_org/mixins/legislation.rb', line 367 def legislation_passed_by read_property(:legislation_passed_by) end |
#legislation_passed_by=(value) ⇒ Object
The person or organization that originally passed or made the law: typically parliament (for primary legislation) or government (for secondary legislation). This indicates the "legal author" of the law, as opposed to its physical author.
372 373 374 |
# File 'lib/schema_org/mixins/legislation.rb', line 372 def legislation_passed_by=(value) write_property(:legislation_passed_by, value) end |
#legislation_repeals ⇒ Object
Another legislation that this legislation repeals (cancels, abrogates).
377 378 379 |
# File 'lib/schema_org/mixins/legislation.rb', line 377 def legislation_repeals read_property(:legislation_repeals) end |
#legislation_repeals=(value) ⇒ Object
Another legislation that this legislation repeals (cancels, abrogates).
382 383 384 |
# File 'lib/schema_org/mixins/legislation.rb', line 382 def legislation_repeals=(value) write_property(:legislation_repeals, value) end |
#legislation_responsible ⇒ Object
An individual or organization that has some kind of responsibility for the legislation. Typically the ministry who is/was in charge of elaborating the legislation, or the adressee for potential questions about the legislation once it is published.
387 388 389 |
# File 'lib/schema_org/mixins/legislation.rb', line 387 def legislation_responsible read_property(:legislation_responsible) end |
#legislation_responsible=(value) ⇒ Object
An individual or organization that has some kind of responsibility for the legislation. Typically the ministry who is/was in charge of elaborating the legislation, or the adressee for potential questions about the legislation once it is published.
392 393 394 |
# File 'lib/schema_org/mixins/legislation.rb', line 392 def legislation_responsible=(value) write_property(:legislation_responsible, value) end |
#legislation_transposes ⇒ Object
Indicates that this legislation (or part of legislation) fulfills the objectives set by another legislation, by passing appropriate implementation measures. Typically, some legislations of European Union's member states or regions transpose European Directives. This indicates a legally binding link between the 2 legislations.
397 398 399 |
# File 'lib/schema_org/mixins/legislation.rb', line 397 def legislation_transposes read_property(:legislation_transposes) end |
#legislation_transposes=(value) ⇒ Object
Indicates that this legislation (or part of legislation) fulfills the objectives set by another legislation, by passing appropriate implementation measures. Typically, some legislations of European Union's member states or regions transpose European Directives. This indicates a legally binding link between the 2 legislations.
402 403 404 |
# File 'lib/schema_org/mixins/legislation.rb', line 402 def legislation_transposes=(value) write_property(:legislation_transposes, value) end |
#legislation_type ⇒ Object
The type of the legislation. Examples of values are "law", "act", "directive", "decree", "regulation", "statutory instrument", "loi organique", "règlement grand-ducal", etc., depending on the country.
407 408 409 |
# File 'lib/schema_org/mixins/legislation.rb', line 407 def legislation_type read_property(:legislation_type) end |
#legislation_type=(value) ⇒ Object
The type of the legislation. Examples of values are "law", "act", "directive", "decree", "regulation", "statutory instrument", "loi organique", "règlement grand-ducal", etc., depending on the country.
412 413 414 |
# File 'lib/schema_org/mixins/legislation.rb', line 412 def legislation_type=(value) write_property(:legislation_type, value) end |