Module: SchemaOrg::Mixins::LegislationObject
- Includes:
- Legislation, MediaObject
- Included in:
- LegislationObject
- Defined in:
- lib/schema_org/mixins/legislation_object.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#legislation_legal_value ⇒ Object
The legal value of this legislation file.
-
#legislation_legal_value=(value) ⇒ Object
The legal value of this legislation file.
Methods included from MediaObject
#associated_article, #associated_article=, #bitrate, #bitrate=, #content_size, #content_size=, #content_url, #content_url=, #duration, #duration=, #embed_url, #embed_url=, #encodes_creative_work, #encodes_creative_work=, #encoding_format, #encoding_format=, #end_time, #end_time=, #height, #height=, #ineligible_region, #ineligible_region=, #interpreted_as_claim, #interpreted_as_claim=, #player_type, #player_type=, #production_company, #production_company=, #regions_allowed, #regions_allowed=, #requires_subscription, #requires_subscription=, #sha256, #sha256=, #start_time, #start_time=, #upload_date, #upload_date=, #width, #width=
Methods included from CreativeWork
#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Methods included from Legislation
#jurisdiction, #jurisdiction=, #legislation_amends, #legislation_amends=, #legislation_applies, #legislation_applies=, #legislation_changes, #legislation_changes=, #legislation_commences, #legislation_commences=, #legislation_consolidates, #legislation_consolidates=, #legislation_corrects, #legislation_corrects=, #legislation_countersigned_by, #legislation_countersigned_by=, #legislation_date, #legislation_date=, #legislation_date_of_applicability, #legislation_date_of_applicability=, #legislation_date_version, #legislation_date_version=, #legislation_ensures_implementation_of, #legislation_ensures_implementation_of=, #legislation_identifier, #legislation_identifier=, #legislation_jurisdiction, #legislation_jurisdiction=, #legislation_legal_force, #legislation_legal_force=, #legislation_passed_by, #legislation_passed_by=, #legislation_repeals, #legislation_repeals=, #legislation_responsible, #legislation_responsible=, #legislation_transposes, #legislation_transposes=, #legislation_type, #legislation_type=
Class Method Details
.schema_property_definitions ⇒ Object
12 13 14 15 16 17 18 19 20 21 22 23 24 25 |
# File 'lib/schema_org/mixins/legislation_object.rb', line 12 def self.schema_property_definitions { legislation_legal_value: { schema_name: "legislationLegalValue", schema_url: "https://schema.org/legislationLegalValue", comment_lines: ["The legal value of this legislation file. The same legislation can be written in multiple files with different legal values. Typically a digitally signed PDF have a \"stronger\" legal value than the HTML file of the same act."].freeze, ranges: ["LegalValueLevel"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#legislation_legal_value ⇒ Object
The legal value of this legislation file. The same legislation can be written in multiple files with different legal values. Typically a digitally signed PDF have a "stronger" legal value than the HTML file of the same act.
28 29 30 |
# File 'lib/schema_org/mixins/legislation_object.rb', line 28 def legislation_legal_value read_property(:legislation_legal_value) end |
#legislation_legal_value=(value) ⇒ Object
The legal value of this legislation file. The same legislation can be written in multiple files with different legal values. Typically a digitally signed PDF have a "stronger" legal value than the HTML file of the same act.
33 34 35 |
# File 'lib/schema_org/mixins/legislation_object.rb', line 33 def legislation_legal_value=(value) write_property(:legislation_legal_value, value) end |