Module: SchemaOrg::Mixins::LinkRole
Class Method Summary collapse
Instance Method Summary collapse
-
#in_language ⇒ Object
The language of the content or performance or used in an action.
-
#in_language=(value) ⇒ Object
The language of the content or performance or used in an action.
-
#link_relationship ⇒ Object
Indicates the relationship type of a Web link.
-
#link_relationship=(value) ⇒ Object
Indicates the relationship type of a Web link.
Methods included from Role
#end_date, #end_date=, #named_position, #named_position=, #role_name, #role_name=, #start_date, #start_date=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/schema_org/mixins/link_role.rb', line 11 def self.schema_property_definitions { in_language: { schema_name: "inLanguage", schema_url: "https://schema.org/inLanguage", comment_lines: ["The language of the content or performance or used in an action. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[availableLanguage]]."].freeze, ranges: ["Language", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["language"].freeze }.freeze, link_relationship: { schema_name: "linkRelationship", schema_url: "https://schema.org/linkRelationship", comment_lines: ["Indicates the relationship type of a Web link."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#in_language ⇒ Object
The language of the content or performance or used in an action. Please use one of the language codes from the IETF BCP 47 standard. See also [[availableLanguage]].
Supersedes language.
38 39 40 |
# File 'lib/schema_org/mixins/link_role.rb', line 38 def in_language read_property(:in_language) end |
#in_language=(value) ⇒ Object
The language of the content or performance or used in an action. Please use one of the language codes from the IETF BCP 47 standard. See also [[availableLanguage]].
Supersedes language.
44 45 46 |
# File 'lib/schema_org/mixins/link_role.rb', line 44 def in_language=(value) write_property(:in_language, value) end |
#link_relationship ⇒ Object
Indicates the relationship type of a Web link.
49 50 51 |
# File 'lib/schema_org/mixins/link_role.rb', line 49 def link_relationship read_property(:link_relationship) end |
#link_relationship=(value) ⇒ Object
Indicates the relationship type of a Web link.
54 55 56 |
# File 'lib/schema_org/mixins/link_role.rb', line 54 def link_relationship=(value) write_property(:link_relationship, value) end |