Module: SchemaOrg::Mixins::LoanOrCredit
- Includes:
- FinancialProduct
- Included in:
- LoanOrCredit, CreditCard, MortgageLoan
- Defined in:
- lib/schema_org/mixins/loan_or_credit.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#amount ⇒ Object
The amount of money.
-
#amount=(value) ⇒ Object
The amount of money.
-
#currency ⇒ Object
The currency in which the monetary amount is expressed.\n\nUse standard formats: ISO 4217 currency format, e.g.
-
#currency=(value) ⇒ Object
The currency in which the monetary amount is expressed.\n\nUse standard formats: ISO 4217 currency format, e.g.
-
#grace_period ⇒ Object
The period of time after any due date that the borrower has to fulfil its obligations before a default (failure to pay) is deemed to have occurred.
-
#grace_period=(value) ⇒ Object
The period of time after any due date that the borrower has to fulfil its obligations before a default (failure to pay) is deemed to have occurred.
-
#loan_repayment_form ⇒ Object
A form of paying back money previously borrowed from a lender.
-
#loan_repayment_form=(value) ⇒ Object
A form of paying back money previously borrowed from a lender.
-
#loan_term ⇒ Object
The duration of the loan or credit agreement.
-
#loan_term=(value) ⇒ Object
The duration of the loan or credit agreement.
-
#loan_type ⇒ Object
The type of a loan or credit.
-
#loan_type=(value) ⇒ Object
The type of a loan or credit.
-
#recourse_loan ⇒ Object
The only way you get the money back in the event of default is the security.
-
#recourse_loan=(value) ⇒ Object
The only way you get the money back in the event of default is the security.
-
#renegotiable_loan ⇒ Object
Whether the terms for payment of interest can be renegotiated during the life of the loan.
-
#renegotiable_loan=(value) ⇒ Object
Whether the terms for payment of interest can be renegotiated during the life of the loan.
-
#required_collateral ⇒ Object
Assets required to secure loan or credit repayments.
-
#required_collateral=(value) ⇒ Object
Assets required to secure loan or credit repayments.
Methods included from FinancialProduct
#annual_percentage_rate, #annual_percentage_rate=, #fees_and_commissions_specification, #fees_and_commissions_specification=, #interest_rate, #interest_rate=
Methods included from Service
#aggregate_rating, #aggregate_rating=, #area_served, #area_served=, #audience, #audience=, #available_channel, #available_channel=, #award, #award=, #brand, #brand=, #broker, #broker=, #category, #category=, #has_certification, #has_certification=, #has_offer_catalog, #has_offer_catalog=, #hours_available, #hours_available=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #logo, #logo=, #offers, #offers=, #produces, #produces=, #provider, #provider=, #provider_mobility, #provider_mobility=, #review, #review=, #service_area, #service_area=, #service_audience, #service_audience=, #service_output, #service_output=, #service_type, #service_type=, #slogan, #slogan=, #terms_of_service, #terms_of_service=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 11 def self.schema_property_definitions { amount: { schema_name: "amount", schema_url: "https://schema.org/amount", comment_lines: ["The amount of money."].freeze, ranges: ["MonetaryAmount", "Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, currency: { schema_name: "currency", schema_url: "https://schema.org/currency", comment_lines: ["The currency in which the monetary amount is expressed.\\n\\nUse standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. \"USD\"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. \"BTC\"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. \"Ithaca HOUR\"."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, grace_period: { schema_name: "gracePeriod", schema_url: "https://schema.org/gracePeriod", comment_lines: ["The period of time after any due date that the borrower has to fulfil its obligations before a default (failure to pay) is deemed to have occurred."].freeze, ranges: ["Duration"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, loan_repayment_form: { schema_name: "loanRepaymentForm", schema_url: "https://schema.org/loanRepaymentForm", comment_lines: ["A form of paying back money previously borrowed from a lender. Repayment usually takes the form of periodic payments that normally include part principal plus interest in each payment."].freeze, ranges: ["RepaymentSpecification"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, loan_term: { schema_name: "loanTerm", schema_url: "https://schema.org/loanTerm", comment_lines: ["The duration of the loan or credit agreement."].freeze, ranges: ["QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, loan_type: { schema_name: "loanType", schema_url: "https://schema.org/loanType", comment_lines: ["The type of a loan or credit."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, recourse_loan: { schema_name: "recourseLoan", schema_url: "https://schema.org/recourseLoan", comment_lines: ["The only way you get the money back in the event of default is the security. Recourse is where you still have the opportunity to go back to the borrower for the rest of the money."].freeze, ranges: ["Boolean"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, renegotiable_loan: { schema_name: "renegotiableLoan", schema_url: "https://schema.org/renegotiableLoan", comment_lines: ["Whether the terms for payment of interest can be renegotiated during the life of the loan."].freeze, ranges: ["Boolean"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, required_collateral: { schema_name: "requiredCollateral", schema_url: "https://schema.org/requiredCollateral", comment_lines: ["Assets required to secure loan or credit repayments. It may take form of third party pledge, goods, financial instruments (cash, securities, etc.)"].freeze, ranges: ["Text", "Thing"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#amount ⇒ Object
The amount of money.
107 108 109 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 107 def amount read_property(:amount) end |
#amount=(value) ⇒ Object
The amount of money.
112 113 114 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 112 def amount=(value) write_property(:amount, value) end |
#currency ⇒ Object
The currency in which the monetary amount is expressed.\n\nUse standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR".
117 118 119 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 117 def currency read_property(:currency) end |
#currency=(value) ⇒ Object
The currency in which the monetary amount is expressed.\n\nUse standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR".
122 123 124 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 122 def currency=(value) write_property(:currency, value) end |
#grace_period ⇒ Object
The period of time after any due date that the borrower has to fulfil its obligations before a default (failure to pay) is deemed to have occurred.
127 128 129 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 127 def grace_period read_property(:grace_period) end |
#grace_period=(value) ⇒ Object
The period of time after any due date that the borrower has to fulfil its obligations before a default (failure to pay) is deemed to have occurred.
132 133 134 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 132 def grace_period=(value) write_property(:grace_period, value) end |
#loan_repayment_form ⇒ Object
A form of paying back money previously borrowed from a lender. Repayment usually takes the form of periodic payments that normally include part principal plus interest in each payment.
137 138 139 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 137 def loan_repayment_form read_property(:loan_repayment_form) end |
#loan_repayment_form=(value) ⇒ Object
A form of paying back money previously borrowed from a lender. Repayment usually takes the form of periodic payments that normally include part principal plus interest in each payment.
142 143 144 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 142 def loan_repayment_form=(value) write_property(:loan_repayment_form, value) end |
#loan_term ⇒ Object
The duration of the loan or credit agreement.
147 148 149 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 147 def loan_term read_property(:loan_term) end |
#loan_term=(value) ⇒ Object
The duration of the loan or credit agreement.
152 153 154 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 152 def loan_term=(value) write_property(:loan_term, value) end |
#loan_type ⇒ Object
The type of a loan or credit.
157 158 159 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 157 def loan_type read_property(:loan_type) end |
#loan_type=(value) ⇒ Object
The type of a loan or credit.
162 163 164 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 162 def loan_type=(value) write_property(:loan_type, value) end |
#recourse_loan ⇒ Object
The only way you get the money back in the event of default is the security. Recourse is where you still have the opportunity to go back to the borrower for the rest of the money.
167 168 169 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 167 def recourse_loan read_property(:recourse_loan) end |
#recourse_loan=(value) ⇒ Object
The only way you get the money back in the event of default is the security. Recourse is where you still have the opportunity to go back to the borrower for the rest of the money.
172 173 174 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 172 def recourse_loan=(value) write_property(:recourse_loan, value) end |
#renegotiable_loan ⇒ Object
Whether the terms for payment of interest can be renegotiated during the life of the loan.
177 178 179 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 177 def renegotiable_loan read_property(:renegotiable_loan) end |
#renegotiable_loan=(value) ⇒ Object
Whether the terms for payment of interest can be renegotiated during the life of the loan.
182 183 184 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 182 def renegotiable_loan=(value) write_property(:renegotiable_loan, value) end |
#required_collateral ⇒ Object
Assets required to secure loan or credit repayments. It may take form of third party pledge, goods, financial instruments (cash, securities, etc.)
187 188 189 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 187 def required_collateral read_property(:required_collateral) end |
#required_collateral=(value) ⇒ Object
Assets required to secure loan or credit repayments. It may take form of third party pledge, goods, financial instruments (cash, securities, etc.)
192 193 194 |
# File 'lib/schema_org/mixins/loan_or_credit.rb', line 192 def required_collateral=(value) write_property(:required_collateral, value) end |