Module: SchemaOrg::Mixins::LocalBusiness
- Includes:
- Organization, Place
- Included in:
- LocalBusiness, AnimalShelter, ArchiveOrganization, AutomotiveBusiness, ChildCare, Dentist, DryCleaningOrLaundry, EmergencyService, EmploymentAgency, EntertainmentBusiness, FinancialService, FoodEstablishment, GovernmentOffice, HealthAndBeautyBusiness, HomeAndConstructionBusiness, InternetCafe, LegalService, Library, LodgingBusiness, MedicalBusiness, ProfessionalService, RadioStation, RealEstateAgent, RecyclingCenter, SelfStorage, ShoppingCenter, SportsActivityLocation, Store, TelevisionStation, TouristInformationCenter, TravelAgency
- Defined in:
- lib/schema_org/mixins/local_business.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#branch_of ⇒ Object
The larger organization that this local business is a branch of, if any.
-
#branch_of=(value) ⇒ Object
The larger organization that this local business is a branch of, if any.
-
#currencies_accepted ⇒ Object
The currency accepted.\n\nUse standard formats: ISO 4217 currency format, e.g.
-
#currencies_accepted=(value) ⇒ Object
The currency accepted.\n\nUse standard formats: ISO 4217 currency format, e.g.
-
#floor_level ⇒ Object
The floor level for an [[Accommodation]] in a multi-storey building.
-
#floor_level=(value) ⇒ Object
The floor level for an [[Accommodation]] in a multi-storey building.
-
#opening_hours ⇒ Object
The general opening hours for a business.
-
#opening_hours=(value) ⇒ Object
The general opening hours for a business.
-
#payment_accepted ⇒ Object
Cash, Credit Card, Cryptocurrency, Local Exchange Tradings System, etc.
-
#payment_accepted=(value) ⇒ Object
Cash, Credit Card, Cryptocurrency, Local Exchange Tradings System, etc.
-
#price_range ⇒ Object
The price range of the business, for example
$$$. -
#price_range=(value) ⇒ Object
The price range of the business, for example
$$$.
Methods included from Place
#additional_property, #additional_property=, #address, #address=, #aggregate_rating, #aggregate_rating=, #amenity_feature, #amenity_feature=, #branch_code, #branch_code=, #contained_in, #contained_in=, #contained_in_place, #contained_in_place=, #contains_place, #contains_place=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #geo, #geo=, #geo_contains, #geo_contains=, #geo_covered_by, #geo_covered_by=, #geo_covers, #geo_covers=, #geo_crosses, #geo_crosses=, #geo_disjoint, #geo_disjoint=, #geo_equals, #geo_equals=, #geo_intersects, #geo_intersects=, #geo_overlaps, #geo_overlaps=, #geo_touches, #geo_touches=, #geo_within, #geo_within=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_drive_through_service, #has_drive_through_service=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_map, #has_map=, #is_accessible_for_free, #is_accessible_for_free=, #isic_v4, #isic_v4=, #keywords, #keywords=, #latitude, #latitude=, #logo, #logo=, #longitude, #longitude=, #map, #map=, #maps, #maps=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #opening_hours_specification, #opening_hours_specification=, #photo, #photo=, #photos, #photos=, #public_access, #public_access=, #review, #review=, #reviews, #reviews=, #slogan, #slogan=, #smoking_allowed, #smoking_allowed=, #special_opening_hours_specification, #special_opening_hours_specification=, #telephone, #telephone=, #tour_booking_page, #tour_booking_page=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Methods included from Organization
#accepted_payment_method, #accepted_payment_method=, #actionable_feedback_policy, #actionable_feedback_policy=, #address, #address=, #agent_interaction_statistic, #agent_interaction_statistic=, #aggregate_rating, #aggregate_rating=, #alumni, #alumni=, #area_served, #area_served=, #award, #award=, #awards, #awards=, #brand, #brand=, #company_registration, #company_registration=, #contact_point, #contact_point=, #contact_points, #contact_points=, #corrections_policy, #corrections_policy=, #department, #department=, #dissolution_date, #dissolution_date=, #diversity_policy, #diversity_policy=, #diversity_staffing_report, #diversity_staffing_report=, #duns, #duns=, #email, #email=, #employee, #employee=, #employees, #employees=, #ethics_policy, #ethics_policy=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #founder, #founder=, #founders, #founders=, #founding_date, #founding_date=, #founding_location, #founding_location=, #funder, #funder=, #funding, #funding=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_credential, #has_credential=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_member_program, #has_member_program=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_offer_catalog, #has_offer_catalog=, #has_pos, #has_pos=, #has_product_return_policy, #has_product_return_policy=, #has_shipping_service, #has_shipping_service=, #interaction_statistic, #interaction_statistic=, #isic_v4, #isic_v4=, #iso6523_code, #iso6523_code=, #keywords, #keywords=, #knows_about, #knows_about=, #knows_language, #knows_language=, #legal_address, #legal_address=, #legal_name, #legal_name=, #legal_representative, #legal_representative=, #lei_code, #lei_code=, #location, #location=, #logo, #logo=, #makes_offer, #makes_offer=, #member, #member=, #member_of, #member_of=, #members, #members=, #naics, #naics=, #nonprofit_status, #nonprofit_status=, #number_of_employees, #number_of_employees=, #ownership_funding_info, #ownership_funding_info=, #owns, #owns=, #parent_organization, #parent_organization=, #publishing_principles, #publishing_principles=, #review, #review=, #reviews, #reviews=, #seeks, #seeks=, #service_area, #service_area=, #skills, #skills=, #slogan, #slogan=, #sponsor, #sponsor=, #sub_organization, #sub_organization=, #tax_id, #tax_id=, #telephone, #telephone=, #unnamed_sources_policy, #unnamed_sources_policy=, #vat_id, #vat_id=
Class Method Details
.schema_property_definitions ⇒ Object
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/schema_org/mixins/local_business.rb', line 12 def self.schema_property_definitions { branch_of: { schema_name: "branchOf", schema_url: "https://schema.org/branchOf", comment_lines: ["The larger organization that this local business is a branch of, if any. Not to be confused with (anatomical) [[branch]]."].freeze, ranges: ["Organization"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "parentOrganization", supersedes: nil }.freeze, currencies_accepted: { schema_name: "currenciesAccepted", schema_url: "https://schema.org/currenciesAccepted", comment_lines: ["The currency accepted.\\n\\nUse standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. \"USD\"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. \"BTC\"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. \"Ithaca HOUR\"."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, floor_level: { schema_name: "floorLevel", schema_url: "https://schema.org/floorLevel", comment_lines: ["The floor level for an [[Accommodation]] in a multi-storey building. Since counting", " systems [vary internationally](https://en.wikipedia.org/wiki/Storey#Consecutive_number_floor_designations), the local system should be used where possible."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, opening_hours: { schema_name: "openingHours", schema_url: "https://schema.org/openingHours", comment_lines: ["The general opening hours for a business. Opening hours can be specified as a weekly time range, starting with days, then times per day. Multiple days can be listed with commas ',' separating each day. Day or time ranges are specified using a hyphen '-'.\\n\\n* Days are specified using the following two-letter combinations: ```Mo```, ```Tu```, ```We```, ```Th```, ```Fr```, ```Sa```, ```Su```.\\n* Times are specified using 24:00 format. For example, 3pm is specified as ```15:00```, 10am as ```10:00```. \\n* Here is an example: <code><time itemprop=\"openingHours\" datetime="Tu,Th 16:00-20:00">Tuesdays and Thursdays 4-8pm</time></code>.\\n* If a business is open 7 days a week, then it can be specified as <code><time itemprop="openingHours" datetime="Mo-Su">Monday through Sunday, all day</time></code>."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, payment_accepted: { schema_name: "paymentAccepted", schema_url: "https://schema.org/paymentAccepted", comment_lines: ["Cash, Credit Card, Cryptocurrency, Local Exchange Tradings System, etc."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, price_range: { schema_name: "priceRange", schema_url: "https://schema.org/priceRange", comment_lines: ["The price range of the business, for example ```$$$```."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#branch_of ⇒ Object
The larger organization that this local business is a branch of, if any. Not to be confused with (anatomical) [[branch]].
Superseded by parentOrganization.
79 80 81 |
# File 'lib/schema_org/mixins/local_business.rb', line 79 def branch_of read_property(:branch_of) end |
#branch_of=(value) ⇒ Object
The larger organization that this local business is a branch of, if any. Not to be confused with (anatomical) [[branch]].
Superseded by parentOrganization.
85 86 87 |
# File 'lib/schema_org/mixins/local_business.rb', line 85 def branch_of=(value) write_property(:branch_of, value) end |
#currencies_accepted ⇒ Object
The currency accepted.\n\nUse standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR".
90 91 92 |
# File 'lib/schema_org/mixins/local_business.rb', line 90 def currencies_accepted read_property(:currencies_accepted) end |
#currencies_accepted=(value) ⇒ Object
The currency accepted.\n\nUse standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR".
95 96 97 |
# File 'lib/schema_org/mixins/local_business.rb', line 95 def currencies_accepted=(value) write_property(:currencies_accepted, value) end |
#floor_level ⇒ Object
The floor level for an [[Accommodation]] in a multi-storey building. Since counting systems vary internationally, the local system should be used where possible.
101 102 103 |
# File 'lib/schema_org/mixins/local_business.rb', line 101 def floor_level read_property(:floor_level) end |
#floor_level=(value) ⇒ Object
The floor level for an [[Accommodation]] in a multi-storey building. Since counting systems vary internationally, the local system should be used where possible.
107 108 109 |
# File 'lib/schema_org/mixins/local_business.rb', line 107 def floor_level=(value) write_property(:floor_level, value) end |
#opening_hours ⇒ Object
The general opening hours for a business. Opening hours can be specified as a weekly time range, starting with days, then times per day. Multiple days can be listed with commas ',' separating each day. Day or time ranges are specified using a hyphen '-'.\n\n* Days are specified using the following two-letter combinations: Mo, Tu, We, Th, Fr, Sa, Su.\n* Times are specified using 24:00 format. For example, 3pm is specified as 15:00, 10am as 10:00. \n* Here is an example: <time itemprop="openingHours" datetime="Tu,Th 16:00-20:00">Tuesdays and Thursdays 4-8pm</time>.\n* If a business is open 7 days a week, then it can be specified as <time itemprop="openingHours" datetime="Mo-Su">Monday through Sunday, all day</time>.
112 113 114 |
# File 'lib/schema_org/mixins/local_business.rb', line 112 def opening_hours read_property(:opening_hours) end |
#opening_hours=(value) ⇒ Object
The general opening hours for a business. Opening hours can be specified as a weekly time range, starting with days, then times per day. Multiple days can be listed with commas ',' separating each day. Day or time ranges are specified using a hyphen '-'.\n\n* Days are specified using the following two-letter combinations: Mo, Tu, We, Th, Fr, Sa, Su.\n* Times are specified using 24:00 format. For example, 3pm is specified as 15:00, 10am as 10:00. \n* Here is an example: <time itemprop="openingHours" datetime="Tu,Th 16:00-20:00">Tuesdays and Thursdays 4-8pm</time>.\n* If a business is open 7 days a week, then it can be specified as <time itemprop="openingHours" datetime="Mo-Su">Monday through Sunday, all day</time>.
117 118 119 |
# File 'lib/schema_org/mixins/local_business.rb', line 117 def opening_hours=(value) write_property(:opening_hours, value) end |
#payment_accepted ⇒ Object
Cash, Credit Card, Cryptocurrency, Local Exchange Tradings System, etc.
122 123 124 |
# File 'lib/schema_org/mixins/local_business.rb', line 122 def payment_accepted read_property(:payment_accepted) end |
#payment_accepted=(value) ⇒ Object
Cash, Credit Card, Cryptocurrency, Local Exchange Tradings System, etc.
127 128 129 |
# File 'lib/schema_org/mixins/local_business.rb', line 127 def payment_accepted=(value) write_property(:payment_accepted, value) end |
#price_range ⇒ Object
The price range of the business, for example $$$.
132 133 134 |
# File 'lib/schema_org/mixins/local_business.rb', line 132 def price_range read_property(:price_range) end |
#price_range=(value) ⇒ Object
The price range of the business, for example $$$.
137 138 139 |
# File 'lib/schema_org/mixins/local_business.rb', line 137 def price_range=(value) write_property(:price_range, value) end |