Module: SchemaOrg::Mixins::MediaObject
- Includes:
- CreativeWork
- Included in:
- SchemaOrg::MediaObject, AmpStory, AudioObject, DataDownload, ImageObject, LegislationObject, MusicVideoObject, TextObject, ThreeDModel, VideoObject
- Defined in:
- lib/schema_org/mixins/media_object.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#associated_article ⇒ Object
A NewsArticle associated with the Media Object.
-
#associated_article=(value) ⇒ Object
A NewsArticle associated with the Media Object.
-
#bitrate ⇒ Object
The bitrate of the media object.
-
#bitrate=(value) ⇒ Object
The bitrate of the media object.
-
#content_size ⇒ Object
File size in (mega/kilo)bytes.
-
#content_size=(value) ⇒ Object
File size in (mega/kilo)bytes.
-
#content_url ⇒ Object
Actual bytes of the media object, for example the image file or video file.
-
#content_url=(value) ⇒ Object
Actual bytes of the media object, for example the image file or video file.
-
#duration ⇒ Object
The duration of the item (movie, audio recording, event, etc.) in ISO 8601 duration format.
-
#duration=(value) ⇒ Object
The duration of the item (movie, audio recording, event, etc.) in ISO 8601 duration format.
-
#embed_url ⇒ Object
A URL pointing to a player for a specific video.
-
#embed_url=(value) ⇒ Object
A URL pointing to a player for a specific video.
-
#encodes_creative_work ⇒ Object
The CreativeWork encoded by this media object.
-
#encodes_creative_work=(value) ⇒ Object
The CreativeWork encoded by this media object.
-
#encoding_format ⇒ Object
Media type typically expressed using a MIME format (see IANA site and MDN reference), e.g.
-
#encoding_format=(value) ⇒ Object
Media type typically expressed using a MIME format (see IANA site and MDN reference), e.g.
-
#end_time ⇒ Object
The endTime of something.
-
#end_time=(value) ⇒ Object
The endTime of something.
-
#height ⇒ Object
The height of the item.
-
#height=(value) ⇒ Object
The height of the item.
-
#ineligible_region ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g.
-
#ineligible_region=(value) ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g.
-
#interpreted_as_claim ⇒ Object
Used to indicate a specific claim contained, implied, translated or refined from the content of a [[MediaObject]] or other [[CreativeWork]].
-
#interpreted_as_claim=(value) ⇒ Object
Used to indicate a specific claim contained, implied, translated or refined from the content of a [[MediaObject]] or other [[CreativeWork]].
-
#player_type ⇒ Object
Player type required—for example, Flash or Silverlight.
-
#player_type=(value) ⇒ Object
Player type required—for example, Flash or Silverlight.
-
#production_company ⇒ Object
The production company or studio responsible for the item, e.g.
-
#production_company=(value) ⇒ Object
The production company or studio responsible for the item, e.g.
-
#regions_allowed ⇒ Object
The regions where the media is allowed.
-
#regions_allowed=(value) ⇒ Object
The regions where the media is allowed.
-
#requires_subscription ⇒ Object
Indicates if use of the media require a subscription (either paid or free).
-
#requires_subscription=(value) ⇒ Object
Indicates if use of the media require a subscription (either paid or free).
-
#sha256 ⇒ Object
The SHA-2 SHA256 hash of the content of the item.
-
#sha256=(value) ⇒ Object
The SHA-2 SHA256 hash of the content of the item.
-
#start_time ⇒ Object
The startTime of something.
-
#start_time=(value) ⇒ Object
The startTime of something.
-
#upload_date ⇒ Object
Date (including time if available) when this media object was uploaded to this site.
-
#upload_date=(value) ⇒ Object
Date (including time if available) when this media object was uploaded to this site.
-
#width ⇒ Object
The width of the item.
-
#width=(value) ⇒ Object
The width of the item.
Methods included from CreativeWork
#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/schema_org/mixins/media_object.rb', line 11 def self.schema_property_definitions { associated_article: { schema_name: "associatedArticle", schema_url: "https://schema.org/associatedArticle", comment_lines: ["A NewsArticle associated with the Media Object."].freeze, ranges: ["NewsArticle"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, bitrate: { schema_name: "bitrate", schema_url: "https://schema.org/bitrate", comment_lines: ["The bitrate of the media object."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, content_size: { schema_name: "contentSize", schema_url: "https://schema.org/contentSize", comment_lines: ["File size in (mega/kilo)bytes."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, content_url: { schema_name: "contentUrl", schema_url: "https://schema.org/contentUrl", comment_lines: ["Actual bytes of the media object, for example the image file or video file."].freeze, ranges: ["URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, duration: { schema_name: "duration", schema_url: "https://schema.org/duration", comment_lines: ["The duration of the item (movie, audio recording, event, etc.) in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601)."].freeze, ranges: ["Duration", "QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, embed_url: { schema_name: "embedUrl", schema_url: "https://schema.org/embedUrl", comment_lines: ["A URL pointing to a player for a specific video. In general, this is the information in the ```src``` element of an ```embed``` tag and should not be the same as the content of the ```loc``` tag."].freeze, ranges: ["URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, encodes_creative_work: { schema_name: "encodesCreativeWork", schema_url: "https://schema.org/encodesCreativeWork", comment_lines: ["The CreativeWork encoded by this media object."].freeze, ranges: ["CreativeWork"].freeze, external_ranges: [].freeze, inverse_of: "encoding", superseded_by: nil, supersedes: nil }.freeze, encoding_format: { schema_name: "encodingFormat", schema_url: "https://schema.org/encodingFormat", comment_lines: ["Media type typically expressed using a MIME format (see [IANA site](http://www.iana.org/assignments/media-types/media-types.xhtml) and [MDN reference](https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/MIME_types)), e.g. application/zip for a SoftwareApplication binary, audio/mpeg for .mp3 etc.", "", "In cases where a [[CreativeWork]] has several media type representations, [[encoding]] can be used to indicate each [[MediaObject]] alongside particular [[encodingFormat]] information.", "", "Unregistered or niche encoding and file formats can be indicated instead via the most appropriate URL, e.g. defining Web page or a Wikipedia/Wikidata entry."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["fileFormat"].freeze }.freeze, end_time: { schema_name: "endTime", schema_url: "https://schema.org/endTime", comment_lines: ["The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to *December*. For media, including audio and video, it's the time offset of the end of a clip within a larger file.\\n\\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions."].freeze, ranges: ["DateTime", "Time"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, height: { schema_name: "height", schema_url: "https://schema.org/height", comment_lines: ["The height of the item."].freeze, ranges: ["Distance", "QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, ineligible_region: { schema_name: "ineligibleRegion", schema_url: "https://schema.org/ineligibleRegion", comment_lines: ["The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed.\\n\\nSee also [[eligibleRegion]]."].freeze, ranges: ["GeoShape", "Place", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, interpreted_as_claim: { schema_name: "interpretedAsClaim", schema_url: "https://schema.org/interpretedAsClaim", comment_lines: ["Used to indicate a specific claim contained, implied, translated or refined from the content of a [[MediaObject]] or other [[CreativeWork]]. The interpreting party can be indicated using [[claimInterpreter]]."].freeze, ranges: ["Claim"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, player_type: { schema_name: "playerType", schema_url: "https://schema.org/playerType", comment_lines: ["Player type required—for example, Flash or Silverlight."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, production_company: { schema_name: "productionCompany", schema_url: "https://schema.org/productionCompany", comment_lines: ["The production company or studio responsible for the item, e.g. series, video game, episode etc."].freeze, ranges: ["Organization"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, regions_allowed: { schema_name: "regionsAllowed", schema_url: "https://schema.org/regionsAllowed", comment_lines: ["The regions where the media is allowed. If not specified, then it's assumed to be allowed everywhere. Specify the countries in [ISO 3166 format](http://en.wikipedia.org/wiki/ISO_3166)."].freeze, ranges: ["Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, requires_subscription: { schema_name: "requiresSubscription", schema_url: "https://schema.org/requiresSubscription", comment_lines: ["Indicates if use of the media require a subscription (either paid or free). Allowed values are ```true``` or ```false``` (note that an earlier version had 'yes', 'no')."].freeze, ranges: ["Boolean", "MediaSubscription"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, sha256: { schema_name: "sha256", schema_url: "https://schema.org/sha256", comment_lines: ["The [SHA-2](https://en.wikipedia.org/wiki/SHA-2) SHA256 hash of the content of the item. For example, a zero-length input has value 'e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855'."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, start_time: { schema_name: "startTime", schema_url: "https://schema.org/startTime", comment_lines: ["The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from *January* to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file.\\n\\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions."].freeze, ranges: ["DateTime", "Time"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, upload_date: { schema_name: "uploadDate", schema_url: "https://schema.org/uploadDate", comment_lines: ["Date (including time if available) when this media object was uploaded to this site."].freeze, ranges: ["Date", "DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, width: { schema_name: "width", schema_url: "https://schema.org/width", comment_lines: ["The width of the item."].freeze, ranges: ["Distance", "QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#associated_article ⇒ Object
A NewsArticle associated with the Media Object.
217 218 219 |
# File 'lib/schema_org/mixins/media_object.rb', line 217 def associated_article read_property(:associated_article) end |
#associated_article=(value) ⇒ Object
A NewsArticle associated with the Media Object.
222 223 224 |
# File 'lib/schema_org/mixins/media_object.rb', line 222 def associated_article=(value) write_property(:associated_article, value) end |
#bitrate ⇒ Object
The bitrate of the media object.
227 228 229 |
# File 'lib/schema_org/mixins/media_object.rb', line 227 def bitrate read_property(:bitrate) end |
#bitrate=(value) ⇒ Object
The bitrate of the media object.
232 233 234 |
# File 'lib/schema_org/mixins/media_object.rb', line 232 def bitrate=(value) write_property(:bitrate, value) end |
#content_size ⇒ Object
File size in (mega/kilo)bytes.
237 238 239 |
# File 'lib/schema_org/mixins/media_object.rb', line 237 def content_size read_property(:content_size) end |
#content_size=(value) ⇒ Object
File size in (mega/kilo)bytes.
242 243 244 |
# File 'lib/schema_org/mixins/media_object.rb', line 242 def content_size=(value) write_property(:content_size, value) end |
#content_url ⇒ Object
Actual bytes of the media object, for example the image file or video file.
247 248 249 |
# File 'lib/schema_org/mixins/media_object.rb', line 247 def content_url read_property(:content_url) end |
#content_url=(value) ⇒ Object
Actual bytes of the media object, for example the image file or video file.
252 253 254 |
# File 'lib/schema_org/mixins/media_object.rb', line 252 def content_url=(value) write_property(:content_url, value) end |
#duration ⇒ Object
The duration of the item (movie, audio recording, event, etc.) in ISO 8601 duration format.
257 258 259 |
# File 'lib/schema_org/mixins/media_object.rb', line 257 def duration read_property(:duration) end |
#duration=(value) ⇒ Object
The duration of the item (movie, audio recording, event, etc.) in ISO 8601 duration format.
262 263 264 |
# File 'lib/schema_org/mixins/media_object.rb', line 262 def duration=(value) write_property(:duration, value) end |
#embed_url ⇒ Object
A URL pointing to a player for a specific video. In general, this is the information in the src element of an embed tag and should not be the same as the content of the loc tag.
267 268 269 |
# File 'lib/schema_org/mixins/media_object.rb', line 267 def read_property(:embed_url) end |
#embed_url=(value) ⇒ Object
A URL pointing to a player for a specific video. In general, this is the information in the src element of an embed tag and should not be the same as the content of the loc tag.
272 273 274 |
# File 'lib/schema_org/mixins/media_object.rb', line 272 def (value) write_property(:embed_url, value) end |
#encodes_creative_work ⇒ Object
The CreativeWork encoded by this media object.
Inverse-property: encoding.
278 279 280 |
# File 'lib/schema_org/mixins/media_object.rb', line 278 def encodes_creative_work read_property(:encodes_creative_work) end |
#encodes_creative_work=(value) ⇒ Object
The CreativeWork encoded by this media object.
Inverse-property: encoding.
284 285 286 |
# File 'lib/schema_org/mixins/media_object.rb', line 284 def encodes_creative_work=(value) write_property(:encodes_creative_work, value) end |
#encoding_format ⇒ Object
Media type typically expressed using a MIME format (see IANA site and MDN reference), e.g. application/zip for a SoftwareApplication binary, audio/mpeg for .mp3 etc.
In cases where a [[CreativeWork]] has several media type representations, [[encoding]] can be used to indicate each [[MediaObject]] alongside particular [[encodingFormat]] information.
Unregistered or niche encoding and file formats can be indicated instead via the most appropriate URL, e.g. defining Web page or a Wikipedia/Wikidata entry.
Supersedes fileFormat.
294 295 296 |
# File 'lib/schema_org/mixins/media_object.rb', line 294 def encoding_format read_property(:encoding_format) end |
#encoding_format=(value) ⇒ Object
Media type typically expressed using a MIME format (see IANA site and MDN reference), e.g. application/zip for a SoftwareApplication binary, audio/mpeg for .mp3 etc.
In cases where a [[CreativeWork]] has several media type representations, [[encoding]] can be used to indicate each [[MediaObject]] alongside particular [[encodingFormat]] information.
Unregistered or niche encoding and file formats can be indicated instead via the most appropriate URL, e.g. defining Web page or a Wikipedia/Wikidata entry.
Supersedes fileFormat.
304 305 306 |
# File 'lib/schema_org/mixins/media_object.rb', line 304 def encoding_format=(value) write_property(:encoding_format, value) end |
#end_time ⇒ Object
The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the end of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.
309 310 311 |
# File 'lib/schema_org/mixins/media_object.rb', line 309 def end_time read_property(:end_time) end |
#end_time=(value) ⇒ Object
The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the end of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.
314 315 316 |
# File 'lib/schema_org/mixins/media_object.rb', line 314 def end_time=(value) write_property(:end_time, value) end |
#height ⇒ Object
The height of the item.
319 320 321 |
# File 'lib/schema_org/mixins/media_object.rb', line 319 def height read_property(:height) end |
#height=(value) ⇒ Object
The height of the item.
324 325 326 |
# File 'lib/schema_org/mixins/media_object.rb', line 324 def height=(value) write_property(:height, value) end |
#ineligible_region ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed.\n\nSee also [[eligibleRegion]].
329 330 331 |
# File 'lib/schema_org/mixins/media_object.rb', line 329 def ineligible_region read_property(:ineligible_region) end |
#ineligible_region=(value) ⇒ Object
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed.\n\nSee also [[eligibleRegion]].
334 335 336 |
# File 'lib/schema_org/mixins/media_object.rb', line 334 def ineligible_region=(value) write_property(:ineligible_region, value) end |
#interpreted_as_claim ⇒ Object
Used to indicate a specific claim contained, implied, translated or refined from the content of a [[MediaObject]] or other [[CreativeWork]]. The interpreting party can be indicated using [[claimInterpreter]].
339 340 341 |
# File 'lib/schema_org/mixins/media_object.rb', line 339 def interpreted_as_claim read_property(:interpreted_as_claim) end |
#interpreted_as_claim=(value) ⇒ Object
Used to indicate a specific claim contained, implied, translated or refined from the content of a [[MediaObject]] or other [[CreativeWork]]. The interpreting party can be indicated using [[claimInterpreter]].
344 345 346 |
# File 'lib/schema_org/mixins/media_object.rb', line 344 def interpreted_as_claim=(value) write_property(:interpreted_as_claim, value) end |
#player_type ⇒ Object
Player type required—for example, Flash or Silverlight.
349 350 351 |
# File 'lib/schema_org/mixins/media_object.rb', line 349 def player_type read_property(:player_type) end |
#player_type=(value) ⇒ Object
Player type required—for example, Flash or Silverlight.
354 355 356 |
# File 'lib/schema_org/mixins/media_object.rb', line 354 def player_type=(value) write_property(:player_type, value) end |
#production_company ⇒ Object
The production company or studio responsible for the item, e.g. series, video game, episode etc.
359 360 361 |
# File 'lib/schema_org/mixins/media_object.rb', line 359 def production_company read_property(:production_company) end |
#production_company=(value) ⇒ Object
The production company or studio responsible for the item, e.g. series, video game, episode etc.
364 365 366 |
# File 'lib/schema_org/mixins/media_object.rb', line 364 def production_company=(value) write_property(:production_company, value) end |
#regions_allowed ⇒ Object
The regions where the media is allowed. If not specified, then it's assumed to be allowed everywhere. Specify the countries in ISO 3166 format.
369 370 371 |
# File 'lib/schema_org/mixins/media_object.rb', line 369 def regions_allowed read_property(:regions_allowed) end |
#regions_allowed=(value) ⇒ Object
The regions where the media is allowed. If not specified, then it's assumed to be allowed everywhere. Specify the countries in ISO 3166 format.
374 375 376 |
# File 'lib/schema_org/mixins/media_object.rb', line 374 def regions_allowed=(value) write_property(:regions_allowed, value) end |
#requires_subscription ⇒ Object
Indicates if use of the media require a subscription (either paid or free). Allowed values are true or false (note that an earlier version had 'yes', 'no').
379 380 381 |
# File 'lib/schema_org/mixins/media_object.rb', line 379 def requires_subscription read_property(:requires_subscription) end |
#requires_subscription=(value) ⇒ Object
Indicates if use of the media require a subscription (either paid or free). Allowed values are true or false (note that an earlier version had 'yes', 'no').
384 385 386 |
# File 'lib/schema_org/mixins/media_object.rb', line 384 def requires_subscription=(value) write_property(:requires_subscription, value) end |
#sha256 ⇒ Object
The SHA-2 SHA256 hash of the content of the item. For example, a zero-length input has value 'e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855'.
389 390 391 |
# File 'lib/schema_org/mixins/media_object.rb', line 389 def sha256 read_property(:sha256) end |
#sha256=(value) ⇒ Object
The SHA-2 SHA256 hash of the content of the item. For example, a zero-length input has value 'e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855'.
394 395 396 |
# File 'lib/schema_org/mixins/media_object.rb', line 394 def sha256=(value) write_property(:sha256, value) end |
#start_time ⇒ Object
The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.
399 400 401 |
# File 'lib/schema_org/mixins/media_object.rb', line 399 def start_time read_property(:start_time) end |
#start_time=(value) ⇒ Object
The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.
404 405 406 |
# File 'lib/schema_org/mixins/media_object.rb', line 404 def start_time=(value) write_property(:start_time, value) end |
#upload_date ⇒ Object
Date (including time if available) when this media object was uploaded to this site.
409 410 411 |
# File 'lib/schema_org/mixins/media_object.rb', line 409 def upload_date read_property(:upload_date) end |
#upload_date=(value) ⇒ Object
Date (including time if available) when this media object was uploaded to this site.
414 415 416 |
# File 'lib/schema_org/mixins/media_object.rb', line 414 def upload_date=(value) write_property(:upload_date, value) end |
#width ⇒ Object
The width of the item.
419 420 421 |
# File 'lib/schema_org/mixins/media_object.rb', line 419 def width read_property(:width) end |
#width=(value) ⇒ Object
The width of the item.
424 425 426 |
# File 'lib/schema_org/mixins/media_object.rb', line 424 def width=(value) write_property(:width, value) end |