Module: SchemaOrg::Mixins::MedicalDevice
- Includes:
- MedicalEntity
- Included in:
- SchemaOrg::MedicalDevice
- Defined in:
- lib/schema_org/mixins/medical_device.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#adverse_outcome ⇒ Object
A possible complication and/or side effect of this therapy.
-
#adverse_outcome=(value) ⇒ Object
A possible complication and/or side effect of this therapy.
-
#contraindication ⇒ Object
A contraindication for this therapy.
-
#contraindication=(value) ⇒ Object
A contraindication for this therapy.
-
#post_op ⇒ Object
A description of the postoperative procedures, care, and/or followups for this device.
-
#post_op=(value) ⇒ Object
A description of the postoperative procedures, care, and/or followups for this device.
-
#pre_op ⇒ Object
A description of the workup, testing, and other preparations required before implanting this device.
-
#pre_op=(value) ⇒ Object
A description of the workup, testing, and other preparations required before implanting this device.
-
#procedure ⇒ Object
A description of the procedure involved in setting up, using, and/or installing the device.
-
#procedure=(value) ⇒ Object
A description of the procedure involved in setting up, using, and/or installing the device.
-
#serious_adverse_outcome ⇒ Object
A possible serious complication and/or serious side effect of this therapy.
-
#serious_adverse_outcome=(value) ⇒ Object
A possible serious complication and/or serious side effect of this therapy.
Methods included from MedicalEntity
#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/schema_org/mixins/medical_device.rb', line 11 def self.schema_property_definitions { adverse_outcome: { schema_name: "adverseOutcome", schema_url: "https://schema.org/adverseOutcome", comment_lines: ["A possible complication and/or side effect of this therapy. If it is known that an adverse outcome is serious (resulting in death, disability, or permanent damage; requiring hospitalization; or otherwise life-threatening or requiring immediate medical attention), tag it as a seriousAdverseOutcome instead."].freeze, ranges: ["MedicalEntity"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, contraindication: { schema_name: "contraindication", schema_url: "https://schema.org/contraindication", comment_lines: ["A contraindication for this therapy."].freeze, ranges: ["MedicalContraindication", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, post_op: { schema_name: "postOp", schema_url: "https://schema.org/postOp", comment_lines: ["A description of the postoperative procedures, care, and/or followups for this device."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, pre_op: { schema_name: "preOp", schema_url: "https://schema.org/preOp", comment_lines: ["A description of the workup, testing, and other preparations required before implanting this device."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, procedure: { schema_name: "procedure", schema_url: "https://schema.org/procedure", comment_lines: ["A description of the procedure involved in setting up, using, and/or installing the device."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, serious_adverse_outcome: { schema_name: "seriousAdverseOutcome", schema_url: "https://schema.org/seriousAdverseOutcome", comment_lines: ["A possible serious complication and/or serious side effect of this therapy. Serious adverse outcomes include those that are life-threatening; result in death, disability, or permanent damage; require hospitalization or prolong existing hospitalization; cause congenital anomalies or birth defects; or jeopardize the patient and may require medical or surgical intervention to prevent one of the outcomes in this definition."].freeze, ranges: ["MedicalEntity"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#adverse_outcome ⇒ Object
A possible complication and/or side effect of this therapy. If it is known that an adverse outcome is serious (resulting in death, disability, or permanent damage; requiring hospitalization; or otherwise life-threatening or requiring immediate medical attention), tag it as a seriousAdverseOutcome instead.
77 78 79 |
# File 'lib/schema_org/mixins/medical_device.rb', line 77 def adverse_outcome read_property(:adverse_outcome) end |
#adverse_outcome=(value) ⇒ Object
A possible complication and/or side effect of this therapy. If it is known that an adverse outcome is serious (resulting in death, disability, or permanent damage; requiring hospitalization; or otherwise life-threatening or requiring immediate medical attention), tag it as a seriousAdverseOutcome instead.
82 83 84 |
# File 'lib/schema_org/mixins/medical_device.rb', line 82 def adverse_outcome=(value) write_property(:adverse_outcome, value) end |
#contraindication ⇒ Object
A contraindication for this therapy.
87 88 89 |
# File 'lib/schema_org/mixins/medical_device.rb', line 87 def contraindication read_property(:contraindication) end |
#contraindication=(value) ⇒ Object
A contraindication for this therapy.
92 93 94 |
# File 'lib/schema_org/mixins/medical_device.rb', line 92 def contraindication=(value) write_property(:contraindication, value) end |
#post_op ⇒ Object
A description of the postoperative procedures, care, and/or followups for this device.
97 98 99 |
# File 'lib/schema_org/mixins/medical_device.rb', line 97 def post_op read_property(:post_op) end |
#post_op=(value) ⇒ Object
A description of the postoperative procedures, care, and/or followups for this device.
102 103 104 |
# File 'lib/schema_org/mixins/medical_device.rb', line 102 def post_op=(value) write_property(:post_op, value) end |
#pre_op ⇒ Object
A description of the workup, testing, and other preparations required before implanting this device.
107 108 109 |
# File 'lib/schema_org/mixins/medical_device.rb', line 107 def pre_op read_property(:pre_op) end |
#pre_op=(value) ⇒ Object
A description of the workup, testing, and other preparations required before implanting this device.
112 113 114 |
# File 'lib/schema_org/mixins/medical_device.rb', line 112 def pre_op=(value) write_property(:pre_op, value) end |
#procedure ⇒ Object
A description of the procedure involved in setting up, using, and/or installing the device.
117 118 119 |
# File 'lib/schema_org/mixins/medical_device.rb', line 117 def procedure read_property(:procedure) end |
#procedure=(value) ⇒ Object
A description of the procedure involved in setting up, using, and/or installing the device.
122 123 124 |
# File 'lib/schema_org/mixins/medical_device.rb', line 122 def procedure=(value) write_property(:procedure, value) end |
#serious_adverse_outcome ⇒ Object
A possible serious complication and/or serious side effect of this therapy. Serious adverse outcomes include those that are life-threatening; result in death, disability, or permanent damage; require hospitalization or prolong existing hospitalization; cause congenital anomalies or birth defects; or jeopardize the patient and may require medical or surgical intervention to prevent one of the outcomes in this definition.
127 128 129 |
# File 'lib/schema_org/mixins/medical_device.rb', line 127 def serious_adverse_outcome read_property(:serious_adverse_outcome) end |
#serious_adverse_outcome=(value) ⇒ Object
A possible serious complication and/or serious side effect of this therapy. Serious adverse outcomes include those that are life-threatening; result in death, disability, or permanent damage; require hospitalization or prolong existing hospitalization; cause congenital anomalies or birth defects; or jeopardize the patient and may require medical or surgical intervention to prevent one of the outcomes in this definition.
132 133 134 |
# File 'lib/schema_org/mixins/medical_device.rb', line 132 def serious_adverse_outcome=(value) write_property(:serious_adverse_outcome, value) end |