Module: SchemaOrg::Mixins::MedicalEntity
- Includes:
- Thing
- Included in:
- SchemaOrg::MedicalEntity, AnatomicalStructure, AnatomicalSystem, DrugClass, DrugCost, LifestyleModification, MedicalCause, MedicalCondition, MedicalContraindication, MedicalDevice, MedicalGuideline, MedicalIndication, MedicalIntangible, MedicalProcedure, MedicalRiskEstimator, MedicalRiskFactor, MedicalStudy, MedicalTest, Substance, SuperficialAnatomy
- Defined in:
- lib/schema_org/mixins/medical_entity.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#code ⇒ Object
A medical code for the entity, taken from a controlled vocabulary or ontology such as ICD-9, DiseasesDB, MeSH, SNOMED-CT, RxNorm, etc.
-
#code=(value) ⇒ Object
A medical code for the entity, taken from a controlled vocabulary or ontology such as ICD-9, DiseasesDB, MeSH, SNOMED-CT, RxNorm, etc.
-
#funding ⇒ Object
A [[Grant]] that directly or indirectly provide funding or sponsorship for this item.
-
#funding=(value) ⇒ Object
A [[Grant]] that directly or indirectly provide funding or sponsorship for this item.
-
#guideline ⇒ Object
A medical guideline related to this entity.
-
#guideline=(value) ⇒ Object
A medical guideline related to this entity.
-
#legal_status ⇒ Object
The drug or supplement's legal status, including any controlled substance schedules that apply.
-
#legal_status=(value) ⇒ Object
The drug or supplement's legal status, including any controlled substance schedules that apply.
-
#medicine_system ⇒ Object
The system of medicine that includes this MedicalEntity, for example 'evidence-based', 'homeopathic', 'chiropractic', etc.
-
#medicine_system=(value) ⇒ Object
The system of medicine that includes this MedicalEntity, for example 'evidence-based', 'homeopathic', 'chiropractic', etc.
-
#recognizing_authority ⇒ Object
If applicable, the organization that officially recognizes this entity as part of its endorsed system of medicine.
-
#recognizing_authority=(value) ⇒ Object
If applicable, the organization that officially recognizes this entity as part of its endorsed system of medicine.
-
#relevant_specialty ⇒ Object
If applicable, a medical specialty in which this entity is relevant.
-
#relevant_specialty=(value) ⇒ Object
If applicable, a medical specialty in which this entity is relevant.
-
#study ⇒ Object
A medical study or trial related to this entity.
-
#study=(value) ⇒ Object
A medical study or trial related to this entity.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/schema_org/mixins/medical_entity.rb', line 11 def self.schema_property_definitions { code: { schema_name: "code", schema_url: "https://schema.org/code", comment_lines: ["A medical code for the entity, taken from a controlled vocabulary or ontology such as ICD-9, DiseasesDB, MeSH, SNOMED-CT, RxNorm, etc."].freeze, ranges: ["MedicalCode"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, funding: { schema_name: "funding", schema_url: "https://schema.org/funding", comment_lines: ["A [[Grant]] that directly or indirectly provide funding or sponsorship for this item. See also [[ownershipFundingInfo]]."].freeze, ranges: ["Grant"].freeze, external_ranges: [].freeze, inverse_of: "fundedItem", superseded_by: nil, supersedes: nil }.freeze, guideline: { schema_name: "guideline", schema_url: "https://schema.org/guideline", comment_lines: ["A medical guideline related to this entity."].freeze, ranges: ["MedicalGuideline"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, legal_status: { schema_name: "legalStatus", schema_url: "https://schema.org/legalStatus", comment_lines: ["The drug or supplement's legal status, including any controlled substance schedules that apply."].freeze, ranges: ["DrugLegalStatus", "MedicalEnumeration", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, medicine_system: { schema_name: "medicineSystem", schema_url: "https://schema.org/medicineSystem", comment_lines: ["The system of medicine that includes this MedicalEntity, for example 'evidence-based', 'homeopathic', 'chiropractic', etc."].freeze, ranges: ["MedicineSystem"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, recognizing_authority: { schema_name: "recognizingAuthority", schema_url: "https://schema.org/recognizingAuthority", comment_lines: ["If applicable, the organization that officially recognizes this entity as part of its endorsed system of medicine."].freeze, ranges: ["Organization"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, relevant_specialty: { schema_name: "relevantSpecialty", schema_url: "https://schema.org/relevantSpecialty", comment_lines: ["If applicable, a medical specialty in which this entity is relevant."].freeze, ranges: ["MedicalSpecialty"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, study: { schema_name: "study", schema_url: "https://schema.org/study", comment_lines: ["A medical study or trial related to this entity."].freeze, ranges: ["MedicalStudy"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#code ⇒ Object
A medical code for the entity, taken from a controlled vocabulary or ontology such as ICD-9, DiseasesDB, MeSH, SNOMED-CT, RxNorm, etc.
97 98 99 |
# File 'lib/schema_org/mixins/medical_entity.rb', line 97 def code read_property(:code) end |
#code=(value) ⇒ Object
A medical code for the entity, taken from a controlled vocabulary or ontology such as ICD-9, DiseasesDB, MeSH, SNOMED-CT, RxNorm, etc.
102 103 104 |
# File 'lib/schema_org/mixins/medical_entity.rb', line 102 def code=(value) write_property(:code, value) end |
#funding ⇒ Object
A [[Grant]] that directly or indirectly provide funding or sponsorship for this item. See also [[ownershipFundingInfo]].
Inverse-property: fundedItem.
108 109 110 |
# File 'lib/schema_org/mixins/medical_entity.rb', line 108 def funding read_property(:funding) end |
#funding=(value) ⇒ Object
A [[Grant]] that directly or indirectly provide funding or sponsorship for this item. See also [[ownershipFundingInfo]].
Inverse-property: fundedItem.
114 115 116 |
# File 'lib/schema_org/mixins/medical_entity.rb', line 114 def funding=(value) write_property(:funding, value) end |
#guideline ⇒ Object
A medical guideline related to this entity.
119 120 121 |
# File 'lib/schema_org/mixins/medical_entity.rb', line 119 def guideline read_property(:guideline) end |
#guideline=(value) ⇒ Object
A medical guideline related to this entity.
124 125 126 |
# File 'lib/schema_org/mixins/medical_entity.rb', line 124 def guideline=(value) write_property(:guideline, value) end |
#legal_status ⇒ Object
The drug or supplement's legal status, including any controlled substance schedules that apply.
129 130 131 |
# File 'lib/schema_org/mixins/medical_entity.rb', line 129 def legal_status read_property(:legal_status) end |
#legal_status=(value) ⇒ Object
The drug or supplement's legal status, including any controlled substance schedules that apply.
134 135 136 |
# File 'lib/schema_org/mixins/medical_entity.rb', line 134 def legal_status=(value) write_property(:legal_status, value) end |
#medicine_system ⇒ Object
The system of medicine that includes this MedicalEntity, for example 'evidence-based', 'homeopathic', 'chiropractic', etc.
139 140 141 |
# File 'lib/schema_org/mixins/medical_entity.rb', line 139 def medicine_system read_property(:medicine_system) end |
#medicine_system=(value) ⇒ Object
The system of medicine that includes this MedicalEntity, for example 'evidence-based', 'homeopathic', 'chiropractic', etc.
144 145 146 |
# File 'lib/schema_org/mixins/medical_entity.rb', line 144 def medicine_system=(value) write_property(:medicine_system, value) end |
#recognizing_authority ⇒ Object
If applicable, the organization that officially recognizes this entity as part of its endorsed system of medicine.
149 150 151 |
# File 'lib/schema_org/mixins/medical_entity.rb', line 149 def read_property(:recognizing_authority) end |
#recognizing_authority=(value) ⇒ Object
If applicable, the organization that officially recognizes this entity as part of its endorsed system of medicine.
154 155 156 |
# File 'lib/schema_org/mixins/medical_entity.rb', line 154 def (value) write_property(:recognizing_authority, value) end |
#relevant_specialty ⇒ Object
If applicable, a medical specialty in which this entity is relevant.
159 160 161 |
# File 'lib/schema_org/mixins/medical_entity.rb', line 159 def relevant_specialty read_property(:relevant_specialty) end |
#relevant_specialty=(value) ⇒ Object
If applicable, a medical specialty in which this entity is relevant.
164 165 166 |
# File 'lib/schema_org/mixins/medical_entity.rb', line 164 def relevant_specialty=(value) write_property(:relevant_specialty, value) end |
#study ⇒ Object
A medical study or trial related to this entity.
169 170 171 |
# File 'lib/schema_org/mixins/medical_entity.rb', line 169 def study read_property(:study) end |
#study=(value) ⇒ Object
A medical study or trial related to this entity.
174 175 176 |
# File 'lib/schema_org/mixins/medical_entity.rb', line 174 def study=(value) write_property(:study, value) end |