Module: SchemaOrg::Mixins::MedicalRiskEstimator
- Includes:
- MedicalEntity
- Included in:
- SchemaOrg::MedicalRiskEstimator, MedicalRiskCalculator, MedicalRiskScore
- Defined in:
- lib/schema_org/mixins/medical_risk_estimator.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#estimates_risk_of ⇒ Object
The condition, complication, or symptom whose risk is being estimated.
-
#estimates_risk_of=(value) ⇒ Object
The condition, complication, or symptom whose risk is being estimated.
-
#included_risk_factor ⇒ Object
A modifiable or non-modifiable risk factor included in the calculation, e.g.
-
#included_risk_factor=(value) ⇒ Object
A modifiable or non-modifiable risk factor included in the calculation, e.g.
Methods included from MedicalEntity
#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/schema_org/mixins/medical_risk_estimator.rb', line 11 def self.schema_property_definitions { estimates_risk_of: { schema_name: "estimatesRiskOf", schema_url: "https://schema.org/estimatesRiskOf", comment_lines: ["The condition, complication, or symptom whose risk is being estimated."].freeze, ranges: ["MedicalEntity"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, included_risk_factor: { schema_name: "includedRiskFactor", schema_url: "https://schema.org/includedRiskFactor", comment_lines: ["A modifiable or non-modifiable risk factor included in the calculation, e.g. age, coexisting condition."].freeze, ranges: ["MedicalRiskFactor"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#estimates_risk_of ⇒ Object
The condition, complication, or symptom whose risk is being estimated.
37 38 39 |
# File 'lib/schema_org/mixins/medical_risk_estimator.rb', line 37 def estimates_risk_of read_property(:estimates_risk_of) end |
#estimates_risk_of=(value) ⇒ Object
The condition, complication, or symptom whose risk is being estimated.
42 43 44 |
# File 'lib/schema_org/mixins/medical_risk_estimator.rb', line 42 def estimates_risk_of=(value) write_property(:estimates_risk_of, value) end |
#included_risk_factor ⇒ Object
A modifiable or non-modifiable risk factor included in the calculation, e.g. age, coexisting condition.
47 48 49 |
# File 'lib/schema_org/mixins/medical_risk_estimator.rb', line 47 def included_risk_factor read_property(:included_risk_factor) end |
#included_risk_factor=(value) ⇒ Object
A modifiable or non-modifiable risk factor included in the calculation, e.g. age, coexisting condition.
52 53 54 |
# File 'lib/schema_org/mixins/medical_risk_estimator.rb', line 52 def included_risk_factor=(value) write_property(:included_risk_factor, value) end |