Module: SchemaOrg::Mixins::MonetaryAmountDistribution
- Includes:
- QuantitativeValueDistribution
- Included in:
- SchemaOrg::MonetaryAmountDistribution
- Defined in:
- lib/schema_org/mixins/monetary_amount_distribution.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#currency ⇒ Object
The currency in which the monetary amount is expressed.\n\nUse standard formats: ISO 4217 currency format, e.g.
-
#currency=(value) ⇒ Object
The currency in which the monetary amount is expressed.\n\nUse standard formats: ISO 4217 currency format, e.g.
Methods included from QuantitativeValueDistribution
#duration, #duration=, #median, #median=, #percentile10, #percentile10=, #percentile25, #percentile25=, #percentile75, #percentile75=, #percentile90, #percentile90=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 |
# File 'lib/schema_org/mixins/monetary_amount_distribution.rb', line 11 def self.schema_property_definitions { currency: { schema_name: "currency", schema_url: "https://schema.org/currency", comment_lines: ["The currency in which the monetary amount is expressed.\\n\\nUse standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. \"USD\"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. \"BTC\"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. \"Ithaca HOUR\"."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#currency ⇒ Object
The currency in which the monetary amount is expressed.\n\nUse standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR".
27 28 29 |
# File 'lib/schema_org/mixins/monetary_amount_distribution.rb', line 27 def currency read_property(:currency) end |
#currency=(value) ⇒ Object
The currency in which the monetary amount is expressed.\n\nUse standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR".
32 33 34 |
# File 'lib/schema_org/mixins/monetary_amount_distribution.rb', line 32 def currency=(value) write_property(:currency, value) end |