Module: SchemaOrg::Mixins::Movie
Class Method Summary collapse
Instance Method Summary collapse
-
#actor ⇒ Object
An actor (individual or a group), e.g.
-
#actor=(value) ⇒ Object
An actor (individual or a group), e.g.
-
#actors ⇒ Object
An actor, e.g.
-
#actors=(value) ⇒ Object
An actor, e.g.
-
#country_of_origin ⇒ Object
The country of origin of something, including products as well as creative works such as movie and TV content.
-
#country_of_origin=(value) ⇒ Object
The country of origin of something, including products as well as creative works such as movie and TV content.
-
#director ⇒ Object
A director of e.g.
-
#director=(value) ⇒ Object
A director of e.g.
-
#directors ⇒ Object
A director of e.g.
-
#directors=(value) ⇒ Object
A director of e.g.
-
#duration ⇒ Object
The duration of the item (movie, audio recording, event, etc.) in ISO 8601 duration format.
-
#duration=(value) ⇒ Object
The duration of the item (movie, audio recording, event, etc.) in ISO 8601 duration format.
-
#music_by ⇒ Object
The composer of the soundtrack.
-
#music_by=(value) ⇒ Object
The composer of the soundtrack.
-
#production_company ⇒ Object
The production company or studio responsible for the item, e.g.
-
#production_company=(value) ⇒ Object
The production company or studio responsible for the item, e.g.
-
#subtitle_language ⇒ Object
Languages in which subtitles/captions are available, in IETF BCP 47 standard format.
-
#subtitle_language=(value) ⇒ Object
Languages in which subtitles/captions are available, in IETF BCP 47 standard format.
-
#title_eidr ⇒ Object
An EIDR (Entertainment Identifier Registry) [[identifier]] representing at the most general/abstract level, a work of film or television.
-
#title_eidr=(value) ⇒ Object
An EIDR (Entertainment Identifier Registry) [[identifier]] representing at the most general/abstract level, a work of film or television.
-
#trailer ⇒ Object
The trailer of a movie or TV/radio series, season, episode, etc.
-
#trailer=(value) ⇒ Object
The trailer of a movie or TV/radio series, season, episode, etc.
Methods included from CreativeWork
#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/schema_org/mixins/movie.rb', line 11 def self.schema_property_definitions { actor: { schema_name: "actor", schema_url: "https://schema.org/actor", comment_lines: ["An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip."].freeze, ranges: ["PerformingGroup", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["actors"].freeze }.freeze, actors: { schema_name: "actors", schema_url: "https://schema.org/actors", comment_lines: ["An actor, e.g. in TV, radio, movie, video games etc. Actors can be associated with individual items or with a series, episode, clip."].freeze, ranges: ["Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "actor", supersedes: nil }.freeze, country_of_origin: { schema_name: "countryOfOrigin", schema_url: "https://schema.org/countryOfOrigin", comment_lines: ["The country of origin of something, including products as well as creative works such as movie and TV content.", "", "In the case of TV and movie, this would be the country of the principle offices of the production company or individual responsible for the movie. For other kinds of [[CreativeWork]] it is difficult to provide fully general guidance, and properties such as [[contentLocation]] and [[locationCreated]] may be more applicable.", "", "In the case of products, the country of origin of the product. The exact interpretation of this may vary by context and product type, and cannot be fully enumerated here."].freeze, ranges: ["Country"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, director: { schema_name: "director", schema_url: "https://schema.org/director", comment_lines: ["A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip."].freeze, ranges: ["Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["directors"].freeze }.freeze, directors: { schema_name: "directors", schema_url: "https://schema.org/directors", comment_lines: ["A director of e.g. TV, radio, movie, video games etc. content. Directors can be associated with individual items or with a series, episode, clip."].freeze, ranges: ["Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "director", supersedes: nil }.freeze, duration: { schema_name: "duration", schema_url: "https://schema.org/duration", comment_lines: ["The duration of the item (movie, audio recording, event, etc.) in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601)."].freeze, ranges: ["Duration", "QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, music_by: { schema_name: "musicBy", schema_url: "https://schema.org/musicBy", comment_lines: ["The composer of the soundtrack."].freeze, ranges: ["MusicGroup", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, production_company: { schema_name: "productionCompany", schema_url: "https://schema.org/productionCompany", comment_lines: ["The production company or studio responsible for the item, e.g. series, video game, episode etc."].freeze, ranges: ["Organization"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, subtitle_language: { schema_name: "subtitleLanguage", schema_url: "https://schema.org/subtitleLanguage", comment_lines: ["Languages in which subtitles/captions are available, in [IETF BCP 47 standard format](http://tools.ietf.org/html/bcp47)."].freeze, ranges: ["Language", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, title_eidr: { schema_name: "titleEIDR", schema_url: "https://schema.org/titleEIDR", comment_lines: ["An [EIDR](https://eidr.org/) (Entertainment Identifier Registry) [[identifier]] representing at the most general/abstract level, a work of film or television.", "", "For example, the motion picture known as \"Ghostbusters\" has a titleEIDR of \"10.5240/7EC7-228A-510A-053E-CBB8-J\". This title (or work) may have several variants, which EIDR calls \"edits\". See [[editEIDR]].", "", "Since schema.org types like [[Movie]], [[TVEpisode]], [[TVSeason]], and [[TVSeries]] can be used for both works and their multiple expressions, it is possible to use [[titleEIDR]] alone (for a general description), or alongside [[editEIDR]] for a more edit-specific description."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, trailer: { schema_name: "trailer", schema_url: "https://schema.org/trailer", comment_lines: ["The trailer of a movie or TV/radio series, season, episode, etc."].freeze, ranges: ["VideoObject"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#actor ⇒ Object
An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip.
Supersedes actors.
128 129 130 |
# File 'lib/schema_org/mixins/movie.rb', line 128 def actor read_property(:actor) end |
#actor=(value) ⇒ Object
An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip.
Supersedes actors.
134 135 136 |
# File 'lib/schema_org/mixins/movie.rb', line 134 def actor=(value) write_property(:actor, value) end |
#actors ⇒ Object
An actor, e.g. in TV, radio, movie, video games etc. Actors can be associated with individual items or with a series, episode, clip.
Superseded by actor.
140 141 142 |
# File 'lib/schema_org/mixins/movie.rb', line 140 def actors read_property(:actors) end |
#actors=(value) ⇒ Object
An actor, e.g. in TV, radio, movie, video games etc. Actors can be associated with individual items or with a series, episode, clip.
Superseded by actor.
146 147 148 |
# File 'lib/schema_org/mixins/movie.rb', line 146 def actors=(value) write_property(:actors, value) end |
#country_of_origin ⇒ Object
The country of origin of something, including products as well as creative works such as movie and TV content.
In the case of TV and movie, this would be the country of the principle offices of the production company or individual responsible for the movie. For other kinds of [[CreativeWork]] it is difficult to provide fully general guidance, and properties such as [[contentLocation]] and [[locationCreated]] may be more applicable.
In the case of products, the country of origin of the product. The exact interpretation of this may vary by context and product type, and cannot be fully enumerated here.
155 156 157 |
# File 'lib/schema_org/mixins/movie.rb', line 155 def country_of_origin read_property(:country_of_origin) end |
#country_of_origin=(value) ⇒ Object
The country of origin of something, including products as well as creative works such as movie and TV content.
In the case of TV and movie, this would be the country of the principle offices of the production company or individual responsible for the movie. For other kinds of [[CreativeWork]] it is difficult to provide fully general guidance, and properties such as [[contentLocation]] and [[locationCreated]] may be more applicable.
In the case of products, the country of origin of the product. The exact interpretation of this may vary by context and product type, and cannot be fully enumerated here.
164 165 166 |
# File 'lib/schema_org/mixins/movie.rb', line 164 def country_of_origin=(value) write_property(:country_of_origin, value) end |
#director ⇒ Object
A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip.
Supersedes directors.
170 171 172 |
# File 'lib/schema_org/mixins/movie.rb', line 170 def director read_property(:director) end |
#director=(value) ⇒ Object
A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip.
Supersedes directors.
176 177 178 |
# File 'lib/schema_org/mixins/movie.rb', line 176 def director=(value) write_property(:director, value) end |
#directors ⇒ Object
A director of e.g. TV, radio, movie, video games etc. content. Directors can be associated with individual items or with a series, episode, clip.
Superseded by director.
182 183 184 |
# File 'lib/schema_org/mixins/movie.rb', line 182 def directors read_property(:directors) end |
#directors=(value) ⇒ Object
A director of e.g. TV, radio, movie, video games etc. content. Directors can be associated with individual items or with a series, episode, clip.
Superseded by director.
188 189 190 |
# File 'lib/schema_org/mixins/movie.rb', line 188 def directors=(value) write_property(:directors, value) end |
#duration ⇒ Object
The duration of the item (movie, audio recording, event, etc.) in ISO 8601 duration format.
193 194 195 |
# File 'lib/schema_org/mixins/movie.rb', line 193 def duration read_property(:duration) end |
#duration=(value) ⇒ Object
The duration of the item (movie, audio recording, event, etc.) in ISO 8601 duration format.
198 199 200 |
# File 'lib/schema_org/mixins/movie.rb', line 198 def duration=(value) write_property(:duration, value) end |
#music_by ⇒ Object
The composer of the soundtrack.
203 204 205 |
# File 'lib/schema_org/mixins/movie.rb', line 203 def music_by read_property(:music_by) end |
#music_by=(value) ⇒ Object
The composer of the soundtrack.
208 209 210 |
# File 'lib/schema_org/mixins/movie.rb', line 208 def music_by=(value) write_property(:music_by, value) end |
#production_company ⇒ Object
The production company or studio responsible for the item, e.g. series, video game, episode etc.
213 214 215 |
# File 'lib/schema_org/mixins/movie.rb', line 213 def production_company read_property(:production_company) end |
#production_company=(value) ⇒ Object
The production company or studio responsible for the item, e.g. series, video game, episode etc.
218 219 220 |
# File 'lib/schema_org/mixins/movie.rb', line 218 def production_company=(value) write_property(:production_company, value) end |
#subtitle_language ⇒ Object
Languages in which subtitles/captions are available, in IETF BCP 47 standard format.
223 224 225 |
# File 'lib/schema_org/mixins/movie.rb', line 223 def subtitle_language read_property(:subtitle_language) end |
#subtitle_language=(value) ⇒ Object
Languages in which subtitles/captions are available, in IETF BCP 47 standard format.
228 229 230 |
# File 'lib/schema_org/mixins/movie.rb', line 228 def subtitle_language=(value) write_property(:subtitle_language, value) end |
#title_eidr ⇒ Object
An EIDR (Entertainment Identifier Registry) [[identifier]] representing at the most general/abstract level, a work of film or television.
For example, the motion picture known as "Ghostbusters" has a titleEIDR of "10.5240/7EC7-228A-510A-053E-CBB8-J". This title (or work) may have several variants, which EIDR calls "edits". See [[editEIDR]].
Since schema.org types like [[Movie]], [[TVEpisode]], [[TVSeason]], and [[TVSeries]] can be used for both works and their multiple expressions, it is possible to use [[titleEIDR]] alone (for a general description), or alongside [[editEIDR]] for a more edit-specific description.
237 238 239 |
# File 'lib/schema_org/mixins/movie.rb', line 237 def title_eidr read_property(:title_eidr) end |
#title_eidr=(value) ⇒ Object
An EIDR (Entertainment Identifier Registry) [[identifier]] representing at the most general/abstract level, a work of film or television.
For example, the motion picture known as "Ghostbusters" has a titleEIDR of "10.5240/7EC7-228A-510A-053E-CBB8-J". This title (or work) may have several variants, which EIDR calls "edits". See [[editEIDR]].
Since schema.org types like [[Movie]], [[TVEpisode]], [[TVSeason]], and [[TVSeries]] can be used for both works and their multiple expressions, it is possible to use [[titleEIDR]] alone (for a general description), or alongside [[editEIDR]] for a more edit-specific description.
246 247 248 |
# File 'lib/schema_org/mixins/movie.rb', line 246 def title_eidr=(value) write_property(:title_eidr, value) end |
#trailer ⇒ Object
The trailer of a movie or TV/radio series, season, episode, etc.
251 252 253 |
# File 'lib/schema_org/mixins/movie.rb', line 251 def trailer read_property(:trailer) end |
#trailer=(value) ⇒ Object
The trailer of a movie or TV/radio series, season, episode, etc.
256 257 258 |
# File 'lib/schema_org/mixins/movie.rb', line 256 def trailer=(value) write_property(:trailer, value) end |