Module: SchemaOrg::Mixins::MusicGroup
- Includes:
- PerformingGroup
- Included in:
- SchemaOrg::MusicGroup
- Defined in:
- lib/schema_org/mixins/music_group.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#album ⇒ Object
A music album.
-
#album=(value) ⇒ Object
A music album.
-
#albums ⇒ Object
A collection of music albums.
-
#albums=(value) ⇒ Object
A collection of music albums.
-
#genre ⇒ Object
Genre of the creative work, broadcast channel or group.
-
#genre=(value) ⇒ Object
Genre of the creative work, broadcast channel or group.
-
#music_group_member ⇒ Object
A member of a music group—for example, John, Paul, George, or Ringo.
-
#music_group_member=(value) ⇒ Object
A member of a music group—for example, John, Paul, George, or Ringo.
-
#track ⇒ Object
A music recording (track)—usually a single song.
-
#track=(value) ⇒ Object
A music recording (track)—usually a single song.
-
#tracks ⇒ Object
A music recording (track)—usually a single song.
-
#tracks=(value) ⇒ Object
A music recording (track)—usually a single song.
Methods included from Organization
#accepted_payment_method, #accepted_payment_method=, #actionable_feedback_policy, #actionable_feedback_policy=, #address, #address=, #agent_interaction_statistic, #agent_interaction_statistic=, #aggregate_rating, #aggregate_rating=, #alumni, #alumni=, #area_served, #area_served=, #award, #award=, #awards, #awards=, #brand, #brand=, #company_registration, #company_registration=, #contact_point, #contact_point=, #contact_points, #contact_points=, #corrections_policy, #corrections_policy=, #department, #department=, #dissolution_date, #dissolution_date=, #diversity_policy, #diversity_policy=, #diversity_staffing_report, #diversity_staffing_report=, #duns, #duns=, #email, #email=, #employee, #employee=, #employees, #employees=, #ethics_policy, #ethics_policy=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #founder, #founder=, #founders, #founders=, #founding_date, #founding_date=, #founding_location, #founding_location=, #funder, #funder=, #funding, #funding=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_credential, #has_credential=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_member_program, #has_member_program=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_offer_catalog, #has_offer_catalog=, #has_pos, #has_pos=, #has_product_return_policy, #has_product_return_policy=, #has_shipping_service, #has_shipping_service=, #interaction_statistic, #interaction_statistic=, #isic_v4, #isic_v4=, #iso6523_code, #iso6523_code=, #keywords, #keywords=, #knows_about, #knows_about=, #knows_language, #knows_language=, #legal_address, #legal_address=, #legal_name, #legal_name=, #legal_representative, #legal_representative=, #lei_code, #lei_code=, #location, #location=, #logo, #logo=, #makes_offer, #makes_offer=, #member, #member=, #member_of, #member_of=, #members, #members=, #naics, #naics=, #nonprofit_status, #nonprofit_status=, #number_of_employees, #number_of_employees=, #ownership_funding_info, #ownership_funding_info=, #owns, #owns=, #parent_organization, #parent_organization=, #publishing_principles, #publishing_principles=, #review, #review=, #reviews, #reviews=, #seeks, #seeks=, #service_area, #service_area=, #skills, #skills=, #slogan, #slogan=, #sponsor, #sponsor=, #sub_organization, #sub_organization=, #tax_id, #tax_id=, #telephone, #telephone=, #unnamed_sources_policy, #unnamed_sources_policy=, #vat_id, #vat_id=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/schema_org/mixins/music_group.rb', line 11 def self.schema_property_definitions { album: { schema_name: "album", schema_url: "https://schema.org/album", comment_lines: ["A music album."].freeze, ranges: ["MusicAlbum"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["albums"].freeze }.freeze, albums: { schema_name: "albums", schema_url: "https://schema.org/albums", comment_lines: ["A collection of music albums."].freeze, ranges: ["MusicAlbum"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "album", supersedes: nil }.freeze, genre: { schema_name: "genre", schema_url: "https://schema.org/genre", comment_lines: ["Genre of the creative work, broadcast channel or group."].freeze, ranges: ["DefinedTerm", "Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, music_group_member: { schema_name: "musicGroupMember", schema_url: "https://schema.org/musicGroupMember", comment_lines: ["A member of a music group—for example, John, Paul, George, or Ringo."].freeze, ranges: ["Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "member", supersedes: nil }.freeze, track: { schema_name: "track", schema_url: "https://schema.org/track", comment_lines: ["A music recording (track)—usually a single song. If an ItemList is given, the list should contain items of type MusicRecording."].freeze, ranges: ["ItemList", "MusicRecording"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["tracks"].freeze }.freeze, tracks: { schema_name: "tracks", schema_url: "https://schema.org/tracks", comment_lines: ["A music recording (track)—usually a single song."].freeze, ranges: ["MusicRecording"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "track", supersedes: nil }.freeze }.freeze end |
Instance Method Details
#album ⇒ Object
A music album.
Supersedes albums.
78 79 80 |
# File 'lib/schema_org/mixins/music_group.rb', line 78 def album read_property(:album) end |
#album=(value) ⇒ Object
A music album.
Supersedes albums.
84 85 86 |
# File 'lib/schema_org/mixins/music_group.rb', line 84 def album=(value) write_property(:album, value) end |
#albums ⇒ Object
A collection of music albums.
Superseded by album.
90 91 92 |
# File 'lib/schema_org/mixins/music_group.rb', line 90 def albums read_property(:albums) end |
#albums=(value) ⇒ Object
A collection of music albums.
Superseded by album.
96 97 98 |
# File 'lib/schema_org/mixins/music_group.rb', line 96 def albums=(value) write_property(:albums, value) end |
#genre ⇒ Object
Genre of the creative work, broadcast channel or group.
101 102 103 |
# File 'lib/schema_org/mixins/music_group.rb', line 101 def genre read_property(:genre) end |
#genre=(value) ⇒ Object
Genre of the creative work, broadcast channel or group.
106 107 108 |
# File 'lib/schema_org/mixins/music_group.rb', line 106 def genre=(value) write_property(:genre, value) end |
#music_group_member ⇒ Object
A member of a music group—for example, John, Paul, George, or Ringo.
Superseded by member.
112 113 114 |
# File 'lib/schema_org/mixins/music_group.rb', line 112 def music_group_member read_property(:music_group_member) end |
#music_group_member=(value) ⇒ Object
A member of a music group—for example, John, Paul, George, or Ringo.
Superseded by member.
118 119 120 |
# File 'lib/schema_org/mixins/music_group.rb', line 118 def music_group_member=(value) write_property(:music_group_member, value) end |
#track ⇒ Object
A music recording (track)—usually a single song. If an ItemList is given, the list should contain items of type MusicRecording.
Supersedes tracks.
124 125 126 |
# File 'lib/schema_org/mixins/music_group.rb', line 124 def track read_property(:track) end |
#track=(value) ⇒ Object
A music recording (track)—usually a single song. If an ItemList is given, the list should contain items of type MusicRecording.
Supersedes tracks.
130 131 132 |
# File 'lib/schema_org/mixins/music_group.rb', line 130 def track=(value) write_property(:track, value) end |
#tracks ⇒ Object
A music recording (track)—usually a single song.
Superseded by track.
136 137 138 |
# File 'lib/schema_org/mixins/music_group.rb', line 136 def tracks read_property(:tracks) end |
#tracks=(value) ⇒ Object
A music recording (track)—usually a single song.
Superseded by track.
142 143 144 |
# File 'lib/schema_org/mixins/music_group.rb', line 142 def tracks=(value) write_property(:tracks, value) end |