Module: SchemaOrg::Mixins::MusicPlaylist
- Includes:
- CreativeWork
- Included in:
- MusicAlbum, MusicRelease, SchemaOrg::MusicPlaylist
- Defined in:
- lib/schema_org/mixins/music_playlist.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#num_tracks ⇒ Object
The number of tracks in this album or playlist.
-
#num_tracks=(value) ⇒ Object
The number of tracks in this album or playlist.
-
#track ⇒ Object
A music recording (track)—usually a single song.
-
#track=(value) ⇒ Object
A music recording (track)—usually a single song.
-
#tracks ⇒ Object
A music recording (track)—usually a single song.
-
#tracks=(value) ⇒ Object
A music recording (track)—usually a single song.
Methods included from CreativeWork
#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/schema_org/mixins/music_playlist.rb', line 11 def self.schema_property_definitions { num_tracks: { schema_name: "numTracks", schema_url: "https://schema.org/numTracks", comment_lines: ["The number of tracks in this album or playlist."].freeze, ranges: ["Integer"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, track: { schema_name: "track", schema_url: "https://schema.org/track", comment_lines: ["A music recording (track)—usually a single song. If an ItemList is given, the list should contain items of type MusicRecording."].freeze, ranges: ["ItemList", "MusicRecording"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["tracks"].freeze }.freeze, tracks: { schema_name: "tracks", schema_url: "https://schema.org/tracks", comment_lines: ["A music recording (track)—usually a single song."].freeze, ranges: ["MusicRecording"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "track", supersedes: nil }.freeze }.freeze end |
Instance Method Details
#num_tracks ⇒ Object
The number of tracks in this album or playlist.
47 48 49 |
# File 'lib/schema_org/mixins/music_playlist.rb', line 47 def num_tracks read_property(:num_tracks) end |
#num_tracks=(value) ⇒ Object
The number of tracks in this album or playlist.
52 53 54 |
# File 'lib/schema_org/mixins/music_playlist.rb', line 52 def num_tracks=(value) write_property(:num_tracks, value) end |
#track ⇒ Object
A music recording (track)—usually a single song. If an ItemList is given, the list should contain items of type MusicRecording.
Supersedes tracks.
58 59 60 |
# File 'lib/schema_org/mixins/music_playlist.rb', line 58 def track read_property(:track) end |
#track=(value) ⇒ Object
A music recording (track)—usually a single song. If an ItemList is given, the list should contain items of type MusicRecording.
Supersedes tracks.
64 65 66 |
# File 'lib/schema_org/mixins/music_playlist.rb', line 64 def track=(value) write_property(:track, value) end |
#tracks ⇒ Object
A music recording (track)—usually a single song.
Superseded by track.
70 71 72 |
# File 'lib/schema_org/mixins/music_playlist.rb', line 70 def tracks read_property(:tracks) end |
#tracks=(value) ⇒ Object
A music recording (track)—usually a single song.
Superseded by track.
76 77 78 |
# File 'lib/schema_org/mixins/music_playlist.rb', line 76 def tracks=(value) write_property(:tracks, value) end |