Module: SchemaOrg::Mixins::Nerve
Class Method Summary collapse
Instance Method Summary collapse
-
#branch ⇒ Object
The branches that delineate from the nerve bundle.
-
#branch=(value) ⇒ Object
The branches that delineate from the nerve bundle.
-
#nerve_motor ⇒ Object
The neurological pathway extension that involves muscle control.
-
#nerve_motor=(value) ⇒ Object
The neurological pathway extension that involves muscle control.
-
#sensory_unit ⇒ Object
The neurological pathway extension that inputs and sends information to the brain or spinal cord.
-
#sensory_unit=(value) ⇒ Object
The neurological pathway extension that inputs and sends information to the brain or spinal cord.
-
#sourced_from ⇒ Object
The neurological pathway that originates the neurons.
-
#sourced_from=(value) ⇒ Object
The neurological pathway that originates the neurons.
Methods included from AnatomicalStructure
#associated_pathophysiology, #associated_pathophysiology=, #body_location, #body_location=, #connected_to, #connected_to=, #diagram, #diagram=, #part_of_system, #part_of_system=, #related_condition, #related_condition=, #related_therapy, #related_therapy=, #sub_structure, #sub_structure=
Methods included from MedicalEntity
#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/schema_org/mixins/nerve.rb', line 11 def self.schema_property_definitions { branch: { schema_name: "branch", schema_url: "https://schema.org/branch", comment_lines: ["The branches that delineate from the nerve bundle. Not to be confused with [[branchOf]]."].freeze, ranges: ["AnatomicalStructure"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "arterialBranch", supersedes: nil }.freeze, nerve_motor: { schema_name: "nerveMotor", schema_url: "https://schema.org/nerveMotor", comment_lines: ["The neurological pathway extension that involves muscle control."].freeze, ranges: ["Muscle"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, sensory_unit: { schema_name: "sensoryUnit", schema_url: "https://schema.org/sensoryUnit", comment_lines: ["The neurological pathway extension that inputs and sends information to the brain or spinal cord."].freeze, ranges: ["AnatomicalStructure", "SuperficialAnatomy"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, sourced_from: { schema_name: "sourcedFrom", schema_url: "https://schema.org/sourcedFrom", comment_lines: ["The neurological pathway that originates the neurons."].freeze, ranges: ["BrainStructure"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#branch ⇒ Object
The branches that delineate from the nerve bundle. Not to be confused with [[branchOf]].
Superseded by arterialBranch.
58 59 60 |
# File 'lib/schema_org/mixins/nerve.rb', line 58 def branch read_property(:branch) end |
#branch=(value) ⇒ Object
The branches that delineate from the nerve bundle. Not to be confused with [[branchOf]].
Superseded by arterialBranch.
64 65 66 |
# File 'lib/schema_org/mixins/nerve.rb', line 64 def branch=(value) write_property(:branch, value) end |
#nerve_motor ⇒ Object
The neurological pathway extension that involves muscle control.
69 70 71 |
# File 'lib/schema_org/mixins/nerve.rb', line 69 def nerve_motor read_property(:nerve_motor) end |
#nerve_motor=(value) ⇒ Object
The neurological pathway extension that involves muscle control.
74 75 76 |
# File 'lib/schema_org/mixins/nerve.rb', line 74 def nerve_motor=(value) write_property(:nerve_motor, value) end |
#sensory_unit ⇒ Object
The neurological pathway extension that inputs and sends information to the brain or spinal cord.
79 80 81 |
# File 'lib/schema_org/mixins/nerve.rb', line 79 def sensory_unit read_property(:sensory_unit) end |
#sensory_unit=(value) ⇒ Object
The neurological pathway extension that inputs and sends information to the brain or spinal cord.
84 85 86 |
# File 'lib/schema_org/mixins/nerve.rb', line 84 def sensory_unit=(value) write_property(:sensory_unit, value) end |
#sourced_from ⇒ Object
The neurological pathway that originates the neurons.
89 90 91 |
# File 'lib/schema_org/mixins/nerve.rb', line 89 def sourced_from read_property(:sourced_from) end |
#sourced_from=(value) ⇒ Object
The neurological pathway that originates the neurons.
94 95 96 |
# File 'lib/schema_org/mixins/nerve.rb', line 94 def sourced_from=(value) write_property(:sourced_from, value) end |