Module: SchemaOrg::Mixins::NewsArticle
- Includes:
- Article
- Included in:
- AnalysisNewsArticle, AskPublicNewsArticle, BackgroundNewsArticle, OpinionNewsArticle, ReportageNewsArticle, ReviewNewsArticle, NewsArticle
- Defined in:
- lib/schema_org/mixins/news_article.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#dateline ⇒ Object
A dateline is a brief piece of text included in news articles that describes where and when the story was written or filed though the date is often omitted.
-
#dateline=(value) ⇒ Object
A dateline is a brief piece of text included in news articles that describes where and when the story was written or filed though the date is often omitted.
-
#print_column ⇒ Object
The number of the column in which the NewsArticle appears in the print edition.
-
#print_column=(value) ⇒ Object
The number of the column in which the NewsArticle appears in the print edition.
-
#print_edition ⇒ Object
The edition of the print product in which the NewsArticle appears.
-
#print_edition=(value) ⇒ Object
The edition of the print product in which the NewsArticle appears.
-
#print_page ⇒ Object
If this NewsArticle appears in print, this field indicates the name of the page on which the article is found.
-
#print_page=(value) ⇒ Object
If this NewsArticle appears in print, this field indicates the name of the page on which the article is found.
-
#print_section ⇒ Object
If this NewsArticle appears in print, this field indicates the print section in which the article appeared.
-
#print_section=(value) ⇒ Object
If this NewsArticle appears in print, this field indicates the print section in which the article appeared.
Methods included from Article
#article_body, #article_body=, #article_section, #article_section=, #backstory, #backstory=, #page_end, #page_end=, #page_start, #page_start=, #pagination, #pagination=, #speakable, #speakable=, #word_count, #word_count=
Methods included from CreativeWork
#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/schema_org/mixins/news_article.rb', line 11 def self.schema_property_definitions { dateline: { schema_name: "dateline", schema_url: "https://schema.org/dateline", comment_lines: ["A [dateline](https://en.wikipedia.org/wiki/Dateline) is a brief piece of text included in news articles that describes where and when the story was written or filed though the date is often omitted. Sometimes only a placename is provided.", "", "Structured representations of dateline-related information can also be expressed more explicitly using [[locationCreated]] (which represents where a work was created, e.g. where a news report was written). For location depicted or described in the content, use [[contentLocation]].", "", "Dateline summaries are oriented more towards human readers than towards automated processing, and can vary substantially. Some examples: \"BEIRUT, Lebanon, June 2.\", \"Paris, France\", \"December 19, 2017 11:43AM Reporting from Washington\", \"Beijing/Moscow\", \"QUEZON CITY, Philippines\"."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, print_column: { schema_name: "printColumn", schema_url: "https://schema.org/printColumn", comment_lines: ["The number of the column in which the NewsArticle appears in the print edition."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, print_edition: { schema_name: "printEdition", schema_url: "https://schema.org/printEdition", comment_lines: ["The edition of the print product in which the NewsArticle appears."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, print_page: { schema_name: "printPage", schema_url: "https://schema.org/printPage", comment_lines: ["If this NewsArticle appears in print, this field indicates the name of the page on which the article is found. Please note that this field is intended for the exact page name (e.g. A5, B18)."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, print_section: { schema_name: "printSection", schema_url: "https://schema.org/printSection", comment_lines: ["If this NewsArticle appears in print, this field indicates the print section in which the article appeared."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#dateline ⇒ Object
A dateline is a brief piece of text included in news articles that describes where and when the story was written or filed though the date is often omitted. Sometimes only a placename is provided.
Structured representations of dateline-related information can also be expressed more explicitly using [[locationCreated]] (which represents where a work was created, e.g. where a news report was written). For location depicted or described in the content, use [[contentLocation]].
Dateline summaries are oriented more towards human readers than towards automated processing, and can vary substantially. Some examples: "BEIRUT, Lebanon, June 2.", "Paris, France", "December 19, 2017 11:43AM Reporting from Washington", "Beijing/Moscow", "QUEZON CITY, Philippines".
71 72 73 |
# File 'lib/schema_org/mixins/news_article.rb', line 71 def dateline read_property(:dateline) end |
#dateline=(value) ⇒ Object
A dateline is a brief piece of text included in news articles that describes where and when the story was written or filed though the date is often omitted. Sometimes only a placename is provided.
Structured representations of dateline-related information can also be expressed more explicitly using [[locationCreated]] (which represents where a work was created, e.g. where a news report was written). For location depicted or described in the content, use [[contentLocation]].
Dateline summaries are oriented more towards human readers than towards automated processing, and can vary substantially. Some examples: "BEIRUT, Lebanon, June 2.", "Paris, France", "December 19, 2017 11:43AM Reporting from Washington", "Beijing/Moscow", "QUEZON CITY, Philippines".
80 81 82 |
# File 'lib/schema_org/mixins/news_article.rb', line 80 def dateline=(value) write_property(:dateline, value) end |
#print_column ⇒ Object
The number of the column in which the NewsArticle appears in the print edition.
85 86 87 |
# File 'lib/schema_org/mixins/news_article.rb', line 85 def print_column read_property(:print_column) end |
#print_column=(value) ⇒ Object
The number of the column in which the NewsArticle appears in the print edition.
90 91 92 |
# File 'lib/schema_org/mixins/news_article.rb', line 90 def print_column=(value) write_property(:print_column, value) end |
#print_edition ⇒ Object
The edition of the print product in which the NewsArticle appears.
95 96 97 |
# File 'lib/schema_org/mixins/news_article.rb', line 95 def print_edition read_property(:print_edition) end |
#print_edition=(value) ⇒ Object
The edition of the print product in which the NewsArticle appears.
100 101 102 |
# File 'lib/schema_org/mixins/news_article.rb', line 100 def print_edition=(value) write_property(:print_edition, value) end |
#print_page ⇒ Object
If this NewsArticle appears in print, this field indicates the name of the page on which the article is found. Please note that this field is intended for the exact page name (e.g. A5, B18).
105 106 107 |
# File 'lib/schema_org/mixins/news_article.rb', line 105 def print_page read_property(:print_page) end |
#print_page=(value) ⇒ Object
If this NewsArticle appears in print, this field indicates the name of the page on which the article is found. Please note that this field is intended for the exact page name (e.g. A5, B18).
110 111 112 |
# File 'lib/schema_org/mixins/news_article.rb', line 110 def print_page=(value) write_property(:print_page, value) end |
#print_section ⇒ Object
If this NewsArticle appears in print, this field indicates the print section in which the article appeared.
115 116 117 |
# File 'lib/schema_org/mixins/news_article.rb', line 115 def print_section read_property(:print_section) end |
#print_section=(value) ⇒ Object
If this NewsArticle appears in print, this field indicates the print section in which the article appeared.
120 121 122 |
# File 'lib/schema_org/mixins/news_article.rb', line 120 def print_section=(value) write_property(:print_section, value) end |