Module: SchemaOrg::Mixins::OccupationalExperienceRequirements
- Includes:
- Intangible
- Included in:
- OccupationalExperienceRequirements
- Defined in:
- lib/schema_org/mixins/occupational_experience_requirements.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#months_of_experience ⇒ Object
Indicates the minimal number of months of experience required for a position.
-
#months_of_experience=(value) ⇒ Object
Indicates the minimal number of months of experience required for a position.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 |
# File 'lib/schema_org/mixins/occupational_experience_requirements.rb', line 11 def self.schema_property_definitions { months_of_experience: { schema_name: "monthsOfExperience", schema_url: "https://schema.org/monthsOfExperience", comment_lines: ["Indicates the minimal number of months of experience required for a position."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#months_of_experience ⇒ Object
Indicates the minimal number of months of experience required for a position.
27 28 29 |
# File 'lib/schema_org/mixins/occupational_experience_requirements.rb', line 27 def months_of_experience read_property(:months_of_experience) end |
#months_of_experience=(value) ⇒ Object
Indicates the minimal number of months of experience required for a position.
32 33 34 |
# File 'lib/schema_org/mixins/occupational_experience_requirements.rb', line 32 def months_of_experience=(value) write_property(:months_of_experience, value) end |