Module: SchemaOrg::Mixins::OrderItem
Class Method Summary collapse
Instance Method Summary collapse
-
#order_delivery ⇒ Object
The delivery of the parcel related to this order or order item.
-
#order_delivery=(value) ⇒ Object
The delivery of the parcel related to this order or order item.
-
#order_item_number ⇒ Object
The identifier of the order item.
-
#order_item_number=(value) ⇒ Object
The identifier of the order item.
-
#order_item_status ⇒ Object
The current status of the order item.
-
#order_item_status=(value) ⇒ Object
The current status of the order item.
-
#order_quantity ⇒ Object
The number of the item ordered.
-
#order_quantity=(value) ⇒ Object
The number of the item ordered.
-
#ordered_item ⇒ Object
The item ordered.
-
#ordered_item=(value) ⇒ Object
The item ordered.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/schema_org/mixins/order_item.rb', line 11 def self.schema_property_definitions { order_delivery: { schema_name: "orderDelivery", schema_url: "https://schema.org/orderDelivery", comment_lines: ["The delivery of the parcel related to this order or order item."].freeze, ranges: ["ParcelDelivery"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, order_item_number: { schema_name: "orderItemNumber", schema_url: "https://schema.org/orderItemNumber", comment_lines: ["The identifier of the order item."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, order_item_status: { schema_name: "orderItemStatus", schema_url: "https://schema.org/orderItemStatus", comment_lines: ["The current status of the order item."].freeze, ranges: ["OrderStatus"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, order_quantity: { schema_name: "orderQuantity", schema_url: "https://schema.org/orderQuantity", comment_lines: ["The number of the item ordered. If the property is not set, assume the quantity is one."].freeze, ranges: ["Number", "QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, ordered_item: { schema_name: "orderedItem", schema_url: "https://schema.org/orderedItem", comment_lines: ["The item ordered."].freeze, ranges: ["OrderItem", "Product", "Service"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#order_delivery ⇒ Object
The delivery of the parcel related to this order or order item.
67 68 69 |
# File 'lib/schema_org/mixins/order_item.rb', line 67 def order_delivery read_property(:order_delivery) end |
#order_delivery=(value) ⇒ Object
The delivery of the parcel related to this order or order item.
72 73 74 |
# File 'lib/schema_org/mixins/order_item.rb', line 72 def order_delivery=(value) write_property(:order_delivery, value) end |
#order_item_number ⇒ Object
The identifier of the order item.
77 78 79 |
# File 'lib/schema_org/mixins/order_item.rb', line 77 def order_item_number read_property(:order_item_number) end |
#order_item_number=(value) ⇒ Object
The identifier of the order item.
82 83 84 |
# File 'lib/schema_org/mixins/order_item.rb', line 82 def order_item_number=(value) write_property(:order_item_number, value) end |
#order_item_status ⇒ Object
The current status of the order item.
87 88 89 |
# File 'lib/schema_org/mixins/order_item.rb', line 87 def order_item_status read_property(:order_item_status) end |
#order_item_status=(value) ⇒ Object
The current status of the order item.
92 93 94 |
# File 'lib/schema_org/mixins/order_item.rb', line 92 def order_item_status=(value) write_property(:order_item_status, value) end |
#order_quantity ⇒ Object
The number of the item ordered. If the property is not set, assume the quantity is one.
97 98 99 |
# File 'lib/schema_org/mixins/order_item.rb', line 97 def order_quantity read_property(:order_quantity) end |
#order_quantity=(value) ⇒ Object
The number of the item ordered. If the property is not set, assume the quantity is one.
102 103 104 |
# File 'lib/schema_org/mixins/order_item.rb', line 102 def order_quantity=(value) write_property(:order_quantity, value) end |
#ordered_item ⇒ Object
The item ordered.
107 108 109 |
# File 'lib/schema_org/mixins/order_item.rb', line 107 def ordered_item read_property(:ordered_item) end |
#ordered_item=(value) ⇒ Object
The item ordered.
112 113 114 |
# File 'lib/schema_org/mixins/order_item.rb', line 112 def ordered_item=(value) write_property(:ordered_item, value) end |