Module: SchemaOrg::Mixins::OwnershipInfo
- Includes:
- StructuredValue
- Included in:
- OwnershipInfo
- Defined in:
- lib/schema_org/mixins/ownership_info.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#acquired_from ⇒ Object
The organization or person from which the product was acquired.
-
#acquired_from=(value) ⇒ Object
The organization or person from which the product was acquired.
-
#owned_from ⇒ Object
The date and time of obtaining the product.
-
#owned_from=(value) ⇒ Object
The date and time of obtaining the product.
-
#owned_through ⇒ Object
The date and time of giving up ownership on the product.
-
#owned_through=(value) ⇒ Object
The date and time of giving up ownership on the product.
-
#type_of_good ⇒ Object
The product that this structured value is referring to.
-
#type_of_good=(value) ⇒ Object
The product that this structured value is referring to.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/schema_org/mixins/ownership_info.rb', line 11 def self.schema_property_definitions { acquired_from: { schema_name: "acquiredFrom", schema_url: "https://schema.org/acquiredFrom", comment_lines: ["The organization or person from which the product was acquired."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, owned_from: { schema_name: "ownedFrom", schema_url: "https://schema.org/ownedFrom", comment_lines: ["The date and time of obtaining the product."].freeze, ranges: ["DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, owned_through: { schema_name: "ownedThrough", schema_url: "https://schema.org/ownedThrough", comment_lines: ["The date and time of giving up ownership on the product."].freeze, ranges: ["DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, type_of_good: { schema_name: "typeOfGood", schema_url: "https://schema.org/typeOfGood", comment_lines: ["The product that this structured value is referring to."].freeze, ranges: ["Product", "Service"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#acquired_from ⇒ Object
The organization or person from which the product was acquired.
57 58 59 |
# File 'lib/schema_org/mixins/ownership_info.rb', line 57 def acquired_from read_property(:acquired_from) end |
#acquired_from=(value) ⇒ Object
The organization or person from which the product was acquired.
62 63 64 |
# File 'lib/schema_org/mixins/ownership_info.rb', line 62 def acquired_from=(value) write_property(:acquired_from, value) end |
#owned_from ⇒ Object
The date and time of obtaining the product.
67 68 69 |
# File 'lib/schema_org/mixins/ownership_info.rb', line 67 def owned_from read_property(:owned_from) end |
#owned_from=(value) ⇒ Object
The date and time of obtaining the product.
72 73 74 |
# File 'lib/schema_org/mixins/ownership_info.rb', line 72 def owned_from=(value) write_property(:owned_from, value) end |
#owned_through ⇒ Object
The date and time of giving up ownership on the product.
77 78 79 |
# File 'lib/schema_org/mixins/ownership_info.rb', line 77 def owned_through read_property(:owned_through) end |
#owned_through=(value) ⇒ Object
The date and time of giving up ownership on the product.
82 83 84 |
# File 'lib/schema_org/mixins/ownership_info.rb', line 82 def owned_through=(value) write_property(:owned_through, value) end |
#type_of_good ⇒ Object
The product that this structured value is referring to.
87 88 89 |
# File 'lib/schema_org/mixins/ownership_info.rb', line 87 def type_of_good read_property(:type_of_good) end |
#type_of_good=(value) ⇒ Object
The product that this structured value is referring to.
92 93 94 |
# File 'lib/schema_org/mixins/ownership_info.rb', line 92 def type_of_good=(value) write_property(:type_of_good, value) end |