Module: SchemaOrg::Mixins::Permit
- Includes:
- Intangible
- Included in:
- GovernmentPermit, Permit
- Defined in:
- lib/schema_org/mixins/permit.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#issued_by ⇒ Object
The organization issuing the item, for example a [[Permit]], [[Ticket]], or [[Certification]].
-
#issued_by=(value) ⇒ Object
The organization issuing the item, for example a [[Permit]], [[Ticket]], or [[Certification]].
-
#issued_through ⇒ Object
The service through which the permit was granted.
-
#issued_through=(value) ⇒ Object
The service through which the permit was granted.
-
#permit_audience ⇒ Object
The target audience for this permit.
-
#permit_audience=(value) ⇒ Object
The target audience for this permit.
-
#valid_for ⇒ Object
The duration of validity of a permit or similar thing.
-
#valid_for=(value) ⇒ Object
The duration of validity of a permit or similar thing.
-
#valid_from ⇒ Object
The date when the item becomes valid.
-
#valid_from=(value) ⇒ Object
The date when the item becomes valid.
-
#valid_in ⇒ Object
The geographic area where the item is valid.
-
#valid_in=(value) ⇒ Object
The geographic area where the item is valid.
-
#valid_until ⇒ Object
The date when the item is no longer valid.
-
#valid_until=(value) ⇒ Object
The date when the item is no longer valid.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/schema_org/mixins/permit.rb', line 11 def self.schema_property_definitions { issued_by: { schema_name: "issuedBy", schema_url: "https://schema.org/issuedBy", comment_lines: ["The organization issuing the item, for example a [[Permit]], [[Ticket]], or [[Certification]]."].freeze, ranges: ["Organization"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, issued_through: { schema_name: "issuedThrough", schema_url: "https://schema.org/issuedThrough", comment_lines: ["The service through which the permit was granted."].freeze, ranges: ["Service"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, permit_audience: { schema_name: "permitAudience", schema_url: "https://schema.org/permitAudience", comment_lines: ["The target audience for this permit."].freeze, ranges: ["Audience"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, valid_for: { schema_name: "validFor", schema_url: "https://schema.org/validFor", comment_lines: ["The duration of validity of a permit or similar thing."].freeze, ranges: ["Duration"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, valid_from: { schema_name: "validFrom", schema_url: "https://schema.org/validFrom", comment_lines: ["The date when the item becomes valid."].freeze, ranges: ["Date", "DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, valid_in: { schema_name: "validIn", schema_url: "https://schema.org/validIn", comment_lines: ["The geographic area where the item is valid. Applies for example to a [[Permit]], a [[Certification]], or an [[EducationalOccupationalCredential]]."].freeze, ranges: ["AdministrativeArea"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, valid_until: { schema_name: "validUntil", schema_url: "https://schema.org/validUntil", comment_lines: ["The date when the item is no longer valid."].freeze, ranges: ["Date"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#issued_by ⇒ Object
The organization issuing the item, for example a [[Permit]], [[Ticket]], or [[Certification]].
87 88 89 |
# File 'lib/schema_org/mixins/permit.rb', line 87 def issued_by read_property(:issued_by) end |
#issued_by=(value) ⇒ Object
The organization issuing the item, for example a [[Permit]], [[Ticket]], or [[Certification]].
92 93 94 |
# File 'lib/schema_org/mixins/permit.rb', line 92 def issued_by=(value) write_property(:issued_by, value) end |
#issued_through ⇒ Object
The service through which the permit was granted.
97 98 99 |
# File 'lib/schema_org/mixins/permit.rb', line 97 def issued_through read_property(:issued_through) end |
#issued_through=(value) ⇒ Object
The service through which the permit was granted.
102 103 104 |
# File 'lib/schema_org/mixins/permit.rb', line 102 def issued_through=(value) write_property(:issued_through, value) end |
#permit_audience ⇒ Object
The target audience for this permit.
107 108 109 |
# File 'lib/schema_org/mixins/permit.rb', line 107 def permit_audience read_property(:permit_audience) end |
#permit_audience=(value) ⇒ Object
The target audience for this permit.
112 113 114 |
# File 'lib/schema_org/mixins/permit.rb', line 112 def permit_audience=(value) write_property(:permit_audience, value) end |
#valid_for ⇒ Object
The duration of validity of a permit or similar thing.
117 118 119 |
# File 'lib/schema_org/mixins/permit.rb', line 117 def valid_for read_property(:valid_for) end |
#valid_for=(value) ⇒ Object
The duration of validity of a permit or similar thing.
122 123 124 |
# File 'lib/schema_org/mixins/permit.rb', line 122 def valid_for=(value) write_property(:valid_for, value) end |
#valid_from ⇒ Object
The date when the item becomes valid.
127 128 129 |
# File 'lib/schema_org/mixins/permit.rb', line 127 def valid_from read_property(:valid_from) end |
#valid_from=(value) ⇒ Object
The date when the item becomes valid.
132 133 134 |
# File 'lib/schema_org/mixins/permit.rb', line 132 def valid_from=(value) write_property(:valid_from, value) end |
#valid_in ⇒ Object
The geographic area where the item is valid. Applies for example to a [[Permit]], a [[Certification]], or an [[EducationalOccupationalCredential]].
137 138 139 |
# File 'lib/schema_org/mixins/permit.rb', line 137 def valid_in read_property(:valid_in) end |
#valid_in=(value) ⇒ Object
The geographic area where the item is valid. Applies for example to a [[Permit]], a [[Certification]], or an [[EducationalOccupationalCredential]].
142 143 144 |
# File 'lib/schema_org/mixins/permit.rb', line 142 def valid_in=(value) write_property(:valid_in, value) end |
#valid_until ⇒ Object
The date when the item is no longer valid.
147 148 149 |
# File 'lib/schema_org/mixins/permit.rb', line 147 def valid_until read_property(:valid_until) end |
#valid_until=(value) ⇒ Object
The date when the item is no longer valid.
152 153 154 |
# File 'lib/schema_org/mixins/permit.rb', line 152 def valid_until=(value) write_property(:valid_until, value) end |