Module: SchemaOrg::Mixins::Physician
- Includes:
- MedicalBusiness, MedicalOrganization
- Included in:
- IndividualPhysician, PhysiciansOffice, Physician
- Defined in:
- lib/schema_org/mixins/physician.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#available_service ⇒ Object
A medical service available from this provider.
-
#available_service=(value) ⇒ Object
A medical service available from this provider.
-
#hospital_affiliation ⇒ Object
A hospital with which the physician or office is affiliated.
-
#hospital_affiliation=(value) ⇒ Object
A hospital with which the physician or office is affiliated.
-
#medical_specialty ⇒ Object
A medical specialty of the provider.
-
#medical_specialty=(value) ⇒ Object
A medical specialty of the provider.
-
#occupational_category ⇒ Object
A category describing the job, preferably using a term from a taxonomy such as BLS O*NET-SOC, ISCO-08 or similar, with the property repeated for each applicable value.
-
#occupational_category=(value) ⇒ Object
A category describing the job, preferably using a term from a taxonomy such as BLS O*NET-SOC, ISCO-08 or similar, with the property repeated for each applicable value.
-
#us_npi ⇒ Object
A National Provider Identifier (NPI) is a unique 10-digit identification number issued to health care providers in the United States by the Centers for Medicare and Medicaid Services.
-
#us_npi=(value) ⇒ Object
A National Provider Identifier (NPI) is a unique 10-digit identification number issued to health care providers in the United States by the Centers for Medicare and Medicaid Services.
Methods included from MedicalOrganization
#health_plan_network_id, #health_plan_network_id=, #is_accepting_new_patients, #is_accepting_new_patients=
Methods included from Organization
#accepted_payment_method, #accepted_payment_method=, #actionable_feedback_policy, #actionable_feedback_policy=, #address, #address=, #agent_interaction_statistic, #agent_interaction_statistic=, #aggregate_rating, #aggregate_rating=, #alumni, #alumni=, #area_served, #area_served=, #award, #award=, #awards, #awards=, #brand, #brand=, #company_registration, #company_registration=, #contact_point, #contact_point=, #contact_points, #contact_points=, #corrections_policy, #corrections_policy=, #department, #department=, #dissolution_date, #dissolution_date=, #diversity_policy, #diversity_policy=, #diversity_staffing_report, #diversity_staffing_report=, #duns, #duns=, #email, #email=, #employee, #employee=, #employees, #employees=, #ethics_policy, #ethics_policy=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #founder, #founder=, #founders, #founders=, #founding_date, #founding_date=, #founding_location, #founding_location=, #funder, #funder=, #funding, #funding=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_credential, #has_credential=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_member_program, #has_member_program=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_offer_catalog, #has_offer_catalog=, #has_pos, #has_pos=, #has_product_return_policy, #has_product_return_policy=, #has_shipping_service, #has_shipping_service=, #interaction_statistic, #interaction_statistic=, #isic_v4, #isic_v4=, #iso6523_code, #iso6523_code=, #keywords, #keywords=, #knows_about, #knows_about=, #knows_language, #knows_language=, #legal_address, #legal_address=, #legal_name, #legal_name=, #legal_representative, #legal_representative=, #lei_code, #lei_code=, #location, #location=, #logo, #logo=, #makes_offer, #makes_offer=, #member, #member=, #member_of, #member_of=, #members, #members=, #naics, #naics=, #nonprofit_status, #nonprofit_status=, #number_of_employees, #number_of_employees=, #ownership_funding_info, #ownership_funding_info=, #owns, #owns=, #parent_organization, #parent_organization=, #publishing_principles, #publishing_principles=, #review, #review=, #reviews, #reviews=, #seeks, #seeks=, #service_area, #service_area=, #skills, #skills=, #slogan, #slogan=, #sponsor, #sponsor=, #sub_organization, #sub_organization=, #tax_id, #tax_id=, #telephone, #telephone=, #unnamed_sources_policy, #unnamed_sources_policy=, #vat_id, #vat_id=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Methods included from LocalBusiness
#branch_of, #branch_of=, #currencies_accepted, #currencies_accepted=, #floor_level, #floor_level=, #opening_hours, #opening_hours=, #payment_accepted, #payment_accepted=, #price_range, #price_range=
Methods included from Place
#additional_property, #additional_property=, #address, #address=, #aggregate_rating, #aggregate_rating=, #amenity_feature, #amenity_feature=, #branch_code, #branch_code=, #contained_in, #contained_in=, #contained_in_place, #contained_in_place=, #contains_place, #contains_place=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #geo, #geo=, #geo_contains, #geo_contains=, #geo_covered_by, #geo_covered_by=, #geo_covers, #geo_covers=, #geo_crosses, #geo_crosses=, #geo_disjoint, #geo_disjoint=, #geo_equals, #geo_equals=, #geo_intersects, #geo_intersects=, #geo_overlaps, #geo_overlaps=, #geo_touches, #geo_touches=, #geo_within, #geo_within=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_drive_through_service, #has_drive_through_service=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_map, #has_map=, #is_accessible_for_free, #is_accessible_for_free=, #isic_v4, #isic_v4=, #keywords, #keywords=, #latitude, #latitude=, #logo, #logo=, #longitude, #longitude=, #map, #map=, #maps, #maps=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #opening_hours_specification, #opening_hours_specification=, #photo, #photo=, #photos, #photos=, #public_access, #public_access=, #review, #review=, #reviews, #reviews=, #slogan, #slogan=, #smoking_allowed, #smoking_allowed=, #special_opening_hours_specification, #special_opening_hours_specification=, #telephone, #telephone=, #tour_booking_page, #tour_booking_page=
Class Method Details
.schema_property_definitions ⇒ Object
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/schema_org/mixins/physician.rb', line 12 def self.schema_property_definitions { available_service: { schema_name: "availableService", schema_url: "https://schema.org/availableService", comment_lines: ["A medical service available from this provider."].freeze, ranges: ["MedicalProcedure", "MedicalTest", "MedicalTherapy"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, hospital_affiliation: { schema_name: "hospitalAffiliation", schema_url: "https://schema.org/hospitalAffiliation", comment_lines: ["A hospital with which the physician or office is affiliated."].freeze, ranges: ["Hospital"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, medical_specialty: { schema_name: "medicalSpecialty", schema_url: "https://schema.org/medicalSpecialty", comment_lines: ["A medical specialty of the provider."].freeze, ranges: ["MedicalSpecialty"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, occupational_category: { schema_name: "occupationalCategory", schema_url: "https://schema.org/occupationalCategory", comment_lines: ["A category describing the job, preferably using a term from a taxonomy such as [BLS O*NET-SOC](http://www.onetcenter.org/taxonomy.html), [ISCO-08](https://www.ilo.org/public/english/bureau/stat/isco/isco08/) or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided.\\n", "Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC."].freeze, ranges: ["CategoryCode", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, us_npi: { schema_name: "usNPI", schema_url: "https://schema.org/usNPI", comment_lines: ["A <a href=\"https://en.wikipedia.org/wiki/National_Provider_Identifier\">National Provider Identifier</a> (NPI)", " is a unique 10-digit identification number issued to health care providers in the United States by the Centers for Medicare and Medicaid Services."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#available_service ⇒ Object
A medical service available from this provider.
68 69 70 |
# File 'lib/schema_org/mixins/physician.rb', line 68 def available_service read_property(:available_service) end |
#available_service=(value) ⇒ Object
A medical service available from this provider.
73 74 75 |
# File 'lib/schema_org/mixins/physician.rb', line 73 def available_service=(value) write_property(:available_service, value) end |
#hospital_affiliation ⇒ Object
A hospital with which the physician or office is affiliated.
78 79 80 |
# File 'lib/schema_org/mixins/physician.rb', line 78 def hospital_affiliation read_property(:hospital_affiliation) end |
#hospital_affiliation=(value) ⇒ Object
A hospital with which the physician or office is affiliated.
83 84 85 |
# File 'lib/schema_org/mixins/physician.rb', line 83 def hospital_affiliation=(value) write_property(:hospital_affiliation, value) end |
#medical_specialty ⇒ Object
A medical specialty of the provider.
88 89 90 |
# File 'lib/schema_org/mixins/physician.rb', line 88 def medical_specialty read_property(:medical_specialty) end |
#medical_specialty=(value) ⇒ Object
A medical specialty of the provider.
93 94 95 |
# File 'lib/schema_org/mixins/physician.rb', line 93 def medical_specialty=(value) write_property(:medical_specialty, value) end |
#occupational_category ⇒ Object
A category describing the job, preferably using a term from a taxonomy such as BLS O*NET-SOC, ISCO-08 or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided.\n Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC.
99 100 101 |
# File 'lib/schema_org/mixins/physician.rb', line 99 def occupational_category read_property(:occupational_category) end |
#occupational_category=(value) ⇒ Object
A category describing the job, preferably using a term from a taxonomy such as BLS O*NET-SOC, ISCO-08 or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided.\n Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC.
105 106 107 |
# File 'lib/schema_org/mixins/physician.rb', line 105 def occupational_category=(value) write_property(:occupational_category, value) end |
#us_npi ⇒ Object
A National Provider Identifier (NPI) is a unique 10-digit identification number issued to health care providers in the United States by the Centers for Medicare and Medicaid Services.
111 112 113 |
# File 'lib/schema_org/mixins/physician.rb', line 111 def us_npi read_property(:us_npi) end |
#us_npi=(value) ⇒ Object
A National Provider Identifier (NPI) is a unique 10-digit identification number issued to health care providers in the United States by the Centers for Medicare and Medicaid Services.
117 118 119 |
# File 'lib/schema_org/mixins/physician.rb', line 117 def us_npi=(value) write_property(:us_npi, value) end |