Module: SchemaOrg::Mixins::PronounceableText
- Includes:
- Text
- Included in:
- PronounceableText
- Defined in:
- lib/schema_org/mixins/pronounceable_text.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#in_language ⇒ Object
The language of the content or performance or used in an action.
-
#in_language=(value) ⇒ Object
The language of the content or performance or used in an action.
-
#phonetic_text ⇒ Object
Representation of a text [[textValue]] using the specified [[speechToTextMarkup]].
-
#phonetic_text=(value) ⇒ Object
Representation of a text [[textValue]] using the specified [[speechToTextMarkup]].
-
#speech_to_text_markup ⇒ Object
Form of markup used.
-
#speech_to_text_markup=(value) ⇒ Object
Form of markup used.
-
#text_value ⇒ Object
Text value being annotated.
-
#text_value=(value) ⇒ Object
Text value being annotated.
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/schema_org/mixins/pronounceable_text.rb', line 11 def self.schema_property_definitions { in_language: { schema_name: "inLanguage", schema_url: "https://schema.org/inLanguage", comment_lines: ["The language of the content or performance or used in an action. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[availableLanguage]]."].freeze, ranges: ["Language", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["language"].freeze }.freeze, phonetic_text: { schema_name: "phoneticText", schema_url: "https://schema.org/phoneticText", comment_lines: ["Representation of a text [[textValue]] using the specified [[speechToTextMarkup]]. For example the city name of Houston in IPA: /ˈhjuːstən/."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, speech_to_text_markup: { schema_name: "speechToTextMarkup", schema_url: "https://schema.org/speechToTextMarkup", comment_lines: ["Form of markup used. eg. [SSML](https://www.w3.org/TR/speech-synthesis11) or [IPA](https://www.wikidata.org/wiki/Property:P898)."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, text_value: { schema_name: "textValue", schema_url: "https://schema.org/textValue", comment_lines: ["Text value being annotated."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#in_language ⇒ Object
The language of the content or performance or used in an action. Please use one of the language codes from the IETF BCP 47 standard. See also [[availableLanguage]].
Supersedes language.
58 59 60 |
# File 'lib/schema_org/mixins/pronounceable_text.rb', line 58 def in_language read_property(:in_language) end |
#in_language=(value) ⇒ Object
The language of the content or performance or used in an action. Please use one of the language codes from the IETF BCP 47 standard. See also [[availableLanguage]].
Supersedes language.
64 65 66 |
# File 'lib/schema_org/mixins/pronounceable_text.rb', line 64 def in_language=(value) write_property(:in_language, value) end |
#phonetic_text ⇒ Object
Representation of a text [[textValue]] using the specified [[speechToTextMarkup]]. For example the city name of Houston in IPA: /ˈhjuːstən/.
69 70 71 |
# File 'lib/schema_org/mixins/pronounceable_text.rb', line 69 def phonetic_text read_property(:phonetic_text) end |
#phonetic_text=(value) ⇒ Object
Representation of a text [[textValue]] using the specified [[speechToTextMarkup]]. For example the city name of Houston in IPA: /ˈhjuːstən/.
74 75 76 |
# File 'lib/schema_org/mixins/pronounceable_text.rb', line 74 def phonetic_text=(value) write_property(:phonetic_text, value) end |
#speech_to_text_markup ⇒ Object
79 80 81 |
# File 'lib/schema_org/mixins/pronounceable_text.rb', line 79 def speech_to_text_markup read_property(:speech_to_text_markup) end |
#speech_to_text_markup=(value) ⇒ Object
84 85 86 |
# File 'lib/schema_org/mixins/pronounceable_text.rb', line 84 def speech_to_text_markup=(value) write_property(:speech_to_text_markup, value) end |
#text_value ⇒ Object
Text value being annotated.
89 90 91 |
# File 'lib/schema_org/mixins/pronounceable_text.rb', line 89 def text_value read_property(:text_value) end |
#text_value=(value) ⇒ Object
Text value being annotated.
94 95 96 |
# File 'lib/schema_org/mixins/pronounceable_text.rb', line 94 def text_value=(value) write_property(:text_value, value) end |