Module: SchemaOrg::Mixins::PropertyValue
- Includes:
- StructuredValue
- Included in:
- LocationFeatureSpecification, PropertyValue
- Defined in:
- lib/schema_org/mixins/property_value.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#max_value ⇒ Object
The upper value of some characteristic or property.
-
#max_value=(value) ⇒ Object
The upper value of some characteristic or property.
-
#measurement_method ⇒ Object
A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].
-
#measurement_method=(value) ⇒ Object
A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].
-
#measurement_technique ⇒ Object
A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]).
-
#measurement_technique=(value) ⇒ Object
A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]).
-
#min_value ⇒ Object
The lower value of some characteristic or property.
-
#min_value=(value) ⇒ Object
The lower value of some characteristic or property.
-
#property_id ⇒ Object
A commonly used identifier for the characteristic represented by the property, e.g.
-
#property_id=(value) ⇒ Object
A commonly used identifier for the characteristic represented by the property, e.g.
-
#unit_code ⇒ Object
The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL.
-
#unit_code=(value) ⇒ Object
The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL.
-
#unit_text ⇒ Object
A string or text indicating the unit of measurement.
-
#unit_text=(value) ⇒ Object
A string or text indicating the unit of measurement.
-
#value ⇒ Object
The value of a [[QuantitativeValue]] (including [[Observation]]) or property value node.\n\n* For [[QuantitativeValue]] and [[MonetaryAmount]], the recommended type for values is 'Number'.\n* For [[PropertyValue]], it can be 'Text', 'Number', 'Boolean', or 'StructuredValue'.\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point.
-
#value=(value) ⇒ Object
The value of a [[QuantitativeValue]] (including [[Observation]]) or property value node.\n\n* For [[QuantitativeValue]] and [[MonetaryAmount]], the recommended type for values is 'Number'.\n* For [[PropertyValue]], it can be 'Text', 'Number', 'Boolean', or 'StructuredValue'.\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point.
-
#value_reference ⇒ Object
A secondary value that provides additional information on the original value, e.g.
-
#value_reference=(value) ⇒ Object
A secondary value that provides additional information on the original value, e.g.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/schema_org/mixins/property_value.rb', line 11 def self.schema_property_definitions { max_value: { schema_name: "maxValue", schema_url: "https://schema.org/maxValue", comment_lines: ["The upper value of some characteristic or property."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, measurement_method: { schema_name: "measurementMethod", schema_url: "https://schema.org/measurementMethod", comment_lines: ["A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]]."].freeze, ranges: ["DefinedTerm", "MeasurementMethodEnum", "Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, measurement_technique: { schema_name: "measurementTechnique", schema_url: "https://schema.org/measurementTechnique", comment_lines: ["A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]). Often but not necessarily each [[variableMeasured]] will have an explicit representation as (or mapping to) an property such as those defined in Schema.org, or other RDF vocabularies and \"knowledge graphs\". In that case the subproperty of [[variableMeasured]] called [[measuredProperty]] is applicable.", "", "The [[measurementTechnique]] property helps when extra clarification is needed about how a [[measuredProperty]] was measured. This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but can often serve as a high level summary for dataset discovery.", "", "For example, if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]] could be: \"mass spectrometry\" or \"nmr spectroscopy\" or \"colorimetry\" or \"immunofluorescence\". If the [[variableMeasured]] is \"depression rating\", the [[measurementTechnique]] could be \"Zung Scale\" or \"HAM-D\" or \"Beck Depression Inventory\".", "", "If there are several [[variableMeasured]] properties recorded for some given data object, use a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]]. The value can also be from an enumeration, organized as a [[MeasurementMethodEnum]]."].freeze, ranges: ["DefinedTerm", "MeasurementMethodEnum", "Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, min_value: { schema_name: "minValue", schema_url: "https://schema.org/minValue", comment_lines: ["The lower value of some characteristic or property."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, property_id: { schema_name: "propertyID", schema_url: "https://schema.org/propertyID", comment_lines: ["A commonly used identifier for the characteristic represented by the property, e.g. a manufacturer or a standard code for a property. propertyID can be", "(1) a prefixed string, mainly meant to be used with standards for product properties; (2) a site-specific, non-prefixed string (e.g. the primary key of the property or the vendor-specific ID of the property), or (3)", "a URL indicating the type of the property, either pointing to an external vocabulary, or a Web resource that describes the property (e.g. a glossary entry).", "Standards bodies should promote a standard prefix for the identifiers of properties from their standards."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, unit_code: { schema_name: "unitCode", schema_url: "https://schema.org/unitCode", comment_lines: ["The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL. Other codes than the UN/CEFACT Common Code may be used with a prefix followed by a colon."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, unit_text: { schema_name: "unitText", schema_url: "https://schema.org/unitText", comment_lines: ["A string or text indicating the unit of measurement. Useful if you cannot provide a standard unit code for", "<a href='unitCode'>unitCode</a>."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, value: { schema_name: "value", schema_url: "https://schema.org/value", comment_lines: ["The value of a [[QuantitativeValue]] (including [[Observation]]) or property value node.\\n\\n* For [[QuantitativeValue]] and [[MonetaryAmount]], the recommended type for values is 'Number'.\\n* For [[PropertyValue]], it can be 'Text', 'Number', 'Boolean', or 'StructuredValue'.\\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator."].freeze, ranges: ["Boolean", "Number", "StructuredValue", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, value_reference: { schema_name: "valueReference", schema_url: "https://schema.org/valueReference", comment_lines: ["A secondary value that provides additional information on the original value, e.g. a reference temperature or a type of measurement."].freeze, ranges: ["DefinedTerm", "Enumeration", "MeasurementTypeEnumeration", "PropertyValue", "QualitativeValue", "QuantitativeValue", "StructuredValue", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#max_value ⇒ Object
The upper value of some characteristic or property.
107 108 109 |
# File 'lib/schema_org/mixins/property_value.rb', line 107 def max_value read_property(:max_value) end |
#max_value=(value) ⇒ Object
The upper value of some characteristic or property.
112 113 114 |
# File 'lib/schema_org/mixins/property_value.rb', line 112 def max_value=(value) write_property(:max_value, value) end |
#measurement_method ⇒ Object
A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].
117 118 119 |
# File 'lib/schema_org/mixins/property_value.rb', line 117 def measurement_method read_property(:measurement_method) end |
#measurement_method=(value) ⇒ Object
A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].
122 123 124 |
# File 'lib/schema_org/mixins/property_value.rb', line 122 def measurement_method=(value) write_property(:measurement_method, value) end |
#measurement_technique ⇒ Object
A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]). Often but not necessarily each [[variableMeasured]] will have an explicit representation as (or mapping to) an property such as those defined in Schema.org, or other RDF vocabularies and "knowledge graphs". In that case the subproperty of [[variableMeasured]] called [[measuredProperty]] is applicable.
The [[measurementTechnique]] property helps when extra clarification is needed about how a [[measuredProperty]] was measured. This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but can often serve as a high level summary for dataset discovery.
For example, if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]] could be: "mass spectrometry" or "nmr spectroscopy" or "colorimetry" or "immunofluorescence". If the [[variableMeasured]] is "depression rating", the [[measurementTechnique]] could be "Zung Scale" or "HAM-D" or "Beck Depression Inventory".
If there are several [[variableMeasured]] properties recorded for some given data object, use a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]]. The value can also be from an enumeration, organized as a [[MeasurementMethodEnum]].
133 134 135 |
# File 'lib/schema_org/mixins/property_value.rb', line 133 def measurement_technique read_property(:measurement_technique) end |
#measurement_technique=(value) ⇒ Object
A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]). Often but not necessarily each [[variableMeasured]] will have an explicit representation as (or mapping to) an property such as those defined in Schema.org, or other RDF vocabularies and "knowledge graphs". In that case the subproperty of [[variableMeasured]] called [[measuredProperty]] is applicable.
The [[measurementTechnique]] property helps when extra clarification is needed about how a [[measuredProperty]] was measured. This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but can often serve as a high level summary for dataset discovery.
For example, if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]] could be: "mass spectrometry" or "nmr spectroscopy" or "colorimetry" or "immunofluorescence". If the [[variableMeasured]] is "depression rating", the [[measurementTechnique]] could be "Zung Scale" or "HAM-D" or "Beck Depression Inventory".
If there are several [[variableMeasured]] properties recorded for some given data object, use a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]]. The value can also be from an enumeration, organized as a [[MeasurementMethodEnum]].
144 145 146 |
# File 'lib/schema_org/mixins/property_value.rb', line 144 def measurement_technique=(value) write_property(:measurement_technique, value) end |
#min_value ⇒ Object
The lower value of some characteristic or property.
149 150 151 |
# File 'lib/schema_org/mixins/property_value.rb', line 149 def min_value read_property(:min_value) end |
#min_value=(value) ⇒ Object
The lower value of some characteristic or property.
154 155 156 |
# File 'lib/schema_org/mixins/property_value.rb', line 154 def min_value=(value) write_property(:min_value, value) end |
#property_id ⇒ Object
A commonly used identifier for the characteristic represented by the property, e.g. a manufacturer or a standard code for a property. propertyID can be (1) a prefixed string, mainly meant to be used with standards for product properties; (2) a site-specific, non-prefixed string (e.g. the primary key of the property or the vendor-specific ID of the property), or (3) a URL indicating the type of the property, either pointing to an external vocabulary, or a Web resource that describes the property (e.g. a glossary entry). Standards bodies should promote a standard prefix for the identifiers of properties from their standards.
162 163 164 |
# File 'lib/schema_org/mixins/property_value.rb', line 162 def property_id read_property(:property_id) end |
#property_id=(value) ⇒ Object
A commonly used identifier for the characteristic represented by the property, e.g. a manufacturer or a standard code for a property. propertyID can be (1) a prefixed string, mainly meant to be used with standards for product properties; (2) a site-specific, non-prefixed string (e.g. the primary key of the property or the vendor-specific ID of the property), or (3) a URL indicating the type of the property, either pointing to an external vocabulary, or a Web resource that describes the property (e.g. a glossary entry). Standards bodies should promote a standard prefix for the identifiers of properties from their standards.
170 171 172 |
# File 'lib/schema_org/mixins/property_value.rb', line 170 def property_id=(value) write_property(:property_id, value) end |
#unit_code ⇒ Object
The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL. Other codes than the UN/CEFACT Common Code may be used with a prefix followed by a colon.
175 176 177 |
# File 'lib/schema_org/mixins/property_value.rb', line 175 def unit_code read_property(:unit_code) end |
#unit_code=(value) ⇒ Object
The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL. Other codes than the UN/CEFACT Common Code may be used with a prefix followed by a colon.
180 181 182 |
# File 'lib/schema_org/mixins/property_value.rb', line 180 def unit_code=(value) write_property(:unit_code, value) end |
#unit_text ⇒ Object
A string or text indicating the unit of measurement. Useful if you cannot provide a standard unit code for unitCode.
186 187 188 |
# File 'lib/schema_org/mixins/property_value.rb', line 186 def unit_text read_property(:unit_text) end |
#unit_text=(value) ⇒ Object
A string or text indicating the unit of measurement. Useful if you cannot provide a standard unit code for unitCode.
192 193 194 |
# File 'lib/schema_org/mixins/property_value.rb', line 192 def unit_text=(value) write_property(:unit_text, value) end |
#value ⇒ Object
The value of a [[QuantitativeValue]] (including [[Observation]]) or property value node.\n\n* For [[QuantitativeValue]] and [[MonetaryAmount]], the recommended type for values is 'Number'.\n* For [[PropertyValue]], it can be 'Text', 'Number', 'Boolean', or 'StructuredValue'.\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.
197 198 199 |
# File 'lib/schema_org/mixins/property_value.rb', line 197 def value read_property(:value) end |
#value=(value) ⇒ Object
The value of a [[QuantitativeValue]] (including [[Observation]]) or property value node.\n\n* For [[QuantitativeValue]] and [[MonetaryAmount]], the recommended type for values is 'Number'.\n* For [[PropertyValue]], it can be 'Text', 'Number', 'Boolean', or 'StructuredValue'.\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.
202 203 204 |
# File 'lib/schema_org/mixins/property_value.rb', line 202 def value=(value) write_property(:value, value) end |
#value_reference ⇒ Object
A secondary value that provides additional information on the original value, e.g. a reference temperature or a type of measurement.
207 208 209 |
# File 'lib/schema_org/mixins/property_value.rb', line 207 def value_reference read_property(:value_reference) end |
#value_reference=(value) ⇒ Object
A secondary value that provides additional information on the original value, e.g. a reference temperature or a type of measurement.
212 213 214 |
# File 'lib/schema_org/mixins/property_value.rb', line 212 def value_reference=(value) write_property(:value_reference, value) end |