Module: SchemaOrg::Mixins::PropertyValueSpecification
- Includes:
- Intangible
- Included in:
- PropertyValueSpecification
- Defined in:
- lib/schema_org/mixins/property_value_specification.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#default_value ⇒ Object
The default value of the input.
-
#default_value=(value) ⇒ Object
The default value of the input.
-
#max_value ⇒ Object
The upper value of some characteristic or property.
-
#max_value=(value) ⇒ Object
The upper value of some characteristic or property.
-
#min_value ⇒ Object
The lower value of some characteristic or property.
-
#min_value=(value) ⇒ Object
The lower value of some characteristic or property.
-
#multiple_values ⇒ Object
Whether multiple values are allowed for the property.
-
#multiple_values=(value) ⇒ Object
Whether multiple values are allowed for the property.
-
#readonly_value ⇒ Object
Whether or not a property is mutable.
-
#readonly_value=(value) ⇒ Object
Whether or not a property is mutable.
-
#step_value ⇒ Object
The stepValue attribute indicates the granularity that is expected (and required) of the value in a PropertyValueSpecification.
-
#step_value=(value) ⇒ Object
The stepValue attribute indicates the granularity that is expected (and required) of the value in a PropertyValueSpecification.
-
#value_max_length ⇒ Object
Specifies the allowed range for number of characters in a literal value.
-
#value_max_length=(value) ⇒ Object
Specifies the allowed range for number of characters in a literal value.
-
#value_min_length ⇒ Object
Specifies the minimum allowed range for number of characters in a literal value.
-
#value_min_length=(value) ⇒ Object
Specifies the minimum allowed range for number of characters in a literal value.
-
#value_name ⇒ Object
Indicates the name of the PropertyValueSpecification to be used in URL templates and form encoding in a manner analogous to HTML's input@name.
-
#value_name=(value) ⇒ Object
Indicates the name of the PropertyValueSpecification to be used in URL templates and form encoding in a manner analogous to HTML's input@name.
-
#value_pattern ⇒ Object
Specifies a regular expression for testing literal values according to the HTML spec.
-
#value_pattern=(value) ⇒ Object
Specifies a regular expression for testing literal values according to the HTML spec.
-
#value_required ⇒ Object
Whether the property must be filled in to complete the action.
-
#value_required=(value) ⇒ Object
Whether the property must be filled in to complete the action.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 11 def self.schema_property_definitions { default_value: { schema_name: "defaultValue", schema_url: "https://schema.org/defaultValue", comment_lines: ["The default value of the input. For properties that expect a literal, the default is a literal value, for properties that expect an object, it's an ID reference to one of the current values."].freeze, ranges: ["Text", "Thing"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, max_value: { schema_name: "maxValue", schema_url: "https://schema.org/maxValue", comment_lines: ["The upper value of some characteristic or property."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, min_value: { schema_name: "minValue", schema_url: "https://schema.org/minValue", comment_lines: ["The lower value of some characteristic or property."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, multiple_values: { schema_name: "multipleValues", schema_url: "https://schema.org/multipleValues", comment_lines: ["Whether multiple values are allowed for the property. Default is false."].freeze, ranges: ["Boolean"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, readonly_value: { schema_name: "readonlyValue", schema_url: "https://schema.org/readonlyValue", comment_lines: ["Whether or not a property is mutable. Default is false. Specifying this for a property that also has a value makes it act similar to a \"hidden\" input in an HTML form."].freeze, ranges: ["Boolean"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, step_value: { schema_name: "stepValue", schema_url: "https://schema.org/stepValue", comment_lines: ["The stepValue attribute indicates the granularity that is expected (and required) of the value in a PropertyValueSpecification."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, value_max_length: { schema_name: "valueMaxLength", schema_url: "https://schema.org/valueMaxLength", comment_lines: ["Specifies the allowed range for number of characters in a literal value."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, value_min_length: { schema_name: "valueMinLength", schema_url: "https://schema.org/valueMinLength", comment_lines: ["Specifies the minimum allowed range for number of characters in a literal value."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, value_name: { schema_name: "valueName", schema_url: "https://schema.org/valueName", comment_lines: ["Indicates the name of the PropertyValueSpecification to be used in URL templates and form encoding in a manner analogous to HTML's input@name."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, value_pattern: { schema_name: "valuePattern", schema_url: "https://schema.org/valuePattern", comment_lines: ["Specifies a regular expression for testing literal values according to the HTML spec."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, value_required: { schema_name: "valueRequired", schema_url: "https://schema.org/valueRequired", comment_lines: ["Whether the property must be filled in to complete the action. Default is false."].freeze, ranges: ["Boolean"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#default_value ⇒ Object
The default value of the input. For properties that expect a literal, the default is a literal value, for properties that expect an object, it's an ID reference to one of the current values.
127 128 129 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 127 def default_value read_property(:default_value) end |
#default_value=(value) ⇒ Object
The default value of the input. For properties that expect a literal, the default is a literal value, for properties that expect an object, it's an ID reference to one of the current values.
132 133 134 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 132 def default_value=(value) write_property(:default_value, value) end |
#max_value ⇒ Object
The upper value of some characteristic or property.
137 138 139 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 137 def max_value read_property(:max_value) end |
#max_value=(value) ⇒ Object
The upper value of some characteristic or property.
142 143 144 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 142 def max_value=(value) write_property(:max_value, value) end |
#min_value ⇒ Object
The lower value of some characteristic or property.
147 148 149 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 147 def min_value read_property(:min_value) end |
#min_value=(value) ⇒ Object
The lower value of some characteristic or property.
152 153 154 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 152 def min_value=(value) write_property(:min_value, value) end |
#multiple_values ⇒ Object
Whether multiple values are allowed for the property. Default is false.
157 158 159 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 157 def multiple_values read_property(:multiple_values) end |
#multiple_values=(value) ⇒ Object
Whether multiple values are allowed for the property. Default is false.
162 163 164 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 162 def multiple_values=(value) write_property(:multiple_values, value) end |
#readonly_value ⇒ Object
Whether or not a property is mutable. Default is false. Specifying this for a property that also has a value makes it act similar to a "hidden" input in an HTML form.
167 168 169 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 167 def readonly_value read_property(:readonly_value) end |
#readonly_value=(value) ⇒ Object
Whether or not a property is mutable. Default is false. Specifying this for a property that also has a value makes it act similar to a "hidden" input in an HTML form.
172 173 174 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 172 def readonly_value=(value) write_property(:readonly_value, value) end |
#step_value ⇒ Object
The stepValue attribute indicates the granularity that is expected (and required) of the value in a PropertyValueSpecification.
177 178 179 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 177 def step_value read_property(:step_value) end |
#step_value=(value) ⇒ Object
The stepValue attribute indicates the granularity that is expected (and required) of the value in a PropertyValueSpecification.
182 183 184 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 182 def step_value=(value) write_property(:step_value, value) end |
#value_max_length ⇒ Object
Specifies the allowed range for number of characters in a literal value.
187 188 189 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 187 def value_max_length read_property(:value_max_length) end |
#value_max_length=(value) ⇒ Object
Specifies the allowed range for number of characters in a literal value.
192 193 194 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 192 def value_max_length=(value) write_property(:value_max_length, value) end |
#value_min_length ⇒ Object
Specifies the minimum allowed range for number of characters in a literal value.
197 198 199 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 197 def value_min_length read_property(:value_min_length) end |
#value_min_length=(value) ⇒ Object
Specifies the minimum allowed range for number of characters in a literal value.
202 203 204 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 202 def value_min_length=(value) write_property(:value_min_length, value) end |
#value_name ⇒ Object
Indicates the name of the PropertyValueSpecification to be used in URL templates and form encoding in a manner analogous to HTML's input@name.
207 208 209 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 207 def value_name read_property(:value_name) end |
#value_name=(value) ⇒ Object
Indicates the name of the PropertyValueSpecification to be used in URL templates and form encoding in a manner analogous to HTML's input@name.
212 213 214 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 212 def value_name=(value) write_property(:value_name, value) end |
#value_pattern ⇒ Object
Specifies a regular expression for testing literal values according to the HTML spec.
217 218 219 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 217 def value_pattern read_property(:value_pattern) end |
#value_pattern=(value) ⇒ Object
Specifies a regular expression for testing literal values according to the HTML spec.
222 223 224 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 222 def value_pattern=(value) write_property(:value_pattern, value) end |
#value_required ⇒ Object
Whether the property must be filled in to complete the action. Default is false.
227 228 229 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 227 def value_required read_property(:value_required) end |
#value_required=(value) ⇒ Object
Whether the property must be filled in to complete the action. Default is false.
232 233 234 |
# File 'lib/schema_org/mixins/property_value_specification.rb', line 232 def value_required=(value) write_property(:value_required, value) end |