Module: SchemaOrg::Mixins::Protein
Class Method Summary collapse
Instance Method Summary collapse
-
#has_bio_polymer_sequence ⇒ Object
A symbolic representation of a BioChemEntity.
-
#has_bio_polymer_sequence=(value) ⇒ Object
A symbolic representation of a BioChemEntity.
Methods included from BioChemEntity
#associated_disease, #associated_disease=, #bio_chem_interaction, #bio_chem_interaction=, #bio_chem_similarity, #bio_chem_similarity=, #biological_role, #biological_role=, #funding, #funding=, #has_bio_chem_entity_part, #has_bio_chem_entity_part=, #has_molecular_function, #has_molecular_function=, #has_representation, #has_representation=, #is_encoded_by_bio_chem_entity, #is_encoded_by_bio_chem_entity=, #is_involved_in_biological_process, #is_involved_in_biological_process=, #is_located_in_subcellular_location, #is_located_in_subcellular_location=, #is_part_of_bio_chem_entity, #is_part_of_bio_chem_entity=, #taxonomic_range, #taxonomic_range=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 |
# File 'lib/schema_org/mixins/protein.rb', line 11 def self.schema_property_definitions { has_bio_polymer_sequence: { schema_name: "hasBioPolymerSequence", schema_url: "https://schema.org/hasBioPolymerSequence", comment_lines: ["A symbolic representation of a BioChemEntity. For example, a nucleotide sequence of a Gene or an amino acid sequence of a Protein."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#has_bio_polymer_sequence ⇒ Object
A symbolic representation of a BioChemEntity. For example, a nucleotide sequence of a Gene or an amino acid sequence of a Protein.
27 28 29 |
# File 'lib/schema_org/mixins/protein.rb', line 27 def has_bio_polymer_sequence read_property(:has_bio_polymer_sequence) end |
#has_bio_polymer_sequence=(value) ⇒ Object
A symbolic representation of a BioChemEntity. For example, a nucleotide sequence of a Gene or an amino acid sequence of a Protein.
32 33 34 |
# File 'lib/schema_org/mixins/protein.rb', line 32 def has_bio_polymer_sequence=(value) write_property(:has_bio_polymer_sequence, value) end |