Module: SchemaOrg::Mixins::PublicationIssue
- Includes:
- CreativeWork
- Included in:
- ComicIssue, PublicationIssue
- Defined in:
- lib/schema_org/mixins/publication_issue.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#issue_number ⇒ Object
Identifies the issue of publication; for example, "iii" or "2".
-
#issue_number=(value) ⇒ Object
Identifies the issue of publication; for example, "iii" or "2".
-
#page_end ⇒ Object
The page on which the work ends; for example "138" or "xvi".
-
#page_end=(value) ⇒ Object
The page on which the work ends; for example "138" or "xvi".
-
#page_start ⇒ Object
The page on which the work starts; for example "135" or "xiii".
-
#page_start=(value) ⇒ Object
The page on which the work starts; for example "135" or "xiii".
-
#pagination ⇒ Object
Any description of pages that is not separated into pageStart and pageEnd; for example, "1-6, 9, 55" or "10-12, 46-49".
-
#pagination=(value) ⇒ Object
Any description of pages that is not separated into pageStart and pageEnd; for example, "1-6, 9, 55" or "10-12, 46-49".
Methods included from CreativeWork
#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/schema_org/mixins/publication_issue.rb', line 11 def self.schema_property_definitions { issue_number: { schema_name: "issueNumber", schema_url: "https://schema.org/issueNumber", comment_lines: ["Identifies the issue of publication; for example, \"iii\" or \"2\"."].freeze, ranges: ["Integer", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, page_end: { schema_name: "pageEnd", schema_url: "https://schema.org/pageEnd", comment_lines: ["The page on which the work ends; for example \"138\" or \"xvi\"."].freeze, ranges: ["Integer", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, page_start: { schema_name: "pageStart", schema_url: "https://schema.org/pageStart", comment_lines: ["The page on which the work starts; for example \"135\" or \"xiii\"."].freeze, ranges: ["Integer", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, pagination: { schema_name: "pagination", schema_url: "https://schema.org/pagination", comment_lines: ["Any description of pages that is not separated into pageStart and pageEnd; for example, \"1-6, 9, 55\" or \"10-12, 46-49\"."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#issue_number ⇒ Object
Identifies the issue of publication; for example, "iii" or "2".
57 58 59 |
# File 'lib/schema_org/mixins/publication_issue.rb', line 57 def issue_number read_property(:issue_number) end |
#issue_number=(value) ⇒ Object
Identifies the issue of publication; for example, "iii" or "2".
62 63 64 |
# File 'lib/schema_org/mixins/publication_issue.rb', line 62 def issue_number=(value) write_property(:issue_number, value) end |
#page_end ⇒ Object
The page on which the work ends; for example "138" or "xvi".
67 68 69 |
# File 'lib/schema_org/mixins/publication_issue.rb', line 67 def page_end read_property(:page_end) end |
#page_end=(value) ⇒ Object
The page on which the work ends; for example "138" or "xvi".
72 73 74 |
# File 'lib/schema_org/mixins/publication_issue.rb', line 72 def page_end=(value) write_property(:page_end, value) end |
#page_start ⇒ Object
The page on which the work starts; for example "135" or "xiii".
77 78 79 |
# File 'lib/schema_org/mixins/publication_issue.rb', line 77 def page_start read_property(:page_start) end |
#page_start=(value) ⇒ Object
The page on which the work starts; for example "135" or "xiii".
82 83 84 |
# File 'lib/schema_org/mixins/publication_issue.rb', line 82 def page_start=(value) write_property(:page_start, value) end |
#pagination ⇒ Object
Any description of pages that is not separated into pageStart and pageEnd; for example, "1-6, 9, 55" or "10-12, 46-49".
87 88 89 |
# File 'lib/schema_org/mixins/publication_issue.rb', line 87 def pagination read_property(:pagination) end |
#pagination=(value) ⇒ Object
Any description of pages that is not separated into pageStart and pageEnd; for example, "1-6, 9, 55" or "10-12, 46-49".
92 93 94 |
# File 'lib/schema_org/mixins/publication_issue.rb', line 92 def pagination=(value) write_property(:pagination, value) end |