Module: SchemaOrg::Mixins::QualitativeValue
- Includes:
- Enumeration
- Included in:
- BedType, DriveWheelConfigurationValue, SizeSpecification, SteeringPositionValue, QualitativeValue
- Defined in:
- lib/schema_org/mixins/qualitative_value.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#additional_property ⇒ Object
A property-value pair representing an additional characteristic of the entity, e.g.
-
#additional_property=(value) ⇒ Object
A property-value pair representing an additional characteristic of the entity, e.g.
-
#equal ⇒ Object
This ordering relation for qualitative values indicates that the subject is equal to the object.
-
#equal=(value) ⇒ Object
This ordering relation for qualitative values indicates that the subject is equal to the object.
-
#greater ⇒ Object
This ordering relation for qualitative values indicates that the subject is greater than the object.
-
#greater=(value) ⇒ Object
This ordering relation for qualitative values indicates that the subject is greater than the object.
-
#greater_or_equal ⇒ Object
This ordering relation for qualitative values indicates that the subject is greater than or equal to the object.
-
#greater_or_equal=(value) ⇒ Object
This ordering relation for qualitative values indicates that the subject is greater than or equal to the object.
-
#lesser ⇒ Object
This ordering relation for qualitative values indicates that the subject is lesser than the object.
-
#lesser=(value) ⇒ Object
This ordering relation for qualitative values indicates that the subject is lesser than the object.
-
#lesser_or_equal ⇒ Object
This ordering relation for qualitative values indicates that the subject is lesser than or equal to the object.
-
#lesser_or_equal=(value) ⇒ Object
This ordering relation for qualitative values indicates that the subject is lesser than or equal to the object.
-
#non_equal ⇒ Object
This ordering relation for qualitative values indicates that the subject is not equal to the object.
-
#non_equal=(value) ⇒ Object
This ordering relation for qualitative values indicates that the subject is not equal to the object.
-
#value_reference ⇒ Object
A secondary value that provides additional information on the original value, e.g.
-
#value_reference=(value) ⇒ Object
A secondary value that provides additional information on the original value, e.g.
Methods included from Enumeration
#superseded_by, #superseded_by=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/schema_org/mixins/qualitative_value.rb', line 11 def self.schema_property_definitions { additional_property: { schema_name: "additionalProperty", schema_url: "https://schema.org/additionalProperty", comment_lines: ["A property-value pair representing an additional characteristic of the entity, e.g. a product feature or another characteristic for which there is no matching property in schema.org.\\n\\nNote: Publishers should be aware that applications designed to use specific schema.org properties (e.g. https://schema.org/width, https://schema.org/color, https://schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism."].freeze, ranges: ["PropertyValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, equal: { schema_name: "equal", schema_url: "https://schema.org/equal", comment_lines: ["This ordering relation for qualitative values indicates that the subject is equal to the object."].freeze, ranges: ["QualitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, greater: { schema_name: "greater", schema_url: "https://schema.org/greater", comment_lines: ["This ordering relation for qualitative values indicates that the subject is greater than the object."].freeze, ranges: ["QualitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, greater_or_equal: { schema_name: "greaterOrEqual", schema_url: "https://schema.org/greaterOrEqual", comment_lines: ["This ordering relation for qualitative values indicates that the subject is greater than or equal to the object."].freeze, ranges: ["QualitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, lesser: { schema_name: "lesser", schema_url: "https://schema.org/lesser", comment_lines: ["This ordering relation for qualitative values indicates that the subject is lesser than the object."].freeze, ranges: ["QualitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, lesser_or_equal: { schema_name: "lesserOrEqual", schema_url: "https://schema.org/lesserOrEqual", comment_lines: ["This ordering relation for qualitative values indicates that the subject is lesser than or equal to the object."].freeze, ranges: ["QualitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, non_equal: { schema_name: "nonEqual", schema_url: "https://schema.org/nonEqual", comment_lines: ["This ordering relation for qualitative values indicates that the subject is not equal to the object."].freeze, ranges: ["QualitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, value_reference: { schema_name: "valueReference", schema_url: "https://schema.org/valueReference", comment_lines: ["A secondary value that provides additional information on the original value, e.g. a reference temperature or a type of measurement."].freeze, ranges: ["DefinedTerm", "Enumeration", "MeasurementTypeEnumeration", "PropertyValue", "QualitativeValue", "QuantitativeValue", "StructuredValue", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#additional_property ⇒ Object
A property-value pair representing an additional characteristic of the entity, e.g. a product feature or another characteristic for which there is no matching property in schema.org.\n\nNote: Publishers should be aware that applications designed to use specific schema.org properties (e.g. https://schema.org/width, https://schema.org/color, https://schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism.
97 98 99 |
# File 'lib/schema_org/mixins/qualitative_value.rb', line 97 def additional_property read_property(:additional_property) end |
#additional_property=(value) ⇒ Object
A property-value pair representing an additional characteristic of the entity, e.g. a product feature or another characteristic for which there is no matching property in schema.org.\n\nNote: Publishers should be aware that applications designed to use specific schema.org properties (e.g. https://schema.org/width, https://schema.org/color, https://schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism.
102 103 104 |
# File 'lib/schema_org/mixins/qualitative_value.rb', line 102 def additional_property=(value) write_property(:additional_property, value) end |
#equal ⇒ Object
This ordering relation for qualitative values indicates that the subject is equal to the object.
107 108 109 |
# File 'lib/schema_org/mixins/qualitative_value.rb', line 107 def equal read_property(:equal) end |
#equal=(value) ⇒ Object
This ordering relation for qualitative values indicates that the subject is equal to the object.
112 113 114 |
# File 'lib/schema_org/mixins/qualitative_value.rb', line 112 def equal=(value) write_property(:equal, value) end |
#greater ⇒ Object
This ordering relation for qualitative values indicates that the subject is greater than the object.
117 118 119 |
# File 'lib/schema_org/mixins/qualitative_value.rb', line 117 def greater read_property(:greater) end |
#greater=(value) ⇒ Object
This ordering relation for qualitative values indicates that the subject is greater than the object.
122 123 124 |
# File 'lib/schema_org/mixins/qualitative_value.rb', line 122 def greater=(value) write_property(:greater, value) end |
#greater_or_equal ⇒ Object
This ordering relation for qualitative values indicates that the subject is greater than or equal to the object.
127 128 129 |
# File 'lib/schema_org/mixins/qualitative_value.rb', line 127 def greater_or_equal read_property(:greater_or_equal) end |
#greater_or_equal=(value) ⇒ Object
This ordering relation for qualitative values indicates that the subject is greater than or equal to the object.
132 133 134 |
# File 'lib/schema_org/mixins/qualitative_value.rb', line 132 def greater_or_equal=(value) write_property(:greater_or_equal, value) end |
#lesser ⇒ Object
This ordering relation for qualitative values indicates that the subject is lesser than the object.
137 138 139 |
# File 'lib/schema_org/mixins/qualitative_value.rb', line 137 def lesser read_property(:lesser) end |
#lesser=(value) ⇒ Object
This ordering relation for qualitative values indicates that the subject is lesser than the object.
142 143 144 |
# File 'lib/schema_org/mixins/qualitative_value.rb', line 142 def lesser=(value) write_property(:lesser, value) end |
#lesser_or_equal ⇒ Object
This ordering relation for qualitative values indicates that the subject is lesser than or equal to the object.
147 148 149 |
# File 'lib/schema_org/mixins/qualitative_value.rb', line 147 def lesser_or_equal read_property(:lesser_or_equal) end |
#lesser_or_equal=(value) ⇒ Object
This ordering relation for qualitative values indicates that the subject is lesser than or equal to the object.
152 153 154 |
# File 'lib/schema_org/mixins/qualitative_value.rb', line 152 def lesser_or_equal=(value) write_property(:lesser_or_equal, value) end |
#non_equal ⇒ Object
This ordering relation for qualitative values indicates that the subject is not equal to the object.
157 158 159 |
# File 'lib/schema_org/mixins/qualitative_value.rb', line 157 def non_equal read_property(:non_equal) end |
#non_equal=(value) ⇒ Object
This ordering relation for qualitative values indicates that the subject is not equal to the object.
162 163 164 |
# File 'lib/schema_org/mixins/qualitative_value.rb', line 162 def non_equal=(value) write_property(:non_equal, value) end |
#value_reference ⇒ Object
A secondary value that provides additional information on the original value, e.g. a reference temperature or a type of measurement.
167 168 169 |
# File 'lib/schema_org/mixins/qualitative_value.rb', line 167 def value_reference read_property(:value_reference) end |
#value_reference=(value) ⇒ Object
A secondary value that provides additional information on the original value, e.g. a reference temperature or a type of measurement.
172 173 174 |
# File 'lib/schema_org/mixins/qualitative_value.rb', line 172 def value_reference=(value) write_property(:value_reference, value) end |