Module: SchemaOrg::Mixins::RentalCarReservation
- Includes:
- Reservation
- Included in:
- RentalCarReservation
- Defined in:
- lib/schema_org/mixins/rental_car_reservation.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#dropoff_location ⇒ Object
Where a rental car can be dropped off.
-
#dropoff_location=(value) ⇒ Object
Where a rental car can be dropped off.
-
#dropoff_time ⇒ Object
When a rental car can be dropped off.
-
#dropoff_time=(value) ⇒ Object
When a rental car can be dropped off.
-
#pickup_location ⇒ Object
Where a taxi will pick up a passenger or a rental car can be picked up.
-
#pickup_location=(value) ⇒ Object
Where a taxi will pick up a passenger or a rental car can be picked up.
-
#pickup_time ⇒ Object
When a taxi will pick up a passenger or a rental car can be picked up.
-
#pickup_time=(value) ⇒ Object
When a taxi will pick up a passenger or a rental car can be picked up.
Methods included from Reservation
#booking_agent, #booking_agent=, #booking_time, #booking_time=, #broker, #broker=, #modified_time, #modified_time=, #price_currency, #price_currency=, #program_membership_used, #program_membership_used=, #provider, #provider=, #reservation_for, #reservation_for=, #reservation_id, #reservation_id=, #reservation_status, #reservation_status=, #reserved_ticket, #reserved_ticket=, #total_price, #total_price=, #under_name, #under_name=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/schema_org/mixins/rental_car_reservation.rb', line 11 def self.schema_property_definitions { dropoff_location: { schema_name: "dropoffLocation", schema_url: "https://schema.org/dropoffLocation", comment_lines: ["Where a rental car can be dropped off."].freeze, ranges: ["Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, dropoff_time: { schema_name: "dropoffTime", schema_url: "https://schema.org/dropoffTime", comment_lines: ["When a rental car can be dropped off."].freeze, ranges: ["DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, pickup_location: { schema_name: "pickupLocation", schema_url: "https://schema.org/pickupLocation", comment_lines: ["Where a taxi will pick up a passenger or a rental car can be picked up."].freeze, ranges: ["Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, pickup_time: { schema_name: "pickupTime", schema_url: "https://schema.org/pickupTime", comment_lines: ["When a taxi will pick up a passenger or a rental car can be picked up."].freeze, ranges: ["DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#dropoff_location ⇒ Object
Where a rental car can be dropped off.
57 58 59 |
# File 'lib/schema_org/mixins/rental_car_reservation.rb', line 57 def dropoff_location read_property(:dropoff_location) end |
#dropoff_location=(value) ⇒ Object
Where a rental car can be dropped off.
62 63 64 |
# File 'lib/schema_org/mixins/rental_car_reservation.rb', line 62 def dropoff_location=(value) write_property(:dropoff_location, value) end |
#dropoff_time ⇒ Object
When a rental car can be dropped off.
67 68 69 |
# File 'lib/schema_org/mixins/rental_car_reservation.rb', line 67 def dropoff_time read_property(:dropoff_time) end |
#dropoff_time=(value) ⇒ Object
When a rental car can be dropped off.
72 73 74 |
# File 'lib/schema_org/mixins/rental_car_reservation.rb', line 72 def dropoff_time=(value) write_property(:dropoff_time, value) end |
#pickup_location ⇒ Object
Where a taxi will pick up a passenger or a rental car can be picked up.
77 78 79 |
# File 'lib/schema_org/mixins/rental_car_reservation.rb', line 77 def pickup_location read_property(:pickup_location) end |
#pickup_location=(value) ⇒ Object
Where a taxi will pick up a passenger or a rental car can be picked up.
82 83 84 |
# File 'lib/schema_org/mixins/rental_car_reservation.rb', line 82 def pickup_location=(value) write_property(:pickup_location, value) end |
#pickup_time ⇒ Object
When a taxi will pick up a passenger or a rental car can be picked up.
87 88 89 |
# File 'lib/schema_org/mixins/rental_car_reservation.rb', line 87 def pickup_time read_property(:pickup_time) end |
#pickup_time=(value) ⇒ Object
When a taxi will pick up a passenger or a rental car can be picked up.
92 93 94 |
# File 'lib/schema_org/mixins/rental_car_reservation.rb', line 92 def pickup_time=(value) write_property(:pickup_time, value) end |