Module: SchemaOrg::Mixins::Reservation
- Includes:
- Intangible
- Included in:
- BoatReservation, BusReservation, EventReservation, FlightReservation, FoodEstablishmentReservation, LodgingReservation, RentalCarReservation, ReservationPackage, TaxiReservation, TrainReservation, Reservation
- Defined in:
- lib/schema_org/mixins/reservation.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#booking_agent ⇒ Object
'bookingAgent' is an out-dated term indicating a 'broker' that serves as a booking agent.
-
#booking_agent=(value) ⇒ Object
'bookingAgent' is an out-dated term indicating a 'broker' that serves as a booking agent.
-
#booking_time ⇒ Object
The date and time the reservation was booked.
-
#booking_time=(value) ⇒ Object
The date and time the reservation was booked.
-
#broker ⇒ Object
An entity that arranges for an exchange between a buyer and a seller.
-
#broker=(value) ⇒ Object
An entity that arranges for an exchange between a buyer and a seller.
-
#modified_time ⇒ Object
The date and time the reservation was modified.
-
#modified_time=(value) ⇒ Object
The date and time the reservation was modified.
-
#price_currency ⇒ Object
The currency of the price, or a price component when attached to [[PriceSpecification]] and its subtypes.\n\nUse standard formats: ISO 4217 currency format, e.g.
-
#price_currency=(value) ⇒ Object
The currency of the price, or a price component when attached to [[PriceSpecification]] and its subtypes.\n\nUse standard formats: ISO 4217 currency format, e.g.
-
#program_membership_used ⇒ Object
Any membership in a frequent flyer, hotel loyalty program, etc.
-
#program_membership_used=(value) ⇒ Object
Any membership in a frequent flyer, hotel loyalty program, etc.
-
#provider ⇒ Object
The service provider, service operator, or service performer; the goods producer.
-
#provider=(value) ⇒ Object
The service provider, service operator, or service performer; the goods producer.
-
#reservation_for ⇒ Object
The thing -- flight, event, restaurant, etc.
-
#reservation_for=(value) ⇒ Object
The thing -- flight, event, restaurant, etc.
-
#reservation_id ⇒ Object
A unique identifier for the reservation.
-
#reservation_id=(value) ⇒ Object
A unique identifier for the reservation.
-
#reservation_status ⇒ Object
The current status of the reservation.
-
#reservation_status=(value) ⇒ Object
The current status of the reservation.
-
#reserved_ticket ⇒ Object
A ticket associated with the reservation.
-
#reserved_ticket=(value) ⇒ Object
A ticket associated with the reservation.
-
#total_price ⇒ Object
The total price for the reservation or ticket, including applicable taxes, shipping, etc.\n\nUsage guidelines:\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point.
-
#total_price=(value) ⇒ Object
The total price for the reservation or ticket, including applicable taxes, shipping, etc.\n\nUsage guidelines:\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point.
-
#under_name ⇒ Object
The person or organization the reservation or ticket is for.
-
#under_name=(value) ⇒ Object
The person or organization the reservation or ticket is for.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/schema_org/mixins/reservation.rb', line 11 def self.schema_property_definitions { booking_agent: { schema_name: "bookingAgent", schema_url: "https://schema.org/bookingAgent", comment_lines: ["'bookingAgent' is an out-dated term indicating a 'broker' that serves as a booking agent."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "broker", supersedes: nil }.freeze, booking_time: { schema_name: "bookingTime", schema_url: "https://schema.org/bookingTime", comment_lines: ["The date and time the reservation was booked."].freeze, ranges: ["DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, broker: { schema_name: "broker", schema_url: "https://schema.org/broker", comment_lines: ["An entity that arranges for an exchange between a buyer and a seller. In most cases a broker never acquires or releases ownership of a product or service involved in an exchange. If it is not clear whether an entity is a broker, seller, or buyer, the latter two terms are preferred."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["bookingAgent"].freeze }.freeze, modified_time: { schema_name: "modifiedTime", schema_url: "https://schema.org/modifiedTime", comment_lines: ["The date and time the reservation was modified."].freeze, ranges: ["DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, price_currency: { schema_name: "priceCurrency", schema_url: "https://schema.org/priceCurrency", comment_lines: ["The currency of the price, or a price component when attached to [[PriceSpecification]] and its subtypes.\\n\\nUse standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. \"USD\"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. \"BTC\"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. \"Ithaca HOUR\"."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, program_membership_used: { schema_name: "programMembershipUsed", schema_url: "https://schema.org/programMembershipUsed", comment_lines: ["Any membership in a frequent flyer, hotel loyalty program, etc. being applied to the reservation."].freeze, ranges: ["ProgramMembership"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, provider: { schema_name: "provider", schema_url: "https://schema.org/provider", comment_lines: ["The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["carrier"].freeze }.freeze, reservation_for: { schema_name: "reservationFor", schema_url: "https://schema.org/reservationFor", comment_lines: ["The thing -- flight, event, restaurant, etc. being reserved."].freeze, ranges: ["Thing"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, reservation_id: { schema_name: "reservationId", schema_url: "https://schema.org/reservationId", comment_lines: ["A unique identifier for the reservation."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, reservation_status: { schema_name: "reservationStatus", schema_url: "https://schema.org/reservationStatus", comment_lines: ["The current status of the reservation."].freeze, ranges: ["ReservationStatusType"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, reserved_ticket: { schema_name: "reservedTicket", schema_url: "https://schema.org/reservedTicket", comment_lines: ["A ticket associated with the reservation."].freeze, ranges: ["Ticket"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, total_price: { schema_name: "totalPrice", schema_url: "https://schema.org/totalPrice", comment_lines: ["The total price for the reservation or ticket, including applicable taxes, shipping, etc.\\n\\nUsage guidelines:\\n\\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator."].freeze, ranges: ["Number", "PriceSpecification", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, under_name: { schema_name: "underName", schema_url: "https://schema.org/underName", comment_lines: ["The person or organization the reservation or ticket is for."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#booking_agent ⇒ Object
'bookingAgent' is an out-dated term indicating a 'broker' that serves as a booking agent.
Superseded by broker.
148 149 150 |
# File 'lib/schema_org/mixins/reservation.rb', line 148 def booking_agent read_property(:booking_agent) end |
#booking_agent=(value) ⇒ Object
'bookingAgent' is an out-dated term indicating a 'broker' that serves as a booking agent.
Superseded by broker.
154 155 156 |
# File 'lib/schema_org/mixins/reservation.rb', line 154 def booking_agent=(value) write_property(:booking_agent, value) end |
#booking_time ⇒ Object
The date and time the reservation was booked.
159 160 161 |
# File 'lib/schema_org/mixins/reservation.rb', line 159 def booking_time read_property(:booking_time) end |
#booking_time=(value) ⇒ Object
The date and time the reservation was booked.
164 165 166 |
# File 'lib/schema_org/mixins/reservation.rb', line 164 def booking_time=(value) write_property(:booking_time, value) end |
#broker ⇒ Object
An entity that arranges for an exchange between a buyer and a seller. In most cases a broker never acquires or releases ownership of a product or service involved in an exchange. If it is not clear whether an entity is a broker, seller, or buyer, the latter two terms are preferred.
Supersedes bookingAgent.
170 171 172 |
# File 'lib/schema_org/mixins/reservation.rb', line 170 def broker read_property(:broker) end |
#broker=(value) ⇒ Object
An entity that arranges for an exchange between a buyer and a seller. In most cases a broker never acquires or releases ownership of a product or service involved in an exchange. If it is not clear whether an entity is a broker, seller, or buyer, the latter two terms are preferred.
Supersedes bookingAgent.
176 177 178 |
# File 'lib/schema_org/mixins/reservation.rb', line 176 def broker=(value) write_property(:broker, value) end |
#modified_time ⇒ Object
The date and time the reservation was modified.
181 182 183 |
# File 'lib/schema_org/mixins/reservation.rb', line 181 def modified_time read_property(:modified_time) end |
#modified_time=(value) ⇒ Object
The date and time the reservation was modified.
186 187 188 |
# File 'lib/schema_org/mixins/reservation.rb', line 186 def modified_time=(value) write_property(:modified_time, value) end |
#price_currency ⇒ Object
The currency of the price, or a price component when attached to [[PriceSpecification]] and its subtypes.\n\nUse standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR".
191 192 193 |
# File 'lib/schema_org/mixins/reservation.rb', line 191 def price_currency read_property(:price_currency) end |
#price_currency=(value) ⇒ Object
The currency of the price, or a price component when attached to [[PriceSpecification]] and its subtypes.\n\nUse standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR".
196 197 198 |
# File 'lib/schema_org/mixins/reservation.rb', line 196 def price_currency=(value) write_property(:price_currency, value) end |
#program_membership_used ⇒ Object
Any membership in a frequent flyer, hotel loyalty program, etc. being applied to the reservation.
201 202 203 |
# File 'lib/schema_org/mixins/reservation.rb', line 201 def program_membership_used read_property(:program_membership_used) end |
#program_membership_used=(value) ⇒ Object
Any membership in a frequent flyer, hotel loyalty program, etc. being applied to the reservation.
206 207 208 |
# File 'lib/schema_org/mixins/reservation.rb', line 206 def program_membership_used=(value) write_property(:program_membership_used, value) end |
#provider ⇒ Object
The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.
Supersedes carrier.
212 213 214 |
# File 'lib/schema_org/mixins/reservation.rb', line 212 def provider read_property(:provider) end |
#provider=(value) ⇒ Object
The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.
Supersedes carrier.
218 219 220 |
# File 'lib/schema_org/mixins/reservation.rb', line 218 def provider=(value) write_property(:provider, value) end |
#reservation_for ⇒ Object
The thing -- flight, event, restaurant, etc. being reserved.
223 224 225 |
# File 'lib/schema_org/mixins/reservation.rb', line 223 def reservation_for read_property(:reservation_for) end |
#reservation_for=(value) ⇒ Object
The thing -- flight, event, restaurant, etc. being reserved.
228 229 230 |
# File 'lib/schema_org/mixins/reservation.rb', line 228 def reservation_for=(value) write_property(:reservation_for, value) end |
#reservation_id ⇒ Object
A unique identifier for the reservation.
233 234 235 |
# File 'lib/schema_org/mixins/reservation.rb', line 233 def reservation_id read_property(:reservation_id) end |
#reservation_id=(value) ⇒ Object
A unique identifier for the reservation.
238 239 240 |
# File 'lib/schema_org/mixins/reservation.rb', line 238 def reservation_id=(value) write_property(:reservation_id, value) end |
#reservation_status ⇒ Object
The current status of the reservation.
243 244 245 |
# File 'lib/schema_org/mixins/reservation.rb', line 243 def reservation_status read_property(:reservation_status) end |
#reservation_status=(value) ⇒ Object
The current status of the reservation.
248 249 250 |
# File 'lib/schema_org/mixins/reservation.rb', line 248 def reservation_status=(value) write_property(:reservation_status, value) end |
#reserved_ticket ⇒ Object
A ticket associated with the reservation.
253 254 255 |
# File 'lib/schema_org/mixins/reservation.rb', line 253 def reserved_ticket read_property(:reserved_ticket) end |
#reserved_ticket=(value) ⇒ Object
A ticket associated with the reservation.
258 259 260 |
# File 'lib/schema_org/mixins/reservation.rb', line 258 def reserved_ticket=(value) write_property(:reserved_ticket, value) end |
#total_price ⇒ Object
The total price for the reservation or ticket, including applicable taxes, shipping, etc.\n\nUsage guidelines:\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.
263 264 265 |
# File 'lib/schema_org/mixins/reservation.rb', line 263 def total_price read_property(:total_price) end |
#total_price=(value) ⇒ Object
The total price for the reservation or ticket, including applicable taxes, shipping, etc.\n\nUsage guidelines:\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.
268 269 270 |
# File 'lib/schema_org/mixins/reservation.rb', line 268 def total_price=(value) write_property(:total_price, value) end |
#under_name ⇒ Object
The person or organization the reservation or ticket is for.
273 274 275 |
# File 'lib/schema_org/mixins/reservation.rb', line 273 def under_name read_property(:under_name) end |
#under_name=(value) ⇒ Object
The person or organization the reservation or ticket is for.
278 279 280 |
# File 'lib/schema_org/mixins/reservation.rb', line 278 def under_name=(value) write_property(:under_name, value) end |