Module: SchemaOrg::Mixins::Residence
- Includes:
- Place
- Included in:
- ApartmentComplex, GatedResidenceCommunity, Residence
- Defined in:
- lib/schema_org/mixins/residence.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#accommodation_floor_plan ⇒ Object
A floorplan of some [[Accommodation]].
-
#accommodation_floor_plan=(value) ⇒ Object
A floorplan of some [[Accommodation]].
-
#floor_level ⇒ Object
The floor level for an [[Accommodation]] in a multi-storey building.
-
#floor_level=(value) ⇒ Object
The floor level for an [[Accommodation]] in a multi-storey building.
Methods included from Place
#additional_property, #additional_property=, #address, #address=, #aggregate_rating, #aggregate_rating=, #amenity_feature, #amenity_feature=, #branch_code, #branch_code=, #contained_in, #contained_in=, #contained_in_place, #contained_in_place=, #contains_place, #contains_place=, #event, #event=, #events, #events=, #fax_number, #fax_number=, #geo, #geo=, #geo_contains, #geo_contains=, #geo_covered_by, #geo_covered_by=, #geo_covers, #geo_covers=, #geo_crosses, #geo_crosses=, #geo_disjoint, #geo_disjoint=, #geo_equals, #geo_equals=, #geo_intersects, #geo_intersects=, #geo_overlaps, #geo_overlaps=, #geo_touches, #geo_touches=, #geo_within, #geo_within=, #global_location_number, #global_location_number=, #has_certification, #has_certification=, #has_drive_through_service, #has_drive_through_service=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_map, #has_map=, #is_accessible_for_free, #is_accessible_for_free=, #isic_v4, #isic_v4=, #keywords, #keywords=, #latitude, #latitude=, #logo, #logo=, #longitude, #longitude=, #map, #map=, #maps, #maps=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #opening_hours_specification, #opening_hours_specification=, #photo, #photo=, #photos, #photos=, #public_access, #public_access=, #review, #review=, #reviews, #reviews=, #slogan, #slogan=, #smoking_allowed, #smoking_allowed=, #special_opening_hours_specification, #special_opening_hours_specification=, #telephone, #telephone=, #tour_booking_page, #tour_booking_page=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/schema_org/mixins/residence.rb', line 11 def self.schema_property_definitions { accommodation_floor_plan: { schema_name: "accommodationFloorPlan", schema_url: "https://schema.org/accommodationFloorPlan", comment_lines: ["A floorplan of some [[Accommodation]]."].freeze, ranges: ["FloorPlan"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, floor_level: { schema_name: "floorLevel", schema_url: "https://schema.org/floorLevel", comment_lines: ["The floor level for an [[Accommodation]] in a multi-storey building. Since counting", " systems [vary internationally](https://en.wikipedia.org/wiki/Storey#Consecutive_number_floor_designations), the local system should be used where possible."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#accommodation_floor_plan ⇒ Object
A floorplan of some [[Accommodation]].
37 38 39 |
# File 'lib/schema_org/mixins/residence.rb', line 37 def accommodation_floor_plan read_property(:accommodation_floor_plan) end |
#accommodation_floor_plan=(value) ⇒ Object
A floorplan of some [[Accommodation]].
42 43 44 |
# File 'lib/schema_org/mixins/residence.rb', line 42 def accommodation_floor_plan=(value) write_property(:accommodation_floor_plan, value) end |
#floor_level ⇒ Object
The floor level for an [[Accommodation]] in a multi-storey building. Since counting systems vary internationally, the local system should be used where possible.
48 49 50 |
# File 'lib/schema_org/mixins/residence.rb', line 48 def floor_level read_property(:floor_level) end |
#floor_level=(value) ⇒ Object
The floor level for an [[Accommodation]] in a multi-storey building. Since counting systems vary internationally, the local system should be used where possible.
54 55 56 |
# File 'lib/schema_org/mixins/residence.rb', line 54 def floor_level=(value) write_property(:floor_level, value) end |