Module: SchemaOrg::Mixins::Review
- Includes:
- CreativeWork
- Included in:
- ClaimReview, CriticReview, EmployerReview, MediaReview, Recommendation, UserReview, Review
- Defined in:
- lib/schema_org/mixins/review.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#associated_claim_review ⇒ Object
An associated [[ClaimReview]], related by specific common content, topic or claim.
-
#associated_claim_review=(value) ⇒ Object
An associated [[ClaimReview]], related by specific common content, topic or claim.
-
#associated_media_review ⇒ Object
An associated [[MediaReview]], related by specific common content, topic or claim.
-
#associated_media_review=(value) ⇒ Object
An associated [[MediaReview]], related by specific common content, topic or claim.
-
#associated_review ⇒ Object
An associated [[Review]].
-
#associated_review=(value) ⇒ Object
An associated [[Review]].
-
#item_reviewed ⇒ Object
The item that is being reviewed/rated.
-
#item_reviewed=(value) ⇒ Object
The item that is being reviewed/rated.
-
#negative_notes ⇒ Object
Provides negative considerations regarding something, most typically in pro/con lists for reviews (alongside [[positiveNotes]]).
-
#negative_notes=(value) ⇒ Object
Provides negative considerations regarding something, most typically in pro/con lists for reviews (alongside [[positiveNotes]]).
-
#positive_notes ⇒ Object
Provides positive considerations regarding something, for example product highlights or (alongside [[negativeNotes]]) pro/con lists for reviews.
-
#positive_notes=(value) ⇒ Object
Provides positive considerations regarding something, for example product highlights or (alongside [[negativeNotes]]) pro/con lists for reviews.
-
#review_aspect ⇒ Object
This Review or Rating is relevant to this part or facet of the itemReviewed.
-
#review_aspect=(value) ⇒ Object
This Review or Rating is relevant to this part or facet of the itemReviewed.
-
#review_body ⇒ Object
The actual body of the review.
-
#review_body=(value) ⇒ Object
The actual body of the review.
-
#review_rating ⇒ Object
The rating given in this review.
-
#review_rating=(value) ⇒ Object
The rating given in this review.
Methods included from CreativeWork
#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/schema_org/mixins/review.rb', line 11 def self.schema_property_definitions { associated_claim_review: { schema_name: "associatedClaimReview", schema_url: "https://schema.org/associatedClaimReview", comment_lines: ["An associated [[ClaimReview]], related by specific common content, topic or claim. The expectation is that this property would be most typically used in cases where a single activity is conducting both claim reviews and media reviews, in which case [[relatedMediaReview]] would commonly be used on a [[ClaimReview]], while [[associatedClaimReview]] would be used on [[MediaReview]]."].freeze, ranges: ["Review"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, associated_media_review: { schema_name: "associatedMediaReview", schema_url: "https://schema.org/associatedMediaReview", comment_lines: ["An associated [[MediaReview]], related by specific common content, topic or claim. The expectation is that this property would be most typically used in cases where a single activity is conducting both claim reviews and media reviews, in which case [[relatedMediaReview]] would commonly be used on a [[ClaimReview]], while [[associatedClaimReview]] would be used on [[MediaReview]]."].freeze, ranges: ["Review"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, associated_review: { schema_name: "associatedReview", schema_url: "https://schema.org/associatedReview", comment_lines: ["An associated [[Review]]."].freeze, ranges: ["Review"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, item_reviewed: { schema_name: "itemReviewed", schema_url: "https://schema.org/itemReviewed", comment_lines: ["The item that is being reviewed/rated."].freeze, ranges: ["Thing"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, negative_notes: { schema_name: "negativeNotes", schema_url: "https://schema.org/negativeNotes", comment_lines: ["Provides negative considerations regarding something, most typically in pro/con lists for reviews (alongside [[positiveNotes]]). For symmetry", "", "In the case of a [[Review]], the property describes the [[itemReviewed]] from the perspective of the review; in the case of a [[Product]], the product itself is being described. Since product descriptions", "tend to emphasise positive claims, it may be relatively unusual to find [[negativeNotes]] used in this way. Nevertheless for the sake of symmetry, [[negativeNotes]] can be used on [[Product]].", "", "The property values can be expressed either as unstructured text (repeated as necessary), or if ordered, as a list (in which case the most negative is at the beginning of the list)."].freeze, ranges: ["ItemList", "ListItem", "Text", "WebContent"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, positive_notes: { schema_name: "positiveNotes", schema_url: "https://schema.org/positiveNotes", comment_lines: ["Provides positive considerations regarding something, for example product highlights or (alongside [[negativeNotes]]) pro/con lists for reviews.", "", "In the case of a [[Review]], the property describes the [[itemReviewed]] from the perspective of the review; in the case of a [[Product]], the product itself is being described.", "", "The property values can be expressed either as unstructured text (repeated as necessary), or if ordered, as a list (in which case the most positive is at the beginning of the list)."].freeze, ranges: ["ItemList", "ListItem", "Text", "WebContent"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, review_aspect: { schema_name: "reviewAspect", schema_url: "https://schema.org/reviewAspect", comment_lines: ["This Review or Rating is relevant to this part or facet of the itemReviewed."].freeze, ranges: ["StructuredValue", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, review_body: { schema_name: "reviewBody", schema_url: "https://schema.org/reviewBody", comment_lines: ["The actual body of the review."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, review_rating: { schema_name: "reviewRating", schema_url: "https://schema.org/reviewRating", comment_lines: ["The rating given in this review. Note that reviews can themselves be rated. The ```reviewRating``` applies to rating given by the review. The [[aggregateRating]] property applies to the review itself, as a creative work."].freeze, ranges: ["Rating"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#associated_claim_review ⇒ Object
An associated [[ClaimReview]], related by specific common content, topic or claim. The expectation is that this property would be most typically used in cases where a single activity is conducting both claim reviews and media reviews, in which case [[relatedMediaReview]] would commonly be used on a [[ClaimReview]], while [[associatedClaimReview]] would be used on [[MediaReview]].
107 108 109 |
# File 'lib/schema_org/mixins/review.rb', line 107 def associated_claim_review read_property(:associated_claim_review) end |
#associated_claim_review=(value) ⇒ Object
An associated [[ClaimReview]], related by specific common content, topic or claim. The expectation is that this property would be most typically used in cases where a single activity is conducting both claim reviews and media reviews, in which case [[relatedMediaReview]] would commonly be used on a [[ClaimReview]], while [[associatedClaimReview]] would be used on [[MediaReview]].
112 113 114 |
# File 'lib/schema_org/mixins/review.rb', line 112 def associated_claim_review=(value) write_property(:associated_claim_review, value) end |
#associated_media_review ⇒ Object
An associated [[MediaReview]], related by specific common content, topic or claim. The expectation is that this property would be most typically used in cases where a single activity is conducting both claim reviews and media reviews, in which case [[relatedMediaReview]] would commonly be used on a [[ClaimReview]], while [[associatedClaimReview]] would be used on [[MediaReview]].
117 118 119 |
# File 'lib/schema_org/mixins/review.rb', line 117 def associated_media_review read_property(:associated_media_review) end |
#associated_media_review=(value) ⇒ Object
An associated [[MediaReview]], related by specific common content, topic or claim. The expectation is that this property would be most typically used in cases where a single activity is conducting both claim reviews and media reviews, in which case [[relatedMediaReview]] would commonly be used on a [[ClaimReview]], while [[associatedClaimReview]] would be used on [[MediaReview]].
122 123 124 |
# File 'lib/schema_org/mixins/review.rb', line 122 def associated_media_review=(value) write_property(:associated_media_review, value) end |
#associated_review ⇒ Object
An associated [[Review]].
127 128 129 |
# File 'lib/schema_org/mixins/review.rb', line 127 def associated_review read_property(:associated_review) end |
#associated_review=(value) ⇒ Object
An associated [[Review]].
132 133 134 |
# File 'lib/schema_org/mixins/review.rb', line 132 def associated_review=(value) write_property(:associated_review, value) end |
#item_reviewed ⇒ Object
The item that is being reviewed/rated.
137 138 139 |
# File 'lib/schema_org/mixins/review.rb', line 137 def item_reviewed read_property(:item_reviewed) end |
#item_reviewed=(value) ⇒ Object
The item that is being reviewed/rated.
142 143 144 |
# File 'lib/schema_org/mixins/review.rb', line 142 def item_reviewed=(value) write_property(:item_reviewed, value) end |
#negative_notes ⇒ Object
Provides negative considerations regarding something, most typically in pro/con lists for reviews (alongside [[positiveNotes]]). For symmetry
In the case of a [[Review]], the property describes the [[itemReviewed]] from the perspective of the review; in the case of a [[Product]], the product itself is being described. Since product descriptions tend to emphasise positive claims, it may be relatively unusual to find [[negativeNotes]] used in this way. Nevertheless for the sake of symmetry, [[negativeNotes]] can be used on [[Product]].
The property values can be expressed either as unstructured text (repeated as necessary), or if ordered, as a list (in which case the most negative is at the beginning of the list).
152 153 154 |
# File 'lib/schema_org/mixins/review.rb', line 152 def negative_notes read_property(:negative_notes) end |
#negative_notes=(value) ⇒ Object
Provides negative considerations regarding something, most typically in pro/con lists for reviews (alongside [[positiveNotes]]). For symmetry
In the case of a [[Review]], the property describes the [[itemReviewed]] from the perspective of the review; in the case of a [[Product]], the product itself is being described. Since product descriptions tend to emphasise positive claims, it may be relatively unusual to find [[negativeNotes]] used in this way. Nevertheless for the sake of symmetry, [[negativeNotes]] can be used on [[Product]].
The property values can be expressed either as unstructured text (repeated as necessary), or if ordered, as a list (in which case the most negative is at the beginning of the list).
162 163 164 |
# File 'lib/schema_org/mixins/review.rb', line 162 def negative_notes=(value) write_property(:negative_notes, value) end |
#positive_notes ⇒ Object
Provides positive considerations regarding something, for example product highlights or (alongside [[negativeNotes]]) pro/con lists for reviews.
In the case of a [[Review]], the property describes the [[itemReviewed]] from the perspective of the review; in the case of a [[Product]], the product itself is being described.
The property values can be expressed either as unstructured text (repeated as necessary), or if ordered, as a list (in which case the most positive is at the beginning of the list).
171 172 173 |
# File 'lib/schema_org/mixins/review.rb', line 171 def positive_notes read_property(:positive_notes) end |
#positive_notes=(value) ⇒ Object
Provides positive considerations regarding something, for example product highlights or (alongside [[negativeNotes]]) pro/con lists for reviews.
In the case of a [[Review]], the property describes the [[itemReviewed]] from the perspective of the review; in the case of a [[Product]], the product itself is being described.
The property values can be expressed either as unstructured text (repeated as necessary), or if ordered, as a list (in which case the most positive is at the beginning of the list).
180 181 182 |
# File 'lib/schema_org/mixins/review.rb', line 180 def positive_notes=(value) write_property(:positive_notes, value) end |
#review_aspect ⇒ Object
This Review or Rating is relevant to this part or facet of the itemReviewed.
185 186 187 |
# File 'lib/schema_org/mixins/review.rb', line 185 def review_aspect read_property(:review_aspect) end |
#review_aspect=(value) ⇒ Object
This Review or Rating is relevant to this part or facet of the itemReviewed.
190 191 192 |
# File 'lib/schema_org/mixins/review.rb', line 190 def review_aspect=(value) write_property(:review_aspect, value) end |
#review_body ⇒ Object
The actual body of the review.
195 196 197 |
# File 'lib/schema_org/mixins/review.rb', line 195 def review_body read_property(:review_body) end |
#review_body=(value) ⇒ Object
The actual body of the review.
200 201 202 |
# File 'lib/schema_org/mixins/review.rb', line 200 def review_body=(value) write_property(:review_body, value) end |
#review_rating ⇒ Object
The rating given in this review. Note that reviews can themselves be rated. The reviewRating applies to rating given by the review. The [[aggregateRating]] property applies to the review itself, as a creative work.
205 206 207 |
# File 'lib/schema_org/mixins/review.rb', line 205 def read_property(:review_rating) end |
#review_rating=(value) ⇒ Object
The rating given in this review. Note that reviews can themselves be rated. The reviewRating applies to rating given by the review. The [[aggregateRating]] property applies to the review itself, as a creative work.
210 211 212 |
# File 'lib/schema_org/mixins/review.rb', line 210 def (value) write_property(:review_rating, value) end |