Module: SchemaOrg::Mixins::RsvpAction
Class Method Summary collapse
Instance Method Summary collapse
-
#additional_number_of_guests ⇒ Object
If responding yes, the number of guests who will attend in addition to the invitee.
-
#additional_number_of_guests=(value) ⇒ Object
If responding yes, the number of guests who will attend in addition to the invitee.
-
#comment ⇒ Object
Comments, typically from users.
-
#comment=(value) ⇒ Object
Comments, typically from users.
-
#rsvp_response ⇒ Object
The response (yes, no, maybe) to the RSVP.
-
#rsvp_response=(value) ⇒ Object
The response (yes, no, maybe) to the RSVP.
Methods included from InformAction
Methods included from CommunicateAction
#about, #about=, #in_language, #in_language=, #language, #language=, #recipient, #recipient=
Methods included from Action
#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, #start_time, #start_time=, #target, #target=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/schema_org/mixins/rsvp_action.rb', line 11 def self.schema_property_definitions { additional_number_of_guests: { schema_name: "additionalNumberOfGuests", schema_url: "https://schema.org/additionalNumberOfGuests", comment_lines: ["If responding yes, the number of guests who will attend in addition to the invitee."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, comment: { schema_name: "comment", schema_url: "https://schema.org/comment", comment_lines: ["Comments, typically from users."].freeze, ranges: ["Comment"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, rsvp_response: { schema_name: "rsvpResponse", schema_url: "https://schema.org/rsvpResponse", comment_lines: ["The response (yes, no, maybe) to the RSVP."].freeze, ranges: ["RsvpResponseType"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#additional_number_of_guests ⇒ Object
If responding yes, the number of guests who will attend in addition to the invitee.
47 48 49 |
# File 'lib/schema_org/mixins/rsvp_action.rb', line 47 def additional_number_of_guests read_property(:additional_number_of_guests) end |
#additional_number_of_guests=(value) ⇒ Object
If responding yes, the number of guests who will attend in addition to the invitee.
52 53 54 |
# File 'lib/schema_org/mixins/rsvp_action.rb', line 52 def additional_number_of_guests=(value) write_property(:additional_number_of_guests, value) end |
#comment ⇒ Object
Comments, typically from users.
57 58 59 |
# File 'lib/schema_org/mixins/rsvp_action.rb', line 57 def comment read_property(:comment) end |
#comment=(value) ⇒ Object
Comments, typically from users.
62 63 64 |
# File 'lib/schema_org/mixins/rsvp_action.rb', line 62 def comment=(value) write_property(:comment, value) end |
#rsvp_response ⇒ Object
The response (yes, no, maybe) to the RSVP.
67 68 69 |
# File 'lib/schema_org/mixins/rsvp_action.rb', line 67 def rsvp_response read_property(:rsvp_response) end |
#rsvp_response=(value) ⇒ Object
The response (yes, no, maybe) to the RSVP.
72 73 74 |
# File 'lib/schema_org/mixins/rsvp_action.rb', line 72 def rsvp_response=(value) write_property(:rsvp_response, value) end |