Module: SchemaOrg::Mixins::Schedule
Class Method Summary collapse
Instance Method Summary collapse
-
#by_day ⇒ Object
Defines the day(s) of the week on which a recurring [[Event]] takes place.
-
#by_day=(value) ⇒ Object
Defines the day(s) of the week on which a recurring [[Event]] takes place.
-
#by_month ⇒ Object
Defines the month(s) of the year on which a recurring [[Event]] takes place.
-
#by_month=(value) ⇒ Object
Defines the month(s) of the year on which a recurring [[Event]] takes place.
-
#by_month_day ⇒ Object
Defines the day(s) of the month on which a recurring [[Event]] takes place.
-
#by_month_day=(value) ⇒ Object
Defines the day(s) of the month on which a recurring [[Event]] takes place.
-
#by_month_week ⇒ Object
Defines the week(s) of the month on which a recurring Event takes place.
-
#by_month_week=(value) ⇒ Object
Defines the week(s) of the month on which a recurring Event takes place.
-
#duration ⇒ Object
The duration of the item (movie, audio recording, event, etc.) in ISO 8601 duration format.
-
#duration=(value) ⇒ Object
The duration of the item (movie, audio recording, event, etc.) in ISO 8601 duration format.
-
#end_date ⇒ Object
The end date and time of the item (in ISO 8601 date format).
-
#end_date=(value) ⇒ Object
The end date and time of the item (in ISO 8601 date format).
-
#end_time ⇒ Object
The endTime of something.
-
#end_time=(value) ⇒ Object
The endTime of something.
-
#except_date ⇒ Object
Defines a [[Date]] or [[DateTime]] during which a scheduled [[Event]] will not take place.
-
#except_date=(value) ⇒ Object
Defines a [[Date]] or [[DateTime]] during which a scheduled [[Event]] will not take place.
-
#repeat_count ⇒ Object
Defines the number of times a recurring [[Event]] will take place.
-
#repeat_count=(value) ⇒ Object
Defines the number of times a recurring [[Event]] will take place.
-
#repeat_frequency ⇒ Object
Defines the frequency at which [[Event]]s will occur according to a schedule [[Schedule]].
-
#repeat_frequency=(value) ⇒ Object
Defines the frequency at which [[Event]]s will occur according to a schedule [[Schedule]].
-
#schedule_timezone ⇒ Object
Indicates the timezone for which the time(s) indicated in the [[Schedule]] are given.
-
#schedule_timezone=(value) ⇒ Object
Indicates the timezone for which the time(s) indicated in the [[Schedule]] are given.
-
#start_date ⇒ Object
The start date and time of the item (in ISO 8601 date format).
-
#start_date=(value) ⇒ Object
The start date and time of the item (in ISO 8601 date format).
-
#start_time ⇒ Object
The startTime of something.
-
#start_time=(value) ⇒ Object
The startTime of something.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/schema_org/mixins/schedule.rb', line 11 def self.schema_property_definitions { by_day: { schema_name: "byDay", schema_url: "https://schema.org/byDay", comment_lines: ["Defines the day(s) of the week on which a recurring [[Event]] takes place. May be specified using either [[DayOfWeek]], or alternatively [[Text]] conforming to iCal's syntax for byDay recurrence rules."].freeze, ranges: ["DayOfWeek", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, by_month: { schema_name: "byMonth", schema_url: "https://schema.org/byMonth", comment_lines: ["Defines the month(s) of the year on which a recurring [[Event]] takes place. Specified as an [[Integer]] between 1-12. January is 1."].freeze, ranges: ["Integer"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, by_month_day: { schema_name: "byMonthDay", schema_url: "https://schema.org/byMonthDay", comment_lines: ["Defines the day(s) of the month on which a recurring [[Event]] takes place. Specified as an [[Integer]] between 1-31."].freeze, ranges: ["Integer"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, by_month_week: { schema_name: "byMonthWeek", schema_url: "https://schema.org/byMonthWeek", comment_lines: ["Defines the week(s) of the month on which a recurring Event takes place. Specified as an Integer between 1-5. For clarity, byMonthWeek is best used in conjunction with byDay to indicate concepts like the first and third Mondays of a month."].freeze, ranges: ["Integer"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, duration: { schema_name: "duration", schema_url: "https://schema.org/duration", comment_lines: ["The duration of the item (movie, audio recording, event, etc.) in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601)."].freeze, ranges: ["Duration", "QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, end_date: { schema_name: "endDate", schema_url: "https://schema.org/endDate", comment_lines: ["The end date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601))."].freeze, ranges: ["Date", "DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, end_time: { schema_name: "endTime", schema_url: "https://schema.org/endTime", comment_lines: ["The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to *December*. For media, including audio and video, it's the time offset of the end of a clip within a larger file.\\n\\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions."].freeze, ranges: ["DateTime", "Time"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, except_date: { schema_name: "exceptDate", schema_url: "https://schema.org/exceptDate", comment_lines: ["Defines a [[Date]] or [[DateTime]] during which a scheduled [[Event]] will not take place. The property allows exceptions to", " a [[Schedule]] to be specified. If an exception is specified as a [[DateTime]] then only the event that would have started at that specific date and time", " should be excluded from the schedule. If an exception is specified as a [[Date]] then any event that is scheduled for that 24 hour period should be", " excluded from the schedule. This allows a whole day to be excluded from the schedule without having to itemise every scheduled event."].freeze, ranges: ["Date", "DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, repeat_count: { schema_name: "repeatCount", schema_url: "https://schema.org/repeatCount", comment_lines: ["Defines the number of times a recurring [[Event]] will take place."].freeze, ranges: ["Integer"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, repeat_frequency: { schema_name: "repeatFrequency", schema_url: "https://schema.org/repeatFrequency", comment_lines: ["Defines the frequency at which [[Event]]s will occur according to a schedule [[Schedule]]. The intervals between", " events should be defined as a [[Duration]] of time."].freeze, ranges: ["Duration", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, schedule_timezone: { schema_name: "scheduleTimezone", schema_url: "https://schema.org/scheduleTimezone", comment_lines: ["Indicates the timezone for which the time(s) indicated in the [[Schedule]] are given. The value provided should be among those listed in the IANA Time Zone Database."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, start_date: { schema_name: "startDate", schema_url: "https://schema.org/startDate", comment_lines: ["The start date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601))."].freeze, ranges: ["Date", "DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, start_time: { schema_name: "startTime", schema_url: "https://schema.org/startTime", comment_lines: ["The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from *January* to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file.\\n\\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions."].freeze, ranges: ["DateTime", "Time"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#by_day ⇒ Object
Defines the day(s) of the week on which a recurring [[Event]] takes place. May be specified using either [[DayOfWeek]], or alternatively [[Text]] conforming to iCal's syntax for byDay recurrence rules.
147 148 149 |
# File 'lib/schema_org/mixins/schedule.rb', line 147 def by_day read_property(:by_day) end |
#by_day=(value) ⇒ Object
Defines the day(s) of the week on which a recurring [[Event]] takes place. May be specified using either [[DayOfWeek]], or alternatively [[Text]] conforming to iCal's syntax for byDay recurrence rules.
152 153 154 |
# File 'lib/schema_org/mixins/schedule.rb', line 152 def by_day=(value) write_property(:by_day, value) end |
#by_month ⇒ Object
Defines the month(s) of the year on which a recurring [[Event]] takes place. Specified as an [[Integer]] between 1-12. January is 1.
157 158 159 |
# File 'lib/schema_org/mixins/schedule.rb', line 157 def by_month read_property(:by_month) end |
#by_month=(value) ⇒ Object
Defines the month(s) of the year on which a recurring [[Event]] takes place. Specified as an [[Integer]] between 1-12. January is 1.
162 163 164 |
# File 'lib/schema_org/mixins/schedule.rb', line 162 def by_month=(value) write_property(:by_month, value) end |
#by_month_day ⇒ Object
Defines the day(s) of the month on which a recurring [[Event]] takes place. Specified as an [[Integer]] between 1-31.
167 168 169 |
# File 'lib/schema_org/mixins/schedule.rb', line 167 def by_month_day read_property(:by_month_day) end |
#by_month_day=(value) ⇒ Object
Defines the day(s) of the month on which a recurring [[Event]] takes place. Specified as an [[Integer]] between 1-31.
172 173 174 |
# File 'lib/schema_org/mixins/schedule.rb', line 172 def by_month_day=(value) write_property(:by_month_day, value) end |
#by_month_week ⇒ Object
Defines the week(s) of the month on which a recurring Event takes place. Specified as an Integer between 1-5. For clarity, byMonthWeek is best used in conjunction with byDay to indicate concepts like the first and third Mondays of a month.
177 178 179 |
# File 'lib/schema_org/mixins/schedule.rb', line 177 def by_month_week read_property(:by_month_week) end |
#by_month_week=(value) ⇒ Object
Defines the week(s) of the month on which a recurring Event takes place. Specified as an Integer between 1-5. For clarity, byMonthWeek is best used in conjunction with byDay to indicate concepts like the first and third Mondays of a month.
182 183 184 |
# File 'lib/schema_org/mixins/schedule.rb', line 182 def by_month_week=(value) write_property(:by_month_week, value) end |
#duration ⇒ Object
The duration of the item (movie, audio recording, event, etc.) in ISO 8601 duration format.
187 188 189 |
# File 'lib/schema_org/mixins/schedule.rb', line 187 def duration read_property(:duration) end |
#duration=(value) ⇒ Object
The duration of the item (movie, audio recording, event, etc.) in ISO 8601 duration format.
192 193 194 |
# File 'lib/schema_org/mixins/schedule.rb', line 192 def duration=(value) write_property(:duration, value) end |
#end_date ⇒ Object
The end date and time of the item (in ISO 8601 date format).
197 198 199 |
# File 'lib/schema_org/mixins/schedule.rb', line 197 def end_date read_property(:end_date) end |
#end_date=(value) ⇒ Object
The end date and time of the item (in ISO 8601 date format).
202 203 204 |
# File 'lib/schema_org/mixins/schedule.rb', line 202 def end_date=(value) write_property(:end_date, value) end |
#end_time ⇒ Object
The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the end of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.
207 208 209 |
# File 'lib/schema_org/mixins/schedule.rb', line 207 def end_time read_property(:end_time) end |
#end_time=(value) ⇒ Object
The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the end of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.
212 213 214 |
# File 'lib/schema_org/mixins/schedule.rb', line 212 def end_time=(value) write_property(:end_time, value) end |
#except_date ⇒ Object
Defines a [[Date]] or [[DateTime]] during which a scheduled [[Event]] will not take place. The property allows exceptions to a [[Schedule]] to be specified. If an exception is specified as a [[DateTime]] then only the event that would have started at that specific date and time should be excluded from the schedule. If an exception is specified as a [[Date]] then any event that is scheduled for that 24 hour period should be excluded from the schedule. This allows a whole day to be excluded from the schedule without having to itemise every scheduled event.
220 221 222 |
# File 'lib/schema_org/mixins/schedule.rb', line 220 def except_date read_property(:except_date) end |
#except_date=(value) ⇒ Object
Defines a [[Date]] or [[DateTime]] during which a scheduled [[Event]] will not take place. The property allows exceptions to a [[Schedule]] to be specified. If an exception is specified as a [[DateTime]] then only the event that would have started at that specific date and time should be excluded from the schedule. If an exception is specified as a [[Date]] then any event that is scheduled for that 24 hour period should be excluded from the schedule. This allows a whole day to be excluded from the schedule without having to itemise every scheduled event.
228 229 230 |
# File 'lib/schema_org/mixins/schedule.rb', line 228 def except_date=(value) write_property(:except_date, value) end |
#repeat_count ⇒ Object
Defines the number of times a recurring [[Event]] will take place.
233 234 235 |
# File 'lib/schema_org/mixins/schedule.rb', line 233 def repeat_count read_property(:repeat_count) end |
#repeat_count=(value) ⇒ Object
Defines the number of times a recurring [[Event]] will take place.
238 239 240 |
# File 'lib/schema_org/mixins/schedule.rb', line 238 def repeat_count=(value) write_property(:repeat_count, value) end |
#repeat_frequency ⇒ Object
Defines the frequency at which [[Event]]s will occur according to a schedule [[Schedule]]. The intervals between events should be defined as a [[Duration]] of time.
244 245 246 |
# File 'lib/schema_org/mixins/schedule.rb', line 244 def repeat_frequency read_property(:repeat_frequency) end |
#repeat_frequency=(value) ⇒ Object
Defines the frequency at which [[Event]]s will occur according to a schedule [[Schedule]]. The intervals between events should be defined as a [[Duration]] of time.
250 251 252 |
# File 'lib/schema_org/mixins/schedule.rb', line 250 def repeat_frequency=(value) write_property(:repeat_frequency, value) end |
#schedule_timezone ⇒ Object
Indicates the timezone for which the time(s) indicated in the [[Schedule]] are given. The value provided should be among those listed in the IANA Time Zone Database.
255 256 257 |
# File 'lib/schema_org/mixins/schedule.rb', line 255 def schedule_timezone read_property(:schedule_timezone) end |
#schedule_timezone=(value) ⇒ Object
Indicates the timezone for which the time(s) indicated in the [[Schedule]] are given. The value provided should be among those listed in the IANA Time Zone Database.
260 261 262 |
# File 'lib/schema_org/mixins/schedule.rb', line 260 def schedule_timezone=(value) write_property(:schedule_timezone, value) end |
#start_date ⇒ Object
The start date and time of the item (in ISO 8601 date format).
265 266 267 |
# File 'lib/schema_org/mixins/schedule.rb', line 265 def start_date read_property(:start_date) end |
#start_date=(value) ⇒ Object
The start date and time of the item (in ISO 8601 date format).
270 271 272 |
# File 'lib/schema_org/mixins/schedule.rb', line 270 def start_date=(value) write_property(:start_date, value) end |
#start_time ⇒ Object
The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.
275 276 277 |
# File 'lib/schema_org/mixins/schedule.rb', line 275 def start_time read_property(:start_time) end |
#start_time=(value) ⇒ Object
The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file.\n\nNote that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.
280 281 282 |
# File 'lib/schema_org/mixins/schedule.rb', line 280 def start_time=(value) write_property(:start_time, value) end |