Module: SchemaOrg::Mixins::Service
- Includes:
- Intangible
- Included in:
- BroadcastService, CableOrSatelliteService, FinancialProduct, FoodService, GovernmentService, Taxi, TaxiService, WebAPI, Service
- Defined in:
- lib/schema_org/mixins/service.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#aggregate_rating ⇒ Object
The overall rating, based on a collection of reviews or ratings, of the item.
-
#aggregate_rating=(value) ⇒ Object
The overall rating, based on a collection of reviews or ratings, of the item.
-
#area_served ⇒ Object
The geographic area where a service or offered item is provided.
-
#area_served=(value) ⇒ Object
The geographic area where a service or offered item is provided.
-
#audience ⇒ Object
An intended audience, i.e.
-
#audience=(value) ⇒ Object
An intended audience, i.e.
-
#available_channel ⇒ Object
A means of accessing the service (e.g. a phone bank, a web site, a location, etc.).
-
#available_channel=(value) ⇒ Object
A means of accessing the service (e.g. a phone bank, a web site, a location, etc.).
-
#award ⇒ Object
An award won by or for this item.
-
#award=(value) ⇒ Object
An award won by or for this item.
-
#brand ⇒ Object
The brand(s) associated with a product or service, or the brand(s) maintained by an organization or business person.
-
#brand=(value) ⇒ Object
The brand(s) associated with a product or service, or the brand(s) maintained by an organization or business person.
-
#broker ⇒ Object
An entity that arranges for an exchange between a buyer and a seller.
-
#broker=(value) ⇒ Object
An entity that arranges for an exchange between a buyer and a seller.
-
#category ⇒ Object
A category for the item.
-
#category=(value) ⇒ Object
A category for the item.
-
#has_certification ⇒ Object
Certification information about a product, organization, service, place, or person.
-
#has_certification=(value) ⇒ Object
Certification information about a product, organization, service, place, or person.
-
#has_offer_catalog ⇒ Object
Indicates an OfferCatalog listing for this Organization, Person, or Service.
-
#has_offer_catalog=(value) ⇒ Object
Indicates an OfferCatalog listing for this Organization, Person, or Service.
-
#hours_available ⇒ Object
The hours during which this service or contact is available.
-
#hours_available=(value) ⇒ Object
The hours during which this service or contact is available.
-
#is_related_to ⇒ Object
A pointer to another, somehow related product (or multiple products).
-
#is_related_to=(value) ⇒ Object
A pointer to another, somehow related product (or multiple products).
-
#is_similar_to ⇒ Object
A pointer to another, functionally similar product (or multiple products).
-
#is_similar_to=(value) ⇒ Object
A pointer to another, functionally similar product (or multiple products).
-
#logo ⇒ Object
An associated logo.
-
#logo=(value) ⇒ Object
An associated logo.
-
#offers ⇒ Object
An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event.
-
#offers=(value) ⇒ Object
An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event.
-
#produces ⇒ Object
The tangible thing generated by the service, e.g.
-
#produces=(value) ⇒ Object
The tangible thing generated by the service, e.g.
-
#provider ⇒ Object
The service provider, service operator, or service performer; the goods producer.
-
#provider=(value) ⇒ Object
The service provider, service operator, or service performer; the goods producer.
-
#provider_mobility ⇒ Object
Indicates the mobility of a provided service (e.g. 'static', 'dynamic').
-
#provider_mobility=(value) ⇒ Object
Indicates the mobility of a provided service (e.g. 'static', 'dynamic').
-
#review ⇒ Object
A review of the item.
-
#review=(value) ⇒ Object
A review of the item.
-
#service_area ⇒ Object
The geographic area where the service is provided.
-
#service_area=(value) ⇒ Object
The geographic area where the service is provided.
-
#service_audience ⇒ Object
The audience eligible for this service.
-
#service_audience=(value) ⇒ Object
The audience eligible for this service.
-
#service_output ⇒ Object
The tangible thing generated by the service, e.g.
-
#service_output=(value) ⇒ Object
The tangible thing generated by the service, e.g.
-
#service_type ⇒ Object
The type of service being offered, e.g.
-
#service_type=(value) ⇒ Object
The type of service being offered, e.g.
-
#slogan ⇒ Object
A slogan or motto associated with the item.
-
#slogan=(value) ⇒ Object
A slogan or motto associated with the item.
-
#terms_of_service ⇒ Object
Human-readable terms of service documentation.
-
#terms_of_service=(value) ⇒ Object
Human-readable terms of service documentation.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/schema_org/mixins/service.rb', line 11 def self.schema_property_definitions { aggregate_rating: { schema_name: "aggregateRating", schema_url: "https://schema.org/aggregateRating", comment_lines: ["The overall rating, based on a collection of reviews or ratings, of the item."].freeze, ranges: ["AggregateRating"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, area_served: { schema_name: "areaServed", schema_url: "https://schema.org/areaServed", comment_lines: ["The geographic area where a service or offered item is provided."].freeze, ranges: ["AdministrativeArea", "GeoShape", "Place", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["serviceArea"].freeze }.freeze, audience: { schema_name: "audience", schema_url: "https://schema.org/audience", comment_lines: ["An intended audience, i.e. a group for whom something was created."].freeze, ranges: ["Audience"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["serviceAudience"].freeze }.freeze, available_channel: { schema_name: "availableChannel", schema_url: "https://schema.org/availableChannel", comment_lines: ["A means of accessing the service (e.g. a phone bank, a web site, a location, etc.)."].freeze, ranges: ["ServiceChannel"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, award: { schema_name: "award", schema_url: "https://schema.org/award", comment_lines: ["An award won by or for this item."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["awards"].freeze }.freeze, brand: { schema_name: "brand", schema_url: "https://schema.org/brand", comment_lines: ["The brand(s) associated with a product or service, or the brand(s) maintained by an organization or business person."].freeze, ranges: ["Brand", "Organization"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, broker: { schema_name: "broker", schema_url: "https://schema.org/broker", comment_lines: ["An entity that arranges for an exchange between a buyer and a seller. In most cases a broker never acquires or releases ownership of a product or service involved in an exchange. If it is not clear whether an entity is a broker, seller, or buyer, the latter two terms are preferred."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["bookingAgent"].freeze }.freeze, category: { schema_name: "category", schema_url: "https://schema.org/category", comment_lines: ["A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy."].freeze, ranges: ["CategoryCode", "PhysicalActivityCategory", "Text", "Thing", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, has_certification: { schema_name: "hasCertification", schema_url: "https://schema.org/hasCertification", comment_lines: ["Certification information about a product, organization, service, place, or person."].freeze, ranges: ["Certification"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, has_offer_catalog: { schema_name: "hasOfferCatalog", schema_url: "https://schema.org/hasOfferCatalog", comment_lines: ["Indicates an OfferCatalog listing for this Organization, Person, or Service."].freeze, ranges: ["OfferCatalog"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, hours_available: { schema_name: "hoursAvailable", schema_url: "https://schema.org/hoursAvailable", comment_lines: ["The hours during which this service or contact is available."].freeze, ranges: ["OpeningHoursSpecification"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, is_related_to: { schema_name: "isRelatedTo", schema_url: "https://schema.org/isRelatedTo", comment_lines: ["A pointer to another, somehow related product (or multiple products)."].freeze, ranges: ["Product", "Service"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, is_similar_to: { schema_name: "isSimilarTo", schema_url: "https://schema.org/isSimilarTo", comment_lines: ["A pointer to another, functionally similar product (or multiple products)."].freeze, ranges: ["Product", "Service"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, logo: { schema_name: "logo", schema_url: "https://schema.org/logo", comment_lines: ["An associated logo."].freeze, ranges: ["ImageObject", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, offers: { schema_name: "offers", schema_url: "https://schema.org/offers", comment_lines: ["An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer."].freeze, ranges: ["Demand", "Offer"].freeze, external_ranges: [].freeze, inverse_of: "itemOffered", superseded_by: nil, supersedes: nil }.freeze, produces: { schema_name: "produces", schema_url: "https://schema.org/produces", comment_lines: ["The tangible thing generated by the service, e.g. a passport, permit, etc."].freeze, ranges: ["Thing"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "serviceOutput", supersedes: nil }.freeze, provider: { schema_name: "provider", schema_url: "https://schema.org/provider", comment_lines: ["The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["carrier"].freeze }.freeze, provider_mobility: { schema_name: "providerMobility", schema_url: "https://schema.org/providerMobility", comment_lines: ["Indicates the mobility of a provided service (e.g. 'static', 'dynamic')."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, review: { schema_name: "review", schema_url: "https://schema.org/review", comment_lines: ["A review of the item."].freeze, ranges: ["Review"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["reviews"].freeze }.freeze, service_area: { schema_name: "serviceArea", schema_url: "https://schema.org/serviceArea", comment_lines: ["The geographic area where the service is provided."].freeze, ranges: ["AdministrativeArea", "GeoShape", "Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "areaServed", supersedes: ["area"].freeze }.freeze, service_audience: { schema_name: "serviceAudience", schema_url: "https://schema.org/serviceAudience", comment_lines: ["The audience eligible for this service."].freeze, ranges: ["Audience"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "audience", supersedes: nil }.freeze, service_output: { schema_name: "serviceOutput", schema_url: "https://schema.org/serviceOutput", comment_lines: ["The tangible thing generated by the service, e.g. a passport, permit, etc."].freeze, ranges: ["Thing"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["produces"].freeze }.freeze, service_type: { schema_name: "serviceType", schema_url: "https://schema.org/serviceType", comment_lines: ["The type of service being offered, e.g. veterans' benefits, emergency relief, etc."].freeze, ranges: ["GovernmentBenefitsType", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, slogan: { schema_name: "slogan", schema_url: "https://schema.org/slogan", comment_lines: ["A slogan or motto associated with the item."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, terms_of_service: { schema_name: "termsOfService", schema_url: "https://schema.org/termsOfService", comment_lines: ["Human-readable terms of service documentation."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#aggregate_rating ⇒ Object
The overall rating, based on a collection of reviews or ratings, of the item.
267 268 269 |
# File 'lib/schema_org/mixins/service.rb', line 267 def read_property(:aggregate_rating) end |
#aggregate_rating=(value) ⇒ Object
The overall rating, based on a collection of reviews or ratings, of the item.
272 273 274 |
# File 'lib/schema_org/mixins/service.rb', line 272 def (value) write_property(:aggregate_rating, value) end |
#area_served ⇒ Object
The geographic area where a service or offered item is provided.
Supersedes serviceArea.
278 279 280 |
# File 'lib/schema_org/mixins/service.rb', line 278 def area_served read_property(:area_served) end |
#area_served=(value) ⇒ Object
The geographic area where a service or offered item is provided.
Supersedes serviceArea.
284 285 286 |
# File 'lib/schema_org/mixins/service.rb', line 284 def area_served=(value) write_property(:area_served, value) end |
#audience ⇒ Object
An intended audience, i.e. a group for whom something was created.
Supersedes serviceAudience.
290 291 292 |
# File 'lib/schema_org/mixins/service.rb', line 290 def audience read_property(:audience) end |
#audience=(value) ⇒ Object
An intended audience, i.e. a group for whom something was created.
Supersedes serviceAudience.
296 297 298 |
# File 'lib/schema_org/mixins/service.rb', line 296 def audience=(value) write_property(:audience, value) end |
#available_channel ⇒ Object
A means of accessing the service (e.g. a phone bank, a web site, a location, etc.).
301 302 303 |
# File 'lib/schema_org/mixins/service.rb', line 301 def available_channel read_property(:available_channel) end |
#available_channel=(value) ⇒ Object
A means of accessing the service (e.g. a phone bank, a web site, a location, etc.).
306 307 308 |
# File 'lib/schema_org/mixins/service.rb', line 306 def available_channel=(value) write_property(:available_channel, value) end |
#award ⇒ Object
An award won by or for this item.
Supersedes awards.
312 313 314 |
# File 'lib/schema_org/mixins/service.rb', line 312 def award read_property(:award) end |
#award=(value) ⇒ Object
An award won by or for this item.
Supersedes awards.
318 319 320 |
# File 'lib/schema_org/mixins/service.rb', line 318 def award=(value) write_property(:award, value) end |
#brand ⇒ Object
The brand(s) associated with a product or service, or the brand(s) maintained by an organization or business person.
323 324 325 |
# File 'lib/schema_org/mixins/service.rb', line 323 def brand read_property(:brand) end |
#brand=(value) ⇒ Object
The brand(s) associated with a product or service, or the brand(s) maintained by an organization or business person.
328 329 330 |
# File 'lib/schema_org/mixins/service.rb', line 328 def brand=(value) write_property(:brand, value) end |
#broker ⇒ Object
An entity that arranges for an exchange between a buyer and a seller. In most cases a broker never acquires or releases ownership of a product or service involved in an exchange. If it is not clear whether an entity is a broker, seller, or buyer, the latter two terms are preferred.
Supersedes bookingAgent.
334 335 336 |
# File 'lib/schema_org/mixins/service.rb', line 334 def broker read_property(:broker) end |
#broker=(value) ⇒ Object
An entity that arranges for an exchange between a buyer and a seller. In most cases a broker never acquires or releases ownership of a product or service involved in an exchange. If it is not clear whether an entity is a broker, seller, or buyer, the latter two terms are preferred.
Supersedes bookingAgent.
340 341 342 |
# File 'lib/schema_org/mixins/service.rb', line 340 def broker=(value) write_property(:broker, value) end |
#category ⇒ Object
A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.
345 346 347 |
# File 'lib/schema_org/mixins/service.rb', line 345 def category read_property(:category) end |
#category=(value) ⇒ Object
A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.
350 351 352 |
# File 'lib/schema_org/mixins/service.rb', line 350 def category=(value) write_property(:category, value) end |
#has_certification ⇒ Object
Certification information about a product, organization, service, place, or person.
355 356 357 |
# File 'lib/schema_org/mixins/service.rb', line 355 def has_certification read_property(:has_certification) end |
#has_certification=(value) ⇒ Object
Certification information about a product, organization, service, place, or person.
360 361 362 |
# File 'lib/schema_org/mixins/service.rb', line 360 def has_certification=(value) write_property(:has_certification, value) end |
#has_offer_catalog ⇒ Object
Indicates an OfferCatalog listing for this Organization, Person, or Service.
365 366 367 |
# File 'lib/schema_org/mixins/service.rb', line 365 def has_offer_catalog read_property(:has_offer_catalog) end |
#has_offer_catalog=(value) ⇒ Object
Indicates an OfferCatalog listing for this Organization, Person, or Service.
370 371 372 |
# File 'lib/schema_org/mixins/service.rb', line 370 def has_offer_catalog=(value) write_property(:has_offer_catalog, value) end |
#hours_available ⇒ Object
The hours during which this service or contact is available.
375 376 377 |
# File 'lib/schema_org/mixins/service.rb', line 375 def hours_available read_property(:hours_available) end |
#hours_available=(value) ⇒ Object
The hours during which this service or contact is available.
380 381 382 |
# File 'lib/schema_org/mixins/service.rb', line 380 def hours_available=(value) write_property(:hours_available, value) end |
#is_related_to ⇒ Object
A pointer to another, somehow related product (or multiple products).
385 386 387 |
# File 'lib/schema_org/mixins/service.rb', line 385 def read_property(:is_related_to) end |
#is_related_to=(value) ⇒ Object
A pointer to another, somehow related product (or multiple products).
390 391 392 |
# File 'lib/schema_org/mixins/service.rb', line 390 def (value) write_property(:is_related_to, value) end |
#is_similar_to ⇒ Object
A pointer to another, functionally similar product (or multiple products).
395 396 397 |
# File 'lib/schema_org/mixins/service.rb', line 395 def is_similar_to read_property(:is_similar_to) end |
#is_similar_to=(value) ⇒ Object
A pointer to another, functionally similar product (or multiple products).
400 401 402 |
# File 'lib/schema_org/mixins/service.rb', line 400 def is_similar_to=(value) write_property(:is_similar_to, value) end |
#logo ⇒ Object
An associated logo.
405 406 407 |
# File 'lib/schema_org/mixins/service.rb', line 405 def logo read_property(:logo) end |
#logo=(value) ⇒ Object
An associated logo.
410 411 412 |
# File 'lib/schema_org/mixins/service.rb', line 410 def logo=(value) write_property(:logo, value) end |
#offers ⇒ Object
An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.
Inverse-property: itemOffered.
416 417 418 |
# File 'lib/schema_org/mixins/service.rb', line 416 def offers read_property(:offers) end |
#offers=(value) ⇒ Object
An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.
Inverse-property: itemOffered.
422 423 424 |
# File 'lib/schema_org/mixins/service.rb', line 422 def offers=(value) write_property(:offers, value) end |
#produces ⇒ Object
The tangible thing generated by the service, e.g. a passport, permit, etc.
Superseded by serviceOutput.
428 429 430 |
# File 'lib/schema_org/mixins/service.rb', line 428 def produces read_property(:produces) end |
#produces=(value) ⇒ Object
The tangible thing generated by the service, e.g. a passport, permit, etc.
Superseded by serviceOutput.
434 435 436 |
# File 'lib/schema_org/mixins/service.rb', line 434 def produces=(value) write_property(:produces, value) end |
#provider ⇒ Object
The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.
Supersedes carrier.
440 441 442 |
# File 'lib/schema_org/mixins/service.rb', line 440 def provider read_property(:provider) end |
#provider=(value) ⇒ Object
The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.
Supersedes carrier.
446 447 448 |
# File 'lib/schema_org/mixins/service.rb', line 446 def provider=(value) write_property(:provider, value) end |
#provider_mobility ⇒ Object
Indicates the mobility of a provided service (e.g. 'static', 'dynamic').
451 452 453 |
# File 'lib/schema_org/mixins/service.rb', line 451 def provider_mobility read_property(:provider_mobility) end |
#provider_mobility=(value) ⇒ Object
Indicates the mobility of a provided service (e.g. 'static', 'dynamic').
456 457 458 |
# File 'lib/schema_org/mixins/service.rb', line 456 def provider_mobility=(value) write_property(:provider_mobility, value) end |
#review ⇒ Object
A review of the item.
Supersedes reviews.
462 463 464 |
# File 'lib/schema_org/mixins/service.rb', line 462 def review read_property(:review) end |
#review=(value) ⇒ Object
A review of the item.
Supersedes reviews.
468 469 470 |
# File 'lib/schema_org/mixins/service.rb', line 468 def review=(value) write_property(:review, value) end |
#service_area ⇒ Object
The geographic area where the service is provided.
Supersedes area.
Superseded by areaServed.
475 476 477 |
# File 'lib/schema_org/mixins/service.rb', line 475 def service_area read_property(:service_area) end |
#service_area=(value) ⇒ Object
The geographic area where the service is provided.
Supersedes area.
Superseded by areaServed.
482 483 484 |
# File 'lib/schema_org/mixins/service.rb', line 482 def service_area=(value) write_property(:service_area, value) end |
#service_audience ⇒ Object
The audience eligible for this service.
Superseded by audience.
488 489 490 |
# File 'lib/schema_org/mixins/service.rb', line 488 def service_audience read_property(:service_audience) end |
#service_audience=(value) ⇒ Object
The audience eligible for this service.
Superseded by audience.
494 495 496 |
# File 'lib/schema_org/mixins/service.rb', line 494 def service_audience=(value) write_property(:service_audience, value) end |
#service_output ⇒ Object
The tangible thing generated by the service, e.g. a passport, permit, etc.
Supersedes produces.
500 501 502 |
# File 'lib/schema_org/mixins/service.rb', line 500 def service_output read_property(:service_output) end |
#service_output=(value) ⇒ Object
The tangible thing generated by the service, e.g. a passport, permit, etc.
Supersedes produces.
506 507 508 |
# File 'lib/schema_org/mixins/service.rb', line 506 def service_output=(value) write_property(:service_output, value) end |
#service_type ⇒ Object
The type of service being offered, e.g. veterans' benefits, emergency relief, etc.
511 512 513 |
# File 'lib/schema_org/mixins/service.rb', line 511 def service_type read_property(:service_type) end |
#service_type=(value) ⇒ Object
The type of service being offered, e.g. veterans' benefits, emergency relief, etc.
516 517 518 |
# File 'lib/schema_org/mixins/service.rb', line 516 def service_type=(value) write_property(:service_type, value) end |
#slogan ⇒ Object
A slogan or motto associated with the item.
521 522 523 |
# File 'lib/schema_org/mixins/service.rb', line 521 def slogan read_property(:slogan) end |
#slogan=(value) ⇒ Object
A slogan or motto associated with the item.
526 527 528 |
# File 'lib/schema_org/mixins/service.rb', line 526 def slogan=(value) write_property(:slogan, value) end |
#terms_of_service ⇒ Object
Human-readable terms of service documentation.
531 532 533 |
# File 'lib/schema_org/mixins/service.rb', line 531 def terms_of_service read_property(:terms_of_service) end |
#terms_of_service=(value) ⇒ Object
Human-readable terms of service documentation.
536 537 538 |
# File 'lib/schema_org/mixins/service.rb', line 536 def terms_of_service=(value) write_property(:terms_of_service, value) end |