Module: SchemaOrg::Mixins::ShippingConditions
- Includes:
- StructuredValue
- Included in:
- ShippingConditions
- Defined in:
- lib/schema_org/mixins/shipping_conditions.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#depth ⇒ Object
The depth of the item.
-
#depth=(value) ⇒ Object
The depth of the item.
-
#does_not_ship ⇒ Object
Indicates when shipping to a particular [[shippingDestination]] is not available.
-
#does_not_ship=(value) ⇒ Object
Indicates when shipping to a particular [[shippingDestination]] is not available.
-
#height ⇒ Object
The height of the item.
-
#height=(value) ⇒ Object
The height of the item.
-
#num_items ⇒ Object
Limits the number of items being shipped for which these conditions apply.
-
#num_items=(value) ⇒ Object
Limits the number of items being shipped for which these conditions apply.
-
#order_value ⇒ Object
Minimum and maximum order value for which these shipping conditions are valid.
-
#order_value=(value) ⇒ Object
Minimum and maximum order value for which these shipping conditions are valid.
-
#seasonal_override ⇒ Object
Limited period during which these shipping conditions apply.
-
#seasonal_override=(value) ⇒ Object
Limited period during which these shipping conditions apply.
-
#shipping_destination ⇒ Object
indicates (possibly multiple) shipping destinations.
-
#shipping_destination=(value) ⇒ Object
indicates (possibly multiple) shipping destinations.
-
#shipping_origin ⇒ Object
Indicates the origin of a shipment, i.e.
-
#shipping_origin=(value) ⇒ Object
Indicates the origin of a shipment, i.e.
-
#shipping_rate ⇒ Object
The shipping rate is the cost of shipping to the specified destination.
-
#shipping_rate=(value) ⇒ Object
The shipping rate is the cost of shipping to the specified destination.
-
#transit_time ⇒ Object
The typical delay the order has been sent for delivery and the goods reach the final customer.
-
#transit_time=(value) ⇒ Object
The typical delay the order has been sent for delivery and the goods reach the final customer.
-
#weight ⇒ Object
The weight of the product or person.
-
#weight=(value) ⇒ Object
The weight of the product or person.
-
#width ⇒ Object
The width of the item.
-
#width=(value) ⇒ Object
The width of the item.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 11 def self.schema_property_definitions { depth: { schema_name: "depth", schema_url: "https://schema.org/depth", comment_lines: ["The depth of the item."].freeze, ranges: ["Distance", "QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, does_not_ship: { schema_name: "doesNotShip", schema_url: "https://schema.org/doesNotShip", comment_lines: ["Indicates when shipping to a particular [[shippingDestination]] is not available."].freeze, ranges: ["Boolean"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, height: { schema_name: "height", schema_url: "https://schema.org/height", comment_lines: ["The height of the item."].freeze, ranges: ["Distance", "QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, num_items: { schema_name: "numItems", schema_url: "https://schema.org/numItems", comment_lines: ["Limits the number of items being shipped for which these conditions apply."].freeze, ranges: ["QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, order_value: { schema_name: "orderValue", schema_url: "https://schema.org/orderValue", comment_lines: ["Minimum and maximum order value for which these shipping conditions are valid."].freeze, ranges: ["MonetaryAmount"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, seasonal_override: { schema_name: "seasonalOverride", schema_url: "https://schema.org/seasonalOverride", comment_lines: ["Limited period during which these shipping conditions apply."].freeze, ranges: ["OpeningHoursSpecification"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, shipping_destination: { schema_name: "shippingDestination", schema_url: "https://schema.org/shippingDestination", comment_lines: ["indicates (possibly multiple) shipping destinations. These can be defined in several ways, e.g. postalCode ranges."].freeze, ranges: ["DefinedRegion"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, shipping_origin: { schema_name: "shippingOrigin", schema_url: "https://schema.org/shippingOrigin", comment_lines: ["Indicates the origin of a shipment, i.e. where it should be coming from."].freeze, ranges: ["DefinedRegion"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, shipping_rate: { schema_name: "shippingRate", schema_url: "https://schema.org/shippingRate", comment_lines: ["The shipping rate is the cost of shipping to the specified destination. Typically, the maxValue and currency values (of the [[MonetaryAmount]]) are most appropriate."].freeze, ranges: ["MonetaryAmount", "ShippingRateSettings"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, transit_time: { schema_name: "transitTime", schema_url: "https://schema.org/transitTime", comment_lines: ["The typical delay the order has been sent for delivery and the goods reach the final customer.", "", " In the context of [[ShippingDeliveryTime]], use the [[QuantitativeValue]]. Typical properties: minValue, maxValue, unitCode (d for DAY).", "", " In the context of [[ShippingConditions]], use the [[ServicePeriod]]. It has a duration (as a [[QuantitativeValue]]) and also business days and a cut-off time."].freeze, ranges: ["QuantitativeValue", "ServicePeriod"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, weight: { schema_name: "weight", schema_url: "https://schema.org/weight", comment_lines: ["The weight of the product or person."].freeze, ranges: ["Mass", "QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, width: { schema_name: "width", schema_url: "https://schema.org/width", comment_lines: ["The width of the item."].freeze, ranges: ["Distance", "QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#depth ⇒ Object
The depth of the item.
137 138 139 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 137 def depth read_property(:depth) end |
#depth=(value) ⇒ Object
The depth of the item.
142 143 144 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 142 def depth=(value) write_property(:depth, value) end |
#does_not_ship ⇒ Object
Indicates when shipping to a particular [[shippingDestination]] is not available.
147 148 149 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 147 def does_not_ship read_property(:does_not_ship) end |
#does_not_ship=(value) ⇒ Object
Indicates when shipping to a particular [[shippingDestination]] is not available.
152 153 154 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 152 def does_not_ship=(value) write_property(:does_not_ship, value) end |
#height ⇒ Object
The height of the item.
157 158 159 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 157 def height read_property(:height) end |
#height=(value) ⇒ Object
The height of the item.
162 163 164 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 162 def height=(value) write_property(:height, value) end |
#num_items ⇒ Object
Limits the number of items being shipped for which these conditions apply.
167 168 169 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 167 def num_items read_property(:num_items) end |
#num_items=(value) ⇒ Object
Limits the number of items being shipped for which these conditions apply.
172 173 174 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 172 def num_items=(value) write_property(:num_items, value) end |
#order_value ⇒ Object
Minimum and maximum order value for which these shipping conditions are valid.
177 178 179 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 177 def order_value read_property(:order_value) end |
#order_value=(value) ⇒ Object
Minimum and maximum order value for which these shipping conditions are valid.
182 183 184 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 182 def order_value=(value) write_property(:order_value, value) end |
#seasonal_override ⇒ Object
Limited period during which these shipping conditions apply.
187 188 189 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 187 def seasonal_override read_property(:seasonal_override) end |
#seasonal_override=(value) ⇒ Object
Limited period during which these shipping conditions apply.
192 193 194 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 192 def seasonal_override=(value) write_property(:seasonal_override, value) end |
#shipping_destination ⇒ Object
indicates (possibly multiple) shipping destinations. These can be defined in several ways, e.g. postalCode ranges.
197 198 199 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 197 def shipping_destination read_property(:shipping_destination) end |
#shipping_destination=(value) ⇒ Object
indicates (possibly multiple) shipping destinations. These can be defined in several ways, e.g. postalCode ranges.
202 203 204 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 202 def shipping_destination=(value) write_property(:shipping_destination, value) end |
#shipping_origin ⇒ Object
Indicates the origin of a shipment, i.e. where it should be coming from.
207 208 209 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 207 def shipping_origin read_property(:shipping_origin) end |
#shipping_origin=(value) ⇒ Object
Indicates the origin of a shipment, i.e. where it should be coming from.
212 213 214 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 212 def shipping_origin=(value) write_property(:shipping_origin, value) end |
#shipping_rate ⇒ Object
The shipping rate is the cost of shipping to the specified destination. Typically, the maxValue and currency values (of the [[MonetaryAmount]]) are most appropriate.
217 218 219 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 217 def shipping_rate read_property(:shipping_rate) end |
#shipping_rate=(value) ⇒ Object
The shipping rate is the cost of shipping to the specified destination. Typically, the maxValue and currency values (of the [[MonetaryAmount]]) are most appropriate.
222 223 224 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 222 def shipping_rate=(value) write_property(:shipping_rate, value) end |
#transit_time ⇒ Object
The typical delay the order has been sent for delivery and the goods reach the final customer.
In the context of [[ShippingDeliveryTime]], use the [[QuantitativeValue]]. Typical properties: minValue, maxValue, unitCode (d for DAY).
In the context of [[ShippingConditions]], use the [[ServicePeriod]]. It has a duration (as a [[QuantitativeValue]]) and also business days and a cut-off time.
231 232 233 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 231 def transit_time read_property(:transit_time) end |
#transit_time=(value) ⇒ Object
The typical delay the order has been sent for delivery and the goods reach the final customer.
In the context of [[ShippingDeliveryTime]], use the [[QuantitativeValue]]. Typical properties: minValue, maxValue, unitCode (d for DAY).
In the context of [[ShippingConditions]], use the [[ServicePeriod]]. It has a duration (as a [[QuantitativeValue]]) and also business days and a cut-off time.
240 241 242 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 240 def transit_time=(value) write_property(:transit_time, value) end |
#weight ⇒ Object
The weight of the product or person.
245 246 247 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 245 def weight read_property(:weight) end |
#weight=(value) ⇒ Object
The weight of the product or person.
250 251 252 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 250 def weight=(value) write_property(:weight, value) end |
#width ⇒ Object
The width of the item.
255 256 257 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 255 def width read_property(:width) end |
#width=(value) ⇒ Object
The width of the item.
260 261 262 |
# File 'lib/schema_org/mixins/shipping_conditions.rb', line 260 def width=(value) write_property(:width, value) end |