Module: SchemaOrg::Mixins::ShippingRateSettings
- Includes:
- StructuredValue
- Included in:
- ShippingRateSettings
- Defined in:
- lib/schema_org/mixins/shipping_rate_settings.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#does_not_ship ⇒ Object
Indicates when shipping to a particular [[shippingDestination]] is not available.
-
#does_not_ship=(value) ⇒ Object
Indicates when shipping to a particular [[shippingDestination]] is not available.
-
#free_shipping_threshold ⇒ Object
A monetary value above (or at) which the shipping rate becomes free.
-
#free_shipping_threshold=(value) ⇒ Object
A monetary value above (or at) which the shipping rate becomes free.
-
#is_unlabelled_fallback ⇒ Object
This can be marked 'true' to indicate that some published [[DeliveryTimeSettings]] or [[ShippingRateSettings]] are intended to apply to all [[OfferShippingDetails]] published by the same merchant, when referenced by a [[shippingSettingsLink]] in those settings.
-
#is_unlabelled_fallback=(value) ⇒ Object
This can be marked 'true' to indicate that some published [[DeliveryTimeSettings]] or [[ShippingRateSettings]] are intended to apply to all [[OfferShippingDetails]] published by the same merchant, when referenced by a [[shippingSettingsLink]] in those settings.
-
#order_percentage ⇒ Object
Value representing the fraction of the value of the order that is charged as shipping cost.
-
#order_percentage=(value) ⇒ Object
Value representing the fraction of the value of the order that is charged as shipping cost.
-
#shipping_destination ⇒ Object
indicates (possibly multiple) shipping destinations.
-
#shipping_destination=(value) ⇒ Object
indicates (possibly multiple) shipping destinations.
-
#shipping_label ⇒ Object
Label to match an [[OfferShippingDetails]] with a [[ShippingRateSettings]] (within the context of a [[shippingSettingsLink]] cross-reference).
-
#shipping_label=(value) ⇒ Object
Label to match an [[OfferShippingDetails]] with a [[ShippingRateSettings]] (within the context of a [[shippingSettingsLink]] cross-reference).
-
#shipping_rate ⇒ Object
The shipping rate is the cost of shipping to the specified destination.
-
#shipping_rate=(value) ⇒ Object
The shipping rate is the cost of shipping to the specified destination.
-
#weight_percentage ⇒ Object
Value representing the fraction of the weight that is used to compute the shipping price.
-
#weight_percentage=(value) ⇒ Object
Value representing the fraction of the weight that is used to compute the shipping price.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/schema_org/mixins/shipping_rate_settings.rb', line 11 def self.schema_property_definitions { does_not_ship: { schema_name: "doesNotShip", schema_url: "https://schema.org/doesNotShip", comment_lines: ["Indicates when shipping to a particular [[shippingDestination]] is not available."].freeze, ranges: ["Boolean"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, free_shipping_threshold: { schema_name: "freeShippingThreshold", schema_url: "https://schema.org/freeShippingThreshold", comment_lines: ["A monetary value above (or at) which the shipping rate becomes free. Intended to be used via an [[OfferShippingDetails]] with [[shippingSettingsLink]] matching this [[ShippingRateSettings]]."].freeze, ranges: ["DeliveryChargeSpecification", "MonetaryAmount"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, is_unlabelled_fallback: { schema_name: "isUnlabelledFallback", schema_url: "https://schema.org/isUnlabelledFallback", comment_lines: ["This can be marked 'true' to indicate that some published [[DeliveryTimeSettings]] or [[ShippingRateSettings]] are intended to apply to all [[OfferShippingDetails]] published by the same merchant, when referenced by a [[shippingSettingsLink]] in those settings. It is not meaningful to use a 'true' value for this property alongside a transitTimeLabel (for [[DeliveryTimeSettings]]) or shippingLabel (for [[ShippingRateSettings]]), since this property is for use with unlabelled settings."].freeze, ranges: ["Boolean"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, order_percentage: { schema_name: "orderPercentage", schema_url: "https://schema.org/orderPercentage", comment_lines: ["Value representing the fraction of the value of the order that is charged as shipping cost. Example: 0.10 would mean shipping rate is 10% of the total order value."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, shipping_destination: { schema_name: "shippingDestination", schema_url: "https://schema.org/shippingDestination", comment_lines: ["indicates (possibly multiple) shipping destinations. These can be defined in several ways, e.g. postalCode ranges."].freeze, ranges: ["DefinedRegion"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, shipping_label: { schema_name: "shippingLabel", schema_url: "https://schema.org/shippingLabel", comment_lines: ["Label to match an [[OfferShippingDetails]] with a [[ShippingRateSettings]] (within the context of a [[shippingSettingsLink]] cross-reference)."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, shipping_rate: { schema_name: "shippingRate", schema_url: "https://schema.org/shippingRate", comment_lines: ["The shipping rate is the cost of shipping to the specified destination. Typically, the maxValue and currency values (of the [[MonetaryAmount]]) are most appropriate."].freeze, ranges: ["MonetaryAmount", "ShippingRateSettings"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, weight_percentage: { schema_name: "weightPercentage", schema_url: "https://schema.org/weightPercentage", comment_lines: ["Value representing the fraction of the weight that is used to compute the shipping price. Example: 0.10 and a shipping weight of 15kg would add $1.5 to the order price, where the $ is the currency of the order."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#does_not_ship ⇒ Object
Indicates when shipping to a particular [[shippingDestination]] is not available.
97 98 99 |
# File 'lib/schema_org/mixins/shipping_rate_settings.rb', line 97 def does_not_ship read_property(:does_not_ship) end |
#does_not_ship=(value) ⇒ Object
Indicates when shipping to a particular [[shippingDestination]] is not available.
102 103 104 |
# File 'lib/schema_org/mixins/shipping_rate_settings.rb', line 102 def does_not_ship=(value) write_property(:does_not_ship, value) end |
#free_shipping_threshold ⇒ Object
A monetary value above (or at) which the shipping rate becomes free. Intended to be used via an [[OfferShippingDetails]] with [[shippingSettingsLink]] matching this [[ShippingRateSettings]].
107 108 109 |
# File 'lib/schema_org/mixins/shipping_rate_settings.rb', line 107 def free_shipping_threshold read_property(:free_shipping_threshold) end |
#free_shipping_threshold=(value) ⇒ Object
A monetary value above (or at) which the shipping rate becomes free. Intended to be used via an [[OfferShippingDetails]] with [[shippingSettingsLink]] matching this [[ShippingRateSettings]].
112 113 114 |
# File 'lib/schema_org/mixins/shipping_rate_settings.rb', line 112 def free_shipping_threshold=(value) write_property(:free_shipping_threshold, value) end |
#is_unlabelled_fallback ⇒ Object
This can be marked 'true' to indicate that some published [[DeliveryTimeSettings]] or [[ShippingRateSettings]] are intended to apply to all [[OfferShippingDetails]] published by the same merchant, when referenced by a [[shippingSettingsLink]] in those settings. It is not meaningful to use a 'true' value for this property alongside a transitTimeLabel (for [[DeliveryTimeSettings]]) or shippingLabel (for [[ShippingRateSettings]]), since this property is for use with unlabelled settings.
117 118 119 |
# File 'lib/schema_org/mixins/shipping_rate_settings.rb', line 117 def is_unlabelled_fallback read_property(:is_unlabelled_fallback) end |
#is_unlabelled_fallback=(value) ⇒ Object
This can be marked 'true' to indicate that some published [[DeliveryTimeSettings]] or [[ShippingRateSettings]] are intended to apply to all [[OfferShippingDetails]] published by the same merchant, when referenced by a [[shippingSettingsLink]] in those settings. It is not meaningful to use a 'true' value for this property alongside a transitTimeLabel (for [[DeliveryTimeSettings]]) or shippingLabel (for [[ShippingRateSettings]]), since this property is for use with unlabelled settings.
122 123 124 |
# File 'lib/schema_org/mixins/shipping_rate_settings.rb', line 122 def is_unlabelled_fallback=(value) write_property(:is_unlabelled_fallback, value) end |
#order_percentage ⇒ Object
Value representing the fraction of the value of the order that is charged as shipping cost. Example: 0.10 would mean shipping rate is 10% of the total order value.
127 128 129 |
# File 'lib/schema_org/mixins/shipping_rate_settings.rb', line 127 def order_percentage read_property(:order_percentage) end |
#order_percentage=(value) ⇒ Object
Value representing the fraction of the value of the order that is charged as shipping cost. Example: 0.10 would mean shipping rate is 10% of the total order value.
132 133 134 |
# File 'lib/schema_org/mixins/shipping_rate_settings.rb', line 132 def order_percentage=(value) write_property(:order_percentage, value) end |
#shipping_destination ⇒ Object
indicates (possibly multiple) shipping destinations. These can be defined in several ways, e.g. postalCode ranges.
137 138 139 |
# File 'lib/schema_org/mixins/shipping_rate_settings.rb', line 137 def shipping_destination read_property(:shipping_destination) end |
#shipping_destination=(value) ⇒ Object
indicates (possibly multiple) shipping destinations. These can be defined in several ways, e.g. postalCode ranges.
142 143 144 |
# File 'lib/schema_org/mixins/shipping_rate_settings.rb', line 142 def shipping_destination=(value) write_property(:shipping_destination, value) end |
#shipping_label ⇒ Object
Label to match an [[OfferShippingDetails]] with a [[ShippingRateSettings]] (within the context of a [[shippingSettingsLink]] cross-reference).
147 148 149 |
# File 'lib/schema_org/mixins/shipping_rate_settings.rb', line 147 def shipping_label read_property(:shipping_label) end |
#shipping_label=(value) ⇒ Object
Label to match an [[OfferShippingDetails]] with a [[ShippingRateSettings]] (within the context of a [[shippingSettingsLink]] cross-reference).
152 153 154 |
# File 'lib/schema_org/mixins/shipping_rate_settings.rb', line 152 def shipping_label=(value) write_property(:shipping_label, value) end |
#shipping_rate ⇒ Object
The shipping rate is the cost of shipping to the specified destination. Typically, the maxValue and currency values (of the [[MonetaryAmount]]) are most appropriate.
157 158 159 |
# File 'lib/schema_org/mixins/shipping_rate_settings.rb', line 157 def shipping_rate read_property(:shipping_rate) end |
#shipping_rate=(value) ⇒ Object
The shipping rate is the cost of shipping to the specified destination. Typically, the maxValue and currency values (of the [[MonetaryAmount]]) are most appropriate.
162 163 164 |
# File 'lib/schema_org/mixins/shipping_rate_settings.rb', line 162 def shipping_rate=(value) write_property(:shipping_rate, value) end |
#weight_percentage ⇒ Object
Value representing the fraction of the weight that is used to compute the shipping price. Example: 0.10 and a shipping weight of 15kg would add $1.5 to the order price, where the $ is the currency of the order.
167 168 169 |
# File 'lib/schema_org/mixins/shipping_rate_settings.rb', line 167 def weight_percentage read_property(:weight_percentage) end |
#weight_percentage=(value) ⇒ Object
Value representing the fraction of the weight that is used to compute the shipping price. Example: 0.10 and a shipping weight of 15kg would add $1.5 to the order price, where the $ is the currency of the order.
172 173 174 |
# File 'lib/schema_org/mixins/shipping_rate_settings.rb', line 172 def weight_percentage=(value) write_property(:weight_percentage, value) end |