Module: SchemaOrg::Mixins::SizeSpecification
- Includes:
- QualitativeValue
- Included in:
- SizeSpecification
- Defined in:
- lib/schema_org/mixins/size_specification.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#has_measurement ⇒ Object
A measurement of an item, For example, the inseam of pants, the wheel size of a bicycle, the gauge of a screw, or the carbon footprint measured for certification by an authority.
-
#has_measurement=(value) ⇒ Object
A measurement of an item, For example, the inseam of pants, the wheel size of a bicycle, the gauge of a screw, or the carbon footprint measured for certification by an authority.
-
#size_group ⇒ Object
The size group (also known as "size type") for a product's size.
-
#size_group=(value) ⇒ Object
The size group (also known as "size type") for a product's size.
-
#size_system ⇒ Object
The size system used to identify a product's size.
-
#size_system=(value) ⇒ Object
The size system used to identify a product's size.
-
#suggested_age ⇒ Object
The age or age range for the intended audience or person, for example 3-12 months for infants, 1-5 years for toddlers.
-
#suggested_age=(value) ⇒ Object
The age or age range for the intended audience or person, for example 3-12 months for infants, 1-5 years for toddlers.
-
#suggested_gender ⇒ Object
The suggested gender of the intended person or audience, for example "male", "female", or "unisex".
-
#suggested_gender=(value) ⇒ Object
The suggested gender of the intended person or audience, for example "male", "female", or "unisex".
-
#suggested_measurement ⇒ Object
A suggested range of body measurements for the intended audience or person, for example inseam between 32 and 34 inches or height between 170 and 190 cm.
-
#suggested_measurement=(value) ⇒ Object
A suggested range of body measurements for the intended audience or person, for example inseam between 32 and 34 inches or height between 170 and 190 cm.
Methods included from QualitativeValue
#additional_property, #additional_property=, #equal, #equal=, #greater, #greater=, #greater_or_equal, #greater_or_equal=, #lesser, #lesser=, #lesser_or_equal, #lesser_or_equal=, #non_equal, #non_equal=, #value_reference, #value_reference=
Methods included from Enumeration
#superseded_by, #superseded_by=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/schema_org/mixins/size_specification.rb', line 11 def self.schema_property_definitions { has_measurement: { schema_name: "hasMeasurement", schema_url: "https://schema.org/hasMeasurement", comment_lines: ["A measurement of an item, For example, the inseam of pants, the wheel size of a bicycle, the gauge of a screw, or the carbon footprint measured for certification by an authority. Usually an exact measurement, but can also be a range of measurements for adjustable products, for example belts and ski bindings."].freeze, ranges: ["QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, size_group: { schema_name: "sizeGroup", schema_url: "https://schema.org/sizeGroup", comment_lines: ["The size group (also known as \"size type\") for a product's size. Size groups are common in the fashion industry to define size segments and suggested audiences for wearable products. Multiple values can be combined, for example \"men's big and tall\", \"petite maternity\" or \"regular\"."].freeze, ranges: ["SizeGroupEnumeration", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, size_system: { schema_name: "sizeSystem", schema_url: "https://schema.org/sizeSystem", comment_lines: ["The size system used to identify a product's size. Typically either a standard (for example, \"GS1\" or \"ISO-EN13402\"), country code (for example \"US\" or \"JP\"), or a measuring system (for example \"Metric\" or \"Imperial\")."].freeze, ranges: ["SizeSystemEnumeration", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, suggested_age: { schema_name: "suggestedAge", schema_url: "https://schema.org/suggestedAge", comment_lines: ["The age or age range for the intended audience or person, for example 3-12 months for infants, 1-5 years for toddlers."].freeze, ranges: ["QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, suggested_gender: { schema_name: "suggestedGender", schema_url: "https://schema.org/suggestedGender", comment_lines: ["The suggested gender of the intended person or audience, for example \"male\", \"female\", or \"unisex\"."].freeze, ranges: ["GenderType", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, suggested_measurement: { schema_name: "suggestedMeasurement", schema_url: "https://schema.org/suggestedMeasurement", comment_lines: ["A suggested range of body measurements for the intended audience or person, for example inseam between 32 and 34 inches or height between 170 and 190 cm. Typically found on a size chart for wearable products."].freeze, ranges: ["QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#has_measurement ⇒ Object
A measurement of an item, For example, the inseam of pants, the wheel size of a bicycle, the gauge of a screw, or the carbon footprint measured for certification by an authority. Usually an exact measurement, but can also be a range of measurements for adjustable products, for example belts and ski bindings.
77 78 79 |
# File 'lib/schema_org/mixins/size_specification.rb', line 77 def has_measurement read_property(:has_measurement) end |
#has_measurement=(value) ⇒ Object
A measurement of an item, For example, the inseam of pants, the wheel size of a bicycle, the gauge of a screw, or the carbon footprint measured for certification by an authority. Usually an exact measurement, but can also be a range of measurements for adjustable products, for example belts and ski bindings.
82 83 84 |
# File 'lib/schema_org/mixins/size_specification.rb', line 82 def has_measurement=(value) write_property(:has_measurement, value) end |
#size_group ⇒ Object
The size group (also known as "size type") for a product's size. Size groups are common in the fashion industry to define size segments and suggested audiences for wearable products. Multiple values can be combined, for example "men's big and tall", "petite maternity" or "regular".
87 88 89 |
# File 'lib/schema_org/mixins/size_specification.rb', line 87 def size_group read_property(:size_group) end |
#size_group=(value) ⇒ Object
The size group (also known as "size type") for a product's size. Size groups are common in the fashion industry to define size segments and suggested audiences for wearable products. Multiple values can be combined, for example "men's big and tall", "petite maternity" or "regular".
92 93 94 |
# File 'lib/schema_org/mixins/size_specification.rb', line 92 def size_group=(value) write_property(:size_group, value) end |
#size_system ⇒ Object
The size system used to identify a product's size. Typically either a standard (for example, "GS1" or "ISO-EN13402"), country code (for example "US" or "JP"), or a measuring system (for example "Metric" or "Imperial").
97 98 99 |
# File 'lib/schema_org/mixins/size_specification.rb', line 97 def size_system read_property(:size_system) end |
#size_system=(value) ⇒ Object
The size system used to identify a product's size. Typically either a standard (for example, "GS1" or "ISO-EN13402"), country code (for example "US" or "JP"), or a measuring system (for example "Metric" or "Imperial").
102 103 104 |
# File 'lib/schema_org/mixins/size_specification.rb', line 102 def size_system=(value) write_property(:size_system, value) end |
#suggested_age ⇒ Object
The age or age range for the intended audience or person, for example 3-12 months for infants, 1-5 years for toddlers.
107 108 109 |
# File 'lib/schema_org/mixins/size_specification.rb', line 107 def suggested_age read_property(:suggested_age) end |
#suggested_age=(value) ⇒ Object
The age or age range for the intended audience or person, for example 3-12 months for infants, 1-5 years for toddlers.
112 113 114 |
# File 'lib/schema_org/mixins/size_specification.rb', line 112 def suggested_age=(value) write_property(:suggested_age, value) end |
#suggested_gender ⇒ Object
The suggested gender of the intended person or audience, for example "male", "female", or "unisex".
117 118 119 |
# File 'lib/schema_org/mixins/size_specification.rb', line 117 def suggested_gender read_property(:suggested_gender) end |
#suggested_gender=(value) ⇒ Object
The suggested gender of the intended person or audience, for example "male", "female", or "unisex".
122 123 124 |
# File 'lib/schema_org/mixins/size_specification.rb', line 122 def suggested_gender=(value) write_property(:suggested_gender, value) end |
#suggested_measurement ⇒ Object
A suggested range of body measurements for the intended audience or person, for example inseam between 32 and 34 inches or height between 170 and 190 cm. Typically found on a size chart for wearable products.
127 128 129 |
# File 'lib/schema_org/mixins/size_specification.rb', line 127 def suggested_measurement read_property(:suggested_measurement) end |
#suggested_measurement=(value) ⇒ Object
A suggested range of body measurements for the intended audience or person, for example inseam between 32 and 34 inches or height between 170 and 190 cm. Typically found on a size chart for wearable products.
132 133 134 |
# File 'lib/schema_org/mixins/size_specification.rb', line 132 def suggested_measurement=(value) write_property(:suggested_measurement, value) end |