Module: SchemaOrg::Mixins::SoftwareSourceCode
- Includes:
- CreativeWork
- Included in:
- SoftwareSourceCode
- Defined in:
- lib/schema_org/mixins/software_source_code.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#code_repository ⇒ Object
Link to the repository where the un-compiled, human readable code and related code is located (SVN, GitHub, CodePlex).
-
#code_repository=(value) ⇒ Object
Link to the repository where the un-compiled, human readable code and related code is located (SVN, GitHub, CodePlex).
-
#code_sample_type ⇒ Object
What type of code sample: full (compile ready) solution, code snippet, inline code, scripts, template.
-
#code_sample_type=(value) ⇒ Object
What type of code sample: full (compile ready) solution, code snippet, inline code, scripts, template.
-
#programming_language ⇒ Object
The computer programming language.
-
#programming_language=(value) ⇒ Object
The computer programming language.
-
#runtime ⇒ Object
Runtime platform or script interpreter dependencies (example: Java v1, Python 2.3, .NET Framework 3.0).
-
#runtime=(value) ⇒ Object
Runtime platform or script interpreter dependencies (example: Java v1, Python 2.3, .NET Framework 3.0).
-
#runtime_platform ⇒ Object
Runtime platform or script interpreter dependencies (example: Java v1, Python 2.3, .NET Framework 3.0).
-
#runtime_platform=(value) ⇒ Object
Runtime platform or script interpreter dependencies (example: Java v1, Python 2.3, .NET Framework 3.0).
-
#sample_type ⇒ Object
What type of code sample: full (compile ready) solution, code snippet, inline code, scripts, template.
-
#sample_type=(value) ⇒ Object
What type of code sample: full (compile ready) solution, code snippet, inline code, scripts, template.
-
#target_product ⇒ Object
Target Operating System / Product to which the code applies.
-
#target_product=(value) ⇒ Object
Target Operating System / Product to which the code applies.
Methods included from CreativeWork
#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #country_of_origin, #country_of_origin=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/schema_org/mixins/software_source_code.rb', line 11 def self.schema_property_definitions { code_repository: { schema_name: "codeRepository", schema_url: "https://schema.org/codeRepository", comment_lines: ["Link to the repository where the un-compiled, human readable code and related code is located (SVN, GitHub, CodePlex)."].freeze, ranges: ["URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, code_sample_type: { schema_name: "codeSampleType", schema_url: "https://schema.org/codeSampleType", comment_lines: ["What type of code sample: full (compile ready) solution, code snippet, inline code, scripts, template."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["sampleType"].freeze }.freeze, programming_language: { schema_name: "programmingLanguage", schema_url: "https://schema.org/programmingLanguage", comment_lines: ["The computer programming language."].freeze, ranges: ["ComputerLanguage", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, runtime: { schema_name: "runtime", schema_url: "https://schema.org/runtime", comment_lines: ["Runtime platform or script interpreter dependencies (example: Java v1, Python 2.3, .NET Framework 3.0)."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "runtimePlatform", supersedes: nil }.freeze, runtime_platform: { schema_name: "runtimePlatform", schema_url: "https://schema.org/runtimePlatform", comment_lines: ["Runtime platform or script interpreter dependencies (example: Java v1, Python 2.3, .NET Framework 3.0)."].freeze, ranges: ["RuntimePlatform", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: ["runtime"].freeze }.freeze, sample_type: { schema_name: "sampleType", schema_url: "https://schema.org/sampleType", comment_lines: ["What type of code sample: full (compile ready) solution, code snippet, inline code, scripts, template."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "codeSampleType", supersedes: nil }.freeze, target_product: { schema_name: "targetProduct", schema_url: "https://schema.org/targetProduct", comment_lines: ["Target Operating System / Product to which the code applies. If applies to several versions, just the product name can be used."].freeze, ranges: ["SoftwareApplication"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#code_repository ⇒ Object
Link to the repository where the un-compiled, human readable code and related code is located (SVN, GitHub, CodePlex).
87 88 89 |
# File 'lib/schema_org/mixins/software_source_code.rb', line 87 def code_repository read_property(:code_repository) end |
#code_repository=(value) ⇒ Object
Link to the repository where the un-compiled, human readable code and related code is located (SVN, GitHub, CodePlex).
92 93 94 |
# File 'lib/schema_org/mixins/software_source_code.rb', line 92 def code_repository=(value) write_property(:code_repository, value) end |
#code_sample_type ⇒ Object
What type of code sample: full (compile ready) solution, code snippet, inline code, scripts, template.
Supersedes sampleType.
98 99 100 |
# File 'lib/schema_org/mixins/software_source_code.rb', line 98 def code_sample_type read_property(:code_sample_type) end |
#code_sample_type=(value) ⇒ Object
What type of code sample: full (compile ready) solution, code snippet, inline code, scripts, template.
Supersedes sampleType.
104 105 106 |
# File 'lib/schema_org/mixins/software_source_code.rb', line 104 def code_sample_type=(value) write_property(:code_sample_type, value) end |
#programming_language ⇒ Object
The computer programming language.
109 110 111 |
# File 'lib/schema_org/mixins/software_source_code.rb', line 109 def programming_language read_property(:programming_language) end |
#programming_language=(value) ⇒ Object
The computer programming language.
114 115 116 |
# File 'lib/schema_org/mixins/software_source_code.rb', line 114 def programming_language=(value) write_property(:programming_language, value) end |
#runtime ⇒ Object
Runtime platform or script interpreter dependencies (example: Java v1, Python 2.3, .NET Framework 3.0).
Superseded by runtimePlatform.
120 121 122 |
# File 'lib/schema_org/mixins/software_source_code.rb', line 120 def runtime read_property(:runtime) end |
#runtime=(value) ⇒ Object
Runtime platform or script interpreter dependencies (example: Java v1, Python 2.3, .NET Framework 3.0).
Superseded by runtimePlatform.
126 127 128 |
# File 'lib/schema_org/mixins/software_source_code.rb', line 126 def runtime=(value) write_property(:runtime, value) end |
#runtime_platform ⇒ Object
Runtime platform or script interpreter dependencies (example: Java v1, Python 2.3, .NET Framework 3.0).
Supersedes runtime.
132 133 134 |
# File 'lib/schema_org/mixins/software_source_code.rb', line 132 def runtime_platform read_property(:runtime_platform) end |
#runtime_platform=(value) ⇒ Object
Runtime platform or script interpreter dependencies (example: Java v1, Python 2.3, .NET Framework 3.0).
Supersedes runtime.
138 139 140 |
# File 'lib/schema_org/mixins/software_source_code.rb', line 138 def runtime_platform=(value) write_property(:runtime_platform, value) end |
#sample_type ⇒ Object
What type of code sample: full (compile ready) solution, code snippet, inline code, scripts, template.
Superseded by codeSampleType.
144 145 146 |
# File 'lib/schema_org/mixins/software_source_code.rb', line 144 def sample_type read_property(:sample_type) end |
#sample_type=(value) ⇒ Object
What type of code sample: full (compile ready) solution, code snippet, inline code, scripts, template.
Superseded by codeSampleType.
150 151 152 |
# File 'lib/schema_org/mixins/software_source_code.rb', line 150 def sample_type=(value) write_property(:sample_type, value) end |
#target_product ⇒ Object
Target Operating System / Product to which the code applies. If applies to several versions, just the product name can be used.
155 156 157 |
# File 'lib/schema_org/mixins/software_source_code.rb', line 155 def target_product read_property(:target_product) end |
#target_product=(value) ⇒ Object
Target Operating System / Product to which the code applies. If applies to several versions, just the product name can be used.
160 161 162 |
# File 'lib/schema_org/mixins/software_source_code.rb', line 160 def target_product=(value) write_property(:target_product, value) end |