Module: SchemaOrg::Mixins::SolveMathAction
- Includes:
- Action
- Included in:
- SolveMathAction
- Defined in:
- lib/schema_org/mixins/solve_math_action.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#edu_question_type ⇒ Object
For questions that are part of learning resources (e.g. Quiz), eduQuestionType indicates the format of question being given.
-
#edu_question_type=(value) ⇒ Object
For questions that are part of learning resources (e.g. Quiz), eduQuestionType indicates the format of question being given.
Methods included from Action
#action_process, #action_process=, #action_status, #action_status=, #agent, #agent=, #end_time, #end_time=, #error, #error=, #instrument, #instrument=, #location, #location=, #object, #object=, #participant, #participant=, #provider, #provider=, #result, #result=, #start_time, #start_time=, #target, #target=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 |
# File 'lib/schema_org/mixins/solve_math_action.rb', line 11 def self.schema_property_definitions { edu_question_type: { schema_name: "eduQuestionType", schema_url: "https://schema.org/eduQuestionType", comment_lines: ["For questions that are part of learning resources (e.g. Quiz), eduQuestionType indicates the format of question being given. Example: \"Multiple choice\", \"Open ended\", \"Flashcard\"."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#edu_question_type ⇒ Object
For questions that are part of learning resources (e.g. Quiz), eduQuestionType indicates the format of question being given. Example: "Multiple choice", "Open ended", "Flashcard".
27 28 29 |
# File 'lib/schema_org/mixins/solve_math_action.rb', line 27 def edu_question_type read_property(:edu_question_type) end |
#edu_question_type=(value) ⇒ Object
For questions that are part of learning resources (e.g. Quiz), eduQuestionType indicates the format of question being given. Example: "Multiple choice", "Open ended", "Flashcard".
32 33 34 |
# File 'lib/schema_org/mixins/solve_math_action.rb', line 32 def edu_question_type=(value) write_property(:edu_question_type, value) end |