Module: SchemaOrg::Mixins::SpeakableSpecification
- Includes:
- Intangible
- Included in:
- SpeakableSpecification
- Defined in:
- lib/schema_org/mixins/speakable_specification.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#css_selector ⇒ Object
A CSS selector, e.g.
-
#css_selector=(value) ⇒ Object
A CSS selector, e.g.
-
#xpath ⇒ Object
An XPath, e.g.
-
#xpath=(value) ⇒ Object
An XPath, e.g.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/schema_org/mixins/speakable_specification.rb', line 11 def self.schema_property_definitions { css_selector: { schema_name: "cssSelector", schema_url: "https://schema.org/cssSelector", comment_lines: ["A CSS selector, e.g. of a [[SpeakableSpecification]] or [[WebPageElement]]. In the latter case, multiple matches within a page can constitute a single conceptual \"Web page element\"."].freeze, ranges: ["CssSelectorType"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, xpath: { schema_name: "xpath", schema_url: "https://schema.org/xpath", comment_lines: ["An XPath, e.g. of a [[SpeakableSpecification]] or [[WebPageElement]]. In the latter case, multiple matches within a page can constitute a single conceptual \"Web page element\"."].freeze, ranges: ["XPathType"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#css_selector ⇒ Object
A CSS selector, e.g. of a [[SpeakableSpecification]] or [[WebPageElement]]. In the latter case, multiple matches within a page can constitute a single conceptual "Web page element".
37 38 39 |
# File 'lib/schema_org/mixins/speakable_specification.rb', line 37 def css_selector read_property(:css_selector) end |
#css_selector=(value) ⇒ Object
A CSS selector, e.g. of a [[SpeakableSpecification]] or [[WebPageElement]]. In the latter case, multiple matches within a page can constitute a single conceptual "Web page element".
42 43 44 |
# File 'lib/schema_org/mixins/speakable_specification.rb', line 42 def css_selector=(value) write_property(:css_selector, value) end |
#xpath ⇒ Object
An XPath, e.g. of a [[SpeakableSpecification]] or [[WebPageElement]]. In the latter case, multiple matches within a page can constitute a single conceptual "Web page element".
47 48 49 |
# File 'lib/schema_org/mixins/speakable_specification.rb', line 47 def xpath read_property(:xpath) end |
#xpath=(value) ⇒ Object
An XPath, e.g. of a [[SpeakableSpecification]] or [[WebPageElement]]. In the latter case, multiple matches within a page can constitute a single conceptual "Web page element".
52 53 54 |
# File 'lib/schema_org/mixins/speakable_specification.rb', line 52 def xpath=(value) write_property(:xpath, value) end |