Module: SchemaOrg::Mixins::SportsEvent
Class Method Summary collapse
Instance Method Summary collapse
-
#away_team ⇒ Object
The away team in a sports event.
-
#away_team=(value) ⇒ Object
The away team in a sports event.
-
#competitor ⇒ Object
A competitor in a sports event.
-
#competitor=(value) ⇒ Object
A competitor in a sports event.
-
#home_team ⇒ Object
The home team in a sports event.
-
#home_team=(value) ⇒ Object
The home team in a sports event.
-
#referee ⇒ Object
An official who watches a game or match closely to enforce the rules and arbitrate on matters arising from the play such as referees, umpires or judges.
-
#referee=(value) ⇒ Object
An official who watches a game or match closely to enforce the rules and arbitrate on matters arising from the play such as referees, umpires or judges.
-
#sport ⇒ Object
A type of sport (e.g. Baseball).
-
#sport=(value) ⇒ Object
A type of sport (e.g. Baseball).
Methods included from Event
#about, #about=, #actor, #actor=, #aggregate_rating, #aggregate_rating=, #attendee, #attendee=, #attendees, #attendees=, #audience, #audience=, #composer, #composer=, #contributor, #contributor=, #director, #director=, #door_time, #door_time=, #duration, #duration=, #end_date, #end_date=, #event_attendance_mode, #event_attendance_mode=, #event_schedule, #event_schedule=, #event_status, #event_status=, #funder, #funder=, #funding, #funding=, #has_participation_offer, #has_participation_offer=, #has_sponsorship_offer, #has_sponsorship_offer=, #in_language, #in_language=, #is_accessible_for_free, #is_accessible_for_free=, #keywords, #keywords=, #location, #location=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #maximum_physical_attendee_capacity, #maximum_physical_attendee_capacity=, #maximum_virtual_attendee_capacity, #maximum_virtual_attendee_capacity=, #offers, #offers=, #organizer, #organizer=, #performer, #performer=, #performers, #performers=, #previous_start_date, #previous_start_date=, #recorded_in, #recorded_in=, #remaining_attendee_capacity, #remaining_attendee_capacity=, #review, #review=, #sponsor, #sponsor=, #start_date, #start_date=, #sub_event, #sub_event=, #sub_events, #sub_events=, #super_event, #super_event=, #translator, #translator=, #typical_age_range, #typical_age_range=, #work_featured, #work_featured=, #work_performed, #work_performed=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/schema_org/mixins/sports_event.rb', line 11 def self.schema_property_definitions { away_team: { schema_name: "awayTeam", schema_url: "https://schema.org/awayTeam", comment_lines: ["The away team in a sports event."].freeze, ranges: ["Person", "SportsTeam"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, competitor: { schema_name: "competitor", schema_url: "https://schema.org/competitor", comment_lines: ["A competitor in a sports event."].freeze, ranges: ["Person", "SportsTeam"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, home_team: { schema_name: "homeTeam", schema_url: "https://schema.org/homeTeam", comment_lines: ["The home team in a sports event."].freeze, ranges: ["Person", "SportsTeam"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, referee: { schema_name: "referee", schema_url: "https://schema.org/referee", comment_lines: ["An official who watches a game or match closely to enforce the rules and arbitrate on matters arising from the play such as referees, umpires or judges. The name of the effective function can vary according to the sport."].freeze, ranges: ["Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, sport: { schema_name: "sport", schema_url: "https://schema.org/sport", comment_lines: ["A type of sport (e.g. Baseball)."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#away_team ⇒ Object
The away team in a sports event.
67 68 69 |
# File 'lib/schema_org/mixins/sports_event.rb', line 67 def away_team read_property(:away_team) end |
#away_team=(value) ⇒ Object
The away team in a sports event.
72 73 74 |
# File 'lib/schema_org/mixins/sports_event.rb', line 72 def away_team=(value) write_property(:away_team, value) end |
#competitor ⇒ Object
A competitor in a sports event.
77 78 79 |
# File 'lib/schema_org/mixins/sports_event.rb', line 77 def competitor read_property(:competitor) end |
#competitor=(value) ⇒ Object
A competitor in a sports event.
82 83 84 |
# File 'lib/schema_org/mixins/sports_event.rb', line 82 def competitor=(value) write_property(:competitor, value) end |
#home_team ⇒ Object
The home team in a sports event.
87 88 89 |
# File 'lib/schema_org/mixins/sports_event.rb', line 87 def home_team read_property(:home_team) end |
#home_team=(value) ⇒ Object
The home team in a sports event.
92 93 94 |
# File 'lib/schema_org/mixins/sports_event.rb', line 92 def home_team=(value) write_property(:home_team, value) end |
#referee ⇒ Object
An official who watches a game or match closely to enforce the rules and arbitrate on matters arising from the play such as referees, umpires or judges. The name of the effective function can vary according to the sport.
97 98 99 |
# File 'lib/schema_org/mixins/sports_event.rb', line 97 def referee read_property(:referee) end |
#referee=(value) ⇒ Object
An official who watches a game or match closely to enforce the rules and arbitrate on matters arising from the play such as referees, umpires or judges. The name of the effective function can vary according to the sport.
102 103 104 |
# File 'lib/schema_org/mixins/sports_event.rb', line 102 def referee=(value) write_property(:referee, value) end |
#sport ⇒ Object
A type of sport (e.g. Baseball).
107 108 109 |
# File 'lib/schema_org/mixins/sports_event.rb', line 107 def sport read_property(:sport) end |
#sport=(value) ⇒ Object
A type of sport (e.g. Baseball).
112 113 114 |
# File 'lib/schema_org/mixins/sports_event.rb', line 112 def sport=(value) write_property(:sport, value) end |