Module: SchemaOrg::Mixins::StatisticalVariable
- Includes:
- ConstraintNode
- Included in:
- StatisticalVariable
- Defined in:
- lib/schema_org/mixins/statistical_variable.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#measured_property ⇒ Object
The measuredProperty of an [[Observation]], typically via its [[StatisticalVariable]].
-
#measured_property=(value) ⇒ Object
The measuredProperty of an [[Observation]], typically via its [[StatisticalVariable]].
-
#measurement_denominator ⇒ Object
Identifies the denominator variable when an observation represents a ratio or percentage.
-
#measurement_denominator=(value) ⇒ Object
Identifies the denominator variable when an observation represents a ratio or percentage.
-
#measurement_method ⇒ Object
A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].
-
#measurement_method=(value) ⇒ Object
A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].
-
#measurement_qualifier ⇒ Object
Provides additional qualification to an observation.
-
#measurement_qualifier=(value) ⇒ Object
Provides additional qualification to an observation.
-
#measurement_technique ⇒ Object
A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]).
-
#measurement_technique=(value) ⇒ Object
A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]).
-
#population_type ⇒ Object
Indicates the populationType common to all members of a [[StatisticalPopulation]] or all cases within the scope of a [[StatisticalVariable]].
-
#population_type=(value) ⇒ Object
Indicates the populationType common to all members of a [[StatisticalPopulation]] or all cases within the scope of a [[StatisticalVariable]].
-
#stat_type ⇒ Object
Indicates the kind of statistic represented by a [[StatisticalVariable]], e.g.
-
#stat_type=(value) ⇒ Object
Indicates the kind of statistic represented by a [[StatisticalVariable]], e.g.
Methods included from ConstraintNode
#constraint_property, #constraint_property=, #num_constraints, #num_constraints=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/schema_org/mixins/statistical_variable.rb', line 11 def self.schema_property_definitions { measured_property: { schema_name: "measuredProperty", schema_url: "https://schema.org/measuredProperty", comment_lines: ["The measuredProperty of an [[Observation]], typically via its [[StatisticalVariable]]. There are various kinds of applicable [[Property]]: a schema.org property, a property from other RDF-compatible systems, e.g. W3C RDF Data Cube, Data Commons, Wikidata, or schema.org extensions such as [GS1's](https://www.gs1.org/voc/?show=properties)."].freeze, ranges: [].freeze, external_ranges: ["Property"].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, measurement_denominator: { schema_name: "measurementDenominator", schema_url: "https://schema.org/measurementDenominator", comment_lines: ["Identifies the denominator variable when an observation represents a ratio or percentage."].freeze, ranges: ["StatisticalVariable"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, measurement_method: { schema_name: "measurementMethod", schema_url: "https://schema.org/measurementMethod", comment_lines: ["A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]]."].freeze, ranges: ["DefinedTerm", "MeasurementMethodEnum", "Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, measurement_qualifier: { schema_name: "measurementQualifier", schema_url: "https://schema.org/measurementQualifier", comment_lines: ["Provides additional qualification to an observation. For example, a GDP observation measures the Nominal value."].freeze, ranges: ["Enumeration"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, measurement_technique: { schema_name: "measurementTechnique", schema_url: "https://schema.org/measurementTechnique", comment_lines: ["A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]). Often but not necessarily each [[variableMeasured]] will have an explicit representation as (or mapping to) an property such as those defined in Schema.org, or other RDF vocabularies and \"knowledge graphs\". In that case the subproperty of [[variableMeasured]] called [[measuredProperty]] is applicable.", "", "The [[measurementTechnique]] property helps when extra clarification is needed about how a [[measuredProperty]] was measured. This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but can often serve as a high level summary for dataset discovery.", "", "For example, if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]] could be: \"mass spectrometry\" or \"nmr spectroscopy\" or \"colorimetry\" or \"immunofluorescence\". If the [[variableMeasured]] is \"depression rating\", the [[measurementTechnique]] could be \"Zung Scale\" or \"HAM-D\" or \"Beck Depression Inventory\".", "", "If there are several [[variableMeasured]] properties recorded for some given data object, use a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]]. The value can also be from an enumeration, organized as a [[MeasurementMethodEnum]]."].freeze, ranges: ["DefinedTerm", "MeasurementMethodEnum", "Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, population_type: { schema_name: "populationType", schema_url: "https://schema.org/populationType", comment_lines: ["Indicates the populationType common to all members of a [[StatisticalPopulation]] or all cases within the scope of a [[StatisticalVariable]]."].freeze, ranges: [].freeze, external_ranges: ["Class"].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, stat_type: { schema_name: "statType", schema_url: "https://schema.org/statType", comment_lines: ["Indicates the kind of statistic represented by a [[StatisticalVariable]], e.g. mean, count etc. The value of statType is a property, either from within Schema.org (e.g. [[median]], [[marginOfError]], [[maxValue]], [[minValue]]) or from other compatible (e.g. RDF) systems such as DataCommons.org or Wikidata.org."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: ["Property"].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#measured_property ⇒ Object
The measuredProperty of an [[Observation]], typically via its [[StatisticalVariable]]. There are various kinds of applicable [[Property]]: a schema.org property, a property from other RDF-compatible systems, e.g. W3C RDF Data Cube, Data Commons, Wikidata, or schema.org extensions such as GS1's.
87 88 89 |
# File 'lib/schema_org/mixins/statistical_variable.rb', line 87 def measured_property read_property(:measured_property) end |
#measured_property=(value) ⇒ Object
The measuredProperty of an [[Observation]], typically via its [[StatisticalVariable]]. There are various kinds of applicable [[Property]]: a schema.org property, a property from other RDF-compatible systems, e.g. W3C RDF Data Cube, Data Commons, Wikidata, or schema.org extensions such as GS1's.
92 93 94 |
# File 'lib/schema_org/mixins/statistical_variable.rb', line 92 def measured_property=(value) write_property(:measured_property, value) end |
#measurement_denominator ⇒ Object
Identifies the denominator variable when an observation represents a ratio or percentage.
97 98 99 |
# File 'lib/schema_org/mixins/statistical_variable.rb', line 97 def measurement_denominator read_property(:measurement_denominator) end |
#measurement_denominator=(value) ⇒ Object
Identifies the denominator variable when an observation represents a ratio or percentage.
102 103 104 |
# File 'lib/schema_org/mixins/statistical_variable.rb', line 102 def measurement_denominator=(value) write_property(:measurement_denominator, value) end |
#measurement_method ⇒ Object
A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].
107 108 109 |
# File 'lib/schema_org/mixins/statistical_variable.rb', line 107 def measurement_method read_property(:measurement_method) end |
#measurement_method=(value) ⇒ Object
A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].
112 113 114 |
# File 'lib/schema_org/mixins/statistical_variable.rb', line 112 def measurement_method=(value) write_property(:measurement_method, value) end |
#measurement_qualifier ⇒ Object
Provides additional qualification to an observation. For example, a GDP observation measures the Nominal value.
117 118 119 |
# File 'lib/schema_org/mixins/statistical_variable.rb', line 117 def measurement_qualifier read_property(:measurement_qualifier) end |
#measurement_qualifier=(value) ⇒ Object
Provides additional qualification to an observation. For example, a GDP observation measures the Nominal value.
122 123 124 |
# File 'lib/schema_org/mixins/statistical_variable.rb', line 122 def measurement_qualifier=(value) write_property(:measurement_qualifier, value) end |
#measurement_technique ⇒ Object
A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]). Often but not necessarily each [[variableMeasured]] will have an explicit representation as (or mapping to) an property such as those defined in Schema.org, or other RDF vocabularies and "knowledge graphs". In that case the subproperty of [[variableMeasured]] called [[measuredProperty]] is applicable.
The [[measurementTechnique]] property helps when extra clarification is needed about how a [[measuredProperty]] was measured. This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but can often serve as a high level summary for dataset discovery.
For example, if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]] could be: "mass spectrometry" or "nmr spectroscopy" or "colorimetry" or "immunofluorescence". If the [[variableMeasured]] is "depression rating", the [[measurementTechnique]] could be "Zung Scale" or "HAM-D" or "Beck Depression Inventory".
If there are several [[variableMeasured]] properties recorded for some given data object, use a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]]. The value can also be from an enumeration, organized as a [[MeasurementMethodEnum]].
133 134 135 |
# File 'lib/schema_org/mixins/statistical_variable.rb', line 133 def measurement_technique read_property(:measurement_technique) end |
#measurement_technique=(value) ⇒ Object
A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]). Often but not necessarily each [[variableMeasured]] will have an explicit representation as (or mapping to) an property such as those defined in Schema.org, or other RDF vocabularies and "knowledge graphs". In that case the subproperty of [[variableMeasured]] called [[measuredProperty]] is applicable.
The [[measurementTechnique]] property helps when extra clarification is needed about how a [[measuredProperty]] was measured. This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but can often serve as a high level summary for dataset discovery.
For example, if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]] could be: "mass spectrometry" or "nmr spectroscopy" or "colorimetry" or "immunofluorescence". If the [[variableMeasured]] is "depression rating", the [[measurementTechnique]] could be "Zung Scale" or "HAM-D" or "Beck Depression Inventory".
If there are several [[variableMeasured]] properties recorded for some given data object, use a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]]. The value can also be from an enumeration, organized as a [[MeasurementMethodEnum]].
144 145 146 |
# File 'lib/schema_org/mixins/statistical_variable.rb', line 144 def measurement_technique=(value) write_property(:measurement_technique, value) end |
#population_type ⇒ Object
Indicates the populationType common to all members of a [[StatisticalPopulation]] or all cases within the scope of a [[StatisticalVariable]].
149 150 151 |
# File 'lib/schema_org/mixins/statistical_variable.rb', line 149 def population_type read_property(:population_type) end |
#population_type=(value) ⇒ Object
Indicates the populationType common to all members of a [[StatisticalPopulation]] or all cases within the scope of a [[StatisticalVariable]].
154 155 156 |
# File 'lib/schema_org/mixins/statistical_variable.rb', line 154 def population_type=(value) write_property(:population_type, value) end |
#stat_type ⇒ Object
Indicates the kind of statistic represented by a [[StatisticalVariable]], e.g. mean, count etc. The value of statType is a property, either from within Schema.org (e.g. [[median]], [[marginOfError]], [[maxValue]], [[minValue]]) or from other compatible (e.g. RDF) systems such as DataCommons.org or Wikidata.org.
159 160 161 |
# File 'lib/schema_org/mixins/statistical_variable.rb', line 159 def stat_type read_property(:stat_type) end |
#stat_type=(value) ⇒ Object
Indicates the kind of statistic represented by a [[StatisticalVariable]], e.g. mean, count etc. The value of statType is a property, either from within Schema.org (e.g. [[median]], [[marginOfError]], [[maxValue]], [[minValue]]) or from other compatible (e.g. RDF) systems such as DataCommons.org or Wikidata.org.
164 165 166 |
# File 'lib/schema_org/mixins/statistical_variable.rb', line 164 def stat_type=(value) write_property(:stat_type, value) end |