Module: SchemaOrg::Mixins::SuperficialAnatomy
- Includes:
- MedicalEntity
- Included in:
- SuperficialAnatomy
- Defined in:
- lib/schema_org/mixins/superficial_anatomy.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#associated_pathophysiology ⇒ Object
If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system.
-
#associated_pathophysiology=(value) ⇒ Object
If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system.
-
#related_anatomy ⇒ Object
Anatomical systems or structures that relate to the superficial anatomy.
-
#related_anatomy=(value) ⇒ Object
Anatomical systems or structures that relate to the superficial anatomy.
-
#related_condition ⇒ Object
A medical condition associated with this anatomy.
-
#related_condition=(value) ⇒ Object
A medical condition associated with this anatomy.
-
#related_therapy ⇒ Object
A medical therapy related to this anatomy.
-
#related_therapy=(value) ⇒ Object
A medical therapy related to this anatomy.
-
#significance ⇒ Object
The significance associated with the superficial anatomy; as an example, how characteristics of the superficial anatomy can suggest underlying medical conditions or courses of treatment.
-
#significance=(value) ⇒ Object
The significance associated with the superficial anatomy; as an example, how characteristics of the superficial anatomy can suggest underlying medical conditions or courses of treatment.
Methods included from MedicalEntity
#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #study, #study=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/schema_org/mixins/superficial_anatomy.rb', line 11 def self.schema_property_definitions { associated_pathophysiology: { schema_name: "associatedPathophysiology", schema_url: "https://schema.org/associatedPathophysiology", comment_lines: ["If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, related_anatomy: { schema_name: "relatedAnatomy", schema_url: "https://schema.org/relatedAnatomy", comment_lines: ["Anatomical systems or structures that relate to the superficial anatomy."].freeze, ranges: ["AnatomicalStructure", "AnatomicalSystem"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, related_condition: { schema_name: "relatedCondition", schema_url: "https://schema.org/relatedCondition", comment_lines: ["A medical condition associated with this anatomy."].freeze, ranges: ["MedicalCondition"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, related_therapy: { schema_name: "relatedTherapy", schema_url: "https://schema.org/relatedTherapy", comment_lines: ["A medical therapy related to this anatomy."].freeze, ranges: ["MedicalTherapy"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, significance: { schema_name: "significance", schema_url: "https://schema.org/significance", comment_lines: ["The significance associated with the superficial anatomy; as an example, how characteristics of the superficial anatomy can suggest underlying medical conditions or courses of treatment."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#associated_pathophysiology ⇒ Object
If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system.
67 68 69 |
# File 'lib/schema_org/mixins/superficial_anatomy.rb', line 67 def associated_pathophysiology read_property(:associated_pathophysiology) end |
#associated_pathophysiology=(value) ⇒ Object
If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system.
72 73 74 |
# File 'lib/schema_org/mixins/superficial_anatomy.rb', line 72 def associated_pathophysiology=(value) write_property(:associated_pathophysiology, value) end |
#related_anatomy ⇒ Object
Anatomical systems or structures that relate to the superficial anatomy.
77 78 79 |
# File 'lib/schema_org/mixins/superficial_anatomy.rb', line 77 def read_property(:related_anatomy) end |
#related_anatomy=(value) ⇒ Object
Anatomical systems or structures that relate to the superficial anatomy.
82 83 84 |
# File 'lib/schema_org/mixins/superficial_anatomy.rb', line 82 def (value) write_property(:related_anatomy, value) end |
#related_condition ⇒ Object
A medical condition associated with this anatomy.
87 88 89 |
# File 'lib/schema_org/mixins/superficial_anatomy.rb', line 87 def read_property(:related_condition) end |
#related_condition=(value) ⇒ Object
A medical condition associated with this anatomy.
92 93 94 |
# File 'lib/schema_org/mixins/superficial_anatomy.rb', line 92 def (value) write_property(:related_condition, value) end |
#related_therapy ⇒ Object
A medical therapy related to this anatomy.
97 98 99 |
# File 'lib/schema_org/mixins/superficial_anatomy.rb', line 97 def read_property(:related_therapy) end |
#related_therapy=(value) ⇒ Object
A medical therapy related to this anatomy.
102 103 104 |
# File 'lib/schema_org/mixins/superficial_anatomy.rb', line 102 def (value) write_property(:related_therapy, value) end |
#significance ⇒ Object
The significance associated with the superficial anatomy; as an example, how characteristics of the superficial anatomy can suggest underlying medical conditions or courses of treatment.
107 108 109 |
# File 'lib/schema_org/mixins/superficial_anatomy.rb', line 107 def significance read_property(:significance) end |
#significance=(value) ⇒ Object
The significance associated with the superficial anatomy; as an example, how characteristics of the superficial anatomy can suggest underlying medical conditions or courses of treatment.
112 113 114 |
# File 'lib/schema_org/mixins/superficial_anatomy.rb', line 112 def significance=(value) write_property(:significance, value) end |