Module: SchemaOrg::Mixins::TVEpisode
Class Method Summary collapse
Instance Method Summary collapse
-
#country_of_origin ⇒ Object
The country of origin of something, including products as well as creative works such as movie and TV content.
-
#country_of_origin=(value) ⇒ Object
The country of origin of something, including products as well as creative works such as movie and TV content.
-
#part_of_tv_series ⇒ Object
The TV series to which this episode or season belongs.
-
#part_of_tv_series=(value) ⇒ Object
The TV series to which this episode or season belongs.
-
#subtitle_language ⇒ Object
Languages in which subtitles/captions are available, in IETF BCP 47 standard format.
-
#subtitle_language=(value) ⇒ Object
Languages in which subtitles/captions are available, in IETF BCP 47 standard format.
-
#title_eidr ⇒ Object
An EIDR (Entertainment Identifier Registry) [[identifier]] representing at the most general/abstract level, a work of film or television.
-
#title_eidr=(value) ⇒ Object
An EIDR (Entertainment Identifier Registry) [[identifier]] representing at the most general/abstract level, a work of film or television.
Methods included from Episode
#actor, #actor=, #actors, #actors=, #director, #director=, #directors, #directors=, #duration, #duration=, #episode_number, #episode_number=, #music_by, #music_by=, #part_of_season, #part_of_season=, #part_of_series, #part_of_series=, #production_company, #production_company=, #trailer, #trailer=
Methods included from CreativeWork
#about, #about=, #abstract, #abstract=, #access_mode, #access_mode=, #access_mode_sufficient, #access_mode_sufficient=, #accessibility_api, #accessibility_api=, #accessibility_control, #accessibility_control=, #accessibility_feature, #accessibility_feature=, #accessibility_hazard, #accessibility_hazard=, #accessibility_summary, #accessibility_summary=, #accountable_person, #accountable_person=, #acquire_license_page, #acquire_license_page=, #aggregate_rating, #aggregate_rating=, #alternative_headline, #alternative_headline=, #archived_at, #archived_at=, #assesses, #assesses=, #associated_media, #associated_media=, #audience, #audience=, #audio, #audio=, #author, #author=, #award, #award=, #awards, #awards=, #character, #character=, #citation, #citation=, #comment, #comment=, #comment_count, #comment_count=, #conditions_of_access, #conditions_of_access=, #content_location, #content_location=, #content_rating, #content_rating=, #content_reference_time, #content_reference_time=, #contributor, #contributor=, #copyright_holder, #copyright_holder=, #copyright_notice, #copyright_notice=, #copyright_year, #copyright_year=, #correction, #correction=, #creative_work_status, #creative_work_status=, #creator, #creator=, #credit_text, #credit_text=, #date_created, #date_created=, #date_modified, #date_modified=, #date_published, #date_published=, #digital_source_type, #digital_source_type=, #discussion_url, #discussion_url=, #display_location, #display_location=, #edit_eidr, #edit_eidr=, #editor, #editor=, #educational_alignment, #educational_alignment=, #educational_level, #educational_level=, #educational_use, #educational_use=, #encoding, #encoding=, #encoding_format, #encoding_format=, #encodings, #encodings=, #example_of_work, #example_of_work=, #expires, #expires=, #file_format, #file_format=, #funder, #funder=, #funding, #funding=, #genre, #genre=, #has_part, #has_part=, #headline, #headline=, #in_language, #in_language=, #interaction_statistic, #interaction_statistic=, #interactivity_type, #interactivity_type=, #interpreted_as_claim, #interpreted_as_claim=, #is_accessible_for_free, #is_accessible_for_free=, #is_based_on, #is_based_on=, #is_based_on_url, #is_based_on_url=, #is_family_friendly, #is_family_friendly=, #is_part_of, #is_part_of=, #keywords, #keywords=, #learning_resource_type, #learning_resource_type=, #license, #license=, #location_created, #location_created=, #main_entity, #main_entity=, #maintainer, #maintainer=, #material, #material=, #material_extent, #material_extent=, #mentions, #mentions=, #offers, #offers=, #pattern, #pattern=, #position, #position=, #producer, #producer=, #provider, #provider=, #publication, #publication=, #publisher, #publisher=, #publisher_imprint, #publisher_imprint=, #publishing_principles, #publishing_principles=, #recorded_at, #recorded_at=, #released_event, #released_event=, #review, #review=, #reviews, #reviews=, #schema_version, #schema_version=, #sd_date_published, #sd_date_published=, #sd_license, #sd_license=, #sd_publisher, #sd_publisher=, #size, #size=, #source_organization, #source_organization=, #spatial, #spatial=, #spatial_coverage, #spatial_coverage=, #sponsor, #sponsor=, #teaches, #teaches=, #temporal, #temporal=, #temporal_coverage, #temporal_coverage=, #text, #text=, #thumbnail, #thumbnail=, #thumbnail_url, #thumbnail_url=, #time_required, #time_required=, #translation_of_work, #translation_of_work=, #translator, #translator=, #typical_age_range, #typical_age_range=, #usage_info, #usage_info=, #version, #version=, #video, #video=, #word_count, #word_count=, #work_example, #work_example=, #work_translation, #work_translation=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/schema_org/mixins/tv_episode.rb', line 11 def self.schema_property_definitions { country_of_origin: { schema_name: "countryOfOrigin", schema_url: "https://schema.org/countryOfOrigin", comment_lines: ["The country of origin of something, including products as well as creative works such as movie and TV content.", "", "In the case of TV and movie, this would be the country of the principle offices of the production company or individual responsible for the movie. For other kinds of [[CreativeWork]] it is difficult to provide fully general guidance, and properties such as [[contentLocation]] and [[locationCreated]] may be more applicable.", "", "In the case of products, the country of origin of the product. The exact interpretation of this may vary by context and product type, and cannot be fully enumerated here."].freeze, ranges: ["Country"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, part_of_tv_series: { schema_name: "partOfTVSeries", schema_url: "https://schema.org/partOfTVSeries", comment_lines: ["The TV series to which this episode or season belongs."].freeze, ranges: ["TVSeries"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: "partOfSeries", supersedes: nil }.freeze, subtitle_language: { schema_name: "subtitleLanguage", schema_url: "https://schema.org/subtitleLanguage", comment_lines: ["Languages in which subtitles/captions are available, in [IETF BCP 47 standard format](http://tools.ietf.org/html/bcp47)."].freeze, ranges: ["Language", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, title_eidr: { schema_name: "titleEIDR", schema_url: "https://schema.org/titleEIDR", comment_lines: ["An [EIDR](https://eidr.org/) (Entertainment Identifier Registry) [[identifier]] representing at the most general/abstract level, a work of film or television.", "", "For example, the motion picture known as \"Ghostbusters\" has a titleEIDR of \"10.5240/7EC7-228A-510A-053E-CBB8-J\". This title (or work) may have several variants, which EIDR calls \"edits\". See [[editEIDR]].", "", "Since schema.org types like [[Movie]], [[TVEpisode]], [[TVSeason]], and [[TVSeries]] can be used for both works and their multiple expressions, it is possible to use [[titleEIDR]] alone (for a general description), or alongside [[editEIDR]] for a more edit-specific description."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#country_of_origin ⇒ Object
The country of origin of something, including products as well as creative works such as movie and TV content.
In the case of TV and movie, this would be the country of the principle offices of the production company or individual responsible for the movie. For other kinds of [[CreativeWork]] it is difficult to provide fully general guidance, and properties such as [[contentLocation]] and [[locationCreated]] may be more applicable.
In the case of products, the country of origin of the product. The exact interpretation of this may vary by context and product type, and cannot be fully enumerated here.
61 62 63 |
# File 'lib/schema_org/mixins/tv_episode.rb', line 61 def country_of_origin read_property(:country_of_origin) end |
#country_of_origin=(value) ⇒ Object
The country of origin of something, including products as well as creative works such as movie and TV content.
In the case of TV and movie, this would be the country of the principle offices of the production company or individual responsible for the movie. For other kinds of [[CreativeWork]] it is difficult to provide fully general guidance, and properties such as [[contentLocation]] and [[locationCreated]] may be more applicable.
In the case of products, the country of origin of the product. The exact interpretation of this may vary by context and product type, and cannot be fully enumerated here.
70 71 72 |
# File 'lib/schema_org/mixins/tv_episode.rb', line 70 def country_of_origin=(value) write_property(:country_of_origin, value) end |
#part_of_tv_series ⇒ Object
The TV series to which this episode or season belongs.
Superseded by partOfSeries.
76 77 78 |
# File 'lib/schema_org/mixins/tv_episode.rb', line 76 def part_of_tv_series read_property(:part_of_tv_series) end |
#part_of_tv_series=(value) ⇒ Object
The TV series to which this episode or season belongs.
Superseded by partOfSeries.
82 83 84 |
# File 'lib/schema_org/mixins/tv_episode.rb', line 82 def part_of_tv_series=(value) write_property(:part_of_tv_series, value) end |
#subtitle_language ⇒ Object
Languages in which subtitles/captions are available, in IETF BCP 47 standard format.
87 88 89 |
# File 'lib/schema_org/mixins/tv_episode.rb', line 87 def subtitle_language read_property(:subtitle_language) end |
#subtitle_language=(value) ⇒ Object
Languages in which subtitles/captions are available, in IETF BCP 47 standard format.
92 93 94 |
# File 'lib/schema_org/mixins/tv_episode.rb', line 92 def subtitle_language=(value) write_property(:subtitle_language, value) end |
#title_eidr ⇒ Object
An EIDR (Entertainment Identifier Registry) [[identifier]] representing at the most general/abstract level, a work of film or television.
For example, the motion picture known as "Ghostbusters" has a titleEIDR of "10.5240/7EC7-228A-510A-053E-CBB8-J". This title (or work) may have several variants, which EIDR calls "edits". See [[editEIDR]].
Since schema.org types like [[Movie]], [[TVEpisode]], [[TVSeason]], and [[TVSeries]] can be used for both works and their multiple expressions, it is possible to use [[titleEIDR]] alone (for a general description), or alongside [[editEIDR]] for a more edit-specific description.
101 102 103 |
# File 'lib/schema_org/mixins/tv_episode.rb', line 101 def title_eidr read_property(:title_eidr) end |
#title_eidr=(value) ⇒ Object
An EIDR (Entertainment Identifier Registry) [[identifier]] representing at the most general/abstract level, a work of film or television.
For example, the motion picture known as "Ghostbusters" has a titleEIDR of "10.5240/7EC7-228A-510A-053E-CBB8-J". This title (or work) may have several variants, which EIDR calls "edits". See [[editEIDR]].
Since schema.org types like [[Movie]], [[TVEpisode]], [[TVSeason]], and [[TVSeries]] can be used for both works and their multiple expressions, it is possible to use [[titleEIDR]] alone (for a general description), or alongside [[editEIDR]] for a more edit-specific description.
110 111 112 |
# File 'lib/schema_org/mixins/tv_episode.rb', line 110 def title_eidr=(value) write_property(:title_eidr, value) end |