Module: SchemaOrg::Mixins::TaxiReservation
- Includes:
- Reservation
- Included in:
- TaxiReservation
- Defined in:
- lib/schema_org/mixins/taxi_reservation.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#party_size ⇒ Object
Number of people the reservation should accommodate.
-
#party_size=(value) ⇒ Object
Number of people the reservation should accommodate.
-
#pickup_location ⇒ Object
Where a taxi will pick up a passenger or a rental car can be picked up.
-
#pickup_location=(value) ⇒ Object
Where a taxi will pick up a passenger or a rental car can be picked up.
-
#pickup_time ⇒ Object
When a taxi will pick up a passenger or a rental car can be picked up.
-
#pickup_time=(value) ⇒ Object
When a taxi will pick up a passenger or a rental car can be picked up.
Methods included from Reservation
#booking_agent, #booking_agent=, #booking_time, #booking_time=, #broker, #broker=, #modified_time, #modified_time=, #price_currency, #price_currency=, #program_membership_used, #program_membership_used=, #provider, #provider=, #reservation_for, #reservation_for=, #reservation_id, #reservation_id=, #reservation_status, #reservation_status=, #reserved_ticket, #reserved_ticket=, #total_price, #total_price=, #under_name, #under_name=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/schema_org/mixins/taxi_reservation.rb', line 11 def self.schema_property_definitions { party_size: { schema_name: "partySize", schema_url: "https://schema.org/partySize", comment_lines: ["Number of people the reservation should accommodate."].freeze, ranges: ["Integer", "QuantitativeValue"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, pickup_location: { schema_name: "pickupLocation", schema_url: "https://schema.org/pickupLocation", comment_lines: ["Where a taxi will pick up a passenger or a rental car can be picked up."].freeze, ranges: ["Place"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, pickup_time: { schema_name: "pickupTime", schema_url: "https://schema.org/pickupTime", comment_lines: ["When a taxi will pick up a passenger or a rental car can be picked up."].freeze, ranges: ["DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#party_size ⇒ Object
Number of people the reservation should accommodate.
47 48 49 |
# File 'lib/schema_org/mixins/taxi_reservation.rb', line 47 def party_size read_property(:party_size) end |
#party_size=(value) ⇒ Object
Number of people the reservation should accommodate.
52 53 54 |
# File 'lib/schema_org/mixins/taxi_reservation.rb', line 52 def party_size=(value) write_property(:party_size, value) end |
#pickup_location ⇒ Object
Where a taxi will pick up a passenger or a rental car can be picked up.
57 58 59 |
# File 'lib/schema_org/mixins/taxi_reservation.rb', line 57 def pickup_location read_property(:pickup_location) end |
#pickup_location=(value) ⇒ Object
Where a taxi will pick up a passenger or a rental car can be picked up.
62 63 64 |
# File 'lib/schema_org/mixins/taxi_reservation.rb', line 62 def pickup_location=(value) write_property(:pickup_location, value) end |
#pickup_time ⇒ Object
When a taxi will pick up a passenger or a rental car can be picked up.
67 68 69 |
# File 'lib/schema_org/mixins/taxi_reservation.rb', line 67 def pickup_time read_property(:pickup_time) end |
#pickup_time=(value) ⇒ Object
When a taxi will pick up a passenger or a rental car can be picked up.
72 73 74 |
# File 'lib/schema_org/mixins/taxi_reservation.rb', line 72 def pickup_time=(value) write_property(:pickup_time, value) end |