Module: SchemaOrg::Mixins::Ticket
Class Method Summary collapse
Instance Method Summary collapse
-
#date_issued ⇒ Object
The date the ticket was issued.
-
#date_issued=(value) ⇒ Object
The date the ticket was issued.
-
#issued_by ⇒ Object
The organization issuing the item, for example a [[Permit]], [[Ticket]], or [[Certification]].
-
#issued_by=(value) ⇒ Object
The organization issuing the item, for example a [[Permit]], [[Ticket]], or [[Certification]].
-
#price_currency ⇒ Object
The currency of the price, or a price component when attached to [[PriceSpecification]] and its subtypes.\n\nUse standard formats: ISO 4217 currency format, e.g.
-
#price_currency=(value) ⇒ Object
The currency of the price, or a price component when attached to [[PriceSpecification]] and its subtypes.\n\nUse standard formats: ISO 4217 currency format, e.g.
-
#ticket_number ⇒ Object
The unique identifier for the ticket.
-
#ticket_number=(value) ⇒ Object
The unique identifier for the ticket.
-
#ticket_token ⇒ Object
Reference to an asset (e.g., Barcode, QR code image or PDF) usable for entrance.
-
#ticket_token=(value) ⇒ Object
Reference to an asset (e.g., Barcode, QR code image or PDF) usable for entrance.
-
#ticketed_seat ⇒ Object
The seat associated with the ticket.
-
#ticketed_seat=(value) ⇒ Object
The seat associated with the ticket.
-
#total_price ⇒ Object
The total price for the reservation or ticket, including applicable taxes, shipping, etc.\n\nUsage guidelines:\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point.
-
#total_price=(value) ⇒ Object
The total price for the reservation or ticket, including applicable taxes, shipping, etc.\n\nUsage guidelines:\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point.
-
#under_name ⇒ Object
The person or organization the reservation or ticket is for.
-
#under_name=(value) ⇒ Object
The person or organization the reservation or ticket is for.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/schema_org/mixins/ticket.rb', line 11 def self.schema_property_definitions { date_issued: { schema_name: "dateIssued", schema_url: "https://schema.org/dateIssued", comment_lines: ["The date the ticket was issued."].freeze, ranges: ["Date", "DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, issued_by: { schema_name: "issuedBy", schema_url: "https://schema.org/issuedBy", comment_lines: ["The organization issuing the item, for example a [[Permit]], [[Ticket]], or [[Certification]]."].freeze, ranges: ["Organization"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, price_currency: { schema_name: "priceCurrency", schema_url: "https://schema.org/priceCurrency", comment_lines: ["The currency of the price, or a price component when attached to [[PriceSpecification]] and its subtypes.\\n\\nUse standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. \"USD\"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. \"BTC\"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. \"Ithaca HOUR\"."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, ticket_number: { schema_name: "ticketNumber", schema_url: "https://schema.org/ticketNumber", comment_lines: ["The unique identifier for the ticket."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, ticket_token: { schema_name: "ticketToken", schema_url: "https://schema.org/ticketToken", comment_lines: ["Reference to an asset (e.g., Barcode, QR code image or PDF) usable for entrance."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, ticketed_seat: { schema_name: "ticketedSeat", schema_url: "https://schema.org/ticketedSeat", comment_lines: ["The seat associated with the ticket."].freeze, ranges: ["Seat"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, total_price: { schema_name: "totalPrice", schema_url: "https://schema.org/totalPrice", comment_lines: ["The total price for the reservation or ticket, including applicable taxes, shipping, etc.\\n\\nUsage guidelines:\\n\\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator."].freeze, ranges: ["Number", "PriceSpecification", "Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, under_name: { schema_name: "underName", schema_url: "https://schema.org/underName", comment_lines: ["The person or organization the reservation or ticket is for."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#date_issued ⇒ Object
The date the ticket was issued.
97 98 99 |
# File 'lib/schema_org/mixins/ticket.rb', line 97 def date_issued read_property(:date_issued) end |
#date_issued=(value) ⇒ Object
The date the ticket was issued.
102 103 104 |
# File 'lib/schema_org/mixins/ticket.rb', line 102 def date_issued=(value) write_property(:date_issued, value) end |
#issued_by ⇒ Object
The organization issuing the item, for example a [[Permit]], [[Ticket]], or [[Certification]].
107 108 109 |
# File 'lib/schema_org/mixins/ticket.rb', line 107 def issued_by read_property(:issued_by) end |
#issued_by=(value) ⇒ Object
The organization issuing the item, for example a [[Permit]], [[Ticket]], or [[Certification]].
112 113 114 |
# File 'lib/schema_org/mixins/ticket.rb', line 112 def issued_by=(value) write_property(:issued_by, value) end |
#price_currency ⇒ Object
The currency of the price, or a price component when attached to [[PriceSpecification]] and its subtypes.\n\nUse standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR".
117 118 119 |
# File 'lib/schema_org/mixins/ticket.rb', line 117 def price_currency read_property(:price_currency) end |
#price_currency=(value) ⇒ Object
The currency of the price, or a price component when attached to [[PriceSpecification]] and its subtypes.\n\nUse standard formats: ISO 4217 currency format, e.g. "USD"; Ticker symbol for cryptocurrencies, e.g. "BTC"; well known names for Local Exchange Trading Systems (LETS) and other currency types, e.g. "Ithaca HOUR".
122 123 124 |
# File 'lib/schema_org/mixins/ticket.rb', line 122 def price_currency=(value) write_property(:price_currency, value) end |
#ticket_number ⇒ Object
The unique identifier for the ticket.
127 128 129 |
# File 'lib/schema_org/mixins/ticket.rb', line 127 def ticket_number read_property(:ticket_number) end |
#ticket_number=(value) ⇒ Object
The unique identifier for the ticket.
132 133 134 |
# File 'lib/schema_org/mixins/ticket.rb', line 132 def ticket_number=(value) write_property(:ticket_number, value) end |
#ticket_token ⇒ Object
Reference to an asset (e.g., Barcode, QR code image or PDF) usable for entrance.
137 138 139 |
# File 'lib/schema_org/mixins/ticket.rb', line 137 def ticket_token read_property(:ticket_token) end |
#ticket_token=(value) ⇒ Object
Reference to an asset (e.g., Barcode, QR code image or PDF) usable for entrance.
142 143 144 |
# File 'lib/schema_org/mixins/ticket.rb', line 142 def ticket_token=(value) write_property(:ticket_token, value) end |
#ticketed_seat ⇒ Object
The seat associated with the ticket.
147 148 149 |
# File 'lib/schema_org/mixins/ticket.rb', line 147 def ticketed_seat read_property(:ticketed_seat) end |
#ticketed_seat=(value) ⇒ Object
The seat associated with the ticket.
152 153 154 |
# File 'lib/schema_org/mixins/ticket.rb', line 152 def ticketed_seat=(value) write_property(:ticketed_seat, value) end |
#total_price ⇒ Object
The total price for the reservation or ticket, including applicable taxes, shipping, etc.\n\nUsage guidelines:\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.
157 158 159 |
# File 'lib/schema_org/mixins/ticket.rb', line 157 def total_price read_property(:total_price) end |
#total_price=(value) ⇒ Object
The total price for the reservation or ticket, including applicable taxes, shipping, etc.\n\nUsage guidelines:\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.
162 163 164 |
# File 'lib/schema_org/mixins/ticket.rb', line 162 def total_price=(value) write_property(:total_price, value) end |
#under_name ⇒ Object
The person or organization the reservation or ticket is for.
167 168 169 |
# File 'lib/schema_org/mixins/ticket.rb', line 167 def under_name read_property(:under_name) end |
#under_name=(value) ⇒ Object
The person or organization the reservation or ticket is for.
172 173 174 |
# File 'lib/schema_org/mixins/ticket.rb', line 172 def under_name=(value) write_property(:under_name, value) end |