Module: SchemaOrg::Mixins::TypeAndQuantityNode
- Includes:
- StructuredValue
- Included in:
- TypeAndQuantityNode
- Defined in:
- lib/schema_org/mixins/type_and_quantity_node.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#amount_of_this_good ⇒ Object
The quantity of the goods included in the offer.
-
#amount_of_this_good=(value) ⇒ Object
The quantity of the goods included in the offer.
-
#business_function ⇒ Object
The business function (e.g. sell, lease, repair, dispose) of the offer or component of a bundle (TypeAndQuantityNode).
-
#business_function=(value) ⇒ Object
The business function (e.g. sell, lease, repair, dispose) of the offer or component of a bundle (TypeAndQuantityNode).
-
#type_of_good ⇒ Object
The product that this structured value is referring to.
-
#type_of_good=(value) ⇒ Object
The product that this structured value is referring to.
-
#unit_code ⇒ Object
The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL.
-
#unit_code=(value) ⇒ Object
The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL.
-
#unit_text ⇒ Object
A string or text indicating the unit of measurement.
-
#unit_text=(value) ⇒ Object
A string or text indicating the unit of measurement.
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/schema_org/mixins/type_and_quantity_node.rb', line 11 def self.schema_property_definitions { amount_of_this_good: { schema_name: "amountOfThisGood", schema_url: "https://schema.org/amountOfThisGood", comment_lines: ["The quantity of the goods included in the offer."].freeze, ranges: ["Number"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, business_function: { schema_name: "businessFunction", schema_url: "https://schema.org/businessFunction", comment_lines: ["The business function (e.g. sell, lease, repair, dispose) of the offer or component of a bundle (TypeAndQuantityNode). The default is http://purl.org/goodrelations/v1#Sell."].freeze, ranges: ["BusinessFunction"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, type_of_good: { schema_name: "typeOfGood", schema_url: "https://schema.org/typeOfGood", comment_lines: ["The product that this structured value is referring to."].freeze, ranges: ["Product", "Service"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, unit_code: { schema_name: "unitCode", schema_url: "https://schema.org/unitCode", comment_lines: ["The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL. Other codes than the UN/CEFACT Common Code may be used with a prefix followed by a colon."].freeze, ranges: ["Text", "URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, unit_text: { schema_name: "unitText", schema_url: "https://schema.org/unitText", comment_lines: ["A string or text indicating the unit of measurement. Useful if you cannot provide a standard unit code for", "<a href='unitCode'>unitCode</a>."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#amount_of_this_good ⇒ Object
The quantity of the goods included in the offer.
67 68 69 |
# File 'lib/schema_org/mixins/type_and_quantity_node.rb', line 67 def amount_of_this_good read_property(:amount_of_this_good) end |
#amount_of_this_good=(value) ⇒ Object
The quantity of the goods included in the offer.
72 73 74 |
# File 'lib/schema_org/mixins/type_and_quantity_node.rb', line 72 def amount_of_this_good=(value) write_property(:amount_of_this_good, value) end |
#business_function ⇒ Object
The business function (e.g. sell, lease, repair, dispose) of the offer or component of a bundle (TypeAndQuantityNode). The default is http://purl.org/goodrelations/v1#Sell.
77 78 79 |
# File 'lib/schema_org/mixins/type_and_quantity_node.rb', line 77 def business_function read_property(:business_function) end |
#business_function=(value) ⇒ Object
The business function (e.g. sell, lease, repair, dispose) of the offer or component of a bundle (TypeAndQuantityNode). The default is http://purl.org/goodrelations/v1#Sell.
82 83 84 |
# File 'lib/schema_org/mixins/type_and_quantity_node.rb', line 82 def business_function=(value) write_property(:business_function, value) end |
#type_of_good ⇒ Object
The product that this structured value is referring to.
87 88 89 |
# File 'lib/schema_org/mixins/type_and_quantity_node.rb', line 87 def type_of_good read_property(:type_of_good) end |
#type_of_good=(value) ⇒ Object
The product that this structured value is referring to.
92 93 94 |
# File 'lib/schema_org/mixins/type_and_quantity_node.rb', line 92 def type_of_good=(value) write_property(:type_of_good, value) end |
#unit_code ⇒ Object
The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL. Other codes than the UN/CEFACT Common Code may be used with a prefix followed by a colon.
97 98 99 |
# File 'lib/schema_org/mixins/type_and_quantity_node.rb', line 97 def unit_code read_property(:unit_code) end |
#unit_code=(value) ⇒ Object
The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL. Other codes than the UN/CEFACT Common Code may be used with a prefix followed by a colon.
102 103 104 |
# File 'lib/schema_org/mixins/type_and_quantity_node.rb', line 102 def unit_code=(value) write_property(:unit_code, value) end |
#unit_text ⇒ Object
A string or text indicating the unit of measurement. Useful if you cannot provide a standard unit code for unitCode.
108 109 110 |
# File 'lib/schema_org/mixins/type_and_quantity_node.rb', line 108 def unit_text read_property(:unit_text) end |
#unit_text=(value) ⇒ Object
A string or text indicating the unit of measurement. Useful if you cannot provide a standard unit code for unitCode.
114 115 116 |
# File 'lib/schema_org/mixins/type_and_quantity_node.rb', line 114 def unit_text=(value) write_property(:unit_text, value) end |