Module: SchemaOrg::Mixins::UserComments
- Includes:
- UserInteraction
- Included in:
- UserComments
- Defined in:
- lib/schema_org/mixins/user_comments.rb
Class Method Summary collapse
Instance Method Summary collapse
-
#comment_text ⇒ Object
The text of the UserComment.
-
#comment_text=(value) ⇒ Object
The text of the UserComment.
-
#comment_time ⇒ Object
The time at which the UserComment was made.
-
#comment_time=(value) ⇒ Object
The time at which the UserComment was made.
-
#creator ⇒ Object
The creator/author of this CreativeWork.
-
#creator=(value) ⇒ Object
The creator/author of this CreativeWork.
-
#discusses ⇒ Object
Specifies the CreativeWork associated with the UserComment.
-
#discusses=(value) ⇒ Object
Specifies the CreativeWork associated with the UserComment.
-
#reply_to_url ⇒ Object
The URL at which a reply may be posted to the specified UserComment.
-
#reply_to_url=(value) ⇒ Object
The URL at which a reply may be posted to the specified UserComment.
Methods included from Event
#about, #about=, #actor, #actor=, #aggregate_rating, #aggregate_rating=, #attendee, #attendee=, #attendees, #attendees=, #audience, #audience=, #composer, #composer=, #contributor, #contributor=, #director, #director=, #door_time, #door_time=, #duration, #duration=, #end_date, #end_date=, #event_attendance_mode, #event_attendance_mode=, #event_schedule, #event_schedule=, #event_status, #event_status=, #funder, #funder=, #funding, #funding=, #has_participation_offer, #has_participation_offer=, #has_sponsorship_offer, #has_sponsorship_offer=, #in_language, #in_language=, #is_accessible_for_free, #is_accessible_for_free=, #keywords, #keywords=, #location, #location=, #maximum_attendee_capacity, #maximum_attendee_capacity=, #maximum_physical_attendee_capacity, #maximum_physical_attendee_capacity=, #maximum_virtual_attendee_capacity, #maximum_virtual_attendee_capacity=, #offers, #offers=, #organizer, #organizer=, #performer, #performer=, #performers, #performers=, #previous_start_date, #previous_start_date=, #recorded_in, #recorded_in=, #remaining_attendee_capacity, #remaining_attendee_capacity=, #review, #review=, #sponsor, #sponsor=, #start_date, #start_date=, #sub_event, #sub_event=, #sub_events, #sub_events=, #super_event, #super_event=, #translator, #translator=, #typical_age_range, #typical_age_range=, #work_featured, #work_featured=, #work_performed, #work_performed=
Methods included from Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.schema_property_definitions ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/schema_org/mixins/user_comments.rb', line 11 def self.schema_property_definitions { comment_text: { schema_name: "commentText", schema_url: "https://schema.org/commentText", comment_lines: ["The text of the UserComment."].freeze, ranges: ["Text"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, comment_time: { schema_name: "commentTime", schema_url: "https://schema.org/commentTime", comment_lines: ["The time at which the UserComment was made."].freeze, ranges: ["Date", "DateTime"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, creator: { schema_name: "creator", schema_url: "https://schema.org/creator", comment_lines: ["The creator/author of this CreativeWork. This is the same as the Author property for CreativeWork."].freeze, ranges: ["Organization", "Person"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, discusses: { schema_name: "discusses", schema_url: "https://schema.org/discusses", comment_lines: ["Specifies the CreativeWork associated with the UserComment."].freeze, ranges: ["CreativeWork"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze, reply_to_url: { schema_name: "replyToUrl", schema_url: "https://schema.org/replyToUrl", comment_lines: ["The URL at which a reply may be posted to the specified UserComment."].freeze, ranges: ["URL"].freeze, external_ranges: [].freeze, inverse_of: nil, superseded_by: nil, supersedes: nil }.freeze }.freeze end |
Instance Method Details
#comment_text ⇒ Object
The text of the UserComment.
67 68 69 |
# File 'lib/schema_org/mixins/user_comments.rb', line 67 def comment_text read_property(:comment_text) end |
#comment_text=(value) ⇒ Object
The text of the UserComment.
72 73 74 |
# File 'lib/schema_org/mixins/user_comments.rb', line 72 def comment_text=(value) write_property(:comment_text, value) end |
#comment_time ⇒ Object
The time at which the UserComment was made.
77 78 79 |
# File 'lib/schema_org/mixins/user_comments.rb', line 77 def comment_time read_property(:comment_time) end |
#comment_time=(value) ⇒ Object
The time at which the UserComment was made.
82 83 84 |
# File 'lib/schema_org/mixins/user_comments.rb', line 82 def comment_time=(value) write_property(:comment_time, value) end |
#creator ⇒ Object
The creator/author of this CreativeWork. This is the same as the Author property for CreativeWork.
87 88 89 |
# File 'lib/schema_org/mixins/user_comments.rb', line 87 def creator read_property(:creator) end |
#creator=(value) ⇒ Object
The creator/author of this CreativeWork. This is the same as the Author property for CreativeWork.
92 93 94 |
# File 'lib/schema_org/mixins/user_comments.rb', line 92 def creator=(value) write_property(:creator, value) end |
#discusses ⇒ Object
Specifies the CreativeWork associated with the UserComment.
97 98 99 |
# File 'lib/schema_org/mixins/user_comments.rb', line 97 def discusses read_property(:discusses) end |
#discusses=(value) ⇒ Object
Specifies the CreativeWork associated with the UserComment.
102 103 104 |
# File 'lib/schema_org/mixins/user_comments.rb', line 102 def discusses=(value) write_property(:discusses, value) end |
#reply_to_url ⇒ Object
The URL at which a reply may be posted to the specified UserComment.
107 108 109 |
# File 'lib/schema_org/mixins/user_comments.rb', line 107 def reply_to_url read_property(:reply_to_url) end |
#reply_to_url=(value) ⇒ Object
The URL at which a reply may be posted to the specified UserComment.
112 113 114 |
# File 'lib/schema_org/mixins/user_comments.rb', line 112 def reply_to_url=(value) write_property(:reply_to_url, value) end |