Class: SchemaOrg::MonetaryAmount
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::MonetaryAmount
- Includes:
- SchemaOrg::Mixins::MonetaryAmount, _MonetaryAmount
- Defined in:
- lib/schema_org/types/monetary_amount.rb,
sig/schema_org.rbs
Overview
https://schema.org/MonetaryAmount
NOTE: Supersedes DatedMoneySpecification.
A monetary value or range. This type can be used to describe an amount of money such as $50 USD, or a range as in describing a bank account being suitable for a balance between £1,000 and £1,000,000 GBP, or the value of a salary, etc. It is recommended to use [[PriceSpecification]] Types to describe the price of an Offer, Invoice, etc.
Constant Summary collapse
- SCHEMA_NAME =
"MonetaryAmount"- SCHEMA_TYPES =
[self, SchemaOrg::StructuredValue, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ MonetaryAmount
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from SchemaOrg::Mixins::MonetaryAmount
#currency, #currency=, #max_value, #max_value=, #min_value, #min_value=, schema_property_definitions, #valid_from, #valid_from=, #valid_through, #valid_through=, #value, #value=
Methods included from SchemaOrg::Mixins::StructuredValue
Methods included from SchemaOrg::Mixins::Intangible
Methods included from SchemaOrg::Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _MonetaryAmount
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #currency, #currency=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #max_value, #max_value=, #min_value, #min_value=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=, #valid_from, #valid_from=, #valid_through, #valid_through=, #value, #value=
Class Method Details
.new(**properties) ⇒ MonetaryAmount
32 33 34 |
# File 'lib/schema_org/types/monetary_amount.rb', line 32 def new(**properties) super end |
.schema_name ⇒ String
19 20 21 |
# File 'lib/schema_org/types/monetary_amount.rb', line 19 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
27 28 29 30 |
# File 'lib/schema_org/types/monetary_amount.rb', line 27 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
23 24 25 |
# File 'lib/schema_org/types/monetary_amount.rb', line 23 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
77640 |
# File 'sig/schema_org.rbs', line 77640
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
77639 |
# File 'sig/schema_org.rbs', line 77639
def schema_types: () -> ::Array[::Class]
|