Class: SchemaOrg::Offer
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::Offer
show all
- Includes:
- Mixins::Offer, _Offer
- Defined in:
- lib/schema_org/types/offer.rb,
sig/schema_org.rbs
Overview
https://schema.org/Offer
An offer to transfer some rights to an item or to provide a service — for example, an offer to sell tickets to an event, to rent the DVD of a movie, to stream a TV show over the internet, to repair a motorcycle, or to loan a book.\n\nNote: As the [[businessFunction]] property, which identifies the form of offer (e.g. sell, lease, repair, dispose), defaults to http://purl.org/goodrelations/v1#Sell; an Offer without a defined businessFunction value can be assumed to be an offer to sell.\n\nFor GTIN-related fields, see Check Digit calculator and validation guide from GS1.
Constant Summary
collapse
- SCHEMA_NAME =
"Offer"
- SCHEMA_TYPES =
[self, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
Class Method Summary
collapse
Instance Method Summary
collapse
#accepted_payment_method, #accepted_payment_method=, #add_on, #add_on=, #additional_property, #additional_property=, #advance_booking_requirement, #advance_booking_requirement=, #aggregate_rating, #aggregate_rating=, #area_served, #area_served=, #asin, #asin=, #availability, #availability=, #availability_ends, #availability_ends=, #availability_starts, #availability_starts=, #available_at_or_from, #available_at_or_from=, #available_delivery_method, #available_delivery_method=, #business_function, #business_function=, #category, #category=, #checkout_page_url_template, #checkout_page_url_template=, #delivery_lead_time, #delivery_lead_time=, #eligible_customer_type, #eligible_customer_type=, #eligible_duration, #eligible_duration=, #eligible_quantity, #eligible_quantity=, #eligible_region, #eligible_region=, #eligible_transaction_volume, #eligible_transaction_volume=, #gtin, #gtin12, #gtin12=, #gtin13, #gtin13=, #gtin14, #gtin14=, #gtin8, #gtin8=, #gtin=, #has_adult_consideration, #has_adult_consideration=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_measurement, #has_measurement=, #has_merchant_return_policy, #has_merchant_return_policy=, #includes_object, #includes_object=, #ineligible_region, #ineligible_region=, #inventory_level, #inventory_level=, #is_family_friendly, #is_family_friendly=, #item_condition, #item_condition=, #item_offered, #item_offered=, #lease_length, #lease_length=, #mobile_url, #mobile_url=, #mpn, #mpn=, #offered_by, #offered_by=, #price, #price=, #price_currency, #price_currency=, #price_specification, #price_specification=, #price_valid_until, #price_valid_until=, #review, #review=, #reviews, #reviews=, schema_property_definitions, #seller, #seller=, #serial_number, #serial_number=, #shipping_details, #shipping_details=, #sku, #sku=, #valid_for_member_tier, #valid_for_member_tier=, #valid_from, #valid_from=, #valid_through, #valid_through=, #warranty, #warranty=
schema_property_definitions
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _Offer
#accepted_payment_method, #accepted_payment_method=, #add_on, #add_on=, #additional_property, #additional_property=, #additional_type, #additional_type=, #advance_booking_requirement, #advance_booking_requirement=, #aggregate_rating, #aggregate_rating=, #alternate_name, #alternate_name=, #area_served, #area_served=, #asin, #asin=, #availability, #availability=, #availability_ends, #availability_ends=, #availability_starts, #availability_starts=, #available_at_or_from, #available_at_or_from=, #available_delivery_method, #available_delivery_method=, #business_function, #business_function=, #category, #category=, #checkout_page_url_template, #checkout_page_url_template=, #delivery_lead_time, #delivery_lead_time=, #description, #description=, #disambiguating_description, #disambiguating_description=, #eligible_customer_type, #eligible_customer_type=, #eligible_duration, #eligible_duration=, #eligible_quantity, #eligible_quantity=, #eligible_region, #eligible_region=, #eligible_transaction_volume, #eligible_transaction_volume=, #gtin, #gtin12, #gtin12=, #gtin13, #gtin13=, #gtin14, #gtin14=, #gtin8, #gtin8=, #gtin=, #has_adult_consideration, #has_adult_consideration=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_measurement, #has_measurement=, #has_merchant_return_policy, #has_merchant_return_policy=, #identifier, #identifier=, #image, #image=, #includes_object, #includes_object=, #ineligible_region, #ineligible_region=, #inventory_level, #inventory_level=, #is_family_friendly, #is_family_friendly=, #item_condition, #item_condition=, #item_offered, #item_offered=, #lease_length, #lease_length=, #main_entity_of_page, #main_entity_of_page=, #mobile_url, #mobile_url=, #mpn, #mpn=, #name, #name=, #offered_by, #offered_by=, #owner, #owner=, #potential_action, #potential_action=, #price, #price=, #price_currency, #price_currency=, #price_specification, #price_specification=, #price_valid_until, #price_valid_until=, #review, #review=, #reviews, #reviews=, #same_as, #same_as=, #seller, #seller=, #serial_number, #serial_number=, #shipping_details, #shipping_details=, #sku, #sku=, #subject_of, #subject_of=, #url, #url=, #valid_for_member_tier, #valid_for_member_tier=, #valid_from, #valid_from=, #valid_through, #valid_through=, #warranty, #warranty=
Class Method Details
.new(**properties) ⇒ Offer
30
31
32
|
# File 'lib/schema_org/types/offer.rb', line 30
def new(**properties)
super
end
|
.schema_name ⇒ String
17
18
19
|
# File 'lib/schema_org/types/offer.rb', line 17
def schema_name
SCHEMA_NAME
end
|
.schema_type?(other_type) ⇒ Boolean
25
26
27
28
|
# File 'lib/schema_org/types/offer.rb', line 25
def schema_type?(other_type)
Base.schema_type_argument!(other_type)
SCHEMA_TYPES.include?(other_type)
end
|
.schema_types ⇒ ::Array[::Class]
21
22
23
|
# File 'lib/schema_org/types/offer.rb', line 21
def schema_types
SCHEMA_TYPES
end
|
Instance Method Details
#schema_type? ⇒ Boolean
86884
|
# File 'sig/schema_org.rbs', line 86884
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
86883
|
# File 'sig/schema_org.rbs', line 86883
def schema_types: () -> ::Array[::Class]
|