Class: SchemaOrg::OpeningHoursSpecification
Overview
https://schema.org/OpeningHoursSpecification
A structured value providing information about the opening hours of a place or a certain service inside a place.\n\n
The place is open if the [[opens]] property is specified, and closed otherwise.\n\nIf the value for the [[closes]] property is less than the value for the [[opens]] property then the hour range is assumed to span over the next day.
Constant Summary
collapse
- SCHEMA_NAME =
"OpeningHoursSpecification"
- SCHEMA_TYPES =
[self, SchemaOrg::StructuredValue, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
Class Method Summary
collapse
Instance Method Summary
collapse
#closes, #closes=, #day_of_week, #day_of_week=, #opens, #opens=, schema_property_definitions, #valid_from, #valid_from=, #valid_through, #valid_through=
schema_property_definitions
schema_property_definitions
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #closes, #closes=, #day_of_week, #day_of_week=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #opens, #opens=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=, #valid_from, #valid_from=, #valid_through, #valid_through=
Class Method Details
31
32
33
|
# File 'lib/schema_org/types/opening_hours_specification.rb', line 31
def new(**properties)
super
end
|
.schema_name ⇒ String
18
19
20
|
# File 'lib/schema_org/types/opening_hours_specification.rb', line 18
def schema_name
SCHEMA_NAME
end
|
.schema_type?(other_type) ⇒ Boolean
26
27
28
29
|
# File 'lib/schema_org/types/opening_hours_specification.rb', line 26
def schema_type?(other_type)
Base.schema_type_argument!(other_type)
SCHEMA_TYPES.include?(other_type)
end
|
.schema_types ⇒ ::Array[::Class]
22
23
24
|
# File 'lib/schema_org/types/opening_hours_specification.rb', line 22
def schema_types
SCHEMA_TYPES
end
|
Instance Method Details
#schema_type? ⇒ Boolean
88372
|
# File 'sig/schema_org.rbs', line 88372
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
88371
|
# File 'sig/schema_org.rbs', line 88371
def schema_types: () -> ::Array[::Class]
|