Class: SchemaOrg::ProductGroup
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::ProductGroup
- Includes:
- Mixins::ProductGroup, _ProductGroup
- Defined in:
- lib/schema_org/types/product_group.rb,
sig/schema_org.rbs
Overview
https://schema.org/ProductGroup
A ProductGroup represents a group of [[Product]]s that vary only in certain well-described ways, such as by [[size]], [[color]], [[material]] etc.
While a ProductGroup itself is not directly offered for sale, the various varying products that it represents can be. The ProductGroup serves as a prototype or template, standing in for all of the products who have an [[isVariantOf]] relationship to it. As such, properties (including additional types) can be applied to the ProductGroup to represent characteristics shared by each of the (possibly very many) variants. Properties that reference a ProductGroup are not included in this mechanism; neither are the following specific properties [[variesBy]], [[hasVariant]], [[url]].
Constant Summary collapse
Class Method Summary collapse
- .new(**properties) ⇒ ProductGroup
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::ProductGroup
#has_variant, #has_variant=, #product_group_id, #product_group_id=, schema_property_definitions, #varies_by, #varies_by=
Methods included from Mixins::Product
#additional_property, #additional_property=, #aggregate_rating, #aggregate_rating=, #asin, #asin=, #audience, #audience=, #award, #award=, #awards, #awards=, #brand, #brand=, #category, #category=, #color, #color=, #color_swatch, #color_swatch=, #country_of_assembly, #country_of_assembly=, #country_of_last_processing, #country_of_last_processing=, #country_of_origin, #country_of_origin=, #depth, #depth=, #display_location, #display_location=, #funding, #funding=, #gtin, #gtin12, #gtin12=, #gtin13, #gtin13=, #gtin14, #gtin14=, #gtin8, #gtin8=, #gtin=, #has_adult_consideration, #has_adult_consideration=, #has_certification, #has_certification=, #has_energy_consumption_details, #has_energy_consumption_details=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_measurement, #has_measurement=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_product_return_policy, #has_product_return_policy=, #height, #height=, #in_product_group_with_id, #in_product_group_with_id=, #is_accessory_or_spare_part_for, #is_accessory_or_spare_part_for=, #is_consumable_for, #is_consumable_for=, #is_family_friendly, #is_family_friendly=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #is_variant_of, #is_variant_of=, #item_condition, #item_condition=, #keywords, #keywords=, #logo, #logo=, #manufacturer, #manufacturer=, #material, #material=, #mobile_url, #mobile_url=, #model, #model=, #mpn, #mpn=, #negative_notes, #negative_notes=, #nsn, #nsn=, #offers, #offers=, #pattern, #pattern=, #positive_notes, #positive_notes=, #product_id, #product_id=, #production_date, #production_date=, #purchase_date, #purchase_date=, #release_date, #release_date=, #review, #review=, #reviews, #reviews=, schema_property_definitions, #size, #size=, #sku, #sku=, #slogan, #slogan=, #weight, #weight=, #width, #width=
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _ProductGroup
#additional_property, #additional_property=, #additional_type, #additional_type=, #aggregate_rating, #aggregate_rating=, #alternate_name, #alternate_name=, #asin, #asin=, #audience, #audience=, #award, #award=, #awards, #awards=, #brand, #brand=, #category, #category=, #color, #color=, #color_swatch, #color_swatch=, #country_of_assembly, #country_of_assembly=, #country_of_last_processing, #country_of_last_processing=, #country_of_origin, #country_of_origin=, #depth, #depth=, #description, #description=, #disambiguating_description, #disambiguating_description=, #display_location, #display_location=, #funding, #funding=, #gtin, #gtin12, #gtin12=, #gtin13, #gtin13=, #gtin14, #gtin14=, #gtin8, #gtin8=, #gtin=, #has_adult_consideration, #has_adult_consideration=, #has_certification, #has_certification=, #has_energy_consumption_details, #has_energy_consumption_details=, #has_gs1_digital_link, #has_gs1_digital_link=, #has_measurement, #has_measurement=, #has_merchant_return_policy, #has_merchant_return_policy=, #has_product_return_policy, #has_product_return_policy=, #has_variant, #has_variant=, #height, #height=, #identifier, #identifier=, #image, #image=, #in_product_group_with_id, #in_product_group_with_id=, #is_accessory_or_spare_part_for, #is_accessory_or_spare_part_for=, #is_consumable_for, #is_consumable_for=, #is_family_friendly, #is_family_friendly=, #is_related_to, #is_related_to=, #is_similar_to, #is_similar_to=, #is_variant_of, #is_variant_of=, #item_condition, #item_condition=, #keywords, #keywords=, #logo, #logo=, #main_entity_of_page, #main_entity_of_page=, #manufacturer, #manufacturer=, #material, #material=, #mobile_url, #mobile_url=, #model, #model=, #mpn, #mpn=, #name, #name=, #negative_notes, #negative_notes=, #nsn, #nsn=, #offers, #offers=, #owner, #owner=, #pattern, #pattern=, #positive_notes, #positive_notes=, #potential_action, #potential_action=, #product_group_id, #product_group_id=, #product_id, #product_id=, #production_date, #production_date=, #purchase_date, #purchase_date=, #release_date, #release_date=, #review, #review=, #reviews, #reviews=, #same_as, #same_as=, #size, #size=, #sku, #sku=, #slogan, #slogan=, #subject_of, #subject_of=, #url, #url=, #varies_by, #varies_by=, #weight, #weight=, #width, #width=
Class Method Details
.new(**properties) ⇒ ProductGroup
32 33 34 |
# File 'lib/schema_org/types/product_group.rb', line 32 def new(**properties) super end |
.schema_name ⇒ String
19 20 21 |
# File 'lib/schema_org/types/product_group.rb', line 19 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
27 28 29 30 |
# File 'lib/schema_org/types/product_group.rb', line 27 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
23 24 25 |
# File 'lib/schema_org/types/product_group.rb', line 23 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
99668 |
# File 'sig/schema_org.rbs', line 99668
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
99667 |
# File 'sig/schema_org.rbs', line 99667
def schema_types: () -> ::Array[::Class]
|