Class: SchemaOrg::PsychologicalTreatment
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::PsychologicalTreatment
- Defined in:
- lib/schema_org/types/psychological_treatment.rb,
sig/schema_org.rbs
Overview
https://schema.org/PsychologicalTreatment
A process of care relying upon counseling, dialogue and communication aimed at improving a mental health condition without use of drugs.
Constant Summary collapse
- SCHEMA_NAME =
"PsychologicalTreatment"- SCHEMA_TYPES =
[self, SchemaOrg::TherapeuticProcedure, SchemaOrg::MedicalProcedure, SchemaOrg::MedicalEntity, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ PsychologicalTreatment
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::PsychologicalTreatment
Methods included from Mixins::TherapeuticProcedure
#adverse_outcome, #adverse_outcome=, #dose_schedule, #dose_schedule=, #drug, #drug=, schema_property_definitions
Methods included from Mixins::MedicalProcedure
#body_location, #body_location=, #followup, #followup=, #how_performed, #how_performed=, #preparation, #preparation=, #procedure_type, #procedure_type=, schema_property_definitions, #status, #status=
Methods included from Mixins::MedicalEntity
#code, #code=, #funding, #funding=, #guideline, #guideline=, #legal_status, #legal_status=, #medicine_system, #medicine_system=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, schema_property_definitions, #study, #study=
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _PsychologicalTreatment
#additional_type, #additional_type=, #adverse_outcome, #adverse_outcome=, #alternate_name, #alternate_name=, #body_location, #body_location=, #code, #code=, #description, #description=, #disambiguating_description, #disambiguating_description=, #dose_schedule, #dose_schedule=, #drug, #drug=, #followup, #followup=, #funding, #funding=, #guideline, #guideline=, #how_performed, #how_performed=, #identifier, #identifier=, #image, #image=, #legal_status, #legal_status=, #main_entity_of_page, #main_entity_of_page=, #medicine_system, #medicine_system=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #preparation, #preparation=, #procedure_type, #procedure_type=, #recognizing_authority, #recognizing_authority=, #relevant_specialty, #relevant_specialty=, #same_as, #same_as=, #status, #status=, #study, #study=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.new(**properties) ⇒ PsychologicalTreatment
30 31 32 |
# File 'lib/schema_org/types/psychological_treatment.rb', line 30 def new(**properties) super end |
.schema_name ⇒ String
17 18 19 |
# File 'lib/schema_org/types/psychological_treatment.rb', line 17 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
25 26 27 28 |
# File 'lib/schema_org/types/psychological_treatment.rb', line 25 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
21 22 23 |
# File 'lib/schema_org/types/psychological_treatment.rb', line 21 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
101044 |
# File 'sig/schema_org.rbs', line 101044
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
101043 |
# File 'sig/schema_org.rbs', line 101043
def schema_types: () -> ::Array[::Class]
|