Class: SchemaOrg::Schedule
Overview
https://schema.org/Schedule
A schedule defines a repeating time period used to describe a regularly occurring [[Event]]. At a minimum a schedule will specify [[repeatFrequency]] which describes the interval between occurrences of the event. Additional information can be provided to specify the schedule more precisely.
This includes identifying the day(s) of the week or month when the recurring event will take place, in addition to its start and end time. Schedules may also
have start and end dates to indicate when they are active, e.g. to define a limited calendar of events.
Constant Summary
collapse
- SCHEMA_NAME =
"Schedule"
- SCHEMA_TYPES =
[self, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
Class Method Summary
collapse
Instance Method Summary
collapse
#by_day, #by_day=, #by_month, #by_month=, #by_month_day, #by_month_day=, #by_month_week, #by_month_week=, #duration, #duration=, #end_date, #end_date=, #end_time, #end_time=, #except_date, #except_date=, #repeat_count, #repeat_count=, #repeat_frequency, #repeat_frequency=, #schedule_timezone, #schedule_timezone=, schema_property_definitions, #start_date, #start_date=, #start_time, #start_time=
schema_property_definitions
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _Schedule
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #by_day, #by_day=, #by_month, #by_month=, #by_month_day, #by_month_day=, #by_month_week, #by_month_week=, #description, #description=, #disambiguating_description, #disambiguating_description=, #duration, #duration=, #end_date, #end_date=, #end_time, #end_time=, #except_date, #except_date=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #repeat_count, #repeat_count=, #repeat_frequency, #repeat_frequency=, #same_as, #same_as=, #schedule_timezone, #schedule_timezone=, #start_date, #start_date=, #start_time, #start_time=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.new(**properties) ⇒ Schedule
32
33
34
|
# File 'lib/schema_org/types/schedule.rb', line 32
def new(**properties)
super
end
|
.schema_name ⇒ String
19
20
21
|
# File 'lib/schema_org/types/schedule.rb', line 19
def schema_name
SCHEMA_NAME
end
|
.schema_type?(other_type) ⇒ Boolean
27
28
29
30
|
# File 'lib/schema_org/types/schedule.rb', line 27
def schema_type?(other_type)
Base.schema_type_argument!(other_type)
SCHEMA_TYPES.include?(other_type)
end
|
.schema_types ⇒ ::Array[::Class]
23
24
25
|
# File 'lib/schema_org/types/schedule.rb', line 23
def schema_types
SCHEMA_TYPES
end
|
Instance Method Details
#schema_type? ⇒ Boolean
112401
|
# File 'sig/schema_org.rbs', line 112401
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
112400
|
# File 'sig/schema_org.rbs', line 112400
def schema_types: () -> ::Array[::Class]
|