Class: SchemaOrg::StatisticalPopulation
Overview
https://schema.org/StatisticalPopulation
A StatisticalPopulation is a set of instances of a certain given type that satisfy some set of constraints. The property [[populationType]] is used to specify the type. Any property that can be used on instances of that type can appear on the statistical population. For example, a [[StatisticalPopulation]] representing all [[Person]]s with a [[homeLocation]] of East Podunk California would be described by applying the appropriate [[homeLocation]] and [[populationType]] properties to a [[StatisticalPopulation]] item that stands for that set of people.
The properties [[numConstraints]] and [[constraintProperty]] are used to specify which of the populations properties are used to specify the population. Note that the sense of "population" used here is the general sense of a statistical
population, and does not imply that the population consists of people. For example, a [[populationType]] of [[Event]] or [[NewsArticle]] could be used. See also [[Observation]], where a [[populationType]] such as [[Person]] or [[Event]] can be indicated directly. In most cases it may be better to use [[StatisticalVariable]] instead of [[StatisticalPopulation]].
Constant Summary
collapse
- SCHEMA_NAME =
"StatisticalPopulation"
- SCHEMA_TYPES =
[self, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
Class Method Summary
collapse
Instance Method Summary
collapse
#population_type, #population_type=, schema_property_definitions
schema_property_definitions
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #population_type, #population_type=, #potential_action, #potential_action=, #same_as, #same_as=, #subject_of, #subject_of=, #url, #url=
Class Method Details
32
33
34
|
# File 'lib/schema_org/types/statistical_population.rb', line 32
def new(**properties)
super
end
|
.schema_name ⇒ String
19
20
21
|
# File 'lib/schema_org/types/statistical_population.rb', line 19
def schema_name
SCHEMA_NAME
end
|
.schema_type?(other_type) ⇒ Boolean
27
28
29
30
|
# File 'lib/schema_org/types/statistical_population.rb', line 27
def schema_type?(other_type)
Base.schema_type_argument!(other_type)
SCHEMA_TYPES.include?(other_type)
end
|
.schema_types ⇒ ::Array[::Class]
23
24
25
|
# File 'lib/schema_org/types/statistical_population.rb', line 23
def schema_types
SCHEMA_TYPES
end
|
Instance Method Details
#schema_type? ⇒ Boolean
121764
|
# File 'sig/schema_org.rbs', line 121764
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
121763
|
# File 'sig/schema_org.rbs', line 121763
def schema_types: () -> ::Array[::Class]
|