Class: SchemaOrg::StatisticalVariable
- Inherits:
-
Base
- Object
- Base
- SchemaOrg::StatisticalVariable
- Includes:
- Mixins::StatisticalVariable, _StatisticalVariable
- Defined in:
- lib/schema_org/types/statistical_variable.rb,
sig/schema_org.rbs
Overview
https://schema.org/StatisticalVariable
[[StatisticalVariable]] represents any type of statistical metric that can be measured at a place and time. The usage pattern for [[StatisticalVariable]] is typically expressed using [[Observation]] with an explicit [[populationType]], which is a type, typically drawn from Schema.org. Each [[StatisticalVariable]] is marked as a [[ConstraintNode]], meaning that some properties (those listed using [[constraintProperty]]) serve in this setting solely to define the statistical variable rather than literally describe a specific person, place or thing. For example, a [[StatisticalVariable]] Median_Height_Person_Female representing the median height of women, could be written as follows: the population type is [[Person]]; the measuredProperty [[height]]; the [[statType]] [[median]]; the [[gender]] [[Female]]. It is important to note that there are many kinds of scientific quantitative observation which are not fully, perfectly or unambiguously described following this pattern, or with solely Schema.org terminology. The approach taken here is designed to allow partial, incremental or minimal description of [[StatisticalVariable]]s, and the use of detailed sets of entity and property IDs from external repositories. The [[measurementMethod]], [[unitCode]] and [[unitText]] properties can also be used to clarify the specific nature and notation of an observed measurement.
Constant Summary collapse
- SCHEMA_NAME =
"StatisticalVariable"- SCHEMA_TYPES =
[self, SchemaOrg::ConstraintNode, SchemaOrg::Intangible, SchemaOrg::Thing].freeze
Class Method Summary collapse
- .new(**properties) ⇒ StatisticalVariable
- .schema_name ⇒ String
- .schema_type?(other_type) ⇒ Boolean
- .schema_types ⇒ ::Array[::Class]
Instance Method Summary collapse
Methods included from Mixins::StatisticalVariable
#measured_property, #measured_property=, #measurement_denominator, #measurement_denominator=, #measurement_method, #measurement_method=, #measurement_qualifier, #measurement_qualifier=, #measurement_technique, #measurement_technique=, #population_type, #population_type=, schema_property_definitions, #stat_type, #stat_type=
Methods included from Mixins::ConstraintNode
#constraint_property, #constraint_property=, #num_constraints, #num_constraints=, schema_property_definitions
Methods included from Mixins::Intangible
Methods included from Mixins::Thing
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #name, #name=, #owner, #owner=, #potential_action, #potential_action=, #same_as, #same_as=, schema_property_definitions, #subject_of, #subject_of=, #url, #url=
Methods included from _StatisticalVariable
#additional_type, #additional_type=, #alternate_name, #alternate_name=, #constraint_property, #constraint_property=, #description, #description=, #disambiguating_description, #disambiguating_description=, #identifier, #identifier=, #image, #image=, #main_entity_of_page, #main_entity_of_page=, #measured_property, #measured_property=, #measurement_denominator, #measurement_denominator=, #measurement_method, #measurement_method=, #measurement_qualifier, #measurement_qualifier=, #measurement_technique, #measurement_technique=, #name, #name=, #num_constraints, #num_constraints=, #owner, #owner=, #population_type, #population_type=, #potential_action, #potential_action=, #same_as, #same_as=, #stat_type, #stat_type=, #subject_of, #subject_of=, #url, #url=
Class Method Details
.new(**properties) ⇒ StatisticalVariable
30 31 32 |
# File 'lib/schema_org/types/statistical_variable.rb', line 30 def new(**properties) super end |
.schema_name ⇒ String
17 18 19 |
# File 'lib/schema_org/types/statistical_variable.rb', line 17 def schema_name SCHEMA_NAME end |
.schema_type?(other_type) ⇒ Boolean
25 26 27 28 |
# File 'lib/schema_org/types/statistical_variable.rb', line 25 def schema_type?(other_type) Base.schema_type_argument!(other_type) SCHEMA_TYPES.include?(other_type) end |
.schema_types ⇒ ::Array[::Class]
21 22 23 |
# File 'lib/schema_org/types/statistical_variable.rb', line 21 def schema_types SCHEMA_TYPES end |
Instance Method Details
#schema_type? ⇒ Boolean
121821 |
# File 'sig/schema_org.rbs', line 121821
def schema_type?: (untyped) -> bool
|
#schema_types ⇒ ::Array[::Class]
121820 |
# File 'sig/schema_org.rbs', line 121820
def schema_types: () -> ::Array[::Class]
|